FB_IMPL_MSG_NO_SYMBOL(SQLERR, 1, "Firebird error")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 74, "Rollback not performed")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 76, "Connection error")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 77, "Connection not established")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 78, "Connection authorization failure.")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 87, "deadlock")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 88, "Unsuccessful execution caused by deadlock.")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 89, "record from transaction @1 is stuck in limbo")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 91, "operation completed with errors")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 94, "the SQL statement cannot be executed")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 96, "Unsuccessful execution caused by an unavailable resource.")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 98, "Unsuccessful execution caused by a system error that precludes successful execution of subsequent statements")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 99, "Unsuccessful execution caused by system error that does not preclude successful execution of subsequent statements")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 158, "Wrong numeric type")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 159, "too many versions")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 160, "intermediate journal file full")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 161, "journal file wrong format")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 162, "database @1 shutdown in @2 seconds")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 163, "restart shared cache manager")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 164, "exception @1")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 165, "bad checksum")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 166, "refresh range number @1 not found")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 167, "expression evaluation not supported")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 168, "FOREIGN KEY column count does not match PRIMARY KEY")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 169, "Attempt to define a second PRIMARY KEY for the same table")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 170, "column used with aggregate")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 171, "invalid column reference")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 172, "invalid key position")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 173, "invalid direction for find operation")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 174, "Invalid statement handle")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 175, "invalid lock handle")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 176, "invalid lock level @1")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 177, "invalid bookmark handle")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 180, "wrong or obsolete version")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 183, "The INSERT, UPDATE, DELETE, DDL or authorization statement cannot be executed because the transaction is inquiry only")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 184, "external file could not be opened for output")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 189, "multiple rows in singleton select")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 190, "No subqueries permitted for VIEW WITH CHECK OPTION")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 191, "DISTINCT, GROUP or HAVING not permitted for VIEW WITH CHECK OPTION")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 192, "Only one table allowed for VIEW WITH CHECK OPTION")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 193, "No WHERE clause for VIEW WITH CHECK OPTION")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 194, "Only simple column names permitted for VIEW WITH CHECK OPTION")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 196, "An error was found in the application program input parameters for the SQL statement.")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 197, "Invalid insert or update value(s): object columns are constrained - no 2 table rows can have duplicate column values")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 198, "Arithmetic overflow or division by zero has occurred.")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 306, "cannot access column @1 in view @2")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 307, "Too many concurrent executions of the same request")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 308, "maximum indexes per table (@1) exceeded")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 309, "new record size of @1 bytes is too big")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 310, "segments not allowed in expression index @1")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 311, "wrong page type")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 315, "invalid ARRAY or BLOB operation")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 323, "@1 extension error")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 336, "key size exceeds implementation restriction for index \"@1\"")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 337, "definition error for index @1")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 340, "cannot create index")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 363, "duplicate specification of @1 - not supported")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 375, "The insert failed because a column definition includes validation constraints.")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 382, "Cannot delete object referenced by another object")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 383, "Cannot modify object referenced by another object")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 384, "Object is referenced by another object")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 385, "lock on conflicts with existing lock")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 393, "This operation is not defined for system tables.")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 395, "Inappropriate self-reference of column")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 396, "Illegal array dimension range")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 399, "database or file exists")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 400, "sort error: corruption in data structure")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 401, "node not supported")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 402, "Shadow number must be a positive integer")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 403, "Preceding file did not specify length, so @1 must include starting page number")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 404, "illegal operation when at beginning of stream")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 405, "the current position is on a crack")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 447, "cannot modify an existing user privilege")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 448, "user does not have the privilege to perform operation")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 449, "This user does not have privilege to perform this operation on this object.")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 468, "transaction marked invalid by I/O error")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 469, "Cannot prepare a CREATE DATABASE/SCHEMA statement")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 470, "violation of FOREIGN KEY constraint \"@1\"")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 481, "The prepare statement identifies a prepare statement with an open cursor")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 482, "Unknown statement or request")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 490, "Attempt to update non-updatable cursor")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 492, "The cursor identified in the UPDATE or DELETE statement is not positioned on a row.")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 496, "Unknown cursor")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 498, "The cursor identified in an OPEN statement is already open.")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 499, "The cursor identified in a FETCH or CLOSE statement is not open.")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 587, "Overflow occurred during data type conversion.")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 593, "null segment of UNIQUE KEY")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 594, "subscript out of bounds")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 598, "data operation not supported")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 599, "invalid comparison operator for find operation")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 686, "Cannot transliterate character between character sets")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 687, "count of column list and variable list do not match")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 697, "Incompatible column/host variable data type")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 703, "Operation violates CHECK constraint @1 on view or table")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 704, "internal Firebird consistency check (invalid RDB$CONSTRAINT_TYPE)")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 705, "Cannot update constraints (RDB$RELATION_CONSTRAINTS).")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 706, "Cannot delete CHECK constraint entry (RDB$CHECK_CONSTRAINTS)")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 707, "Cannot update constraints (RDB$CHECK_CONSTRAINTS).")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 708, "Cannot update constraints (RDB$REF_CONSTRAINTS).")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 709, "Column used in a PRIMARY constraint must be NOT NULL.")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 716, "index @1 cannot be used in the specified plan")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 717, "table @1 is referenced in the plan but not the from list")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 718, "the table @1 is referenced twice; use aliases to differentiate")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 719, "table @1 is not referenced in plan")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 739, "Log file specification partition error")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 740, "Cache or Log redefined")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 741, "Write-ahead Log with shadowing configuration not allowed")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 742, "Overflow log specification required for round-robin log")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 743, "WAL defined; Cache Manager must be started first")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 745, "Write-ahead Log without shared cache configuration not allowed")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 746, "Cannot start WAL writer for the database @1")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 747, "WAL writer synchronization error for the database @1")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 748, "WAL setup error.  Please see Firebird log.")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 749, "WAL buffers cannot be increased.  Please see Firebird log.")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 750, "WAL writer - Journal server communication error.  Please see Firebird log.")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 751, "WAL I/O error.  Please see Firebird log.")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 752, "Unable to roll over; please see Firebird log.")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 753, "obsolete")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 754, "obsolete")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 755, "obsolete")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 756, "obsolete")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 757, "database does not use Write-ahead Log")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 758, "Cannot roll over to the next log file @1")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 759, "obsolete")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 760, "obsolete")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 761, "Cache or Log size too small")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 762, "Log record header too small at offset @1 in log file @2")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 763, "Incomplete log record at offset @1 in log file @2")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 764, "Unexpected end of log file @1 at offset @2")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 765, "Database name in the log file @1 is different")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 766, "Log file @1 not closed properly; database recovery may be required")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 767, "Log file @1 not latest in the chain but open flag still set")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 768, "Invalid version of log file @1")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 769, "Log file header of @1 too small")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 770, "obsolete")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 781, "table @1 is not defined")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 792, "invalid ORDER BY clause")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 794, "Column does not belong to referenced table")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 795, "column @1 is not defined in table @2")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 796, "Undefined name")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 797, "Ambiguous column reference.")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 828, "function @1 is not defined")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 829, "Invalid data type, length, or value")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 830, "Invalid number of arguments")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 838, "dbkey not available for multi-table views")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 842, "number of columns does not match select list")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 843, "must specify column name for view select expression")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 845, "@1 is not a valid base table of the specified view")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 849, "This column cannot be updated because it is derived from an SQL function or expression.")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 850, "The object of the INSERT, DELETE or UPDATE statement is a view for which the requested operation is not permitted.")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 895, "Invalid String")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 896, "Invalid token")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 897, "Invalid numeric literal")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 915, "An error occurred while trying to update the security database")
FB_IMPL_MSG_NO_SYMBOL(SQLERR, 916, "non-SQL security class defined")
FB_IMPL_MSG(SQLERR, 917, dsql_too_old_ods, -804, "HY", "000", "ODS versions before ODS@1 are not supported")
FB_IMPL_MSG(SQLERR, 918, dsql_table_not_found, -607, "42", "S02", "Table @1 does not exist")
FB_IMPL_MSG(SQLERR, 919, dsql_view_not_found, -607, "42", "S02", "View @1 does not exist")
FB_IMPL_MSG(SQLERR, 920, dsql_line_col_error, -206, "42", "000", "At line @1, column @2")
FB_IMPL_MSG(SQLERR, 921, dsql_unknown_pos, -206, "42", "000", "At unknown line and column")
FB_IMPL_MSG(SQLERR, 922, dsql_no_dup_name, -206, "HY", "000", "Column @1 cannot be repeated in @2 statement")
FB_IMPL_MSG(SQLERR, 923, dsql_too_many_values, -901, "07", "002", "Too many values (more than @1) in member list to match against")
FB_IMPL_MSG(SQLERR, 924, dsql_no_array_computed, -607, "HY", "000", "Array and BLOB data types not allowed in computed field")
FB_IMPL_MSG(SQLERR, 925, dsql_implicit_domain_name, -637, "00", "000", "Implicit domain name @1 not allowed in user created domain")
FB_IMPL_MSG(SQLERR, 926, dsql_only_can_subscript_array, -607, "42", "000", "scalar operator used on field @1 which is not an array")
FB_IMPL_MSG(SQLERR, 927, dsql_max_sort_items, -104, "54", "011", "cannot sort on more than 255 items")
FB_IMPL_MSG(SQLERR, 928, dsql_max_group_items, -104, "54", "011", "cannot group on more than 255 items")
FB_IMPL_MSG(SQLERR, 929, dsql_conflicting_sort_field, -104, "42", "000", "Cannot include the same field (@1.@2) twice in the ORDER BY clause with conflicting sorting options")
FB_IMPL_MSG(SQLERR, 930, dsql_derived_table_more_columns, -104, "54", "001", "column list from derived table @1 has more columns than the number of items in its SELECT statement")
FB_IMPL_MSG(SQLERR, 931, dsql_derived_table_less_columns, -104, "54", "001", "column list from derived table @1 has less columns than the number of items in its SELECT statement")
FB_IMPL_MSG(SQLERR, 932, dsql_derived_field_unnamed, -104, "42", "000", "no column name specified for column number @1 in derived table @2")
FB_IMPL_MSG(SQLERR, 933, dsql_derived_field_dup_name, -104, "42", "000", "column @1 was specified multiple times for derived table @2")
FB_IMPL_MSG(SQLERR, 934, dsql_derived_alias_select, -104, "42", "000", "Internal dsql error: alias type expected by pass1_expand_select_node")
FB_IMPL_MSG(SQLERR, 935, dsql_derived_alias_field, -104, "42", "000", "Internal dsql error: alias type expected by pass1_field")
FB_IMPL_MSG(SQLERR, 936, dsql_auto_field_bad_pos, -104, "42", "000", "Internal dsql error: column position out of range in pass1_union_auto_cast")
FB_IMPL_MSG(SQLERR, 937, dsql_cte_wrong_reference, -104, "42", "000", "Recursive CTE member (@1) can refer itself only in FROM clause")
FB_IMPL_MSG(SQLERR, 938, dsql_cte_cycle, -104, "42", "000", "CTE '@1' has cyclic dependencies")
FB_IMPL_MSG(SQLERR, 939, dsql_cte_outer_join, -104, "42", "000", "Recursive member of CTE can't be member of an outer join")
FB_IMPL_MSG(SQLERR, 940, dsql_cte_mult_references, -104, "42", "000", "Recursive member of CTE can't reference itself more than once")
FB_IMPL_MSG(SQLERR, 941, dsql_cte_not_a_union, -104, "42", "000", "Recursive CTE (@1) must be an UNION")
FB_IMPL_MSG(SQLERR, 942, dsql_cte_nonrecurs_after_recurs, -104, "42", "000", "CTE '@1' defined non-recursive member after recursive")
FB_IMPL_MSG(SQLERR, 943, dsql_cte_wrong_clause, -104, "42", "000", "Recursive member of CTE '@1' has @2 clause")
FB_IMPL_MSG(SQLERR, 944, dsql_cte_union_all, -104, "42", "000", "Recursive members of CTE (@1) must be linked with another members via UNION ALL")
FB_IMPL_MSG(SQLERR, 945, dsql_cte_miss_nonrecursive, -104, "42", "000", "Non-recursive member is missing in CTE '@1'")
FB_IMPL_MSG(SQLERR, 946, dsql_cte_nested_with, -104, "42", "000", "WITH clause can't be nested")
FB_IMPL_MSG(SQLERR, 947, dsql_col_more_than_once_using, -104, "42", "000", "column @1 appears more than once in USING clause")
FB_IMPL_MSG(SQLERR, 948, dsql_unsupp_feature_dialect, -901, "HY", "000", "feature is not supported in dialect @1")
FB_IMPL_MSG(SQLERR, 949, dsql_cte_not_used, -104, "42", "000", "CTE \"@1\" is not used in query")
FB_IMPL_MSG(SQLERR, 950, dsql_col_more_than_once_view, -104, "42", "000", "column @1 appears more than once in ALTER VIEW")
FB_IMPL_MSG(SQLERR, 951, dsql_unsupported_in_auto_trans, -901, "HY", "000", "@1 is not supported inside IN AUTONOMOUS TRANSACTION block")
FB_IMPL_MSG(SQLERR, 952, dsql_eval_unknode, -833, "42", "000", "Unknown node type @1 in dsql/GEN_expr")
FB_IMPL_MSG(SQLERR, 953, dsql_agg_wrongarg, -833, "42", "000", "Argument for @1 in dialect 1 must be string or numeric")
FB_IMPL_MSG(SQLERR, 954, dsql_agg2_wrongarg, -833, "42", "000", "Argument for @1 in dialect 3 must be numeric")
FB_IMPL_MSG(SQLERR, 955, dsql_nodateortime_pm_string, -833, "42", "000", "Strings cannot be added to or subtracted from DATE or TIME types")
FB_IMPL_MSG(SQLERR, 956, dsql_invalid_datetime_subtract, -833, "42", "000", "Invalid data type for subtraction involving DATE, TIME or TIMESTAMP types")
FB_IMPL_MSG(SQLERR, 957, dsql_invalid_dateortime_add, -833, "42", "000", "Adding two DATE values or two TIME values is not allowed")
FB_IMPL_MSG(SQLERR, 958, dsql_invalid_type_minus_date, -833, "42", "000", "DATE value cannot be subtracted from the provided data type")
FB_IMPL_MSG(SQLERR, 959, dsql_nostring_addsub_dial3, -833, "42", "000", "Strings cannot be added or subtracted in dialect 3")
FB_IMPL_MSG(SQLERR, 960, dsql_invalid_type_addsub_dial3, -833, "42", "000", "Invalid data type for addition or subtraction in dialect 3")
FB_IMPL_MSG(SQLERR, 961, dsql_invalid_type_multip_dial1, -833, "42", "000", "Invalid data type for multiplication in dialect 1")
FB_IMPL_MSG(SQLERR, 962, dsql_nostring_multip_dial3, -833, "42", "000", "Strings cannot be multiplied in dialect 3")
FB_IMPL_MSG(SQLERR, 963, dsql_invalid_type_multip_dial3, -833, "42", "000", "Invalid data type for multiplication in dialect 3")
FB_IMPL_MSG(SQLERR, 964, dsql_mustuse_numeric_div_dial1, -833, "42", "000", "Division in dialect 1 must be between numeric data types")
FB_IMPL_MSG(SQLERR, 965, dsql_nostring_div_dial3, -833, "42", "000", "Strings cannot be divided in dialect 3")
FB_IMPL_MSG(SQLERR, 966, dsql_invalid_type_div_dial3, -833, "42", "000", "Invalid data type for division in dialect 3")
FB_IMPL_MSG(SQLERR, 967, dsql_nostring_neg_dial3, -833, "42", "000", "Strings cannot be negated (applied the minus operator) in dialect 3")
FB_IMPL_MSG(SQLERR, 968, dsql_invalid_type_neg, -833, "42", "000", "Invalid data type for negation (minus operator)")
FB_IMPL_MSG(SQLERR, 969, dsql_max_distinct_items, -104, "54", "011", "Cannot have more than 255 items in DISTINCT / UNION DISTINCT list")
FB_IMPL_MSG(SQLERR, 970, dsql_alter_charset_failed, -901, "42", "000", "ALTER CHARACTER SET @1 failed")
FB_IMPL_MSG(SQLERR, 971, dsql_comment_on_failed, -901, "42", "000", "COMMENT ON @1 failed")
FB_IMPL_MSG(SQLERR, 972, dsql_create_func_failed, -901, "42", "000", "CREATE FUNCTION @1 failed")
FB_IMPL_MSG(SQLERR, 973, dsql_alter_func_failed, -901, "42", "000", "ALTER FUNCTION @1 failed")
FB_IMPL_MSG(SQLERR, 974, dsql_create_alter_func_failed, -901, "42", "000", "CREATE OR ALTER FUNCTION @1 failed")
FB_IMPL_MSG(SQLERR, 975, dsql_drop_func_failed, -901, "42", "000", "DROP FUNCTION @1 failed")
FB_IMPL_MSG(SQLERR, 976, dsql_recreate_func_failed, -901, "42", "000", "RECREATE FUNCTION @1 failed")
FB_IMPL_MSG(SQLERR, 977, dsql_create_proc_failed, -901, "42", "000", "CREATE PROCEDURE @1 failed")
FB_IMPL_MSG(SQLERR, 978, dsql_alter_proc_failed, -901, "42", "000", "ALTER PROCEDURE @1 failed")
FB_IMPL_MSG(SQLERR, 979, dsql_create_alter_proc_failed, -901, "42", "000", "CREATE OR ALTER PROCEDURE @1 failed")
FB_IMPL_MSG(SQLERR, 980, dsql_drop_proc_failed, -901, "42", "000", "DROP PROCEDURE @1 failed")
FB_IMPL_MSG(SQLERR, 981, dsql_recreate_proc_failed, -901, "42", "000", "RECREATE PROCEDURE @1 failed")
FB_IMPL_MSG(SQLERR, 982, dsql_create_trigger_failed, -901, "42", "000", "CREATE TRIGGER @1 failed")
FB_IMPL_MSG(SQLERR, 983, dsql_alter_trigger_failed, -901, "42", "000", "ALTER TRIGGER @1 failed")
FB_IMPL_MSG(SQLERR, 984, dsql_create_alter_trigger_failed, -901, "42", "000", "CREATE OR ALTER TRIGGER @1 failed")
FB_IMPL_MSG(SQLERR, 985, dsql_drop_trigger_failed, -901, "42", "000", "DROP TRIGGER @1 failed")
FB_IMPL_MSG(SQLERR, 986, dsql_recreate_trigger_failed, -901, "42", "000", "RECREATE TRIGGER @1 failed")
FB_IMPL_MSG(SQLERR, 987, dsql_create_collation_failed, -901, "42", "000", "CREATE COLLATION @1 failed")
FB_IMPL_MSG(SQLERR, 988, dsql_drop_collation_failed, -901, "42", "000", "DROP COLLATION @1 failed")
FB_IMPL_MSG(SQLERR, 989, dsql_create_domain_failed, -901, "42", "000", "CREATE DOMAIN @1 failed")
FB_IMPL_MSG(SQLERR, 990, dsql_alter_domain_failed, -901, "42", "000", "ALTER DOMAIN @1 failed")
FB_IMPL_MSG(SQLERR, 991, dsql_drop_domain_failed, -901, "42", "000", "DROP DOMAIN @1 failed")
FB_IMPL_MSG(SQLERR, 992, dsql_create_except_failed, -901, "42", "000", "CREATE EXCEPTION @1 failed")
FB_IMPL_MSG(SQLERR, 993, dsql_alter_except_failed, -901, "42", "000", "ALTER EXCEPTION @1 failed")
FB_IMPL_MSG(SQLERR, 994, dsql_create_alter_except_failed, -901, "42", "000", "CREATE OR ALTER EXCEPTION @1 failed")
FB_IMPL_MSG(SQLERR, 995, dsql_recreate_except_failed, -901, "42", "000", "RECREATE EXCEPTION @1 failed")
FB_IMPL_MSG(SQLERR, 996, dsql_drop_except_failed, -901, "42", "000", "DROP EXCEPTION @1 failed")
FB_IMPL_MSG(SQLERR, 997, dsql_create_sequence_failed, -901, "42", "000", "CREATE SEQUENCE @1 failed")
FB_IMPL_MSG(SQLERR, 998, dsql_create_table_failed, -901, "42", "000", "CREATE TABLE @1 failed")
FB_IMPL_MSG(SQLERR, 999, dsql_alter_table_failed, -901, "42", "000", "ALTER TABLE @1 failed")
FB_IMPL_MSG(SQLERR, 1000, dsql_drop_table_failed, -901, "42", "000", "DROP TABLE @1 failed")
FB_IMPL_MSG(SQLERR, 1001, dsql_recreate_table_failed, -901, "42", "000", "RECREATE TABLE @1 failed")
FB_IMPL_MSG(SQLERR, 1002, dsql_create_pack_failed, -901, "42", "000", "CREATE PACKAGE @1 failed")
FB_IMPL_MSG(SQLERR, 1003, dsql_alter_pack_failed, -901, "42", "000", "ALTER PACKAGE @1 failed")
FB_IMPL_MSG(SQLERR, 1004, dsql_create_alter_pack_failed, -901, "42", "000", "CREATE OR ALTER PACKAGE @1 failed")
FB_IMPL_MSG(SQLERR, 1005, dsql_drop_pack_failed, -901, "42", "000", "DROP PACKAGE @1 failed")
FB_IMPL_MSG(SQLERR, 1006, dsql_recreate_pack_failed, -901, "42", "000", "RECREATE PACKAGE @1 failed")
FB_IMPL_MSG(SQLERR, 1007, dsql_create_pack_body_failed, -901, "42", "000", "CREATE PACKAGE BODY @1 failed")
FB_IMPL_MSG(SQLERR, 1008, dsql_drop_pack_body_failed, -901, "42", "000", "DROP PACKAGE BODY @1 failed")
FB_IMPL_MSG(SQLERR, 1009, dsql_recreate_pack_body_failed, -901, "42", "000", "RECREATE PACKAGE BODY @1 failed")
FB_IMPL_MSG(SQLERR, 1010, dsql_create_view_failed, -901, "42", "000", "CREATE VIEW @1 failed")
FB_IMPL_MSG(SQLERR, 1011, dsql_alter_view_failed, -901, "42", "000", "ALTER VIEW @1 failed")
FB_IMPL_MSG(SQLERR, 1012, dsql_create_alter_view_failed, -901, "42", "000", "CREATE OR ALTER VIEW @1 failed")
FB_IMPL_MSG(SQLERR, 1013, dsql_recreate_view_failed, -901, "42", "000", "RECREATE VIEW @1 failed")
FB_IMPL_MSG(SQLERR, 1014, dsql_drop_view_failed, -901, "42", "000", "DROP VIEW @1 failed")
FB_IMPL_MSG(SQLERR, 1015, dsql_drop_sequence_failed, -901, "42", "000", "DROP SEQUENCE @1 failed")
FB_IMPL_MSG(SQLERR, 1016, dsql_recreate_sequence_failed, -901, "42", "000", "RECREATE SEQUENCE @1 failed")
FB_IMPL_MSG(SQLERR, 1017, dsql_drop_index_failed, -901, "42", "000", "DROP INDEX @1 failed")
FB_IMPL_MSG(SQLERR, 1018, dsql_drop_filter_failed, -901, "42", "000", "DROP FILTER @1 failed")
FB_IMPL_MSG(SQLERR, 1019, dsql_drop_shadow_failed, -901, "42", "000", "DROP SHADOW @1 failed")
FB_IMPL_MSG(SQLERR, 1020, dsql_drop_role_failed, -901, "42", "000", "DROP ROLE @1 failed")
FB_IMPL_MSG(SQLERR, 1021, dsql_drop_user_failed, -901, "42", "000", "DROP USER @1 failed")
FB_IMPL_MSG(SQLERR, 1022, dsql_create_role_failed, -901, "42", "000", "CREATE ROLE @1 failed")
FB_IMPL_MSG(SQLERR, 1023, dsql_alter_role_failed, -901, "42", "000", "ALTER ROLE @1 failed")
FB_IMPL_MSG(SQLERR, 1024, dsql_alter_index_failed, -901, "42", "000", "ALTER INDEX @1 failed")
FB_IMPL_MSG(SQLERR, 1025, dsql_alter_database_failed, -901, "42", "000", "ALTER DATABASE failed")
FB_IMPL_MSG(SQLERR, 1026, dsql_create_shadow_failed, -901, "42", "000", "CREATE SHADOW @1 failed")
FB_IMPL_MSG(SQLERR, 1027, dsql_create_filter_failed, -901, "42", "000", "DECLARE FILTER @1 failed")
FB_IMPL_MSG(SQLERR, 1028, dsql_create_index_failed, -901, "42", "000", "CREATE INDEX @1 failed")
FB_IMPL_MSG(SQLERR, 1029, dsql_create_user_failed, -901, "42", "000", "CREATE USER @1 failed")
FB_IMPL_MSG(SQLERR, 1030, dsql_alter_user_failed, -901, "42", "000", "ALTER USER @1 failed")
FB_IMPL_MSG(SQLERR, 1031, dsql_grant_failed, -901, "42", "000", "GRANT failed")
FB_IMPL_MSG(SQLERR, 1032, dsql_revoke_failed, -901, "42", "000", "REVOKE failed")
FB_IMPL_MSG(SQLERR, 1033, dsql_cte_recursive_aggregate, -104, "42", "000", "Recursive member of CTE cannot use aggregate or window function")
FB_IMPL_MSG(SQLERR, 1034, dsql_mapping_failed, -901, "42", "000", "@2 MAPPING @1 failed")
FB_IMPL_MSG(SQLERR, 1035, dsql_alter_sequence_failed, -901, "42", "000", "ALTER SEQUENCE @1 failed")
FB_IMPL_MSG(SQLERR, 1036, dsql_create_generator_failed, -901, "42", "000", "CREATE GENERATOR @1 failed")
FB_IMPL_MSG(SQLERR, 1037, dsql_set_generator_failed, -901, "42", "000", "SET GENERATOR @1 failed")
FB_IMPL_MSG(SQLERR, 1038, dsql_wlock_simple, -104, "42", "000", "WITH LOCK can be used only with a single physical table")
FB_IMPL_MSG(SQLERR, 1039, dsql_firstskip_rows, -104, "42", "000", "FIRST/SKIP cannot be used with OFFSET/FETCH or ROWS")
FB_IMPL_MSG(SQLERR, 1040, dsql_wlock_aggregates, -104, "42", "000", "WITH LOCK cannot be used with aggregates")
FB_IMPL_MSG(SQLERR, 1041, dsql_wlock_conflict, -104, "42", "000", "WITH LOCK cannot be used with @1")
FB_IMPL_MSG(SQLERR, 1042, dsql_max_exception_arguments, -901, "07", "002", "Number of arguments (@1) exceeds the maximum (@2) number of EXCEPTION USING arguments")
FB_IMPL_MSG(SQLERR, 1043, dsql_string_byte_length, -901, "42", "000", "String literal with @1 bytes exceeds the maximum length of @2 bytes")
FB_IMPL_MSG(SQLERR, 1044, dsql_string_char_length, -901, "42", "000", "String literal with @1 characters exceeds the maximum length of @2 characters for the @3 character set")
FB_IMPL_MSG(SQLERR, 1045, dsql_max_nesting, -901, "07", "002", "Too many BEGIN...END nesting. Maximum level is @1")
FB_IMPL_MSG(SQLERR, 1046, dsql_recreate_user_failed, -901, "42", "000", "RECREATE USER @1 failed")
