FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 147, "invalid block type encountered")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 148, "wrong packet type")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 149, "cannot map page")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 150, "request to allocate invalid block type")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 151, "request to allocate block type larger than maximum size")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 152, "memory pool free list is invalid")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 153, "invalid pool id encountered")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 154, "attempt to release free block")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 155, "attempt to release block overlapping following free block")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 156, "attempt to release block overlapping prior free block")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 157, "cannot sort on a field that does not exist")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 158, "database file not available")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 159, "cannot assert logical lock")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 160, "wrong ACL version")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 161, "shadow block not found")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 162, "shadow lock not synchronized properly")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 163, "root file name not listed for shadow")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 164, "failed to remove symbol from hash table")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 165, "cannot find tip page")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 166, "invalid rsb type")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 167, "invalid SEND request")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 168, "looper: action not yet implemented")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 169, "return data type not supported")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 170, "unexpected reply from journal server")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 171, "journal server is incompatible version")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 172, "journal server refused connection")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 173, "referenced index description not found")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 174, "index key too big")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 175, "partner index description not found")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 176, "bad difference record")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 177, "applied differences will not fit in record")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 178, "record length inconsistent")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 179, "decompression overran buffer")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 180, "cannot reposition for update after sort for RMS")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 181, "external access type not implemented")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 182, "differences record too long")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 183, "wrong record length")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 184, "limbo impossible")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 185, "wrong record version")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 186, "record disappeared")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 187, "cannot delete system tables")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 188, "cannot update erased record")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 189, "comparison not supported for specified data types")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 190, "conversion not supported for specified data types")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 191, "conversion error")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 192, "overflow during conversion")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 193, "null or invalid array")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 194, "BLOB not found")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 195, "cannot update old BLOB")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 196, "relation for array not known")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 197, "field for array not known")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 198, "array subscript computation error")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 199, "expected field node")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 200, "invalid BLOB ID")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 201, "cannot find BLOB page")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 202, "unknown data type")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 203, "shadow block not found for extend file")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 204, "index inconsistent")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 205, "index bucket overfilled")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 206, "exceeded index level")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 207, "page already in use")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 208, "page not accessed for write")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 209, "attempt to release page not acquired")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 210, "page in use during flush")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 211, "attempt to remove page from dirty page list when not there")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 212, "CCH_precedence: block marked")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 213, "insufficient cache size")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 214, "no cache buffers available for reuse")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 215, "page @1, page type @2 lock conversion denied")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 216, "page @1, page type @2 lock denied")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 217, "buffer marked for update")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 218, "CCH: @1, status = @2 (218)")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 219, "request of unknown resource")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 220, "release of unknown resource")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 221, "(CMP) copy: cannot remap")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 222, "bad BLR -- invalid stream")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 223, "argument of scalar operation must be an array")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 224, "quad word arithmetic not supported")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 225, "data type not supported for arithmetic")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 226, "request size limit exceeded")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 227, "cannot access field @1 in view @2")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 228, "cannot access field in view @1")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 229, "EVL_assign_to: invalid operation")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 230, "EVL_bitmap: invalid operation")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 231, "EVL_boolean: invalid operation")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 232, "EVL_expr: invalid operation")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 233, "eval_statistical: invalid operation")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 234, "Unimplemented conversion, FAO directive O,Z,S")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 235, "Unimplemented conversion, FAO directive X,U")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 236, "Error parsing RDB FAO msg string")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 237, "Error parsing RDB FAO msg str")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 238, "unknown parameter in RdB status vector")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 239, "Firebird status vector inconsistent")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 240, "Firebird/RdB message parameter inconsistency")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 241, "error parsing RDB FAO message string")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 242, "unimplemented FAO directive")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 243, "missing pointer page in DPM_data_pages")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 244, "Fragment does not exist")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 245, "pointer page disappeared in DPM_delete")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 246, "pointer page lost from DPM_delete_relation")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 247, "missing pointer page in DPM_dump")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 248, "cannot find record fragment")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 249, "pointer page vanished from DPM_next")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 250, "temporary page buffer too small")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 251, "damaged data page")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 252, "header fragment length changed")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 253, "pointer page vanished from extend_relation")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 254, "pointer page vanished from relation list in locate_space")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 255, "cannot find free space")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 256, "pointer page vanished from mark_full")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 257, "bad record in RDB$PAGES")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 258, "page slot not empty")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 259, "bad pointer page")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 260, "index unexpectedly deleted")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 261, "scalar operator used on field which is not an array")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 262, "active")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 263, "committed")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 264, "rolled back")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 265, "in an ill-defined state")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 266, "next transaction older than oldest active transaction")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 267, "next transaction older than oldest transaction")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 268, "buffer marked during cache unwind")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 269, "error in recovery! database corrupted")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 270, "error in recovery! wrong data page record")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 271, "error in recovery! no space on data page")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 272, "error in recovery! wrong header page record")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 273, "error in recovery! wrong generator page record")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 274, "error in recovery! wrong b-tree page record")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 275, "error in recovery! wrong page inventory page record")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 276, "error in recovery! wrong pointer page record")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 277, "error in recovery! wrong index root page record")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 278, "error in recovery! wrong transaction page record")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 279, "error in recovery! out of sequence log record encountered")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 280, "error in recovery! unknown page type")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 281, "error in recovery! unknown record type")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 282, "journal server cannot archive to specified archive directory")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 283, "checksum error in log record when reading from log file")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 284, "cannot restore singleton select data")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 285, "lock not found in internal lock manager")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 286, "size of opt block exceeded")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 287, "Too many savepoints")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 288, "garbage collect record disappeared")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 289, "Unknown BLOB FILTER ACTION_")
FB_IMPL_MSG_SYMBOL(JRD_BUGCHK, 290, savepoint_error, "error during savepoint backout")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 291, "cannot find record back version")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 292, "Illegal user_type.")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 293, "bad ACL")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 294, "inconsistent LATCH_mark release")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 295, "inconsistent LATCH_mark call")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 296, "inconsistent latch downgrade call")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 297, "bdb is unexpectedly marked")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 298, "missing exclusive latch")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 299, "exceeded maximum number of shared latches on a bdb")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 300, "can't find shared latch")
FB_IMPL_MSG_SYMBOL(JRD_BUGCHK, 301, cache_non_zero_use_count, "Non-zero use_count of a buffer in the empty que")
FB_IMPL_MSG_SYMBOL(JRD_BUGCHK, 302, unexpected_page_change, "Unexpected page change from latching")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 303, "Invalid expression for evaluation")
FB_IMPL_MSG_SYMBOL(JRD_BUGCHK, 304, rdb$triggers_rdb$flags_corrupt, "RDB$FLAGS for trigger @1 in RDB$TRIGGERS is corrupted")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 305, "Blobs accounting is inconsistent")
FB_IMPL_MSG_NO_SYMBOL(JRD_BUGCHK, 306, "Found array data type with more than 16 dimensions")
