# /* **************************************************************************
#  *                                                                          *
#  *     (C) Copyright Paul Mensonides 2002.
#  *     Distributed under the Boost Software License, Version 1.0. (See
#  *     accompanying file LICENSE_1_0.txt or copy at
#  *     http://www.boost.org/LICENSE_1_0.txt)
#  *                                                                          *
#  ************************************************************************** */
#
# /* See http://www.boost.org for most recent version. */
#
# ifndef FB_BOOST_PREPROCESSOR_SEQ_SIZE_HPP
# define FB_BOOST_PREPROCESSOR_SEQ_SIZE_HPP
#
# include <firebird/impl/boost/preprocessor/cat.hpp>
# include <firebird/impl/boost/preprocessor/config/config.hpp>
# include <firebird/impl/boost/preprocessor/tuple/eat.hpp>
#
# if FB_BOOST_PP_CONFIG_FLAGS() & FB_BOOST_PP_CONFIG_MWCC()
#    define FB_BOOST_PP_SEQ_SIZE(seq) FB_BOOST_PP_SEQ_SIZE_I((seq))
#    define FB_BOOST_PP_SEQ_SIZE_I(par) FB_BOOST_PP_SEQ_SIZE_II ## par
#    define FB_BOOST_PP_SEQ_SIZE_II(seq) FB_BOOST_PP_CAT(FB_BOOST_PP_SEQ_SIZE_, FB_BOOST_PP_SEQ_SIZE_0 ## seq)
# elif FB_BOOST_PP_CONFIG_FLAGS() & FB_BOOST_PP_CONFIG_EDG() || FB_BOOST_PP_CONFIG_FLAGS() & FB_BOOST_PP_CONFIG_MSVC()
#    define FB_BOOST_PP_SEQ_SIZE(seq) FB_BOOST_PP_SEQ_SIZE_I(seq)
#    define FB_BOOST_PP_SEQ_SIZE_I(seq) FB_BOOST_PP_CAT(FB_BOOST_PP_SEQ_SIZE_, FB_BOOST_PP_SEQ_SIZE_0 seq)
# elif defined(__IBMC__) || defined(__IBMCPP__)
#    define FB_BOOST_PP_SEQ_SIZE(seq) FB_BOOST_PP_CAT(FB_BOOST_PP_SEQ_SIZE_, FB_BOOST_PP_CAT(FB_BOOST_PP_SEQ_SIZE_0, seq))
# else
#    define FB_BOOST_PP_SEQ_SIZE(seq) FB_BOOST_PP_CAT(FB_BOOST_PP_SEQ_SIZE_, FB_BOOST_PP_SEQ_SIZE_0 seq)
# endif
#
# define FB_BOOST_PP_SEQ_SIZE_0(_) FB_BOOST_PP_SEQ_SIZE_1
# define FB_BOOST_PP_SEQ_SIZE_1(_) FB_BOOST_PP_SEQ_SIZE_2
# define FB_BOOST_PP_SEQ_SIZE_2(_) FB_BOOST_PP_SEQ_SIZE_3
# define FB_BOOST_PP_SEQ_SIZE_3(_) FB_BOOST_PP_SEQ_SIZE_4
# define FB_BOOST_PP_SEQ_SIZE_4(_) FB_BOOST_PP_SEQ_SIZE_5
# define FB_BOOST_PP_SEQ_SIZE_5(_) FB_BOOST_PP_SEQ_SIZE_6
# define FB_BOOST_PP_SEQ_SIZE_6(_) FB_BOOST_PP_SEQ_SIZE_7
# define FB_BOOST_PP_SEQ_SIZE_7(_) FB_BOOST_PP_SEQ_SIZE_8
# define FB_BOOST_PP_SEQ_SIZE_8(_) FB_BOOST_PP_SEQ_SIZE_9
# define FB_BOOST_PP_SEQ_SIZE_9(_) FB_BOOST_PP_SEQ_SIZE_10
# define FB_BOOST_PP_SEQ_SIZE_10(_) FB_BOOST_PP_SEQ_SIZE_11
# define FB_BOOST_PP_SEQ_SIZE_11(_) FB_BOOST_PP_SEQ_SIZE_12
# define FB_BOOST_PP_SEQ_SIZE_12(_) FB_BOOST_PP_SEQ_SIZE_13
# define FB_BOOST_PP_SEQ_SIZE_13(_) FB_BOOST_PP_SEQ_SIZE_14
# define FB_BOOST_PP_SEQ_SIZE_14(_) FB_BOOST_PP_SEQ_SIZE_15
# define FB_BOOST_PP_SEQ_SIZE_15(_) FB_BOOST_PP_SEQ_SIZE_16
# define FB_BOOST_PP_SEQ_SIZE_16(_) FB_BOOST_PP_SEQ_SIZE_17
# define FB_BOOST_PP_SEQ_SIZE_17(_) FB_BOOST_PP_SEQ_SIZE_18
# define FB_BOOST_PP_SEQ_SIZE_18(_) FB_BOOST_PP_SEQ_SIZE_19
# define FB_BOOST_PP_SEQ_SIZE_19(_) FB_BOOST_PP_SEQ_SIZE_20
# define FB_BOOST_PP_SEQ_SIZE_20(_) FB_BOOST_PP_SEQ_SIZE_21
# define FB_BOOST_PP_SEQ_SIZE_21(_) FB_BOOST_PP_SEQ_SIZE_22
# define FB_BOOST_PP_SEQ_SIZE_22(_) FB_BOOST_PP_SEQ_SIZE_23
# define FB_BOOST_PP_SEQ_SIZE_23(_) FB_BOOST_PP_SEQ_SIZE_24
# define FB_BOOST_PP_SEQ_SIZE_24(_) FB_BOOST_PP_SEQ_SIZE_25
# define FB_BOOST_PP_SEQ_SIZE_25(_) FB_BOOST_PP_SEQ_SIZE_26
# define FB_BOOST_PP_SEQ_SIZE_26(_) FB_BOOST_PP_SEQ_SIZE_27
# define FB_BOOST_PP_SEQ_SIZE_27(_) FB_BOOST_PP_SEQ_SIZE_28
# define FB_BOOST_PP_SEQ_SIZE_28(_) FB_BOOST_PP_SEQ_SIZE_29
# define FB_BOOST_PP_SEQ_SIZE_29(_) FB_BOOST_PP_SEQ_SIZE_30
# define FB_BOOST_PP_SEQ_SIZE_30(_) FB_BOOST_PP_SEQ_SIZE_31
# define FB_BOOST_PP_SEQ_SIZE_31(_) FB_BOOST_PP_SEQ_SIZE_32
# define FB_BOOST_PP_SEQ_SIZE_32(_) FB_BOOST_PP_SEQ_SIZE_33
# define FB_BOOST_PP_SEQ_SIZE_33(_) FB_BOOST_PP_SEQ_SIZE_34
# define FB_BOOST_PP_SEQ_SIZE_34(_) FB_BOOST_PP_SEQ_SIZE_35
# define FB_BOOST_PP_SEQ_SIZE_35(_) FB_BOOST_PP_SEQ_SIZE_36
# define FB_BOOST_PP_SEQ_SIZE_36(_) FB_BOOST_PP_SEQ_SIZE_37
# define FB_BOOST_PP_SEQ_SIZE_37(_) FB_BOOST_PP_SEQ_SIZE_38
# define FB_BOOST_PP_SEQ_SIZE_38(_) FB_BOOST_PP_SEQ_SIZE_39
# define FB_BOOST_PP_SEQ_SIZE_39(_) FB_BOOST_PP_SEQ_SIZE_40
# define FB_BOOST_PP_SEQ_SIZE_40(_) FB_BOOST_PP_SEQ_SIZE_41
# define FB_BOOST_PP_SEQ_SIZE_41(_) FB_BOOST_PP_SEQ_SIZE_42
# define FB_BOOST_PP_SEQ_SIZE_42(_) FB_BOOST_PP_SEQ_SIZE_43
# define FB_BOOST_PP_SEQ_SIZE_43(_) FB_BOOST_PP_SEQ_SIZE_44
# define FB_BOOST_PP_SEQ_SIZE_44(_) FB_BOOST_PP_SEQ_SIZE_45
# define FB_BOOST_PP_SEQ_SIZE_45(_) FB_BOOST_PP_SEQ_SIZE_46
# define FB_BOOST_PP_SEQ_SIZE_46(_) FB_BOOST_PP_SEQ_SIZE_47
# define FB_BOOST_PP_SEQ_SIZE_47(_) FB_BOOST_PP_SEQ_SIZE_48
# define FB_BOOST_PP_SEQ_SIZE_48(_) FB_BOOST_PP_SEQ_SIZE_49
# define FB_BOOST_PP_SEQ_SIZE_49(_) FB_BOOST_PP_SEQ_SIZE_50
# define FB_BOOST_PP_SEQ_SIZE_50(_) FB_BOOST_PP_SEQ_SIZE_51
# define FB_BOOST_PP_SEQ_SIZE_51(_) FB_BOOST_PP_SEQ_SIZE_52
# define FB_BOOST_PP_SEQ_SIZE_52(_) FB_BOOST_PP_SEQ_SIZE_53
# define FB_BOOST_PP_SEQ_SIZE_53(_) FB_BOOST_PP_SEQ_SIZE_54
# define FB_BOOST_PP_SEQ_SIZE_54(_) FB_BOOST_PP_SEQ_SIZE_55
# define FB_BOOST_PP_SEQ_SIZE_55(_) FB_BOOST_PP_SEQ_SIZE_56
# define FB_BOOST_PP_SEQ_SIZE_56(_) FB_BOOST_PP_SEQ_SIZE_57
# define FB_BOOST_PP_SEQ_SIZE_57(_) FB_BOOST_PP_SEQ_SIZE_58
# define FB_BOOST_PP_SEQ_SIZE_58(_) FB_BOOST_PP_SEQ_SIZE_59
# define FB_BOOST_PP_SEQ_SIZE_59(_) FB_BOOST_PP_SEQ_SIZE_60
# define FB_BOOST_PP_SEQ_SIZE_60(_) FB_BOOST_PP_SEQ_SIZE_61
# define FB_BOOST_PP_SEQ_SIZE_61(_) FB_BOOST_PP_SEQ_SIZE_62
# define FB_BOOST_PP_SEQ_SIZE_62(_) FB_BOOST_PP_SEQ_SIZE_63
# define FB_BOOST_PP_SEQ_SIZE_63(_) FB_BOOST_PP_SEQ_SIZE_64
# define FB_BOOST_PP_SEQ_SIZE_64(_) FB_BOOST_PP_SEQ_SIZE_65
# define FB_BOOST_PP_SEQ_SIZE_65(_) FB_BOOST_PP_SEQ_SIZE_66
# define FB_BOOST_PP_SEQ_SIZE_66(_) FB_BOOST_PP_SEQ_SIZE_67
# define FB_BOOST_PP_SEQ_SIZE_67(_) FB_BOOST_PP_SEQ_SIZE_68
# define FB_BOOST_PP_SEQ_SIZE_68(_) FB_BOOST_PP_SEQ_SIZE_69
# define FB_BOOST_PP_SEQ_SIZE_69(_) FB_BOOST_PP_SEQ_SIZE_70
# define FB_BOOST_PP_SEQ_SIZE_70(_) FB_BOOST_PP_SEQ_SIZE_71
# define FB_BOOST_PP_SEQ_SIZE_71(_) FB_BOOST_PP_SEQ_SIZE_72
# define FB_BOOST_PP_SEQ_SIZE_72(_) FB_BOOST_PP_SEQ_SIZE_73
# define FB_BOOST_PP_SEQ_SIZE_73(_) FB_BOOST_PP_SEQ_SIZE_74
# define FB_BOOST_PP_SEQ_SIZE_74(_) FB_BOOST_PP_SEQ_SIZE_75
# define FB_BOOST_PP_SEQ_SIZE_75(_) FB_BOOST_PP_SEQ_SIZE_76
# define FB_BOOST_PP_SEQ_SIZE_76(_) FB_BOOST_PP_SEQ_SIZE_77
# define FB_BOOST_PP_SEQ_SIZE_77(_) FB_BOOST_PP_SEQ_SIZE_78
# define FB_BOOST_PP_SEQ_SIZE_78(_) FB_BOOST_PP_SEQ_SIZE_79
# define FB_BOOST_PP_SEQ_SIZE_79(_) FB_BOOST_PP_SEQ_SIZE_80
# define FB_BOOST_PP_SEQ_SIZE_80(_) FB_BOOST_PP_SEQ_SIZE_81
# define FB_BOOST_PP_SEQ_SIZE_81(_) FB_BOOST_PP_SEQ_SIZE_82
# define FB_BOOST_PP_SEQ_SIZE_82(_) FB_BOOST_PP_SEQ_SIZE_83
# define FB_BOOST_PP_SEQ_SIZE_83(_) FB_BOOST_PP_SEQ_SIZE_84
# define FB_BOOST_PP_SEQ_SIZE_84(_) FB_BOOST_PP_SEQ_SIZE_85
# define FB_BOOST_PP_SEQ_SIZE_85(_) FB_BOOST_PP_SEQ_SIZE_86
# define FB_BOOST_PP_SEQ_SIZE_86(_) FB_BOOST_PP_SEQ_SIZE_87
# define FB_BOOST_PP_SEQ_SIZE_87(_) FB_BOOST_PP_SEQ_SIZE_88
# define FB_BOOST_PP_SEQ_SIZE_88(_) FB_BOOST_PP_SEQ_SIZE_89
# define FB_BOOST_PP_SEQ_SIZE_89(_) FB_BOOST_PP_SEQ_SIZE_90
# define FB_BOOST_PP_SEQ_SIZE_90(_) FB_BOOST_PP_SEQ_SIZE_91
# define FB_BOOST_PP_SEQ_SIZE_91(_) FB_BOOST_PP_SEQ_SIZE_92
# define FB_BOOST_PP_SEQ_SIZE_92(_) FB_BOOST_PP_SEQ_SIZE_93
# define FB_BOOST_PP_SEQ_SIZE_93(_) FB_BOOST_PP_SEQ_SIZE_94
# define FB_BOOST_PP_SEQ_SIZE_94(_) FB_BOOST_PP_SEQ_SIZE_95
# define FB_BOOST_PP_SEQ_SIZE_95(_) FB_BOOST_PP_SEQ_SIZE_96
# define FB_BOOST_PP_SEQ_SIZE_96(_) FB_BOOST_PP_SEQ_SIZE_97
# define FB_BOOST_PP_SEQ_SIZE_97(_) FB_BOOST_PP_SEQ_SIZE_98
# define FB_BOOST_PP_SEQ_SIZE_98(_) FB_BOOST_PP_SEQ_SIZE_99
# define FB_BOOST_PP_SEQ_SIZE_99(_) FB_BOOST_PP_SEQ_SIZE_100
# define FB_BOOST_PP_SEQ_SIZE_100(_) FB_BOOST_PP_SEQ_SIZE_101
# define FB_BOOST_PP_SEQ_SIZE_101(_) FB_BOOST_PP_SEQ_SIZE_102
# define FB_BOOST_PP_SEQ_SIZE_102(_) FB_BOOST_PP_SEQ_SIZE_103
# define FB_BOOST_PP_SEQ_SIZE_103(_) FB_BOOST_PP_SEQ_SIZE_104
# define FB_BOOST_PP_SEQ_SIZE_104(_) FB_BOOST_PP_SEQ_SIZE_105
# define FB_BOOST_PP_SEQ_SIZE_105(_) FB_BOOST_PP_SEQ_SIZE_106
# define FB_BOOST_PP_SEQ_SIZE_106(_) FB_BOOST_PP_SEQ_SIZE_107
# define FB_BOOST_PP_SEQ_SIZE_107(_) FB_BOOST_PP_SEQ_SIZE_108
# define FB_BOOST_PP_SEQ_SIZE_108(_) FB_BOOST_PP_SEQ_SIZE_109
# define FB_BOOST_PP_SEQ_SIZE_109(_) FB_BOOST_PP_SEQ_SIZE_110
# define FB_BOOST_PP_SEQ_SIZE_110(_) FB_BOOST_PP_SEQ_SIZE_111
# define FB_BOOST_PP_SEQ_SIZE_111(_) FB_BOOST_PP_SEQ_SIZE_112
# define FB_BOOST_PP_SEQ_SIZE_112(_) FB_BOOST_PP_SEQ_SIZE_113
# define FB_BOOST_PP_SEQ_SIZE_113(_) FB_BOOST_PP_SEQ_SIZE_114
# define FB_BOOST_PP_SEQ_SIZE_114(_) FB_BOOST_PP_SEQ_SIZE_115
# define FB_BOOST_PP_SEQ_SIZE_115(_) FB_BOOST_PP_SEQ_SIZE_116
# define FB_BOOST_PP_SEQ_SIZE_116(_) FB_BOOST_PP_SEQ_SIZE_117
# define FB_BOOST_PP_SEQ_SIZE_117(_) FB_BOOST_PP_SEQ_SIZE_118
# define FB_BOOST_PP_SEQ_SIZE_118(_) FB_BOOST_PP_SEQ_SIZE_119
# define FB_BOOST_PP_SEQ_SIZE_119(_) FB_BOOST_PP_SEQ_SIZE_120
# define FB_BOOST_PP_SEQ_SIZE_120(_) FB_BOOST_PP_SEQ_SIZE_121
# define FB_BOOST_PP_SEQ_SIZE_121(_) FB_BOOST_PP_SEQ_SIZE_122
# define FB_BOOST_PP_SEQ_SIZE_122(_) FB_BOOST_PP_SEQ_SIZE_123
# define FB_BOOST_PP_SEQ_SIZE_123(_) FB_BOOST_PP_SEQ_SIZE_124
# define FB_BOOST_PP_SEQ_SIZE_124(_) FB_BOOST_PP_SEQ_SIZE_125
# define FB_BOOST_PP_SEQ_SIZE_125(_) FB_BOOST_PP_SEQ_SIZE_126
# define FB_BOOST_PP_SEQ_SIZE_126(_) FB_BOOST_PP_SEQ_SIZE_127
# define FB_BOOST_PP_SEQ_SIZE_127(_) FB_BOOST_PP_SEQ_SIZE_128
# define FB_BOOST_PP_SEQ_SIZE_128(_) FB_BOOST_PP_SEQ_SIZE_129
# define FB_BOOST_PP_SEQ_SIZE_129(_) FB_BOOST_PP_SEQ_SIZE_130
# define FB_BOOST_PP_SEQ_SIZE_130(_) FB_BOOST_PP_SEQ_SIZE_131
# define FB_BOOST_PP_SEQ_SIZE_131(_) FB_BOOST_PP_SEQ_SIZE_132
# define FB_BOOST_PP_SEQ_SIZE_132(_) FB_BOOST_PP_SEQ_SIZE_133
# define FB_BOOST_PP_SEQ_SIZE_133(_) FB_BOOST_PP_SEQ_SIZE_134
# define FB_BOOST_PP_SEQ_SIZE_134(_) FB_BOOST_PP_SEQ_SIZE_135
# define FB_BOOST_PP_SEQ_SIZE_135(_) FB_BOOST_PP_SEQ_SIZE_136
# define FB_BOOST_PP_SEQ_SIZE_136(_) FB_BOOST_PP_SEQ_SIZE_137
# define FB_BOOST_PP_SEQ_SIZE_137(_) FB_BOOST_PP_SEQ_SIZE_138
# define FB_BOOST_PP_SEQ_SIZE_138(_) FB_BOOST_PP_SEQ_SIZE_139
# define FB_BOOST_PP_SEQ_SIZE_139(_) FB_BOOST_PP_SEQ_SIZE_140
# define FB_BOOST_PP_SEQ_SIZE_140(_) FB_BOOST_PP_SEQ_SIZE_141
# define FB_BOOST_PP_SEQ_SIZE_141(_) FB_BOOST_PP_SEQ_SIZE_142
# define FB_BOOST_PP_SEQ_SIZE_142(_) FB_BOOST_PP_SEQ_SIZE_143
# define FB_BOOST_PP_SEQ_SIZE_143(_) FB_BOOST_PP_SEQ_SIZE_144
# define FB_BOOST_PP_SEQ_SIZE_144(_) FB_BOOST_PP_SEQ_SIZE_145
# define FB_BOOST_PP_SEQ_SIZE_145(_) FB_BOOST_PP_SEQ_SIZE_146
# define FB_BOOST_PP_SEQ_SIZE_146(_) FB_BOOST_PP_SEQ_SIZE_147
# define FB_BOOST_PP_SEQ_SIZE_147(_) FB_BOOST_PP_SEQ_SIZE_148
# define FB_BOOST_PP_SEQ_SIZE_148(_) FB_BOOST_PP_SEQ_SIZE_149
# define FB_BOOST_PP_SEQ_SIZE_149(_) FB_BOOST_PP_SEQ_SIZE_150
# define FB_BOOST_PP_SEQ_SIZE_150(_) FB_BOOST_PP_SEQ_SIZE_151
# define FB_BOOST_PP_SEQ_SIZE_151(_) FB_BOOST_PP_SEQ_SIZE_152
# define FB_BOOST_PP_SEQ_SIZE_152(_) FB_BOOST_PP_SEQ_SIZE_153
# define FB_BOOST_PP_SEQ_SIZE_153(_) FB_BOOST_PP_SEQ_SIZE_154
# define FB_BOOST_PP_SEQ_SIZE_154(_) FB_BOOST_PP_SEQ_SIZE_155
# define FB_BOOST_PP_SEQ_SIZE_155(_) FB_BOOST_PP_SEQ_SIZE_156
# define FB_BOOST_PP_SEQ_SIZE_156(_) FB_BOOST_PP_SEQ_SIZE_157
# define FB_BOOST_PP_SEQ_SIZE_157(_) FB_BOOST_PP_SEQ_SIZE_158
# define FB_BOOST_PP_SEQ_SIZE_158(_) FB_BOOST_PP_SEQ_SIZE_159
# define FB_BOOST_PP_SEQ_SIZE_159(_) FB_BOOST_PP_SEQ_SIZE_160
# define FB_BOOST_PP_SEQ_SIZE_160(_) FB_BOOST_PP_SEQ_SIZE_161
# define FB_BOOST_PP_SEQ_SIZE_161(_) FB_BOOST_PP_SEQ_SIZE_162
# define FB_BOOST_PP_SEQ_SIZE_162(_) FB_BOOST_PP_SEQ_SIZE_163
# define FB_BOOST_PP_SEQ_SIZE_163(_) FB_BOOST_PP_SEQ_SIZE_164
# define FB_BOOST_PP_SEQ_SIZE_164(_) FB_BOOST_PP_SEQ_SIZE_165
# define FB_BOOST_PP_SEQ_SIZE_165(_) FB_BOOST_PP_SEQ_SIZE_166
# define FB_BOOST_PP_SEQ_SIZE_166(_) FB_BOOST_PP_SEQ_SIZE_167
# define FB_BOOST_PP_SEQ_SIZE_167(_) FB_BOOST_PP_SEQ_SIZE_168
# define FB_BOOST_PP_SEQ_SIZE_168(_) FB_BOOST_PP_SEQ_SIZE_169
# define FB_BOOST_PP_SEQ_SIZE_169(_) FB_BOOST_PP_SEQ_SIZE_170
# define FB_BOOST_PP_SEQ_SIZE_170(_) FB_BOOST_PP_SEQ_SIZE_171
# define FB_BOOST_PP_SEQ_SIZE_171(_) FB_BOOST_PP_SEQ_SIZE_172
# define FB_BOOST_PP_SEQ_SIZE_172(_) FB_BOOST_PP_SEQ_SIZE_173
# define FB_BOOST_PP_SEQ_SIZE_173(_) FB_BOOST_PP_SEQ_SIZE_174
# define FB_BOOST_PP_SEQ_SIZE_174(_) FB_BOOST_PP_SEQ_SIZE_175
# define FB_BOOST_PP_SEQ_SIZE_175(_) FB_BOOST_PP_SEQ_SIZE_176
# define FB_BOOST_PP_SEQ_SIZE_176(_) FB_BOOST_PP_SEQ_SIZE_177
# define FB_BOOST_PP_SEQ_SIZE_177(_) FB_BOOST_PP_SEQ_SIZE_178
# define FB_BOOST_PP_SEQ_SIZE_178(_) FB_BOOST_PP_SEQ_SIZE_179
# define FB_BOOST_PP_SEQ_SIZE_179(_) FB_BOOST_PP_SEQ_SIZE_180
# define FB_BOOST_PP_SEQ_SIZE_180(_) FB_BOOST_PP_SEQ_SIZE_181
# define FB_BOOST_PP_SEQ_SIZE_181(_) FB_BOOST_PP_SEQ_SIZE_182
# define FB_BOOST_PP_SEQ_SIZE_182(_) FB_BOOST_PP_SEQ_SIZE_183
# define FB_BOOST_PP_SEQ_SIZE_183(_) FB_BOOST_PP_SEQ_SIZE_184
# define FB_BOOST_PP_SEQ_SIZE_184(_) FB_BOOST_PP_SEQ_SIZE_185
# define FB_BOOST_PP_SEQ_SIZE_185(_) FB_BOOST_PP_SEQ_SIZE_186
# define FB_BOOST_PP_SEQ_SIZE_186(_) FB_BOOST_PP_SEQ_SIZE_187
# define FB_BOOST_PP_SEQ_SIZE_187(_) FB_BOOST_PP_SEQ_SIZE_188
# define FB_BOOST_PP_SEQ_SIZE_188(_) FB_BOOST_PP_SEQ_SIZE_189
# define FB_BOOST_PP_SEQ_SIZE_189(_) FB_BOOST_PP_SEQ_SIZE_190
# define FB_BOOST_PP_SEQ_SIZE_190(_) FB_BOOST_PP_SEQ_SIZE_191
# define FB_BOOST_PP_SEQ_SIZE_191(_) FB_BOOST_PP_SEQ_SIZE_192
# define FB_BOOST_PP_SEQ_SIZE_192(_) FB_BOOST_PP_SEQ_SIZE_193
# define FB_BOOST_PP_SEQ_SIZE_193(_) FB_BOOST_PP_SEQ_SIZE_194
# define FB_BOOST_PP_SEQ_SIZE_194(_) FB_BOOST_PP_SEQ_SIZE_195
# define FB_BOOST_PP_SEQ_SIZE_195(_) FB_BOOST_PP_SEQ_SIZE_196
# define FB_BOOST_PP_SEQ_SIZE_196(_) FB_BOOST_PP_SEQ_SIZE_197
# define FB_BOOST_PP_SEQ_SIZE_197(_) FB_BOOST_PP_SEQ_SIZE_198
# define FB_BOOST_PP_SEQ_SIZE_198(_) FB_BOOST_PP_SEQ_SIZE_199
# define FB_BOOST_PP_SEQ_SIZE_199(_) FB_BOOST_PP_SEQ_SIZE_200
# define FB_BOOST_PP_SEQ_SIZE_200(_) FB_BOOST_PP_SEQ_SIZE_201
# define FB_BOOST_PP_SEQ_SIZE_201(_) FB_BOOST_PP_SEQ_SIZE_202
# define FB_BOOST_PP_SEQ_SIZE_202(_) FB_BOOST_PP_SEQ_SIZE_203
# define FB_BOOST_PP_SEQ_SIZE_203(_) FB_BOOST_PP_SEQ_SIZE_204
# define FB_BOOST_PP_SEQ_SIZE_204(_) FB_BOOST_PP_SEQ_SIZE_205
# define FB_BOOST_PP_SEQ_SIZE_205(_) FB_BOOST_PP_SEQ_SIZE_206
# define FB_BOOST_PP_SEQ_SIZE_206(_) FB_BOOST_PP_SEQ_SIZE_207
# define FB_BOOST_PP_SEQ_SIZE_207(_) FB_BOOST_PP_SEQ_SIZE_208
# define FB_BOOST_PP_SEQ_SIZE_208(_) FB_BOOST_PP_SEQ_SIZE_209
# define FB_BOOST_PP_SEQ_SIZE_209(_) FB_BOOST_PP_SEQ_SIZE_210
# define FB_BOOST_PP_SEQ_SIZE_210(_) FB_BOOST_PP_SEQ_SIZE_211
# define FB_BOOST_PP_SEQ_SIZE_211(_) FB_BOOST_PP_SEQ_SIZE_212
# define FB_BOOST_PP_SEQ_SIZE_212(_) FB_BOOST_PP_SEQ_SIZE_213
# define FB_BOOST_PP_SEQ_SIZE_213(_) FB_BOOST_PP_SEQ_SIZE_214
# define FB_BOOST_PP_SEQ_SIZE_214(_) FB_BOOST_PP_SEQ_SIZE_215
# define FB_BOOST_PP_SEQ_SIZE_215(_) FB_BOOST_PP_SEQ_SIZE_216
# define FB_BOOST_PP_SEQ_SIZE_216(_) FB_BOOST_PP_SEQ_SIZE_217
# define FB_BOOST_PP_SEQ_SIZE_217(_) FB_BOOST_PP_SEQ_SIZE_218
# define FB_BOOST_PP_SEQ_SIZE_218(_) FB_BOOST_PP_SEQ_SIZE_219
# define FB_BOOST_PP_SEQ_SIZE_219(_) FB_BOOST_PP_SEQ_SIZE_220
# define FB_BOOST_PP_SEQ_SIZE_220(_) FB_BOOST_PP_SEQ_SIZE_221
# define FB_BOOST_PP_SEQ_SIZE_221(_) FB_BOOST_PP_SEQ_SIZE_222
# define FB_BOOST_PP_SEQ_SIZE_222(_) FB_BOOST_PP_SEQ_SIZE_223
# define FB_BOOST_PP_SEQ_SIZE_223(_) FB_BOOST_PP_SEQ_SIZE_224
# define FB_BOOST_PP_SEQ_SIZE_224(_) FB_BOOST_PP_SEQ_SIZE_225
# define FB_BOOST_PP_SEQ_SIZE_225(_) FB_BOOST_PP_SEQ_SIZE_226
# define FB_BOOST_PP_SEQ_SIZE_226(_) FB_BOOST_PP_SEQ_SIZE_227
# define FB_BOOST_PP_SEQ_SIZE_227(_) FB_BOOST_PP_SEQ_SIZE_228
# define FB_BOOST_PP_SEQ_SIZE_228(_) FB_BOOST_PP_SEQ_SIZE_229
# define FB_BOOST_PP_SEQ_SIZE_229(_) FB_BOOST_PP_SEQ_SIZE_230
# define FB_BOOST_PP_SEQ_SIZE_230(_) FB_BOOST_PP_SEQ_SIZE_231
# define FB_BOOST_PP_SEQ_SIZE_231(_) FB_BOOST_PP_SEQ_SIZE_232
# define FB_BOOST_PP_SEQ_SIZE_232(_) FB_BOOST_PP_SEQ_SIZE_233
# define FB_BOOST_PP_SEQ_SIZE_233(_) FB_BOOST_PP_SEQ_SIZE_234
# define FB_BOOST_PP_SEQ_SIZE_234(_) FB_BOOST_PP_SEQ_SIZE_235
# define FB_BOOST_PP_SEQ_SIZE_235(_) FB_BOOST_PP_SEQ_SIZE_236
# define FB_BOOST_PP_SEQ_SIZE_236(_) FB_BOOST_PP_SEQ_SIZE_237
# define FB_BOOST_PP_SEQ_SIZE_237(_) FB_BOOST_PP_SEQ_SIZE_238
# define FB_BOOST_PP_SEQ_SIZE_238(_) FB_BOOST_PP_SEQ_SIZE_239
# define FB_BOOST_PP_SEQ_SIZE_239(_) FB_BOOST_PP_SEQ_SIZE_240
# define FB_BOOST_PP_SEQ_SIZE_240(_) FB_BOOST_PP_SEQ_SIZE_241
# define FB_BOOST_PP_SEQ_SIZE_241(_) FB_BOOST_PP_SEQ_SIZE_242
# define FB_BOOST_PP_SEQ_SIZE_242(_) FB_BOOST_PP_SEQ_SIZE_243
# define FB_BOOST_PP_SEQ_SIZE_243(_) FB_BOOST_PP_SEQ_SIZE_244
# define FB_BOOST_PP_SEQ_SIZE_244(_) FB_BOOST_PP_SEQ_SIZE_245
# define FB_BOOST_PP_SEQ_SIZE_245(_) FB_BOOST_PP_SEQ_SIZE_246
# define FB_BOOST_PP_SEQ_SIZE_246(_) FB_BOOST_PP_SEQ_SIZE_247
# define FB_BOOST_PP_SEQ_SIZE_247(_) FB_BOOST_PP_SEQ_SIZE_248
# define FB_BOOST_PP_SEQ_SIZE_248(_) FB_BOOST_PP_SEQ_SIZE_249
# define FB_BOOST_PP_SEQ_SIZE_249(_) FB_BOOST_PP_SEQ_SIZE_250
# define FB_BOOST_PP_SEQ_SIZE_250(_) FB_BOOST_PP_SEQ_SIZE_251
# define FB_BOOST_PP_SEQ_SIZE_251(_) FB_BOOST_PP_SEQ_SIZE_252
# define FB_BOOST_PP_SEQ_SIZE_252(_) FB_BOOST_PP_SEQ_SIZE_253
# define FB_BOOST_PP_SEQ_SIZE_253(_) FB_BOOST_PP_SEQ_SIZE_254
# define FB_BOOST_PP_SEQ_SIZE_254(_) FB_BOOST_PP_SEQ_SIZE_255
# define FB_BOOST_PP_SEQ_SIZE_255(_) FB_BOOST_PP_SEQ_SIZE_256
# define FB_BOOST_PP_SEQ_SIZE_256(_) FB_BOOST_PP_SEQ_SIZE_257
#
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_0 0
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_1 1
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_2 2
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_3 3
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_4 4
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_5 5
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_6 6
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_7 7
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_8 8
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_9 9
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_10 10
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_11 11
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_12 12
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_13 13
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_14 14
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_15 15
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_16 16
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_17 17
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_18 18
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_19 19
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_20 20
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_21 21
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_22 22
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_23 23
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_24 24
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_25 25
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_26 26
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_27 27
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_28 28
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_29 29
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_30 30
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_31 31
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_32 32
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_33 33
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_34 34
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_35 35
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_36 36
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_37 37
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_38 38
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_39 39
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_40 40
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_41 41
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_42 42
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_43 43
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_44 44
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_45 45
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_46 46
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_47 47
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_48 48
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_49 49
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_50 50
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_51 51
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_52 52
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_53 53
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_54 54
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_55 55
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_56 56
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_57 57
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_58 58
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_59 59
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_60 60
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_61 61
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_62 62
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_63 63
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_64 64
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_65 65
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_66 66
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_67 67
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_68 68
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_69 69
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_70 70
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_71 71
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_72 72
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_73 73
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_74 74
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_75 75
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_76 76
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_77 77
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_78 78
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_79 79
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_80 80
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_81 81
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_82 82
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_83 83
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_84 84
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_85 85
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_86 86
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_87 87
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_88 88
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_89 89
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_90 90
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_91 91
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_92 92
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_93 93
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_94 94
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_95 95
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_96 96
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_97 97
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_98 98
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_99 99
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_100 100
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_101 101
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_102 102
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_103 103
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_104 104
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_105 105
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_106 106
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_107 107
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_108 108
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_109 109
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_110 110
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_111 111
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_112 112
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_113 113
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_114 114
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_115 115
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_116 116
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_117 117
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_118 118
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_119 119
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_120 120
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_121 121
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_122 122
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_123 123
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_124 124
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_125 125
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_126 126
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_127 127
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_128 128
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_129 129
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_130 130
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_131 131
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_132 132
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_133 133
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_134 134
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_135 135
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_136 136
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_137 137
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_138 138
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_139 139
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_140 140
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_141 141
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_142 142
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_143 143
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_144 144
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_145 145
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_146 146
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_147 147
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_148 148
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_149 149
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_150 150
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_151 151
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_152 152
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_153 153
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_154 154
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_155 155
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_156 156
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_157 157
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_158 158
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_159 159
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_160 160
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_161 161
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_162 162
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_163 163
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_164 164
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_165 165
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_166 166
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_167 167
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_168 168
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_169 169
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_170 170
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_171 171
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_172 172
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_173 173
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_174 174
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_175 175
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_176 176
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_177 177
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_178 178
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_179 179
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_180 180
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_181 181
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_182 182
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_183 183
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_184 184
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_185 185
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_186 186
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_187 187
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_188 188
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_189 189
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_190 190
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_191 191
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_192 192
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_193 193
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_194 194
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_195 195
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_196 196
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_197 197
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_198 198
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_199 199
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_200 200
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_201 201
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_202 202
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_203 203
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_204 204
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_205 205
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_206 206
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_207 207
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_208 208
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_209 209
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_210 210
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_211 211
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_212 212
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_213 213
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_214 214
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_215 215
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_216 216
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_217 217
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_218 218
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_219 219
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_220 220
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_221 221
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_222 222
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_223 223
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_224 224
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_225 225
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_226 226
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_227 227
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_228 228
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_229 229
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_230 230
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_231 231
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_232 232
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_233 233
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_234 234
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_235 235
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_236 236
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_237 237
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_238 238
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_239 239
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_240 240
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_241 241
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_242 242
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_243 243
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_244 244
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_245 245
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_246 246
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_247 247
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_248 248
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_249 249
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_250 250
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_251 251
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_252 252
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_253 253
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_254 254
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_255 255
# define FB_BOOST_PP_SEQ_SIZE_FB_BOOST_PP_SEQ_SIZE_256 256
#
# endif
