#ifndef FIREBIRD_TIME_ZONES_H
#define FIREBIRD_TIME_ZONES_H

// The content of this file is generated with help of update-ids utility Do not edit.

#define fb_tzid_gmt                                  65535 /* GMT */
#define fb_tzid_act                                  65534 /* ACT */
#define fb_tzid_aet                                  65533 /* AET */
#define fb_tzid_agt                                  65532 /* AGT */
#define fb_tzid_art                                  65531 /* ART */
#define fb_tzid_ast                                  65530 /* AST */
#define fb_tzid_africa_abidjan                       65529 /* Africa/Abidjan */
#define fb_tzid_africa_accra                         65528 /* Africa/Accra */
#define fb_tzid_africa_addis_ababa                   65527 /* Africa/Addis_Ababa */
#define fb_tzid_africa_algiers                       65526 /* Africa/Algiers */
#define fb_tzid_africa_asmara                        65525 /* Africa/Asmara */
#define fb_tzid_africa_asmera                        65524 /* Africa/Asmera */
#define fb_tzid_africa_bamako                        65523 /* Africa/Bamako */
#define fb_tzid_africa_bangui                        65522 /* Africa/Bangui */
#define fb_tzid_africa_banjul                        65521 /* Africa/Banjul */
#define fb_tzid_africa_bissau                        65520 /* Africa/Bissau */
#define fb_tzid_africa_blantyre                      65519 /* Africa/Blantyre */
#define fb_tzid_africa_brazzaville                   65518 /* Africa/Brazzaville */
#define fb_tzid_africa_bujumbura                     65517 /* Africa/Bujumbura */
#define fb_tzid_africa_cairo                         65516 /* Africa/Cairo */
#define fb_tzid_africa_casablanca                    65515 /* Africa/Casablanca */
#define fb_tzid_africa_ceuta                         65514 /* Africa/Ceuta */
#define fb_tzid_africa_conakry                       65513 /* Africa/Conakry */
#define fb_tzid_africa_dakar                         65512 /* Africa/Dakar */
#define fb_tzid_africa_dar_es_salaam                 65511 /* Africa/Dar_es_Salaam */
#define fb_tzid_africa_djibouti                      65510 /* Africa/Djibouti */
#define fb_tzid_africa_douala                        65509 /* Africa/Douala */
#define fb_tzid_africa_el_aaiun                      65508 /* Africa/El_Aaiun */
#define fb_tzid_africa_freetown                      65507 /* Africa/Freetown */
#define fb_tzid_africa_gaborone                      65506 /* Africa/Gaborone */
#define fb_tzid_africa_harare                        65505 /* Africa/Harare */
#define fb_tzid_africa_johannesburg                  65504 /* Africa/Johannesburg */
#define fb_tzid_africa_juba                          65503 /* Africa/Juba */
#define fb_tzid_africa_kampala                       65502 /* Africa/Kampala */
#define fb_tzid_africa_khartoum                      65501 /* Africa/Khartoum */
#define fb_tzid_africa_kigali                        65500 /* Africa/Kigali */
#define fb_tzid_africa_kinshasa                      65499 /* Africa/Kinshasa */
#define fb_tzid_africa_lagos                         65498 /* Africa/Lagos */
#define fb_tzid_africa_libreville                    65497 /* Africa/Libreville */
#define fb_tzid_africa_lome                          65496 /* Africa/Lome */
#define fb_tzid_africa_luanda                        65495 /* Africa/Luanda */
#define fb_tzid_africa_lubumbashi                    65494 /* Africa/Lubumbashi */
#define fb_tzid_africa_lusaka                        65493 /* Africa/Lusaka */
#define fb_tzid_africa_malabo                        65492 /* Africa/Malabo */
#define fb_tzid_africa_maputo                        65491 /* Africa/Maputo */
#define fb_tzid_africa_maseru                        65490 /* Africa/Maseru */
#define fb_tzid_africa_mbabane                       65489 /* Africa/Mbabane */
#define fb_tzid_africa_mogadishu                     65488 /* Africa/Mogadishu */
#define fb_tzid_africa_monrovia                      65487 /* Africa/Monrovia */
#define fb_tzid_africa_nairobi                       65486 /* Africa/Nairobi */
#define fb_tzid_africa_ndjamena                      65485 /* Africa/Ndjamena */
#define fb_tzid_africa_niamey                        65484 /* Africa/Niamey */
#define fb_tzid_africa_nouakchott                    65483 /* Africa/Nouakchott */
#define fb_tzid_africa_ouagadougou                   65482 /* Africa/Ouagadougou */
#define fb_tzid_africa_porto_novo                    65481 /* Africa/Porto-Novo */
#define fb_tzid_africa_sao_tome                      65480 /* Africa/Sao_Tome */
#define fb_tzid_africa_timbuktu                      65479 /* Africa/Timbuktu */
#define fb_tzid_africa_tripoli                       65478 /* Africa/Tripoli */
#define fb_tzid_africa_tunis                         65477 /* Africa/Tunis */
#define fb_tzid_africa_windhoek                      65476 /* Africa/Windhoek */
#define fb_tzid_america_adak                         65475 /* America/Adak */
#define fb_tzid_america_anchorage                    65474 /* America/Anchorage */
#define fb_tzid_america_anguilla                     65473 /* America/Anguilla */
#define fb_tzid_america_antigua                      65472 /* America/Antigua */
#define fb_tzid_america_araguaina                    65471 /* America/Araguaina */
#define fb_tzid_america_argentina_buenos_aires       65470 /* America/Argentina/Buenos_Aires */
#define fb_tzid_america_argentina_catamarca          65469 /* America/Argentina/Catamarca */
#define fb_tzid_america_argentina_comodrivadavia     65468 /* America/Argentina/ComodRivadavia */
#define fb_tzid_america_argentina_cordoba            65467 /* America/Argentina/Cordoba */
#define fb_tzid_america_argentina_jujuy              65466 /* America/Argentina/Jujuy */
#define fb_tzid_america_argentina_la_rioja           65465 /* America/Argentina/La_Rioja */
#define fb_tzid_america_argentina_mendoza            65464 /* America/Argentina/Mendoza */
#define fb_tzid_america_argentina_rio_gallegos       65463 /* America/Argentina/Rio_Gallegos */
#define fb_tzid_america_argentina_salta              65462 /* America/Argentina/Salta */
#define fb_tzid_america_argentina_san_juan           65461 /* America/Argentina/San_Juan */
#define fb_tzid_america_argentina_san_luis           65460 /* America/Argentina/San_Luis */
#define fb_tzid_america_argentina_tucuman            65459 /* America/Argentina/Tucuman */
#define fb_tzid_america_argentina_ushuaia            65458 /* America/Argentina/Ushuaia */
#define fb_tzid_america_aruba                        65457 /* America/Aruba */
#define fb_tzid_america_asuncion                     65456 /* America/Asuncion */
#define fb_tzid_america_atikokan                     65455 /* America/Atikokan */
#define fb_tzid_america_atka                         65454 /* America/Atka */
#define fb_tzid_america_bahia                        65453 /* America/Bahia */
#define fb_tzid_america_bahia_banderas               65452 /* America/Bahia_Banderas */
#define fb_tzid_america_barbados                     65451 /* America/Barbados */
#define fb_tzid_america_belem                        65450 /* America/Belem */
#define fb_tzid_america_belize                       65449 /* America/Belize */
#define fb_tzid_america_blanc_sablon                 65448 /* America/Blanc-Sablon */
#define fb_tzid_america_boa_vista                    65447 /* America/Boa_Vista */
#define fb_tzid_america_bogota                       65446 /* America/Bogota */
#define fb_tzid_america_boise                        65445 /* America/Boise */
#define fb_tzid_america_buenos_aires                 65444 /* America/Buenos_Aires */
#define fb_tzid_america_cambridge_bay                65443 /* America/Cambridge_Bay */
#define fb_tzid_america_campo_grande                 65442 /* America/Campo_Grande */
#define fb_tzid_america_cancun                       65441 /* America/Cancun */
#define fb_tzid_america_caracas                      65440 /* America/Caracas */
#define fb_tzid_america_catamarca                    65439 /* America/Catamarca */
#define fb_tzid_america_cayenne                      65438 /* America/Cayenne */
#define fb_tzid_america_cayman                       65437 /* America/Cayman */
#define fb_tzid_america_chicago                      65436 /* America/Chicago */
#define fb_tzid_america_chihuahua                    65435 /* America/Chihuahua */
#define fb_tzid_america_coral_harbour                65434 /* America/Coral_Harbour */
#define fb_tzid_america_cordoba                      65433 /* America/Cordoba */
#define fb_tzid_america_costa_rica                   65432 /* America/Costa_Rica */
#define fb_tzid_america_creston                      65431 /* America/Creston */
#define fb_tzid_america_cuiaba                       65430 /* America/Cuiaba */
#define fb_tzid_america_curacao                      65429 /* America/Curacao */
#define fb_tzid_america_danmarkshavn                 65428 /* America/Danmarkshavn */
#define fb_tzid_america_dawson                       65427 /* America/Dawson */
#define fb_tzid_america_dawson_creek                 65426 /* America/Dawson_Creek */
#define fb_tzid_america_denver                       65425 /* America/Denver */
#define fb_tzid_america_detroit                      65424 /* America/Detroit */
#define fb_tzid_america_dominica                     65423 /* America/Dominica */
#define fb_tzid_america_edmonton                     65422 /* America/Edmonton */
#define fb_tzid_america_eirunepe                     65421 /* America/Eirunepe */
#define fb_tzid_america_el_salvador                  65420 /* America/El_Salvador */
#define fb_tzid_america_ensenada                     65419 /* America/Ensenada */
#define fb_tzid_america_fort_nelson                  65418 /* America/Fort_Nelson */
#define fb_tzid_america_fort_wayne                   65417 /* America/Fort_Wayne */
#define fb_tzid_america_fortaleza                    65416 /* America/Fortaleza */
#define fb_tzid_america_glace_bay                    65415 /* America/Glace_Bay */
#define fb_tzid_america_godthab                      65414 /* America/Godthab */
#define fb_tzid_america_goose_bay                    65413 /* America/Goose_Bay */
#define fb_tzid_america_grand_turk                   65412 /* America/Grand_Turk */
#define fb_tzid_america_grenada                      65411 /* America/Grenada */
#define fb_tzid_america_guadeloupe                   65410 /* America/Guadeloupe */
#define fb_tzid_america_guatemala                    65409 /* America/Guatemala */
#define fb_tzid_america_guayaquil                    65408 /* America/Guayaquil */
#define fb_tzid_america_guyana                       65407 /* America/Guyana */
#define fb_tzid_america_halifax                      65406 /* America/Halifax */
#define fb_tzid_america_havana                       65405 /* America/Havana */
#define fb_tzid_america_hermosillo                   65404 /* America/Hermosillo */
#define fb_tzid_america_indiana_indianapolis         65403 /* America/Indiana/Indianapolis */
#define fb_tzid_america_indiana_knox                 65402 /* America/Indiana/Knox */
#define fb_tzid_america_indiana_marengo              65401 /* America/Indiana/Marengo */
#define fb_tzid_america_indiana_petersburg           65400 /* America/Indiana/Petersburg */
#define fb_tzid_america_indiana_tell_city            65399 /* America/Indiana/Tell_City */
#define fb_tzid_america_indiana_vevay                65398 /* America/Indiana/Vevay */
#define fb_tzid_america_indiana_vincennes            65397 /* America/Indiana/Vincennes */
#define fb_tzid_america_indiana_winamac              65396 /* America/Indiana/Winamac */
#define fb_tzid_america_indianapolis                 65395 /* America/Indianapolis */
#define fb_tzid_america_inuvik                       65394 /* America/Inuvik */
#define fb_tzid_america_iqaluit                      65393 /* America/Iqaluit */
#define fb_tzid_america_jamaica                      65392 /* America/Jamaica */
#define fb_tzid_america_jujuy                        65391 /* America/Jujuy */
#define fb_tzid_america_juneau                       65390 /* America/Juneau */
#define fb_tzid_america_kentucky_louisville          65389 /* America/Kentucky/Louisville */
#define fb_tzid_america_kentucky_monticello          65388 /* America/Kentucky/Monticello */
#define fb_tzid_america_knox_in                      65387 /* America/Knox_IN */
#define fb_tzid_america_kralendijk                   65386 /* America/Kralendijk */
#define fb_tzid_america_la_paz                       65385 /* America/La_Paz */
#define fb_tzid_america_lima                         65384 /* America/Lima */
#define fb_tzid_america_los_angeles                  65383 /* America/Los_Angeles */
#define fb_tzid_america_louisville                   65382 /* America/Louisville */
#define fb_tzid_america_lower_princes                65381 /* America/Lower_Princes */
#define fb_tzid_america_maceio                       65380 /* America/Maceio */
#define fb_tzid_america_managua                      65379 /* America/Managua */
#define fb_tzid_america_manaus                       65378 /* America/Manaus */
#define fb_tzid_america_marigot                      65377 /* America/Marigot */
#define fb_tzid_america_martinique                   65376 /* America/Martinique */
#define fb_tzid_america_matamoros                    65375 /* America/Matamoros */
#define fb_tzid_america_mazatlan                     65374 /* America/Mazatlan */
#define fb_tzid_america_mendoza                      65373 /* America/Mendoza */
#define fb_tzid_america_menominee                    65372 /* America/Menominee */
#define fb_tzid_america_merida                       65371 /* America/Merida */
#define fb_tzid_america_metlakatla                   65370 /* America/Metlakatla */
#define fb_tzid_america_mexico_city                  65369 /* America/Mexico_City */
#define fb_tzid_america_miquelon                     65368 /* America/Miquelon */
#define fb_tzid_america_moncton                      65367 /* America/Moncton */
#define fb_tzid_america_monterrey                    65366 /* America/Monterrey */
#define fb_tzid_america_montevideo                   65365 /* America/Montevideo */
#define fb_tzid_america_montreal                     65364 /* America/Montreal */
#define fb_tzid_america_montserrat                   65363 /* America/Montserrat */
#define fb_tzid_america_nassau                       65362 /* America/Nassau */
#define fb_tzid_america_new_york                     65361 /* America/New_York */
#define fb_tzid_america_nipigon                      65360 /* America/Nipigon */
#define fb_tzid_america_nome                         65359 /* America/Nome */
#define fb_tzid_america_noronha                      65358 /* America/Noronha */
#define fb_tzid_america_north_dakota_beulah          65357 /* America/North_Dakota/Beulah */
#define fb_tzid_america_north_dakota_center          65356 /* America/North_Dakota/Center */
#define fb_tzid_america_north_dakota_new_salem       65355 /* America/North_Dakota/New_Salem */
#define fb_tzid_america_ojinaga                      65354 /* America/Ojinaga */
#define fb_tzid_america_panama                       65353 /* America/Panama */
#define fb_tzid_america_pangnirtung                  65352 /* America/Pangnirtung */
#define fb_tzid_america_paramaribo                   65351 /* America/Paramaribo */
#define fb_tzid_america_phoenix                      65350 /* America/Phoenix */
#define fb_tzid_america_port_au_prince               65349 /* America/Port-au-Prince */
#define fb_tzid_america_port_of_spain                65348 /* America/Port_of_Spain */
#define fb_tzid_america_porto_acre                   65347 /* America/Porto_Acre */
#define fb_tzid_america_porto_velho                  65346 /* America/Porto_Velho */
#define fb_tzid_america_puerto_rico                  65345 /* America/Puerto_Rico */
#define fb_tzid_america_punta_arenas                 65344 /* America/Punta_Arenas */
#define fb_tzid_america_rainy_river                  65343 /* America/Rainy_River */
#define fb_tzid_america_rankin_inlet                 65342 /* America/Rankin_Inlet */
#define fb_tzid_america_recife                       65341 /* America/Recife */
#define fb_tzid_america_regina                       65340 /* America/Regina */
#define fb_tzid_america_resolute                     65339 /* America/Resolute */
#define fb_tzid_america_rio_branco                   65338 /* America/Rio_Branco */
#define fb_tzid_america_rosario                      65337 /* America/Rosario */
#define fb_tzid_america_santa_isabel                 65336 /* America/Santa_Isabel */
#define fb_tzid_america_santarem                     65335 /* America/Santarem */
#define fb_tzid_america_santiago                     65334 /* America/Santiago */
#define fb_tzid_america_santo_domingo                65333 /* America/Santo_Domingo */
#define fb_tzid_america_sao_paulo                    65332 /* America/Sao_Paulo */
#define fb_tzid_america_scoresbysund                 65331 /* America/Scoresbysund */
#define fb_tzid_america_shiprock                     65330 /* America/Shiprock */
#define fb_tzid_america_sitka                        65329 /* America/Sitka */
#define fb_tzid_america_st_barthelemy                65328 /* America/St_Barthelemy */
#define fb_tzid_america_st_johns                     65327 /* America/St_Johns */
#define fb_tzid_america_st_kitts                     65326 /* America/St_Kitts */
#define fb_tzid_america_st_lucia                     65325 /* America/St_Lucia */
#define fb_tzid_america_st_thomas                    65324 /* America/St_Thomas */
#define fb_tzid_america_st_vincent                   65323 /* America/St_Vincent */
#define fb_tzid_america_swift_current                65322 /* America/Swift_Current */
#define fb_tzid_america_tegucigalpa                  65321 /* America/Tegucigalpa */
#define fb_tzid_america_thule                        65320 /* America/Thule */
#define fb_tzid_america_thunder_bay                  65319 /* America/Thunder_Bay */
#define fb_tzid_america_tijuana                      65318 /* America/Tijuana */
#define fb_tzid_america_toronto                      65317 /* America/Toronto */
#define fb_tzid_america_tortola                      65316 /* America/Tortola */
#define fb_tzid_america_vancouver                    65315 /* America/Vancouver */
#define fb_tzid_america_virgin                       65314 /* America/Virgin */
#define fb_tzid_america_whitehorse                   65313 /* America/Whitehorse */
#define fb_tzid_america_winnipeg                     65312 /* America/Winnipeg */
#define fb_tzid_america_yakutat                      65311 /* America/Yakutat */
#define fb_tzid_america_yellowknife                  65310 /* America/Yellowknife */
#define fb_tzid_antarctica_casey                     65309 /* Antarctica/Casey */
#define fb_tzid_antarctica_davis                     65308 /* Antarctica/Davis */
#define fb_tzid_antarctica_dumontdurville            65307 /* Antarctica/DumontDUrville */
#define fb_tzid_antarctica_macquarie                 65306 /* Antarctica/Macquarie */
#define fb_tzid_antarctica_mawson                    65305 /* Antarctica/Mawson */
#define fb_tzid_antarctica_mcmurdo                   65304 /* Antarctica/McMurdo */
#define fb_tzid_antarctica_palmer                    65303 /* Antarctica/Palmer */
#define fb_tzid_antarctica_rothera                   65302 /* Antarctica/Rothera */
#define fb_tzid_antarctica_south_pole                65301 /* Antarctica/South_Pole */
#define fb_tzid_antarctica_syowa                     65300 /* Antarctica/Syowa */
#define fb_tzid_antarctica_troll                     65299 /* Antarctica/Troll */
#define fb_tzid_antarctica_vostok                    65298 /* Antarctica/Vostok */
#define fb_tzid_arctic_longyearbyen                  65297 /* Arctic/Longyearbyen */
#define fb_tzid_asia_aden                            65296 /* Asia/Aden */
#define fb_tzid_asia_almaty                          65295 /* Asia/Almaty */
#define fb_tzid_asia_amman                           65294 /* Asia/Amman */
#define fb_tzid_asia_anadyr                          65293 /* Asia/Anadyr */
#define fb_tzid_asia_aqtau                           65292 /* Asia/Aqtau */
#define fb_tzid_asia_aqtobe                          65291 /* Asia/Aqtobe */
#define fb_tzid_asia_ashgabat                        65290 /* Asia/Ashgabat */
#define fb_tzid_asia_ashkhabad                       65289 /* Asia/Ashkhabad */
#define fb_tzid_asia_atyrau                          65288 /* Asia/Atyrau */
#define fb_tzid_asia_baghdad                         65287 /* Asia/Baghdad */
#define fb_tzid_asia_bahrain                         65286 /* Asia/Bahrain */
#define fb_tzid_asia_baku                            65285 /* Asia/Baku */
#define fb_tzid_asia_bangkok                         65284 /* Asia/Bangkok */
#define fb_tzid_asia_barnaul                         65283 /* Asia/Barnaul */
#define fb_tzid_asia_beirut                          65282 /* Asia/Beirut */
#define fb_tzid_asia_bishkek                         65281 /* Asia/Bishkek */
#define fb_tzid_asia_brunei                          65280 /* Asia/Brunei */
#define fb_tzid_asia_calcutta                        65279 /* Asia/Calcutta */
#define fb_tzid_asia_chita                           65278 /* Asia/Chita */
#define fb_tzid_asia_choibalsan                      65277 /* Asia/Choibalsan */
#define fb_tzid_asia_chongqing                       65276 /* Asia/Chongqing */
#define fb_tzid_asia_chungking                       65275 /* Asia/Chungking */
#define fb_tzid_asia_colombo                         65274 /* Asia/Colombo */
#define fb_tzid_asia_dacca                           65273 /* Asia/Dacca */
#define fb_tzid_asia_damascus                        65272 /* Asia/Damascus */
#define fb_tzid_asia_dhaka                           65271 /* Asia/Dhaka */
#define fb_tzid_asia_dili                            65270 /* Asia/Dili */
#define fb_tzid_asia_dubai                           65269 /* Asia/Dubai */
#define fb_tzid_asia_dushanbe                        65268 /* Asia/Dushanbe */
#define fb_tzid_asia_famagusta                       65267 /* Asia/Famagusta */
#define fb_tzid_asia_gaza                            65266 /* Asia/Gaza */
#define fb_tzid_asia_harbin                          65265 /* Asia/Harbin */
#define fb_tzid_asia_hebron                          65264 /* Asia/Hebron */
#define fb_tzid_asia_ho_chi_minh                     65263 /* Asia/Ho_Chi_Minh */
#define fb_tzid_asia_hong_kong                       65262 /* Asia/Hong_Kong */
#define fb_tzid_asia_hovd                            65261 /* Asia/Hovd */
#define fb_tzid_asia_irkutsk                         65260 /* Asia/Irkutsk */
#define fb_tzid_asia_istanbul                        65259 /* Asia/Istanbul */
#define fb_tzid_asia_jakarta                         65258 /* Asia/Jakarta */
#define fb_tzid_asia_jayapura                        65257 /* Asia/Jayapura */
#define fb_tzid_asia_jerusalem                       65256 /* Asia/Jerusalem */
#define fb_tzid_asia_kabul                           65255 /* Asia/Kabul */
#define fb_tzid_asia_kamchatka                       65254 /* Asia/Kamchatka */
#define fb_tzid_asia_karachi                         65253 /* Asia/Karachi */
#define fb_tzid_asia_kashgar                         65252 /* Asia/Kashgar */
#define fb_tzid_asia_kathmandu                       65251 /* Asia/Kathmandu */
#define fb_tzid_asia_katmandu                        65250 /* Asia/Katmandu */
#define fb_tzid_asia_khandyga                        65249 /* Asia/Khandyga */
#define fb_tzid_asia_kolkata                         65248 /* Asia/Kolkata */
#define fb_tzid_asia_krasnoyarsk                     65247 /* Asia/Krasnoyarsk */
#define fb_tzid_asia_kuala_lumpur                    65246 /* Asia/Kuala_Lumpur */
#define fb_tzid_asia_kuching                         65245 /* Asia/Kuching */
#define fb_tzid_asia_kuwait                          65244 /* Asia/Kuwait */
#define fb_tzid_asia_macao                           65243 /* Asia/Macao */
#define fb_tzid_asia_macau                           65242 /* Asia/Macau */
#define fb_tzid_asia_magadan                         65241 /* Asia/Magadan */
#define fb_tzid_asia_makassar                        65240 /* Asia/Makassar */
#define fb_tzid_asia_manila                          65239 /* Asia/Manila */
#define fb_tzid_asia_muscat                          65238 /* Asia/Muscat */
#define fb_tzid_asia_nicosia                         65237 /* Asia/Nicosia */
#define fb_tzid_asia_novokuznetsk                    65236 /* Asia/Novokuznetsk */
#define fb_tzid_asia_novosibirsk                     65235 /* Asia/Novosibirsk */
#define fb_tzid_asia_omsk                            65234 /* Asia/Omsk */
#define fb_tzid_asia_oral                            65233 /* Asia/Oral */
#define fb_tzid_asia_phnom_penh                      65232 /* Asia/Phnom_Penh */
#define fb_tzid_asia_pontianak                       65231 /* Asia/Pontianak */
#define fb_tzid_asia_pyongyang                       65230 /* Asia/Pyongyang */
#define fb_tzid_asia_qatar                           65229 /* Asia/Qatar */
#define fb_tzid_asia_qyzylorda                       65228 /* Asia/Qyzylorda */
#define fb_tzid_asia_rangoon                         65227 /* Asia/Rangoon */
#define fb_tzid_asia_riyadh                          65226 /* Asia/Riyadh */
#define fb_tzid_asia_saigon                          65225 /* Asia/Saigon */
#define fb_tzid_asia_sakhalin                        65224 /* Asia/Sakhalin */
#define fb_tzid_asia_samarkand                       65223 /* Asia/Samarkand */
#define fb_tzid_asia_seoul                           65222 /* Asia/Seoul */
#define fb_tzid_asia_shanghai                        65221 /* Asia/Shanghai */
#define fb_tzid_asia_singapore                       65220 /* Asia/Singapore */
#define fb_tzid_asia_srednekolymsk                   65219 /* Asia/Srednekolymsk */
#define fb_tzid_asia_taipei                          65218 /* Asia/Taipei */
#define fb_tzid_asia_tashkent                        65217 /* Asia/Tashkent */
#define fb_tzid_asia_tbilisi                         65216 /* Asia/Tbilisi */
#define fb_tzid_asia_tehran                          65215 /* Asia/Tehran */
#define fb_tzid_asia_tel_aviv                        65214 /* Asia/Tel_Aviv */
#define fb_tzid_asia_thimbu                          65213 /* Asia/Thimbu */
#define fb_tzid_asia_thimphu                         65212 /* Asia/Thimphu */
#define fb_tzid_asia_tokyo                           65211 /* Asia/Tokyo */
#define fb_tzid_asia_tomsk                           65210 /* Asia/Tomsk */
#define fb_tzid_asia_ujung_pandang                   65209 /* Asia/Ujung_Pandang */
#define fb_tzid_asia_ulaanbaatar                     65208 /* Asia/Ulaanbaatar */
#define fb_tzid_asia_ulan_bator                      65207 /* Asia/Ulan_Bator */
#define fb_tzid_asia_urumqi                          65206 /* Asia/Urumqi */
#define fb_tzid_asia_ust_nera                        65205 /* Asia/Ust-Nera */
#define fb_tzid_asia_vientiane                       65204 /* Asia/Vientiane */
#define fb_tzid_asia_vladivostok                     65203 /* Asia/Vladivostok */
#define fb_tzid_asia_yakutsk                         65202 /* Asia/Yakutsk */
#define fb_tzid_asia_yangon                          65201 /* Asia/Yangon */
#define fb_tzid_asia_yekaterinburg                   65200 /* Asia/Yekaterinburg */
#define fb_tzid_asia_yerevan                         65199 /* Asia/Yerevan */
#define fb_tzid_atlantic_azores                      65198 /* Atlantic/Azores */
#define fb_tzid_atlantic_bermuda                     65197 /* Atlantic/Bermuda */
#define fb_tzid_atlantic_canary                      65196 /* Atlantic/Canary */
#define fb_tzid_atlantic_cape_verde                  65195 /* Atlantic/Cape_Verde */
#define fb_tzid_atlantic_faeroe                      65194 /* Atlantic/Faeroe */
#define fb_tzid_atlantic_faroe                       65193 /* Atlantic/Faroe */
#define fb_tzid_atlantic_jan_mayen                   65192 /* Atlantic/Jan_Mayen */
#define fb_tzid_atlantic_madeira                     65191 /* Atlantic/Madeira */
#define fb_tzid_atlantic_reykjavik                   65190 /* Atlantic/Reykjavik */
#define fb_tzid_atlantic_south_georgia               65189 /* Atlantic/South_Georgia */
#define fb_tzid_atlantic_st_helena                   65188 /* Atlantic/St_Helena */
#define fb_tzid_atlantic_stanley                     65187 /* Atlantic/Stanley */
#define fb_tzid_australia_act                        65186 /* Australia/ACT */
#define fb_tzid_australia_adelaide                   65185 /* Australia/Adelaide */
#define fb_tzid_australia_brisbane                   65184 /* Australia/Brisbane */
#define fb_tzid_australia_broken_hill                65183 /* Australia/Broken_Hill */
#define fb_tzid_australia_canberra                   65182 /* Australia/Canberra */
#define fb_tzid_australia_currie                     65181 /* Australia/Currie */
#define fb_tzid_australia_darwin                     65180 /* Australia/Darwin */
#define fb_tzid_australia_eucla                      65179 /* Australia/Eucla */
#define fb_tzid_australia_hobart                     65178 /* Australia/Hobart */
#define fb_tzid_australia_lhi                        65177 /* Australia/LHI */
#define fb_tzid_australia_lindeman                   65176 /* Australia/Lindeman */
#define fb_tzid_australia_lord_howe                  65175 /* Australia/Lord_Howe */
#define fb_tzid_australia_melbourne                  65174 /* Australia/Melbourne */
#define fb_tzid_australia_nsw                        65173 /* Australia/NSW */
#define fb_tzid_australia_north                      65172 /* Australia/North */
#define fb_tzid_australia_perth                      65171 /* Australia/Perth */
#define fb_tzid_australia_queensland                 65170 /* Australia/Queensland */
#define fb_tzid_australia_south                      65169 /* Australia/South */
#define fb_tzid_australia_sydney                     65168 /* Australia/Sydney */
#define fb_tzid_australia_tasmania                   65167 /* Australia/Tasmania */
#define fb_tzid_australia_victoria                   65166 /* Australia/Victoria */
#define fb_tzid_australia_west                       65165 /* Australia/West */
#define fb_tzid_australia_yancowinna                 65164 /* Australia/Yancowinna */
#define fb_tzid_bet                                  65163 /* BET */
#define fb_tzid_bst                                  65162 /* BST */
#define fb_tzid_brazil_acre                          65161 /* Brazil/Acre */
#define fb_tzid_brazil_denoronha                     65160 /* Brazil/DeNoronha */
#define fb_tzid_brazil_east                          65159 /* Brazil/East */
#define fb_tzid_brazil_west                          65158 /* Brazil/West */
#define fb_tzid_cat                                  65157 /* CAT */
#define fb_tzid_cet                                  65156 /* CET */
#define fb_tzid_cnt                                  65155 /* CNT */
#define fb_tzid_cst                                  65154 /* CST */
#define fb_tzid_cst6cdt                              65153 /* CST6CDT */
#define fb_tzid_ctt                                  65152 /* CTT */
#define fb_tzid_canada_atlantic                      65151 /* Canada/Atlantic */
#define fb_tzid_canada_central                       65150 /* Canada/Central */
#define fb_tzid_canada_east_saskatchewan             65149 /* Canada/East-Saskatchewan */
#define fb_tzid_canada_eastern                       65148 /* Canada/Eastern */
#define fb_tzid_canada_mountain                      65147 /* Canada/Mountain */
#define fb_tzid_canada_newfoundland                  65146 /* Canada/Newfoundland */
#define fb_tzid_canada_pacific                       65145 /* Canada/Pacific */
#define fb_tzid_canada_saskatchewan                  65144 /* Canada/Saskatchewan */
#define fb_tzid_canada_yukon                         65143 /* Canada/Yukon */
#define fb_tzid_chile_continental                    65142 /* Chile/Continental */
#define fb_tzid_chile_easterisland                   65141 /* Chile/EasterIsland */
#define fb_tzid_cuba                                 65140 /* Cuba */
#define fb_tzid_eat                                  65139 /* EAT */
#define fb_tzid_ect                                  65138 /* ECT */
#define fb_tzid_eet                                  65137 /* EET */
#define fb_tzid_est                                  65136 /* EST */
#define fb_tzid_est5edt                              65135 /* EST5EDT */
#define fb_tzid_egypt                                65134 /* Egypt */
#define fb_tzid_eire                                 65133 /* Eire */
#define fb_tzid_etc_gmt                              65132 /* Etc/GMT */
#define fb_tzid_etc_gmt_plus_0                       65131 /* Etc/GMT+0 */
#define fb_tzid_etc_gmt_plus_1                       65130 /* Etc/GMT+1 */
#define fb_tzid_etc_gmt_plus_10                      65129 /* Etc/GMT+10 */
#define fb_tzid_etc_gmt_plus_11                      65128 /* Etc/GMT+11 */
#define fb_tzid_etc_gmt_plus_12                      65127 /* Etc/GMT+12 */
#define fb_tzid_etc_gmt_plus_2                       65126 /* Etc/GMT+2 */
#define fb_tzid_etc_gmt_plus_3                       65125 /* Etc/GMT+3 */
#define fb_tzid_etc_gmt_plus_4                       65124 /* Etc/GMT+4 */
#define fb_tzid_etc_gmt_plus_5                       65123 /* Etc/GMT+5 */
#define fb_tzid_etc_gmt_plus_6                       65122 /* Etc/GMT+6 */
#define fb_tzid_etc_gmt_plus_7                       65121 /* Etc/GMT+7 */
#define fb_tzid_etc_gmt_plus_8                       65120 /* Etc/GMT+8 */
#define fb_tzid_etc_gmt_plus_9                       65119 /* Etc/GMT+9 */
#define fb_tzid_etc_gmt_minus_0                      65118 /* Etc/GMT-0 */
#define fb_tzid_etc_gmt_minus_1                      65117 /* Etc/GMT-1 */
#define fb_tzid_etc_gmt_minus_10                     65116 /* Etc/GMT-10 */
#define fb_tzid_etc_gmt_minus_11                     65115 /* Etc/GMT-11 */
#define fb_tzid_etc_gmt_minus_12                     65114 /* Etc/GMT-12 */
#define fb_tzid_etc_gmt_minus_13                     65113 /* Etc/GMT-13 */
#define fb_tzid_etc_gmt_minus_14                     65112 /* Etc/GMT-14 */
#define fb_tzid_etc_gmt_minus_2                      65111 /* Etc/GMT-2 */
#define fb_tzid_etc_gmt_minus_3                      65110 /* Etc/GMT-3 */
#define fb_tzid_etc_gmt_minus_4                      65109 /* Etc/GMT-4 */
#define fb_tzid_etc_gmt_minus_5                      65108 /* Etc/GMT-5 */
#define fb_tzid_etc_gmt_minus_6                      65107 /* Etc/GMT-6 */
#define fb_tzid_etc_gmt_minus_7                      65106 /* Etc/GMT-7 */
#define fb_tzid_etc_gmt_minus_8                      65105 /* Etc/GMT-8 */
#define fb_tzid_etc_gmt_minus_9                      65104 /* Etc/GMT-9 */
#define fb_tzid_etc_gmt0                             65103 /* Etc/GMT0 */
#define fb_tzid_etc_greenwich                        65102 /* Etc/Greenwich */
#define fb_tzid_etc_uct                              65101 /* Etc/UCT */
#define fb_tzid_etc_utc                              65100 /* Etc/UTC */
#define fb_tzid_etc_universal                        65099 /* Etc/Universal */
#define fb_tzid_etc_zulu                             65098 /* Etc/Zulu */
#define fb_tzid_europe_amsterdam                     65097 /* Europe/Amsterdam */
#define fb_tzid_europe_andorra                       65096 /* Europe/Andorra */
#define fb_tzid_europe_astrakhan                     65095 /* Europe/Astrakhan */
#define fb_tzid_europe_athens                        65094 /* Europe/Athens */
#define fb_tzid_europe_belfast                       65093 /* Europe/Belfast */
#define fb_tzid_europe_belgrade                      65092 /* Europe/Belgrade */
#define fb_tzid_europe_berlin                        65091 /* Europe/Berlin */
#define fb_tzid_europe_bratislava                    65090 /* Europe/Bratislava */
#define fb_tzid_europe_brussels                      65089 /* Europe/Brussels */
#define fb_tzid_europe_bucharest                     65088 /* Europe/Bucharest */
#define fb_tzid_europe_budapest                      65087 /* Europe/Budapest */
#define fb_tzid_europe_busingen                      65086 /* Europe/Busingen */
#define fb_tzid_europe_chisinau                      65085 /* Europe/Chisinau */
#define fb_tzid_europe_copenhagen                    65084 /* Europe/Copenhagen */
#define fb_tzid_europe_dublin                        65083 /* Europe/Dublin */
#define fb_tzid_europe_gibraltar                     65082 /* Europe/Gibraltar */
#define fb_tzid_europe_guernsey                      65081 /* Europe/Guernsey */
#define fb_tzid_europe_helsinki                      65080 /* Europe/Helsinki */
#define fb_tzid_europe_isle_of_man                   65079 /* Europe/Isle_of_Man */
#define fb_tzid_europe_istanbul                      65078 /* Europe/Istanbul */
#define fb_tzid_europe_jersey                        65077 /* Europe/Jersey */
#define fb_tzid_europe_kaliningrad                   65076 /* Europe/Kaliningrad */
#define fb_tzid_europe_kiev                          65075 /* Europe/Kiev */
#define fb_tzid_europe_kirov                         65074 /* Europe/Kirov */
#define fb_tzid_europe_lisbon                        65073 /* Europe/Lisbon */
#define fb_tzid_europe_ljubljana                     65072 /* Europe/Ljubljana */
#define fb_tzid_europe_london                        65071 /* Europe/London */
#define fb_tzid_europe_luxembourg                    65070 /* Europe/Luxembourg */
#define fb_tzid_europe_madrid                        65069 /* Europe/Madrid */
#define fb_tzid_europe_malta                         65068 /* Europe/Malta */
#define fb_tzid_europe_mariehamn                     65067 /* Europe/Mariehamn */
#define fb_tzid_europe_minsk                         65066 /* Europe/Minsk */
#define fb_tzid_europe_monaco                        65065 /* Europe/Monaco */
#define fb_tzid_europe_moscow                        65064 /* Europe/Moscow */
#define fb_tzid_europe_nicosia                       65063 /* Europe/Nicosia */
#define fb_tzid_europe_oslo                          65062 /* Europe/Oslo */
#define fb_tzid_europe_paris                         65061 /* Europe/Paris */
#define fb_tzid_europe_podgorica                     65060 /* Europe/Podgorica */
#define fb_tzid_europe_prague                        65059 /* Europe/Prague */
#define fb_tzid_europe_riga                          65058 /* Europe/Riga */
#define fb_tzid_europe_rome                          65057 /* Europe/Rome */
#define fb_tzid_europe_samara                        65056 /* Europe/Samara */
#define fb_tzid_europe_san_marino                    65055 /* Europe/San_Marino */
#define fb_tzid_europe_sarajevo                      65054 /* Europe/Sarajevo */
#define fb_tzid_europe_saratov                       65053 /* Europe/Saratov */
#define fb_tzid_europe_simferopol                    65052 /* Europe/Simferopol */
#define fb_tzid_europe_skopje                        65051 /* Europe/Skopje */
#define fb_tzid_europe_sofia                         65050 /* Europe/Sofia */
#define fb_tzid_europe_stockholm                     65049 /* Europe/Stockholm */
#define fb_tzid_europe_tallinn                       65048 /* Europe/Tallinn */
#define fb_tzid_europe_tirane                        65047 /* Europe/Tirane */
#define fb_tzid_europe_tiraspol                      65046 /* Europe/Tiraspol */
#define fb_tzid_europe_ulyanovsk                     65045 /* Europe/Ulyanovsk */
#define fb_tzid_europe_uzhgorod                      65044 /* Europe/Uzhgorod */
#define fb_tzid_europe_vaduz                         65043 /* Europe/Vaduz */
#define fb_tzid_europe_vatican                       65042 /* Europe/Vatican */
#define fb_tzid_europe_vienna                        65041 /* Europe/Vienna */
#define fb_tzid_europe_vilnius                       65040 /* Europe/Vilnius */
#define fb_tzid_europe_volgograd                     65039 /* Europe/Volgograd */
#define fb_tzid_europe_warsaw                        65038 /* Europe/Warsaw */
#define fb_tzid_europe_zagreb                        65037 /* Europe/Zagreb */
#define fb_tzid_europe_zaporozhye                    65036 /* Europe/Zaporozhye */
#define fb_tzid_europe_zurich                        65035 /* Europe/Zurich */
#define fb_tzid_factory                              65034 /* Factory */
#define fb_tzid_gb                                   65033 /* GB */
#define fb_tzid_gb_eire                              65032 /* GB-Eire */
#define fb_tzid_gmt_plus_0                           65031 /* GMT+0 */
#define fb_tzid_gmt_minus_0                          65030 /* GMT-0 */
#define fb_tzid_gmt0                                 65029 /* GMT0 */
#define fb_tzid_greenwich                            65028 /* Greenwich */
#define fb_tzid_hst                                  65027 /* HST */
#define fb_tzid_hongkong                             65026 /* Hongkong */
#define fb_tzid_iet                                  65025 /* IET */
#define fb_tzid_ist                                  65024 /* IST */
#define fb_tzid_iceland                              65023 /* Iceland */
#define fb_tzid_indian_antananarivo                  65022 /* Indian/Antananarivo */
#define fb_tzid_indian_chagos                        65021 /* Indian/Chagos */
#define fb_tzid_indian_christmas                     65020 /* Indian/Christmas */
#define fb_tzid_indian_cocos                         65019 /* Indian/Cocos */
#define fb_tzid_indian_comoro                        65018 /* Indian/Comoro */
#define fb_tzid_indian_kerguelen                     65017 /* Indian/Kerguelen */
#define fb_tzid_indian_mahe                          65016 /* Indian/Mahe */
#define fb_tzid_indian_maldives                      65015 /* Indian/Maldives */
#define fb_tzid_indian_mauritius                     65014 /* Indian/Mauritius */
#define fb_tzid_indian_mayotte                       65013 /* Indian/Mayotte */
#define fb_tzid_indian_reunion                       65012 /* Indian/Reunion */
#define fb_tzid_iran                                 65011 /* Iran */
#define fb_tzid_israel                               65010 /* Israel */
#define fb_tzid_jst                                  65009 /* JST */
#define fb_tzid_jamaica                              65008 /* Jamaica */
#define fb_tzid_japan                                65007 /* Japan */
#define fb_tzid_kwajalein                            65006 /* Kwajalein */
#define fb_tzid_libya                                65005 /* Libya */
#define fb_tzid_met                                  65004 /* MET */
#define fb_tzid_mit                                  65003 /* MIT */
#define fb_tzid_mst                                  65002 /* MST */
#define fb_tzid_mst7mdt                              65001 /* MST7MDT */
#define fb_tzid_mexico_bajanorte                     65000 /* Mexico/BajaNorte */
#define fb_tzid_mexico_bajasur                       64999 /* Mexico/BajaSur */
#define fb_tzid_mexico_general                       64998 /* Mexico/General */
#define fb_tzid_net                                  64997 /* NET */
#define fb_tzid_nst                                  64996 /* NST */
#define fb_tzid_nz                                   64995 /* NZ */
#define fb_tzid_nz_chat                              64994 /* NZ-CHAT */
#define fb_tzid_navajo                               64993 /* Navajo */
#define fb_tzid_plt                                  64992 /* PLT */
#define fb_tzid_pnt                                  64991 /* PNT */
#define fb_tzid_prc                                  64990 /* PRC */
#define fb_tzid_prt                                  64989 /* PRT */
#define fb_tzid_pst                                  64988 /* PST */
#define fb_tzid_pst8pdt                              64987 /* PST8PDT */
#define fb_tzid_pacific_apia                         64986 /* Pacific/Apia */
#define fb_tzid_pacific_auckland                     64985 /* Pacific/Auckland */
#define fb_tzid_pacific_bougainville                 64984 /* Pacific/Bougainville */
#define fb_tzid_pacific_chatham                      64983 /* Pacific/Chatham */
#define fb_tzid_pacific_chuuk                        64982 /* Pacific/Chuuk */
#define fb_tzid_pacific_easter                       64981 /* Pacific/Easter */
#define fb_tzid_pacific_efate                        64980 /* Pacific/Efate */
#define fb_tzid_pacific_enderbury                    64979 /* Pacific/Enderbury */
#define fb_tzid_pacific_fakaofo                      64978 /* Pacific/Fakaofo */
#define fb_tzid_pacific_fiji                         64977 /* Pacific/Fiji */
#define fb_tzid_pacific_funafuti                     64976 /* Pacific/Funafuti */
#define fb_tzid_pacific_galapagos                    64975 /* Pacific/Galapagos */
#define fb_tzid_pacific_gambier                      64974 /* Pacific/Gambier */
#define fb_tzid_pacific_guadalcanal                  64973 /* Pacific/Guadalcanal */
#define fb_tzid_pacific_guam                         64972 /* Pacific/Guam */
#define fb_tzid_pacific_honolulu                     64971 /* Pacific/Honolulu */
#define fb_tzid_pacific_johnston                     64970 /* Pacific/Johnston */
#define fb_tzid_pacific_kiritimati                   64969 /* Pacific/Kiritimati */
#define fb_tzid_pacific_kosrae                       64968 /* Pacific/Kosrae */
#define fb_tzid_pacific_kwajalein                    64967 /* Pacific/Kwajalein */
#define fb_tzid_pacific_majuro                       64966 /* Pacific/Majuro */
#define fb_tzid_pacific_marquesas                    64965 /* Pacific/Marquesas */
#define fb_tzid_pacific_midway                       64964 /* Pacific/Midway */
#define fb_tzid_pacific_nauru                        64963 /* Pacific/Nauru */
#define fb_tzid_pacific_niue                         64962 /* Pacific/Niue */
#define fb_tzid_pacific_norfolk                      64961 /* Pacific/Norfolk */
#define fb_tzid_pacific_noumea                       64960 /* Pacific/Noumea */
#define fb_tzid_pacific_pago_pago                    64959 /* Pacific/Pago_Pago */
#define fb_tzid_pacific_palau                        64958 /* Pacific/Palau */
#define fb_tzid_pacific_pitcairn                     64957 /* Pacific/Pitcairn */
#define fb_tzid_pacific_pohnpei                      64956 /* Pacific/Pohnpei */
#define fb_tzid_pacific_ponape                       64955 /* Pacific/Ponape */
#define fb_tzid_pacific_port_moresby                 64954 /* Pacific/Port_Moresby */
#define fb_tzid_pacific_rarotonga                    64953 /* Pacific/Rarotonga */
#define fb_tzid_pacific_saipan                       64952 /* Pacific/Saipan */
#define fb_tzid_pacific_samoa                        64951 /* Pacific/Samoa */
#define fb_tzid_pacific_tahiti                       64950 /* Pacific/Tahiti */
#define fb_tzid_pacific_tarawa                       64949 /* Pacific/Tarawa */
#define fb_tzid_pacific_tongatapu                    64948 /* Pacific/Tongatapu */
#define fb_tzid_pacific_truk                         64947 /* Pacific/Truk */
#define fb_tzid_pacific_wake                         64946 /* Pacific/Wake */
#define fb_tzid_pacific_wallis                       64945 /* Pacific/Wallis */
#define fb_tzid_pacific_yap                          64944 /* Pacific/Yap */
#define fb_tzid_poland                               64943 /* Poland */
#define fb_tzid_portugal                             64942 /* Portugal */
#define fb_tzid_roc                                  64941 /* ROC */
#define fb_tzid_rok                                  64940 /* ROK */
#define fb_tzid_sst                                  64939 /* SST */
#define fb_tzid_singapore                            64938 /* Singapore */
#define fb_tzid_systemv_ast4                         64937 /* SystemV/AST4 */
#define fb_tzid_systemv_ast4adt                      64936 /* SystemV/AST4ADT */
#define fb_tzid_systemv_cst6                         64935 /* SystemV/CST6 */
#define fb_tzid_systemv_cst6cdt                      64934 /* SystemV/CST6CDT */
#define fb_tzid_systemv_est5                         64933 /* SystemV/EST5 */
#define fb_tzid_systemv_est5edt                      64932 /* SystemV/EST5EDT */
#define fb_tzid_systemv_hst10                        64931 /* SystemV/HST10 */
#define fb_tzid_systemv_mst7                         64930 /* SystemV/MST7 */
#define fb_tzid_systemv_mst7mdt                      64929 /* SystemV/MST7MDT */
#define fb_tzid_systemv_pst8                         64928 /* SystemV/PST8 */
#define fb_tzid_systemv_pst8pdt                      64927 /* SystemV/PST8PDT */
#define fb_tzid_systemv_yst9                         64926 /* SystemV/YST9 */
#define fb_tzid_systemv_yst9ydt                      64925 /* SystemV/YST9YDT */
#define fb_tzid_turkey                               64924 /* Turkey */
#define fb_tzid_uct                                  64923 /* UCT */
#define fb_tzid_us_alaska                            64922 /* US/Alaska */
#define fb_tzid_us_aleutian                          64921 /* US/Aleutian */
#define fb_tzid_us_arizona                           64920 /* US/Arizona */
#define fb_tzid_us_central                           64919 /* US/Central */
#define fb_tzid_us_east_indiana                      64918 /* US/East-Indiana */
#define fb_tzid_us_eastern                           64917 /* US/Eastern */
#define fb_tzid_us_hawaii                            64916 /* US/Hawaii */
#define fb_tzid_us_indiana_starke                    64915 /* US/Indiana-Starke */
#define fb_tzid_us_michigan                          64914 /* US/Michigan */
#define fb_tzid_us_mountain                          64913 /* US/Mountain */
#define fb_tzid_us_pacific                           64912 /* US/Pacific */
#define fb_tzid_us_pacific_new                       64911 /* US/Pacific-New */
#define fb_tzid_us_samoa                             64910 /* US/Samoa */
#define fb_tzid_utc                                  64909 /* UTC */
#define fb_tzid_universal                            64908 /* Universal */
#define fb_tzid_vst                                  64907 /* VST */
#define fb_tzid_w_su                                 64906 /* W-SU */
#define fb_tzid_wet                                  64905 /* WET */
#define fb_tzid_zulu                                 64904 /* Zulu */
#define fb_tzid_america_nuuk                         64903 /* America/Nuuk */
#define fb_tzid_asia_qostanay                        64902 /* Asia/Qostanay */
#define fb_tzid_pacific_kanton                       64901 /* Pacific/Kanton */
#define fb_tzid_europe_kyiv                          64900 /* Europe/Kyiv */
#define fb_tzid_america_ciudad_juarez                64899 /* America/Ciudad_Juarez */
#define fb_tzid_america_coyhaique                    64898 /* America/Coyhaique */

#endif /* FIREBIRD_TIME_ZONES_H */
