/*
 * The contents of this file are subject to the Interbase Public
 * License Version 1.0 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a copy
 * of the License at http://www.Inprise.com/IPL.html
 * 
 * Software distributed under the License is distributed on an
 * "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express
 * or implied. See the License for the specific language governing
 * rights and limitations under the License.
 * 
 * *** WARNING *** - This file is automatically generated
 */

#define isc_arith_except 335544321L
#define isc_bad_dbkey 335544322L
#define isc_bad_db_format 335544323L
#define isc_bad_db_handle 335544324L
#define isc_bad_dpb_content 335544325L
#define isc_bad_dpb_form 335544326L
#define isc_bad_req_handle 335544327L
#define isc_bad_segstr_handle 335544328L
#define isc_bad_segstr_id 335544329L
#define isc_bad_tpb_content 335544330L
#define isc_bad_tpb_form 335544331L
#define isc_bad_trans_handle 335544332L
#define isc_bug_check 335544333L
#define isc_convert_error 335544334L
#define isc_db_corrupt 335544335L
#define isc_deadlock 335544336L
#define isc_excess_trans 335544337L
#define isc_from_no_match 335544338L
#define isc_infinap 335544339L
#define isc_infona 335544340L
#define isc_infunk 335544341L
#define isc_integ_fail 335544342L
#define isc_invalid_blr 335544343L
#define isc_io_error 335544344L
#define isc_lock_conflict 335544345L
#define isc_metadata_corrupt 335544346L
#define isc_not_valid 335544347L
#define isc_no_cur_rec 335544348L
#define isc_no_dup 335544349L
#define isc_no_finish 335544350L
#define isc_no_meta_update 335544351L
#define isc_no_priv 335544352L
#define isc_no_recon 335544353L
#define isc_no_record 335544354L
#define isc_no_segstr_close 335544355L
#define isc_obsolete_metadata 335544356L
#define isc_open_trans 335544357L
#define isc_port_len 335544358L
#define isc_read_only_field 335544359L
#define isc_read_only_rel 335544360L
#define isc_read_only_trans 335544361L
#define isc_read_only_view 335544362L
#define isc_req_no_trans 335544363L
#define isc_req_sync 335544364L
#define isc_req_wrong_db 335544365L
#define isc_segment 335544366L
#define isc_segstr_eof 335544367L
#define isc_segstr_no_op 335544368L
#define isc_segstr_no_read 335544369L
#define isc_segstr_no_trans 335544370L
#define isc_segstr_no_write 335544371L
#define isc_segstr_wrong_db 335544372L
#define isc_sys_request 335544373L
#define isc_stream_eof 335544374L
#define isc_unavailable 335544375L
#define isc_unres_rel 335544376L
#define isc_uns_ext 335544377L
#define isc_wish_list 335544378L
#define isc_wrong_ods 335544379L
#define isc_wronumarg 335544380L
#define isc_imp_exc 335544381L
#define isc_random 335544382L
#define isc_fatal_conflict 335544383L
#define isc_badblk 335544384L
#define isc_invpoolcl 335544385L
#define isc_nopoolids 335544386L
#define isc_relbadblk 335544387L
#define isc_blktoobig 335544388L
#define isc_bufexh 335544389L
#define isc_syntaxerr 335544390L
#define isc_bufinuse 335544391L
#define isc_bdbincon 335544392L
#define isc_reqinuse 335544393L
#define isc_badodsver 335544394L
#define isc_relnotdef 335544395L
#define isc_fldnotdef 335544396L
#define isc_dirtypage 335544397L
#define isc_waifortra 335544398L
#define isc_doubleloc 335544399L
#define isc_nodnotfnd 335544400L
#define isc_dupnodfnd 335544401L
#define isc_locnotmar 335544402L
#define isc_badpagtyp 335544403L
#define isc_corrupt 335544404L
#define isc_badpage 335544405L
#define isc_badindex 335544406L
#define isc_dbbnotzer 335544407L
#define isc_tranotzer 335544408L
#define isc_trareqmis 335544409L
#define isc_badhndcnt 335544410L
#define isc_wrotpbver 335544411L
#define isc_wroblrver 335544412L
#define isc_wrodpbver 335544413L
#define isc_blobnotsup 335544414L
#define isc_badrelation 335544415L
#define isc_nodetach 335544416L
#define isc_notremote 335544417L
#define isc_trainlim 335544418L
#define isc_notinlim 335544419L
#define isc_traoutsta 335544420L
#define isc_connect_reject 335544421L
#define isc_dbfile 335544422L
#define isc_orphan 335544423L
#define isc_no_lock_mgr 335544424L
#define isc_ctxinuse 335544425L
#define isc_ctxnotdef 335544426L
#define isc_datnotsup 335544427L
#define isc_badmsgnum 335544428L
#define isc_badparnum 335544429L
#define isc_virmemexh 335544430L
#define isc_blocking_signal 335544431L
#define isc_lockmanerr 335544432L
#define isc_journerr 335544433L
#define isc_keytoobig 335544434L
#define isc_nullsegkey 335544435L
#define isc_sqlerr 335544436L
#define isc_wrodynver 335544437L
#define isc_funnotdef 335544438L
#define isc_funmismat 335544439L
#define isc_bad_msg_vec 335544440L
#define isc_bad_detach 335544441L
#define isc_noargacc_read 335544442L
#define isc_noargacc_write 335544443L
#define isc_read_only 335544444L
#define isc_ext_err 335544445L
#define isc_non_updatable 335544446L
#define isc_no_rollback 335544447L
#define isc_bad_sec_info 335544448L
#define isc_invalid_sec_info 335544449L
#define isc_misc_interpreted 335544450L
#define isc_update_conflict 335544451L
#define isc_unlicensed 335544452L
#define isc_obj_in_use 335544453L
#define isc_nofilter 335544454L
#define isc_shadow_accessed 335544455L
#define isc_invalid_sdl 335544456L
#define isc_out_of_bounds 335544457L
#define isc_invalid_dimension 335544458L
#define isc_rec_in_limbo 335544459L
#define isc_shadow_missing 335544460L
#define isc_cant_validate 335544461L
#define isc_cant_start_journal 335544462L
#define isc_gennotdef 335544463L
#define isc_cant_start_logging 335544464L
#define isc_bad_segstr_type 335544465L
#define isc_foreign_key 335544466L
#define isc_high_minor 335544467L
#define isc_tra_state 335544468L
#define isc_trans_invalid 335544469L
#define isc_buf_invalid 335544470L
#define isc_indexnotdefined 335544471L
#define isc_login 335544472L
#define isc_invalid_bookmark 335544473L
#define isc_bad_lock_level 335544474L
#define isc_relation_lock 335544475L
#define isc_record_lock 335544476L
#define isc_max_idx 335544477L
#define isc_jrn_enable 335544478L
#define isc_old_failure 335544479L
#define isc_old_in_progress 335544480L
#define isc_old_no_space 335544481L
#define isc_no_wal_no_jrn 335544482L
#define isc_num_old_files 335544483L
#define isc_wal_file_open 335544484L
#define isc_bad_stmt_handle 335544485L
#define isc_wal_failure 335544486L
#define isc_walw_err 335544487L
#define isc_logh_small 335544488L
#define isc_logh_inv_version 335544489L
#define isc_logh_open_flag 335544490L
#define isc_logh_open_flag2 335544491L
#define isc_logh_diff_dbname 335544492L
#define isc_logf_unexpected_eof 335544493L
#define isc_logr_incomplete 335544494L
#define isc_logr_header_small 335544495L
#define isc_logb_small 335544496L
#define isc_wal_illegal_attach 335544497L
#define isc_wal_invalid_wpb 335544498L
#define isc_wal_err_rollover 335544499L
#define isc_no_wal 335544500L
#define isc_drop_wal 335544501L
#define isc_stream_not_defined 335544502L
#define isc_wal_subsys_error 335544503L
#define isc_wal_subsys_corrupt 335544504L
#define isc_no_archive 335544505L
#define isc_shutinprog 335544506L
#define isc_range_in_use 335544507L
#define isc_range_not_found 335544508L
#define isc_charset_not_found 335544509L
#define isc_lock_timeout 335544510L
#define isc_prcnotdef 335544511L
#define isc_prcmismat 335544512L
#define isc_wal_bugcheck 335544513L
#define isc_wal_cant_expand 335544514L
#define isc_codnotdef 335544515L
#define isc_xcpnotdef 335544516L
#define isc_except 335544517L
#define isc_cache_restart 335544518L
#define isc_bad_lock_handle 335544519L
#define isc_jrn_present 335544520L
#define isc_wal_err_rollover2 335544521L
#define isc_wal_err_logwrite 335544522L
#define isc_wal_err_jrn_comm 335544523L
#define isc_wal_err_expansion 335544524L
#define isc_wal_err_setup 335544525L
#define isc_wal_err_ww_sync 335544526L
#define isc_wal_err_ww_start 335544527L
#define isc_shutdown 335544528L
#define isc_existing_priv_mod 335544529L
#define isc_primary_key_ref 335544530L
#define isc_primary_key_notnull 335544531L
#define isc_ref_cnstrnt_notfound 335544532L
#define isc_foreign_key_notfound 335544533L
#define isc_ref_cnstrnt_update 335544534L
#define isc_check_cnstrnt_update 335544535L
#define isc_check_cnstrnt_del 335544536L
#define isc_integ_index_seg_del 335544537L
#define isc_integ_index_seg_mod 335544538L
#define isc_integ_index_del 335544539L
#define isc_integ_index_mod 335544540L
#define isc_check_trig_del 335544541L
#define isc_check_trig_update 335544542L
#define isc_cnstrnt_fld_del 335544543L
#define isc_cnstrnt_fld_rename 335544544L
#define isc_rel_cnstrnt_update 335544545L
#define isc_constaint_on_view 335544546L
#define isc_invld_cnstrnt_type 335544547L
#define isc_primary_key_exists 335544548L
#define isc_systrig_update 335544549L
#define isc_not_rel_owner 335544550L
#define isc_grant_obj_notfound 335544551L
#define isc_grant_fld_notfound 335544552L
#define isc_grant_nopriv 335544553L
#define isc_nonsql_security_rel 335544554L
#define isc_nonsql_security_fld 335544555L
#define isc_wal_cache_err 335544556L
#define isc_shutfail 335544557L
#define isc_check_constraint 335544558L
#define isc_bad_svc_handle 335544559L
#define isc_shutwarn 335544560L
#define isc_wrospbver 335544561L
#define isc_bad_spb_form 335544562L
#define isc_svcnotdef 335544563L
#define isc_no_jrn 335544564L
#define isc_transliteration_failed 335544565L
#define isc_start_cm_for_wal 335544566L
#define isc_wal_ovflow_log_required 335544567L
#define isc_text_subtype 335544568L
#define isc_dsql_error 335544569L
#define isc_dsql_command_err 335544570L
#define isc_dsql_constant_err 335544571L
#define isc_dsql_cursor_err 335544572L
#define isc_dsql_datatype_err 335544573L
#define isc_dsql_decl_err 335544574L
#define isc_dsql_cursor_update_err 335544575L
#define isc_dsql_cursor_open_err 335544576L
#define isc_dsql_cursor_close_err 335544577L
#define isc_dsql_field_err 335544578L
#define isc_dsql_internal_err 335544579L
#define isc_dsql_relation_err 335544580L
#define isc_dsql_procedure_err 335544581L
#define isc_dsql_request_err 335544582L
#define isc_dsql_sqlda_err 335544583L
#define isc_dsql_var_count_err 335544584L
#define isc_dsql_stmt_handle 335544585L
#define isc_dsql_function_err 335544586L
#define isc_dsql_blob_err 335544587L
#define isc_collation_not_found 335544588L
#define isc_collation_not_for_charset 335544589L
#define isc_dsql_dup_option 335544590L
#define isc_dsql_tran_err 335544591L
#define isc_dsql_invalid_array 335544592L
#define isc_dsql_max_arr_dim_exceeded 335544593L
#define isc_dsql_arr_range_error 335544594L
#define isc_dsql_trigger_err 335544595L
#define isc_dsql_subselect_err 335544596L
#define isc_dsql_crdb_prepare_err 335544597L
#define isc_specify_field_err 335544598L
#define isc_num_field_err 335544599L
#define isc_col_name_err 335544600L
#define isc_where_err 335544601L
#define isc_table_view_err 335544602L
#define isc_distinct_err 335544603L
#define isc_key_field_count_err 335544604L
#define isc_subquery_err 335544605L
#define isc_expression_eval_err 335544606L
#define isc_node_err 335544607L
#define isc_command_end_err 335544608L
#define isc_index_name 335544609L
#define isc_exception_name 335544610L
#define isc_field_name 335544611L
#define isc_token_err 335544612L
#define isc_union_err 335544613L
#define isc_dsql_construct_err 335544614L
#define isc_field_aggregate_err 335544615L
#define isc_field_ref_err 335544616L
#define isc_order_by_err 335544617L
#define isc_return_mode_err 335544618L
#define isc_extern_func_err 335544619L
#define isc_alias_conflict_err 335544620L
#define isc_procedure_conflict_error 335544621L
#define isc_relation_conflict_err 335544622L
#define isc_dsql_domain_err 335544623L
#define isc_idx_seg_err 335544624L
#define isc_node_name_err 335544625L
#define isc_table_name 335544626L
#define isc_proc_name 335544627L
#define isc_idx_create_err 335544628L
#define isc_wal_shadow_err 335544629L
#define isc_dependency 335544630L
#define isc_idx_key_err 335544631L
#define isc_dsql_file_length_err 335544632L
#define isc_dsql_shadow_number_err 335544633L
#define isc_dsql_token_unk_err 335544634L
#define isc_dsql_no_relation_alias 335544635L
#define isc_indexname 335544636L
#define isc_no_stream_plan 335544637L
#define isc_stream_twice 335544638L
#define isc_stream_not_found 335544639L
#define isc_collation_requires_text 335544640L
#define isc_dsql_domain_not_found 335544641L
#define isc_index_unused 335544642L
#define isc_dsql_self_join 335544643L
#define isc_stream_bof 335544644L
#define isc_stream_crack 335544645L
#define isc_db_or_file_exists 335544646L
#define isc_invalid_operator 335544647L
#define isc_conn_lost 335544648L
#define isc_bad_checksum 335544649L
#define isc_page_type_err 335544650L
#define isc_ext_readonly_err 335544651L
#define isc_sing_select_err 335544652L
#define isc_psw_attach 335544653L
#define isc_psw_start_trans 335544654L
#define isc_invalid_direction 335544655L
#define isc_dsql_var_conflict 335544656L
#define isc_dsql_no_blob_array 335544657L
#define isc_dsql_base_table 335544658L
#define isc_duplicate_base_table 335544659L
#define isc_view_alias 335544660L
#define isc_index_root_page_full 335544661L
#define isc_dsql_blob_type_unknown 335544662L
#define isc_req_max_clones_exceeded 335544663L
#define isc_dsql_duplicate_spec 335544664L
#define isc_unique_key_violation 335544665L
#define isc_srvr_version_too_old 335544666L
#define isc_drdb_completed_with_errs 335544667L
#define isc_dsql_procedure_use_err 335544668L
#define isc_dsql_count_mismatch 335544669L
#define isc_blob_idx_err 335544670L
#define isc_array_idx_err 335544671L
#define isc_key_field_err 335544672L
#define isc_no_delete 335544673L
#define isc_del_last_field 335544674L
#define isc_sort_err 335544675L
#define isc_sort_mem_err 335544676L
#define isc_version_err 335544677L
#define isc_inval_key_posn 335544678L
#define isc_no_segments_err 335544679L
#define isc_crrp_data_err 335544680L
#define isc_rec_size_err 335544681L
#define isc_dsql_field_ref 335544682L
#define isc_req_depth_exceeded 335544683L
#define isc_no_field_access 335544684L
#define isc_no_dbkey 335544685L
#define isc_jrn_format_err 335544686L
#define isc_jrn_file_full 335544687L
#define isc_dsql_open_cursor_request 335544688L
#define isc_ib_error 335544689L
#define isc_cache_redef 335544690L
#define isc_cache_too_small 335544691L
#define isc_log_redef 335544692L
#define isc_log_too_small 335544693L
#define isc_partition_too_small 335544694L
#define isc_partition_not_supp 335544695L
#define isc_log_length_spec 335544696L
#define isc_precision_err 335544697L
#define isc_scale_nogt 335544698L
#define isc_expec_short 335544699L
#define isc_expec_long 335544700L
#define isc_expec_ushort 335544701L
#define isc_escape_invalid 335544702L
#define isc_svcnoexe 335544703L
#define isc_net_lookup_err 335544704L
#define isc_service_unknown 335544705L
#define isc_host_unknown 335544706L
#define isc_grant_nopriv_on_base 335544707L
#define isc_dyn_fld_ambiguous 335544708L
#define isc_dsql_agg_ref_err 335544709L
#define isc_complex_view 335544710L
#define isc_unprepared_stmt 335544711L
#define isc_expec_positive 335544712L
#define isc_dsql_sqlda_value_err 335544713L
#define isc_invalid_array_id 335544714L
#define isc_extfile_uns_op 335544715L
#define isc_svc_in_use 335544716L
#define isc_err_stack_limit 335544717L
#define isc_invalid_key 335544718L
#define isc_net_init_error 335544719L
#define isc_loadlib_failure 335544720L
#define isc_network_error 335544721L
#define isc_net_connect_err 335544722L
#define isc_net_connect_listen_err 335544723L
#define isc_net_event_connect_err 335544724L
#define isc_net_event_listen_err 335544725L
#define isc_net_read_err 335544726L
#define isc_net_write_err 335544727L
#define isc_integ_index_deactivate 335544728L
#define isc_integ_deactivate_primary 335544729L
#define isc_cse_not_supported 335544730L
#define isc_tra_must_sweep 335544731L
#define isc_unsupported_network_drive 335544732L
#define isc_io_create_err 335544733L
#define isc_io_open_err 335544734L
#define isc_io_close_err 335544735L
#define isc_io_read_err 335544736L
#define isc_io_write_err 335544737L
#define isc_io_delete_err 335544738L
#define isc_io_access_err 335544739L
#define isc_udf_exception 335544740L
#define isc_lost_db_connection 335544741L
#define isc_no_write_user_priv 335544742L
#define isc_token_too_long 335544743L
#define isc_max_att_exceeded 335544744L
#define isc_login_same_as_role_name 335544745L
#define isc_reftable_requires_pk 335544746L
#define isc_usrname_too_long 335544747L
#define isc_password_too_long 335544748L
#define isc_usrname_required 335544749L
#define isc_password_required 335544750L
#define isc_bad_protocol 335544751L
#define isc_dup_usrname_found 335544752L
#define isc_usrname_not_found 335544753L
#define isc_error_adding_sec_record 335544754L
#define isc_error_modifying_sec_record 335544755L
#define isc_error_deleting_sec_record 335544756L
#define isc_error_updating_sec_db 335544757L
#define isc_sort_rec_size_err 335544758L
#define isc_bad_default_value 335544759L
#define isc_invalid_clause 335544760L
#define isc_too_many_handles 335544761L
#define isc_optimizer_blk_exc 335544762L
#define isc_invalid_string_constant 335544763L
#define isc_transitional_date 335544764L
#define isc_read_only_database 335544765L
#define isc_must_be_dialect_2_and_up 335544766L
#define isc_blob_filter_exception 335544767L
#define isc_exception_access_violation 335544768L
#define isc_exception_datatype_missalignment 335544769L
#define isc_exception_array_bounds_exceeded 335544770L
#define isc_exception_float_denormal_operand 335544771L
#define isc_exception_float_divide_by_zero 335544772L
#define isc_exception_float_inexact_result 335544773L
#define isc_exception_float_invalid_operand 335544774L
#define isc_exception_float_overflow 335544775L
#define isc_exception_float_stack_check 335544776L
#define isc_exception_float_underflow 335544777L
#define isc_exception_integer_divide_by_zero 335544778L
#define isc_exception_integer_overflow 335544779L
#define isc_exception_unknown 335544780L
#define isc_exception_stack_overflow 335544781L
#define isc_exception_sigsegv 335544782L
#define isc_exception_sigill 335544783L
#define isc_exception_sigbus 335544784L
#define isc_exception_sigfpe 335544785L
#define isc_ext_file_delete 335544786L
#define isc_ext_file_modify 335544787L
#define isc_adm_task_denied 335544788L
#define isc_extract_input_mismatch 335544789L
#define isc_insufficient_svc_privileges 335544790L
#define isc_file_in_use 335544791L
#define isc_service_att_err 335544792L
#define isc_ddl_not_allowed_by_db_sql_dial 335544793L
#define isc_cancelled 335544794L
#define isc_unexp_spb_form 335544795L
#define isc_sql_dialect_datatype_unsupport 335544796L
#define isc_svcnouser 335544797L
#define isc_depend_on_uncommitted_rel 335544798L
#define isc_svc_name_missing 335544799L
#define isc_too_many_contexts 335544800L
#define isc_datype_notsup 335544801L
#define isc_dialect_reset_warning 335544802L
#define isc_dialect_not_changed 335544803L
#define isc_database_create_failed 335544804L
#define isc_inv_dialect_specified 335544805L
#define isc_valid_db_dialects 335544806L
#define isc_sqlwarn 335544807L
#define isc_dtype_renamed 335544808L
#define isc_extern_func_dir_error 335544809L
#define isc_date_range_exceeded 335544810L
#define isc_inv_client_dialect_specified 335544811L
#define isc_valid_client_dialects 335544812L
#define isc_optimizer_between_err 335544813L
#define isc_service_not_supported 335544814L
#define isc_generator_name 335544815L
#define isc_udf_name 335544816L
#define isc_bad_limit_param 335544817L
#define isc_bad_skip_param 335544818L
#define isc_io_32bit_exceeded_err 335544819L
#define isc_invalid_savepoint 335544820L
#define isc_dsql_column_pos_err 335544821L
#define isc_dsql_agg_where_err 335544822L
#define isc_dsql_agg_group_err 335544823L
#define isc_dsql_agg_column_err 335544824L
#define isc_dsql_agg_having_err 335544825L
#define isc_dsql_agg_nested_err 335544826L
#define isc_exec_sql_invalid_arg 335544827L
#define isc_exec_sql_invalid_req 335544828L
#define isc_exec_sql_invalid_var 335544829L
#define isc_exec_sql_max_call_exceeded 335544830L
#define isc_conf_access_denied 335544831L
#define isc_wrong_backup_state 335544832L
#define isc_wal_backup_err 335544833L
#define isc_cursor_not_open 335544834L
#define isc_bad_shutdown_mode 335544835L
#define isc_concat_overflow 335544836L
#define isc_bad_substring_offset 335544837L
#define isc_foreign_key_target_doesnt_exist 335544838L
#define isc_foreign_key_references_present 335544839L
#define isc_no_update 335544840L
#define isc_cursor_already_open 335544841L
#define isc_stack_trace 335544842L
#define isc_ctx_var_not_found 335544843L
#define isc_ctx_namespace_invalid 335544844L
#define isc_ctx_too_big 335544845L
#define isc_ctx_bad_argument 335544846L
#define isc_identifier_too_long 335544847L
#define isc_except2 335544848L
#define isc_malformed_string 335544849L
#define isc_prc_out_param_mismatch 335544850L
#define isc_command_end_err2 335544851L
#define isc_partner_idx_incompat_type 335544852L
#define isc_bad_substring_length 335544853L
#define isc_charset_not_installed 335544854L
#define isc_collation_not_installed 335544855L
#define isc_att_shutdown 335544856L
#define isc_blobtoobig 335544857L
#define isc_must_have_phys_field 335544858L
#define isc_invalid_time_precision 335544859L
#define isc_blob_convert_error 335544860L
#define isc_array_convert_error 335544861L
#define isc_record_lock_not_supp 335544862L
#define isc_partner_idx_not_found 335544863L
#define isc_tra_num_exc 335544864L
#define isc_field_disappeared 335544865L
#define isc_met_wrong_gtt_scope 335544866L
#define isc_subtype_for_internal_use 335544867L
#define isc_illegal_prc_type 335544868L
#define isc_invalid_sort_datatype 335544869L
#define isc_collation_name 335544870L
#define isc_domain_name 335544871L
#define isc_domnotdef 335544872L
#define isc_array_max_dimensions 335544873L
#define isc_max_db_per_trans_allowed 335544874L
#define isc_bad_debug_format 335544875L
#define isc_bad_proc_BLR 335544876L
#define isc_key_too_big 335544877L
#define isc_concurrent_transaction 335544878L
#define isc_not_valid_for_var 335544879L
#define isc_not_valid_for 335544880L
#define isc_need_difference 335544881L
#define isc_long_login 335544882L
#define isc_fldnotdef2 335544883L
#define isc_invalid_similar_pattern 335544884L
#define isc_bad_teb_form 335544885L
#define isc_tpb_multiple_txn_isolation 335544886L
#define isc_tpb_reserv_before_table 335544887L
#define isc_tpb_multiple_spec 335544888L
#define isc_tpb_option_without_rc 335544889L
#define isc_tpb_conflicting_options 335544890L
#define isc_tpb_reserv_missing_tlen 335544891L
#define isc_tpb_reserv_long_tlen 335544892L
#define isc_tpb_reserv_missing_tname 335544893L
#define isc_tpb_reserv_corrup_tlen 335544894L
#define isc_tpb_reserv_null_tlen 335544895L
#define isc_tpb_reserv_relnotfound 335544896L
#define isc_tpb_reserv_baserelnotfound 335544897L
#define isc_tpb_missing_len 335544898L
#define isc_tpb_missing_value 335544899L
#define isc_tpb_corrupt_len 335544900L
#define isc_tpb_null_len 335544901L
#define isc_tpb_overflow_len 335544902L
#define isc_tpb_invalid_value 335544903L
#define isc_tpb_reserv_stronger_wng 335544904L
#define isc_tpb_reserv_stronger 335544905L
#define isc_tpb_reserv_max_recursion 335544906L
#define isc_tpb_reserv_virtualtbl 335544907L
#define isc_tpb_reserv_systbl 335544908L
#define isc_tpb_reserv_temptbl 335544909L
#define isc_tpb_readtxn_after_writelock 335544910L
#define isc_tpb_writelock_after_readtxn 335544911L
#define isc_time_range_exceeded 335544912L
#define isc_datetime_range_exceeded 335544913L
#define isc_string_truncation 335544914L
#define isc_blob_truncation 335544915L
#define isc_numeric_out_of_range 335544916L
#define isc_shutdown_timeout 335544917L
#define isc_att_handle_busy 335544918L
#define isc_bad_udf_freeit 335544919L
#define isc_eds_provider_not_found 335544920L
#define isc_eds_connection 335544921L
#define isc_eds_preprocess 335544922L
#define isc_eds_stmt_expected 335544923L
#define isc_eds_prm_name_expected 335544924L
#define isc_eds_unclosed_comment 335544925L
#define isc_eds_statement 335544926L
#define isc_eds_input_prm_mismatch 335544927L
#define isc_eds_output_prm_mismatch 335544928L
#define isc_eds_input_prm_not_set 335544929L
#define isc_too_big_blr 335544930L
#define isc_montabexh 335544931L
#define isc_modnotfound 335544932L
#define isc_nothing_to_cancel 335544933L
#define isc_ibutil_not_loaded 335544934L
#define isc_circular_computed 335544935L
#define isc_psw_db_error 335544936L
#define isc_invalid_type_datetime_op 335544937L
#define isc_onlycan_add_timetodate 335544938L
#define isc_onlycan_add_datetotime 335544939L
#define isc_onlycansub_tstampfromtstamp 335544940L
#define isc_onlyoneop_mustbe_tstamp 335544941L
#define isc_invalid_extractpart_time 335544942L
#define isc_invalid_extractpart_date 335544943L
#define isc_invalidarg_extract 335544944L
#define isc_sysf_argmustbe_exact 335544945L
#define isc_sysf_argmustbe_exact_or_fp 335544946L
#define isc_sysf_argviolates_uuidtype 335544947L
#define isc_sysf_argviolates_uuidlen 335544948L
#define isc_sysf_argviolates_uuidfmt 335544949L
#define isc_sysf_argviolates_guidigits 335544950L
#define isc_sysf_invalid_addpart_time 335544951L
#define isc_sysf_invalid_add_datetime 335544952L
#define isc_sysf_invalid_addpart_dtime 335544953L
#define isc_sysf_invalid_add_dtime_rc 335544954L
#define isc_sysf_invalid_diff_dtime 335544955L
#define isc_sysf_invalid_timediff 335544956L
#define isc_sysf_invalid_tstamptimediff 335544957L
#define isc_sysf_invalid_datetimediff 335544958L
#define isc_sysf_invalid_diffpart 335544959L
#define isc_sysf_argmustbe_positive 335544960L
#define isc_sysf_basemustbe_positive 335544961L
#define isc_sysf_argnmustbe_nonneg 335544962L
#define isc_sysf_argnmustbe_positive 335544963L
#define isc_sysf_invalid_zeropowneg 335544964L
#define isc_sysf_invalid_negpowfp 335544965L
#define isc_sysf_invalid_scale 335544966L
#define isc_sysf_argmustbe_nonneg 335544967L
#define isc_sysf_binuuid_mustbe_str 335544968L
#define isc_sysf_binuuid_wrongsize 335544969L
#define isc_missing_required_spb 335544970L
#define isc_net_server_shutdown 335544971L
#define isc_bad_conn_str 335544972L
#define isc_bad_epb_form 335544973L
#define isc_no_threads 335544974L
#define isc_net_event_connect_timeout 335544975L
#define isc_sysf_argmustbe_nonzero 335544976L
#define isc_sysf_argmustbe_range_inc1_1 335544977L
#define isc_sysf_argmustbe_gteq_one 335544978L
#define isc_sysf_argmustbe_range_exc1_1 335544979L
#define isc_internal_rejected_params 335544980L
#define isc_sysf_fp_overflow 335544981L
#define isc_udf_fp_overflow 335544982L
#define isc_udf_fp_nan 335544983L
#define isc_instance_conflict 335544984L
#define isc_out_of_temp_space 335544985L
#define isc_eds_expl_tran_ctrl 335544986L
#define isc_no_trusted_spb 335544987L
#define isc_package_name 335544988L
#define isc_cannot_make_not_null 335544989L
#define isc_feature_removed 335544990L
#define isc_view_name 335544991L
#define isc_lock_dir_access 335544992L
#define isc_invalid_fetch_option 335544993L
#define isc_bad_fun_BLR 335544994L
#define isc_func_pack_not_implemented 335544995L
#define isc_proc_pack_not_implemented 335544996L
#define isc_eem_func_not_returned 335544997L
#define isc_eem_proc_not_returned 335544998L
#define isc_eem_trig_not_returned 335544999L
#define isc_eem_bad_plugin_ver 335545000L
#define isc_eem_engine_notfound 335545001L
#define isc_attachment_in_use 335545002L
#define isc_transaction_in_use 335545003L
#define isc_pman_cannot_load_plugin 335545004L
#define isc_pman_module_notfound 335545005L
#define isc_pman_entrypoint_notfound 335545006L
#define isc_pman_module_bad 335545007L
#define isc_pman_plugin_notfound 335545008L
#define isc_sysf_invalid_trig_namespace 335545009L
#define isc_unexpected_null 335545010L
#define isc_type_notcompat_blob 335545011L
#define isc_invalid_date_val 335545012L
#define isc_invalid_time_val 335545013L
#define isc_invalid_timestamp_val 335545014L
#define isc_invalid_index_val 335545015L
#define isc_formatted_exception 335545016L
#define isc_async_active 335545017L
#define isc_private_function 335545018L
#define isc_private_procedure 335545019L
#define isc_request_outdated 335545020L
#define isc_bad_events_handle 335545021L
#define isc_cannot_copy_stmt 335545022L
#define isc_invalid_boolean_usage 335545023L
#define isc_sysf_argscant_both_be_zero 335545024L
#define isc_spb_no_id 335545025L
#define isc_ee_blr_mismatch_null 335545026L
#define isc_ee_blr_mismatch_length 335545027L
#define isc_ss_out_of_bounds 335545028L
#define isc_missing_data_structures 335545029L
#define isc_protect_sys_tab 335545030L
#define isc_libtommath_generic 335545031L
#define isc_wroblrver2 335545032L
#define isc_trunc_limits 335545033L
#define isc_info_access 335545034L
#define isc_svc_no_stdin 335545035L
#define isc_svc_start_failed 335545036L
#define isc_svc_no_switches 335545037L
#define isc_svc_bad_size 335545038L
#define isc_no_crypt_plugin 335545039L
#define isc_cp_name_too_long 335545040L
#define isc_cp_process_active 335545041L
#define isc_cp_already_crypted 335545042L
#define isc_decrypt_error 335545043L
#define isc_no_providers 335545044L
#define isc_null_spb 335545045L
#define isc_max_args_exceeded 335545046L
#define isc_ee_blr_mismatch_names_count 335545047L
#define isc_ee_blr_mismatch_name_not_found 335545048L
#define isc_bad_result_set 335545049L
#define isc_wrong_message_length 335545050L
#define isc_no_output_format 335545051L
#define isc_item_finish 335545052L
#define isc_miss_config 335545053L
#define isc_conf_line 335545054L
#define isc_conf_include 335545055L
#define isc_include_depth 335545056L
#define isc_include_miss 335545057L
#define isc_protect_ownership 335545058L
#define isc_badvarnum 335545059L
#define isc_sec_context 335545060L
#define isc_multi_segment 335545061L
#define isc_login_changed 335545062L
#define isc_auth_handshake_limit 335545063L
#define isc_wirecrypt_incompatible 335545064L
#define isc_miss_wirecrypt 335545065L
#define isc_wirecrypt_key 335545066L
#define isc_wirecrypt_plugin 335545067L
#define isc_secdb_name 335545068L
#define isc_auth_data 335545069L
#define isc_auth_datalength 335545070L
#define isc_info_unprepared_stmt 335545071L
#define isc_idx_key_value 335545072L
#define isc_forupdate_virtualtbl 335545073L
#define isc_forupdate_systbl 335545074L
#define isc_forupdate_temptbl 335545075L
#define isc_cant_modify_sysobj 335545076L
#define isc_server_misconfigured 335545077L
#define isc_alter_role 335545078L
#define isc_map_already_exists 335545079L
#define isc_map_not_exists 335545080L
#define isc_map_load 335545081L
#define isc_map_aster 335545082L
#define isc_map_multi 335545083L
#define isc_map_undefined 335545084L
#define isc_baddpb_damaged_mode 335545085L
#define isc_baddpb_buffers_range 335545086L
#define isc_baddpb_temp_buffers 335545087L
#define isc_map_nodb 335545088L
#define isc_map_notable 335545089L
#define isc_miss_trusted_role 335545090L
#define isc_set_invalid_role 335545091L
#define isc_cursor_not_positioned 335545092L
#define isc_dup_attribute 335545093L
#define isc_dyn_no_priv 335545094L
#define isc_dsql_cant_grant_option 335545095L
#define isc_read_conflict 335545096L
#define isc_crdb_load 335545097L
#define isc_crdb_nodb 335545098L
#define isc_crdb_notable 335545099L
#define isc_interface_version_too_old 335545100L
#define isc_fun_param_mismatch 335545101L
#define isc_savepoint_backout_err 335545102L
#define isc_domain_primary_key_notnull 335545103L
#define isc_invalid_attachment_charset 335545104L
#define isc_map_down 335545105L
#define isc_login_error 335545106L
#define isc_already_opened 335545107L
#define isc_bad_crypt_key 335545108L
#define isc_encrypt_error 335545109L
#define isc_max_idx_depth 335545110L
#define isc_wrong_prvlg 335545111L
#define isc_miss_prvlg 335545112L
#define isc_crypt_checksum 335545113L
#define isc_not_dba 335545114L
#define isc_no_cursor 335545115L
#define isc_dsql_window_incompat_frames 335545116L
#define isc_dsql_window_range_multi_key 335545117L
#define isc_dsql_window_range_inv_key_type 335545118L
#define isc_dsql_window_frame_value_inv_type 335545119L
#define isc_window_frame_value_invalid 335545120L
#define isc_dsql_window_not_found 335545121L
#define isc_dsql_window_cant_overr_part 335545122L
#define isc_dsql_window_cant_overr_order 335545123L
#define isc_dsql_window_cant_overr_frame 335545124L
#define isc_dsql_window_duplicate 335545125L
#define isc_sql_too_long 335545126L
#define isc_cfg_stmt_timeout 335545127L
#define isc_att_stmt_timeout 335545128L
#define isc_req_stmt_timeout 335545129L
#define isc_att_shut_killed 335545130L
#define isc_att_shut_idle 335545131L
#define isc_att_shut_db_down 335545132L
#define isc_att_shut_engine 335545133L
#define isc_overriding_without_identity 335545134L
#define isc_overriding_system_invalid 335545135L
#define isc_overriding_user_invalid 335545136L
#define isc_overriding_missing 335545137L
#define isc_decprecision_err 335545138L
#define isc_decfloat_divide_by_zero 335545139L
#define isc_decfloat_inexact_result 335545140L
#define isc_decfloat_invalid_operation 335545141L
#define isc_decfloat_overflow 335545142L
#define isc_decfloat_underflow 335545143L
#define isc_subfunc_notdef 335545144L
#define isc_subproc_notdef 335545145L
#define isc_subfunc_signat 335545146L
#define isc_subproc_signat 335545147L
#define isc_subfunc_defvaldecl 335545148L
#define isc_subproc_defvaldecl 335545149L
#define isc_subfunc_not_impl 335545150L
#define isc_subproc_not_impl 335545151L
#define isc_sysf_invalid_hash_algorithm 335545152L
#define isc_expression_eval_index 335545153L
#define isc_invalid_decfloat_trap 335545154L
#define isc_invalid_decfloat_round 335545155L
#define isc_sysf_invalid_first_last_part 335545156L
#define isc_sysf_invalid_date_timestamp 335545157L
#define isc_precision_err2 335545158L
#define isc_bad_batch_handle 335545159L
#define isc_intl_char 335545160L
#define isc_null_block 335545161L
#define isc_mixed_info 335545162L
#define isc_unknown_info 335545163L
#define isc_bpb_version 335545164L
#define isc_user_manager 335545165L
#define isc_icu_entrypoint 335545166L
#define isc_icu_library 335545167L
#define isc_metadata_name 335545168L
#define isc_tokens_parse 335545169L
#define isc_iconv_open 335545170L
#define isc_batch_compl_range 335545171L
#define isc_batch_compl_detail 335545172L
#define isc_deflate_init 335545173L
#define isc_inflate_init 335545174L
#define isc_big_segment 335545175L
#define isc_batch_policy 335545176L
#define isc_batch_defbpb 335545177L
#define isc_batch_align 335545178L
#define isc_multi_segment_dup 335545179L
#define isc_non_plugin_protocol 335545180L
#define isc_message_format 335545181L
#define isc_batch_param_version 335545182L
#define isc_batch_msg_long 335545183L
#define isc_batch_open 335545184L
#define isc_batch_type 335545185L
#define isc_batch_param 335545186L
#define isc_batch_blobs 335545187L
#define isc_batch_blob_append 335545188L
#define isc_batch_stream_align 335545189L
#define isc_batch_rpt_blob 335545190L
#define isc_batch_blob_buf 335545191L
#define isc_batch_small_data 335545192L
#define isc_batch_cont_bpb 335545193L
#define isc_batch_big_bpb 335545194L
#define isc_batch_big_segment 335545195L
#define isc_batch_big_seg2 335545196L
#define isc_batch_blob_id 335545197L
#define isc_batch_too_big 335545198L
#define isc_num_literal 335545199L
#define isc_map_event 335545200L
#define isc_map_overflow 335545201L
#define isc_hdr_overflow 335545202L
#define isc_vld_plugins 335545203L
#define isc_db_crypt_key 335545204L
#define isc_no_keyholder_plugin 335545205L
#define isc_ses_reset_err 335545206L
#define isc_ses_reset_open_trans 335545207L
#define isc_ses_reset_warn 335545208L
#define isc_ses_reset_tran_rollback 335545209L
#define isc_plugin_name 335545210L
#define isc_parameter_name 335545211L
#define isc_file_starting_page_err 335545212L
#define isc_invalid_timezone_offset 335545213L
#define isc_invalid_timezone_region 335545214L
#define isc_invalid_timezone_id 335545215L
#define isc_tom_decode64len 335545216L
#define isc_tom_strblob 335545217L
#define isc_tom_reg 335545218L
#define isc_tom_algorithm 335545219L
#define isc_tom_mode_miss 335545220L
#define isc_tom_mode_bad 335545221L
#define isc_tom_no_mode 335545222L
#define isc_tom_iv_miss 335545223L
#define isc_tom_no_iv 335545224L
#define isc_tom_ctrtype_bad 335545225L
#define isc_tom_no_ctrtype 335545226L
#define isc_tom_ctr_big 335545227L
#define isc_tom_no_ctr 335545228L
#define isc_tom_iv_length 335545229L
#define isc_tom_error 335545230L
#define isc_tom_yarrow_start 335545231L
#define isc_tom_yarrow_setup 335545232L
#define isc_tom_init_mode 335545233L
#define isc_tom_crypt_mode 335545234L
#define isc_tom_decrypt_mode 335545235L
#define isc_tom_init_cip 335545236L
#define isc_tom_crypt_cip 335545237L
#define isc_tom_decrypt_cip 335545238L
#define isc_tom_setup_cip 335545239L
#define isc_tom_setup_chacha 335545240L
#define isc_tom_encode 335545241L
#define isc_tom_decode 335545242L
#define isc_tom_rsa_import 335545243L
#define isc_tom_oaep 335545244L
#define isc_tom_hash_bad 335545245L
#define isc_tom_rsa_make 335545246L
#define isc_tom_rsa_export 335545247L
#define isc_tom_rsa_sign 335545248L
#define isc_tom_rsa_verify 335545249L
#define isc_tom_chacha_key 335545250L
#define isc_bad_repl_handle 335545251L
#define isc_tra_snapshot_does_not_exist 335545252L
#define isc_eds_input_prm_not_used 335545253L
#define isc_effective_user 335545254L
#define isc_invalid_time_zone_bind 335545255L
#define isc_invalid_decfloat_bind 335545256L
#define isc_odd_hex_len 335545257L
#define isc_invalid_hex_digit 335545258L
#define isc_bind_err 335545259L
#define isc_bind_statement 335545260L
#define isc_bind_convert 335545261L
#define isc_cannot_update_old_blob 335545262L
#define isc_cannot_read_new_blob 335545263L
#define isc_dyn_no_create_priv 335545264L
#define isc_suspend_without_returns 335545265L
#define isc_truncate_warn 335545266L
#define isc_truncate_monitor 335545267L
#define isc_truncate_context 335545268L
#define isc_merge_dup_update 335545269L
#define isc_wrong_page 335545270L
#define isc_repl_error 335545271L
#define isc_ses_reset_failed 335545272L
#define isc_block_size 335545273L
#define isc_tom_key_length 335545274L
#define isc_inf_invalid_args 335545275L
#define isc_sysf_invalid_null_empty 335545276L
#define isc_bad_loctab_num 335545277L
#define isc_quoted_str_bad 335545278L
#define isc_quoted_str_miss 335545279L
#define isc_wrong_shmem_ver 335545280L
#define isc_wrong_shmem_bitness 335545281L
#define isc_wrong_proc_plan 335545282L
#define isc_invalid_blob_util_handle 335545283L
#define isc_bad_temp_blob_id 335545284L
#define isc_ods_upgrade_err 335545285L
#define isc_bad_par_workers 335545286L
#define isc_idx_expr_not_found 335545287L
#define isc_idx_cond_not_found 335545288L
#define isc_sweep_unable_to_run 335545308L
#define isc_sweep_concurrent_instance 335545309L
#define isc_sweep_read_only 335545310L
#define isc_sweep_attach_no_cleanup 335545311L
#define isc_no_user_att_while_restore 335545318L
#define isc_gfix_db_name 335740929L
#define isc_gfix_invalid_sw 335740930L
#define isc_gfix_incmp_sw 335740932L
#define isc_gfix_replay_req 335740933L
#define isc_gfix_pgbuf_req 335740934L
#define isc_gfix_val_req 335740935L
#define isc_gfix_pval_req 335740936L
#define isc_gfix_trn_req 335740937L
#define isc_gfix_full_req 335740940L
#define isc_gfix_usrname_req 335740941L
#define isc_gfix_pass_req 335740942L
#define isc_gfix_subs_name 335740943L
#define isc_gfix_wal_req 335740944L
#define isc_gfix_sec_req 335740945L
#define isc_gfix_nval_req 335740946L
#define isc_gfix_type_shut 335740947L
#define isc_gfix_retry 335740948L
#define isc_gfix_retry_db 335740951L
#define isc_gfix_exceed_max 335740991L
#define isc_gfix_corrupt_pool 335740992L
#define isc_gfix_mem_exhausted 335740993L
#define isc_gfix_bad_pool 335740994L
#define isc_gfix_trn_not_valid 335740995L
#define isc_gfix_unexp_eoi 335741012L
#define isc_gfix_recon_fail 335741018L
#define isc_gfix_trn_unknown 335741036L
#define isc_gfix_mode_req 335741038L
#define isc_gfix_pzval_req 335741042L
#define isc_dsql_dbkey_from_non_table 336003074L
#define isc_dsql_transitional_numeric 336003075L
#define isc_dsql_dialect_warning_expr 336003076L
#define isc_sql_db_dialect_dtype_unsupport 336003077L
#define isc_sql_dialect_conflict_num 336003079L
#define isc_dsql_warning_number_ambiguous 336003080L
#define isc_dsql_warning_number_ambiguous1 336003081L
#define isc_dsql_warn_precision_ambiguous 336003082L
#define isc_dsql_warn_precision_ambiguous1 336003083L
#define isc_dsql_warn_precision_ambiguous2 336003084L
#define isc_dsql_ambiguous_field_name 336003085L
#define isc_dsql_udf_return_pos_err 336003086L
#define isc_dsql_invalid_label 336003087L
#define isc_dsql_datatypes_not_comparable 336003088L
#define isc_dsql_cursor_invalid 336003089L
#define isc_dsql_cursor_redefined 336003090L
#define isc_dsql_cursor_not_found 336003091L
#define isc_dsql_cursor_exists 336003092L
#define isc_dsql_cursor_rel_ambiguous 336003093L
#define isc_dsql_cursor_rel_not_found 336003094L
#define isc_dsql_cursor_not_open 336003095L
#define isc_dsql_type_not_supp_ext_tab 336003096L
#define isc_dsql_feature_not_supported_ods 336003097L
#define isc_primary_key_required 336003098L
#define isc_upd_ins_doesnt_match_pk 336003099L
#define isc_upd_ins_doesnt_match_matching 336003100L
#define isc_upd_ins_with_complex_view 336003101L
#define isc_dsql_incompatible_trigger_type 336003102L
#define isc_dsql_db_trigger_type_cant_change 336003103L
#define isc_dsql_record_version_table 336003104L
#define isc_dsql_invalid_sqlda_version 336003105L
#define isc_dsql_sqlvar_index 336003106L
#define isc_dsql_no_sqlind 336003107L
#define isc_dsql_no_sqldata 336003108L
#define isc_dsql_no_input_sqlda 336003109L
#define isc_dsql_no_output_sqlda 336003110L
#define isc_dsql_wrong_param_num 336003111L
#define isc_dsql_invalid_drop_ss_clause 336003112L
#define isc_upd_ins_cannot_default 336003113L
#define isc_dyn_filter_not_found 336068645L
#define isc_dyn_func_not_found 336068649L
#define isc_dyn_index_not_found 336068656L
#define isc_dyn_view_not_found 336068662L
#define isc_dyn_domain_not_found 336068697L
#define isc_dyn_cant_modify_auto_trig 336068717L
#define isc_dyn_dup_table 336068740L
#define isc_dyn_proc_not_found 336068748L
#define isc_dyn_exception_not_found 336068752L
#define isc_dyn_proc_param_not_found 336068754L
#define isc_dyn_trig_not_found 336068755L
#define isc_dyn_charset_not_found 336068759L
#define isc_dyn_collation_not_found 336068760L
#define isc_dyn_role_not_found 336068763L
#define isc_dyn_name_longer 336068767L
#define isc_dyn_column_does_not_exist 336068784L
#define isc_dyn_role_does_not_exist 336068796L
#define isc_dyn_no_grant_admin_opt 336068797L
#define isc_dyn_user_not_role_member 336068798L
#define isc_dyn_delete_role_failed 336068799L
#define isc_dyn_grant_role_to_user 336068800L
#define isc_dyn_inv_sql_role_name 336068801L
#define isc_dyn_dup_sql_role 336068802L
#define isc_dyn_kywd_spec_for_role 336068803L
#define isc_dyn_roles_not_supported 336068804L
#define isc_dyn_domain_name_exists 336068812L
#define isc_dyn_field_name_exists 336068813L
#define isc_dyn_dependency_exists 336068814L
#define isc_dyn_dtype_invalid 336068815L
#define isc_dyn_char_fld_too_small 336068816L
#define isc_dyn_invalid_dtype_conversion 336068817L
#define isc_dyn_dtype_conv_invalid 336068818L
#define isc_dyn_zero_len_id 336068820L
#define isc_dyn_gen_not_found 336068822L
#define isc_max_coll_per_charset 336068829L
#define isc_invalid_coll_attr 336068830L
#define isc_dyn_wrong_gtt_scope 336068840L
#define isc_dyn_coll_used_table 336068843L
#define isc_dyn_coll_used_domain 336068844L
#define isc_dyn_cannot_del_syscoll 336068845L
#define isc_dyn_cannot_del_def_coll 336068846L
#define isc_dyn_table_not_found 336068849L
#define isc_dyn_coll_used_procedure 336068851L
#define isc_dyn_scale_too_big 336068852L
#define isc_dyn_precision_too_small 336068853L
#define isc_dyn_miss_priv_warning 336068855L
#define isc_dyn_ods_not_supp_feature 336068856L
#define isc_dyn_cannot_addrem_computed 336068857L
#define isc_dyn_no_empty_pw 336068858L
#define isc_dyn_dup_index 336068859L
#define isc_dyn_package_not_found 336068864L
#define isc_dyn_schema_not_found 336068865L
#define isc_dyn_cannot_mod_sysproc 336068866L
#define isc_dyn_cannot_mod_systrig 336068867L
#define isc_dyn_cannot_mod_sysfunc 336068868L
#define isc_dyn_invalid_ddl_proc 336068869L
#define isc_dyn_invalid_ddl_trig 336068870L
#define isc_dyn_funcnotdef_package 336068871L
#define isc_dyn_procnotdef_package 336068872L
#define isc_dyn_funcsignat_package 336068873L
#define isc_dyn_procsignat_package 336068874L
#define isc_dyn_defvaldecl_package_proc 336068875L
#define isc_dyn_package_body_exists 336068877L
#define isc_dyn_invalid_ddl_func 336068878L
#define isc_dyn_newfc_oldsyntax 336068879L
#define isc_dyn_func_param_not_found 336068886L
#define isc_dyn_routine_param_not_found 336068887L
#define isc_dyn_routine_param_ambiguous 336068888L
#define isc_dyn_coll_used_function 336068889L
#define isc_dyn_domain_used_function 336068890L
#define isc_dyn_alter_user_no_clause 336068891L
#define isc_dyn_duplicate_package_item 336068894L
#define isc_dyn_cant_modify_sysobj 336068895L
#define isc_dyn_cant_use_zero_increment 336068896L
#define isc_dyn_cant_use_in_foreignkey 336068897L
#define isc_dyn_defvaldecl_package_func 336068898L
#define isc_dyn_cyclic_role 336068900L
#define isc_dyn_cant_use_zero_inc_ident 336068904L
#define isc_dyn_no_ddl_grant_opt_priv 336068907L
#define isc_dyn_no_grant_opt_priv 336068908L
#define isc_dyn_func_not_exist 336068909L
#define isc_dyn_proc_not_exist 336068910L
#define isc_dyn_pack_not_exist 336068911L
#define isc_dyn_trig_not_exist 336068912L
#define isc_dyn_view_not_exist 336068913L
#define isc_dyn_rel_not_exist 336068914L
#define isc_dyn_exc_not_exist 336068915L
#define isc_dyn_gen_not_exist 336068916L
#define isc_dyn_fld_not_exist 336068917L
#define isc_gbak_unknown_switch 336330753L
#define isc_gbak_page_size_missing 336330754L
#define isc_gbak_page_size_toobig 336330755L
#define isc_gbak_redir_ouput_missing 336330756L
#define isc_gbak_switches_conflict 336330757L
#define isc_gbak_unknown_device 336330758L
#define isc_gbak_no_protection 336330759L
#define isc_gbak_page_size_not_allowed 336330760L
#define isc_gbak_multi_source_dest 336330761L
#define isc_gbak_filename_missing 336330762L
#define isc_gbak_dup_inout_names 336330763L
#define isc_gbak_inv_page_size 336330764L
#define isc_gbak_db_specified 336330765L
#define isc_gbak_db_exists 336330766L
#define isc_gbak_unk_device 336330767L
#define isc_gbak_blob_info_failed 336330772L
#define isc_gbak_unk_blob_item 336330773L
#define isc_gbak_get_seg_failed 336330774L
#define isc_gbak_close_blob_failed 336330775L
#define isc_gbak_open_blob_failed 336330776L
#define isc_gbak_put_blr_gen_id_failed 336330777L
#define isc_gbak_unk_type 336330778L
#define isc_gbak_comp_req_failed 336330779L
#define isc_gbak_start_req_failed 336330780L
#define isc_gbak_rec_failed 336330781L
#define isc_gbak_rel_req_failed 336330782L
#define isc_gbak_db_info_failed 336330783L
#define isc_gbak_no_db_desc 336330784L
#define isc_gbak_db_create_failed 336330785L
#define isc_gbak_decomp_len_error 336330786L
#define isc_gbak_tbl_missing 336330787L
#define isc_gbak_blob_col_missing 336330788L
#define isc_gbak_create_blob_failed 336330789L
#define isc_gbak_put_seg_failed 336330790L
#define isc_gbak_rec_len_exp 336330791L
#define isc_gbak_inv_rec_len 336330792L
#define isc_gbak_exp_data_type 336330793L
#define isc_gbak_gen_id_failed 336330794L
#define isc_gbak_unk_rec_type 336330795L
#define isc_gbak_inv_bkup_ver 336330796L
#define isc_gbak_missing_bkup_desc 336330797L
#define isc_gbak_string_trunc 336330798L
#define isc_gbak_cant_rest_record 336330799L
#define isc_gbak_send_failed 336330800L
#define isc_gbak_no_tbl_name 336330801L
#define isc_gbak_unexp_eof 336330802L
#define isc_gbak_db_format_too_old 336330803L
#define isc_gbak_inv_array_dim 336330804L
#define isc_gbak_xdr_len_expected 336330807L
#define isc_gbak_open_bkup_error 336330817L
#define isc_gbak_open_error 336330818L
#define isc_gbak_missing_block_fac 336330934L
#define isc_gbak_inv_block_fac 336330935L
#define isc_gbak_block_fac_specified 336330936L
#define isc_gbak_missing_username 336330940L
#define isc_gbak_missing_password 336330941L
#define isc_gbak_missing_skipped_bytes 336330952L
#define isc_gbak_inv_skipped_bytes 336330953L
#define isc_gbak_err_restore_charset 336330965L
#define isc_gbak_err_restore_collation 336330967L
#define isc_gbak_read_error 336330972L
#define isc_gbak_write_error 336330973L
#define isc_gbak_db_in_use 336330985L
#define isc_gbak_sysmemex 336330990L
#define isc_gbak_restore_role_failed 336331002L
#define isc_gbak_role_op_missing 336331005L
#define isc_gbak_page_buffers_missing 336331010L
#define isc_gbak_page_buffers_wrong_param 336331011L
#define isc_gbak_page_buffers_restore 336331012L
#define isc_gbak_inv_size 336331014L
#define isc_gbak_file_outof_sequence 336331015L
#define isc_gbak_join_file_missing 336331016L
#define isc_gbak_stdin_not_supptd 336331017L
#define isc_gbak_stdout_not_supptd 336331018L
#define isc_gbak_bkup_corrupt 336331019L
#define isc_gbak_unk_db_file_spec 336331020L
#define isc_gbak_hdr_write_failed 336331021L
#define isc_gbak_disk_space_ex 336331022L
#define isc_gbak_size_lt_min 336331023L
#define isc_gbak_svc_name_missing 336331025L
#define isc_gbak_not_ownr 336331026L
#define isc_gbak_mode_req 336331031L
#define isc_gbak_just_data 336331033L
#define isc_gbak_data_only 336331034L
#define isc_gbak_missing_interval 336331078L
#define isc_gbak_wrong_interval 336331079L
#define isc_gbak_verify_verbint 336331081L
#define isc_gbak_option_only_restore 336331082L
#define isc_gbak_option_only_backup 336331083L
#define isc_gbak_option_conflict 336331084L
#define isc_gbak_param_conflict 336331085L
#define isc_gbak_option_repeated 336331086L
#define isc_gbak_max_dbkey_recursion 336331091L
#define isc_gbak_max_dbkey_length 336331092L
#define isc_gbak_invalid_metadata 336331093L
#define isc_gbak_invalid_data 336331094L
#define isc_gbak_inv_bkup_ver2 336331096L
#define isc_gbak_db_format_too_old2 336331100L
#define isc_dsql_too_old_ods 336397205L
#define isc_dsql_table_not_found 336397206L
#define isc_dsql_view_not_found 336397207L
#define isc_dsql_line_col_error 336397208L
#define isc_dsql_unknown_pos 336397209L
#define isc_dsql_no_dup_name 336397210L
#define isc_dsql_too_many_values 336397211L
#define isc_dsql_no_array_computed 336397212L
#define isc_dsql_implicit_domain_name 336397213L
#define isc_dsql_only_can_subscript_array 336397214L
#define isc_dsql_max_sort_items 336397215L
#define isc_dsql_max_group_items 336397216L
#define isc_dsql_conflicting_sort_field 336397217L
#define isc_dsql_derived_table_more_columns 336397218L
#define isc_dsql_derived_table_less_columns 336397219L
#define isc_dsql_derived_field_unnamed 336397220L
#define isc_dsql_derived_field_dup_name 336397221L
#define isc_dsql_derived_alias_select 336397222L
#define isc_dsql_derived_alias_field 336397223L
#define isc_dsql_auto_field_bad_pos 336397224L
#define isc_dsql_cte_wrong_reference 336397225L
#define isc_dsql_cte_cycle 336397226L
#define isc_dsql_cte_outer_join 336397227L
#define isc_dsql_cte_mult_references 336397228L
#define isc_dsql_cte_not_a_union 336397229L
#define isc_dsql_cte_nonrecurs_after_recurs 336397230L
#define isc_dsql_cte_wrong_clause 336397231L
#define isc_dsql_cte_union_all 336397232L
#define isc_dsql_cte_miss_nonrecursive 336397233L
#define isc_dsql_cte_nested_with 336397234L
#define isc_dsql_col_more_than_once_using 336397235L
#define isc_dsql_unsupp_feature_dialect 336397236L
#define isc_dsql_cte_not_used 336397237L
#define isc_dsql_col_more_than_once_view 336397238L
#define isc_dsql_unsupported_in_auto_trans 336397239L
#define isc_dsql_eval_unknode 336397240L
#define isc_dsql_agg_wrongarg 336397241L
#define isc_dsql_agg2_wrongarg 336397242L
#define isc_dsql_nodateortime_pm_string 336397243L
#define isc_dsql_invalid_datetime_subtract 336397244L
#define isc_dsql_invalid_dateortime_add 336397245L
#define isc_dsql_invalid_type_minus_date 336397246L
#define isc_dsql_nostring_addsub_dial3 336397247L
#define isc_dsql_invalid_type_addsub_dial3 336397248L
#define isc_dsql_invalid_type_multip_dial1 336397249L
#define isc_dsql_nostring_multip_dial3 336397250L
#define isc_dsql_invalid_type_multip_dial3 336397251L
#define isc_dsql_mustuse_numeric_div_dial1 336397252L
#define isc_dsql_nostring_div_dial3 336397253L
#define isc_dsql_invalid_type_div_dial3 336397254L
#define isc_dsql_nostring_neg_dial3 336397255L
#define isc_dsql_invalid_type_neg 336397256L
#define isc_dsql_max_distinct_items 336397257L
#define isc_dsql_alter_charset_failed 336397258L
#define isc_dsql_comment_on_failed 336397259L
#define isc_dsql_create_func_failed 336397260L
#define isc_dsql_alter_func_failed 336397261L
#define isc_dsql_create_alter_func_failed 336397262L
#define isc_dsql_drop_func_failed 336397263L
#define isc_dsql_recreate_func_failed 336397264L
#define isc_dsql_create_proc_failed 336397265L
#define isc_dsql_alter_proc_failed 336397266L
#define isc_dsql_create_alter_proc_failed 336397267L
#define isc_dsql_drop_proc_failed 336397268L
#define isc_dsql_recreate_proc_failed 336397269L
#define isc_dsql_create_trigger_failed 336397270L
#define isc_dsql_alter_trigger_failed 336397271L
#define isc_dsql_create_alter_trigger_failed 336397272L
#define isc_dsql_drop_trigger_failed 336397273L
#define isc_dsql_recreate_trigger_failed 336397274L
#define isc_dsql_create_collation_failed 336397275L
#define isc_dsql_drop_collation_failed 336397276L
#define isc_dsql_create_domain_failed 336397277L
#define isc_dsql_alter_domain_failed 336397278L
#define isc_dsql_drop_domain_failed 336397279L
#define isc_dsql_create_except_failed 336397280L
#define isc_dsql_alter_except_failed 336397281L
#define isc_dsql_create_alter_except_failed 336397282L
#define isc_dsql_recreate_except_failed 336397283L
#define isc_dsql_drop_except_failed 336397284L
#define isc_dsql_create_sequence_failed 336397285L
#define isc_dsql_create_table_failed 336397286L
#define isc_dsql_alter_table_failed 336397287L
#define isc_dsql_drop_table_failed 336397288L
#define isc_dsql_recreate_table_failed 336397289L
#define isc_dsql_create_pack_failed 336397290L
#define isc_dsql_alter_pack_failed 336397291L
#define isc_dsql_create_alter_pack_failed 336397292L
#define isc_dsql_drop_pack_failed 336397293L
#define isc_dsql_recreate_pack_failed 336397294L
#define isc_dsql_create_pack_body_failed 336397295L
#define isc_dsql_drop_pack_body_failed 336397296L
#define isc_dsql_recreate_pack_body_failed 336397297L
#define isc_dsql_create_view_failed 336397298L
#define isc_dsql_alter_view_failed 336397299L
#define isc_dsql_create_alter_view_failed 336397300L
#define isc_dsql_recreate_view_failed 336397301L
#define isc_dsql_drop_view_failed 336397302L
#define isc_dsql_drop_sequence_failed 336397303L
#define isc_dsql_recreate_sequence_failed 336397304L
#define isc_dsql_drop_index_failed 336397305L
#define isc_dsql_drop_filter_failed 336397306L
#define isc_dsql_drop_shadow_failed 336397307L
#define isc_dsql_drop_role_failed 336397308L
#define isc_dsql_drop_user_failed 336397309L
#define isc_dsql_create_role_failed 336397310L
#define isc_dsql_alter_role_failed 336397311L
#define isc_dsql_alter_index_failed 336397312L
#define isc_dsql_alter_database_failed 336397313L
#define isc_dsql_create_shadow_failed 336397314L
#define isc_dsql_create_filter_failed 336397315L
#define isc_dsql_create_index_failed 336397316L
#define isc_dsql_create_user_failed 336397317L
#define isc_dsql_alter_user_failed 336397318L
#define isc_dsql_grant_failed 336397319L
#define isc_dsql_revoke_failed 336397320L
#define isc_dsql_cte_recursive_aggregate 336397321L
#define isc_dsql_mapping_failed 336397322L
#define isc_dsql_alter_sequence_failed 336397323L
#define isc_dsql_create_generator_failed 336397324L
#define isc_dsql_set_generator_failed 336397325L
#define isc_dsql_wlock_simple 336397326L
#define isc_dsql_firstskip_rows 336397327L
#define isc_dsql_wlock_aggregates 336397328L
#define isc_dsql_wlock_conflict 336397329L
#define isc_dsql_max_exception_arguments 336397330L
#define isc_dsql_string_byte_length 336397331L
#define isc_dsql_string_char_length 336397332L
#define isc_dsql_max_nesting 336397333L
#define isc_dsql_recreate_user_failed 336397334L
#define isc_gsec_cant_open_db 336723983L
#define isc_gsec_switches_error 336723984L
#define isc_gsec_no_op_spec 336723985L
#define isc_gsec_no_usr_name 336723986L
#define isc_gsec_err_add 336723987L
#define isc_gsec_err_modify 336723988L
#define isc_gsec_err_find_mod 336723989L
#define isc_gsec_err_rec_not_found 336723990L
#define isc_gsec_err_delete 336723991L
#define isc_gsec_err_find_del 336723992L
#define isc_gsec_err_find_disp 336723996L
#define isc_gsec_inv_param 336723997L
#define isc_gsec_op_specified 336723998L
#define isc_gsec_pw_specified 336723999L
#define isc_gsec_uid_specified 336724000L
#define isc_gsec_gid_specified 336724001L
#define isc_gsec_proj_specified 336724002L
#define isc_gsec_org_specified 336724003L
#define isc_gsec_fname_specified 336724004L
#define isc_gsec_mname_specified 336724005L
#define isc_gsec_lname_specified 336724006L
#define isc_gsec_inv_switch 336724008L
#define isc_gsec_amb_switch 336724009L
#define isc_gsec_no_op_specified 336724010L
#define isc_gsec_params_not_allowed 336724011L
#define isc_gsec_incompat_switch 336724012L
#define isc_gsec_inv_username 336724044L
#define isc_gsec_inv_pw_length 336724045L
#define isc_gsec_db_specified 336724046L
#define isc_gsec_db_admin_specified 336724047L
#define isc_gsec_db_admin_pw_specified 336724048L
#define isc_gsec_sql_role_specified 336724049L
#define isc_gstat_unknown_switch 336920577L
#define isc_gstat_retry 336920578L
#define isc_gstat_wrong_ods 336920579L
#define isc_gstat_unexpected_eof 336920580L
#define isc_gstat_open_err 336920605L
#define isc_gstat_read_err 336920606L
#define isc_gstat_sysmemex 336920607L
#define isc_fbsvcmgr_bad_am 336986113L
#define isc_fbsvcmgr_bad_wm 336986114L
#define isc_fbsvcmgr_bad_rs 336986115L
#define isc_fbsvcmgr_info_err 336986116L
#define isc_fbsvcmgr_query_err 336986117L
#define isc_fbsvcmgr_switch_unknown 336986118L
#define isc_fbsvcmgr_bad_sm 336986159L
#define isc_fbsvcmgr_fp_open 336986160L
#define isc_fbsvcmgr_fp_read 336986161L
#define isc_fbsvcmgr_fp_empty 336986162L
#define isc_fbsvcmgr_bad_arg 336986164L
#define isc_fbsvcmgr_info_limbo 336986170L
#define isc_fbsvcmgr_limbo_state 336986171L
#define isc_fbsvcmgr_limbo_advise 336986172L
#define isc_fbsvcmgr_bad_rm 336986173L
#define isc_utl_trusted_switch 337051649L
#define isc_nbackup_missing_param 337117213L
#define isc_nbackup_allowed_switches 337117214L
#define isc_nbackup_unknown_param 337117215L
#define isc_nbackup_unknown_switch 337117216L
#define isc_nbackup_nofetchpw_svc 337117217L
#define isc_nbackup_pwfile_error 337117218L
#define isc_nbackup_size_with_lock 337117219L
#define isc_nbackup_no_switch 337117220L
#define isc_nbackup_err_read 337117223L
#define isc_nbackup_err_write 337117224L
#define isc_nbackup_err_seek 337117225L
#define isc_nbackup_err_opendb 337117226L
#define isc_nbackup_err_fadvice 337117227L
#define isc_nbackup_err_createdb 337117228L
#define isc_nbackup_err_openbk 337117229L
#define isc_nbackup_err_createbk 337117230L
#define isc_nbackup_err_eofdb 337117231L
#define isc_nbackup_fixup_wrongstate 337117232L
#define isc_nbackup_err_db 337117233L
#define isc_nbackup_userpw_toolong 337117234L
#define isc_nbackup_lostrec_db 337117235L
#define isc_nbackup_lostguid_db 337117236L
#define isc_nbackup_err_eofhdrdb 337117237L
#define isc_nbackup_db_notlock 337117238L
#define isc_nbackup_lostguid_bk 337117239L
#define isc_nbackup_page_changed 337117240L
#define isc_nbackup_dbsize_inconsistent 337117241L
#define isc_nbackup_failed_lzbk 337117242L
#define isc_nbackup_err_eofhdrbk 337117243L
#define isc_nbackup_invalid_incbk 337117244L
#define isc_nbackup_unsupvers_incbk 337117245L
#define isc_nbackup_invlevel_incbk 337117246L
#define isc_nbackup_wrong_orderbk 337117247L
#define isc_nbackup_err_eofbk 337117248L
#define isc_nbackup_err_copy 337117249L
#define isc_nbackup_err_eofhdr_restdb 337117250L
#define isc_nbackup_lostguid_l0bk 337117251L
#define isc_nbackup_switchd_parameter 337117255L
#define isc_nbackup_user_stop 337117257L
#define isc_nbackup_deco_parse 337117259L
#define isc_nbackup_lostrec_guid_db 337117261L
#define isc_nbackup_seq_misuse 337117265L
#define isc_nbackup_wrong_param 337117268L
#define isc_nbackup_clean_hist_misuse 337117269L
#define isc_nbackup_clean_hist_missed 337117270L
#define isc_nbackup_keep_hist_missed 337117271L
#define isc_nbackup_second_keep_switch 337117272L
#define isc_trace_conflict_acts 337182750L
#define isc_trace_act_notfound 337182751L
#define isc_trace_switch_once 337182752L
#define isc_trace_param_val_miss 337182753L
#define isc_trace_param_invalid 337182754L
#define isc_trace_switch_unknown 337182755L
#define isc_trace_switch_svc_only 337182756L
#define isc_trace_switch_user_only 337182757L
#define isc_trace_switch_param_miss 337182758L
#define isc_trace_param_act_notcompat 337182759L
#define isc_trace_mandatory_switch_miss 337182760L
#define isc_err_max 1470
