FB_IMPL_MSG(FBSVCMGR, 1, fbsvcmgr_bad_am, -901, "00", "000", "Wrong value for access mode")
FB_IMPL_MSG(FBSVCMGR, 2, fbsvcmgr_bad_wm, -901, "00", "000", "Wrong value for write mode")
FB_IMPL_MSG(FBSVCMGR, 3, fbsvcmgr_bad_rs, -901, "00", "000", "Wrong value for reserve space")
FB_IMPL_MSG(FBSVCMGR, 4, fbsvcmgr_info_err, -901, "00", "000", "Unknown tag (@1) in info_svr_db_info block after isc_svc_query()")
FB_IMPL_MSG(FBSVCMGR, 5, fbsvcmgr_query_err, -901, "00", "000", "Unknown tag (@1) in isc_svc_query() results")
FB_IMPL_MSG(FBSVCMGR, 6, fbsvcmgr_switch_unknown, -901, "00", "000", "Unknown switch \"@1\"")
FB_IMPL_MSG_NO_SYMBOL(FBSVCMGR, 7, "Service Manager Version")
FB_IMPL_MSG_NO_SYMBOL(FBSVCMGR, 8, "Server version")
FB_IMPL_MSG_NO_SYMBOL(FBSVCMGR, 9, "Server implementation")
FB_IMPL_MSG_NO_SYMBOL(FBSVCMGR, 10, "Path to firebird.msg")
FB_IMPL_MSG_NO_SYMBOL(FBSVCMGR, 11, "Server root")
FB_IMPL_MSG_NO_SYMBOL(FBSVCMGR, 12, "Path to lock files")
FB_IMPL_MSG_NO_SYMBOL(FBSVCMGR, 13, "Security database")
FB_IMPL_MSG_NO_SYMBOL(FBSVCMGR, 14, "Databases")
FB_IMPL_MSG_NO_SYMBOL(FBSVCMGR, 15, "   Database in use")
FB_IMPL_MSG_NO_SYMBOL(FBSVCMGR, 16, "   Number of attachments")
FB_IMPL_MSG_NO_SYMBOL(FBSVCMGR, 17, "   Number of databases")
FB_IMPL_MSG_NO_SYMBOL(FBSVCMGR, 18, "Information truncated")
FB_IMPL_MSG_NO_SYMBOL(FBSVCMGR, 19, "Usage: fbsvcmgr manager-name switches...")
FB_IMPL_MSG_NO_SYMBOL(FBSVCMGR, 20, "Manager-name should be service_mgr, may be prefixed with host name")
FB_IMPL_MSG_NO_SYMBOL(FBSVCMGR, 21, "according to common rules (host:service_mgr, \\\\host\\service_mgr).")
FB_IMPL_MSG_NO_SYMBOL(FBSVCMGR, 22, "Switches exactly match SPB tags, used in abbreviated form.")
FB_IMPL_MSG_NO_SYMBOL(FBSVCMGR, 23, "Remove isc_, spb_ and svc_ parts of tag and you will get the switch.")
FB_IMPL_MSG_NO_SYMBOL(FBSVCMGR, 24, "For example: isc_action_svc_backup is specified as action_backup,")
FB_IMPL_MSG_NO_SYMBOL(FBSVCMGR, 25, "             isc_spb_dbname => dbname,")
FB_IMPL_MSG_NO_SYMBOL(FBSVCMGR, 26, "             isc_info_svc_implementation => info_implementation,")
FB_IMPL_MSG_NO_SYMBOL(FBSVCMGR, 27, "             isc_spb_prp_db_online => prp_db_online and so on.")
FB_IMPL_MSG_NO_SYMBOL(FBSVCMGR, 28, "You may specify single action or multiple info items when calling fbsvcmgr once.")
FB_IMPL_MSG_NO_SYMBOL(FBSVCMGR, 29, "Full command line samples:")
FB_IMPL_MSG_NO_SYMBOL(FBSVCMGR, 30, "fbsvcmgr service_mgr user sysdba password masterkey action_db_stats dbname employee sts_hdr_pages")
FB_IMPL_MSG_NO_SYMBOL(FBSVCMGR, 31, "  (will list header info in database employee on local machine)")
FB_IMPL_MSG_NO_SYMBOL(FBSVCMGR, 32, "fbsvcmgr yourserver:service_mgr user sysdba password masterkey info_server_version info_svr_db_info")
FB_IMPL_MSG_NO_SYMBOL(FBSVCMGR, 33, "  (will show firebird version and databases usage on yourserver)")
FB_IMPL_MSG_NO_SYMBOL(FBSVCMGR, 34, "Transaction in limbo")
FB_IMPL_MSG_NO_SYMBOL(FBSVCMGR, 35, "Multidatabase transaction in limbo")
FB_IMPL_MSG_NO_SYMBOL(FBSVCMGR, 36, "Host Site")
FB_IMPL_MSG_NO_SYMBOL(FBSVCMGR, 37, "Transaction")
FB_IMPL_MSG_NO_SYMBOL(FBSVCMGR, 38, "has been prepared")
FB_IMPL_MSG_NO_SYMBOL(FBSVCMGR, 39, "has been committed")
FB_IMPL_MSG_NO_SYMBOL(FBSVCMGR, 40, "has been rolled back")
FB_IMPL_MSG_NO_SYMBOL(FBSVCMGR, 41, "is not available")
FB_IMPL_MSG_NO_SYMBOL(FBSVCMGR, 42, "Remote Site")
FB_IMPL_MSG_NO_SYMBOL(FBSVCMGR, 43, "Database Path")
FB_IMPL_MSG_NO_SYMBOL(FBSVCMGR, 44, "Automated recovery would commit this transaction")
FB_IMPL_MSG_NO_SYMBOL(FBSVCMGR, 45, "Automated recovery would rollback this transaction")
FB_IMPL_MSG_NO_SYMBOL(FBSVCMGR, 46, "No idea should it be commited or rolled back")
FB_IMPL_MSG(FBSVCMGR, 47, fbsvcmgr_bad_sm, -901, "00", "000", "Wrong value for shutdown mode")
FB_IMPL_MSG(FBSVCMGR, 48, fbsvcmgr_fp_open, -901, "00", "000", "could not open file @1")
FB_IMPL_MSG(FBSVCMGR, 49, fbsvcmgr_fp_read, -901, "00", "000", "could not read file @1")
FB_IMPL_MSG(FBSVCMGR, 50, fbsvcmgr_fp_empty, -901, "00", "000", "empty file @1")
FB_IMPL_MSG_NO_SYMBOL(FBSVCMGR, 51, "Firebird Services Manager version @1")
FB_IMPL_MSG(FBSVCMGR, 52, fbsvcmgr_bad_arg, -901, "00", "000", "Invalid or missing parameter for switch @1")
FB_IMPL_MSG_NO_SYMBOL(FBSVCMGR, 53, "To get full list of known services run with -? switch")
FB_IMPL_MSG_NO_SYMBOL(FBSVCMGR, 54, "Attaching to services manager:")
FB_IMPL_MSG_NO_SYMBOL(FBSVCMGR, 55, "Information requests:")
FB_IMPL_MSG_NO_SYMBOL(FBSVCMGR, 56, "Actions:")
FB_IMPL_MSG_NO_SYMBOL(FBSVCMGR, 57, "Server capabilities:")
FB_IMPL_MSG(FBSVCMGR, 58, fbsvcmgr_info_limbo, -901, "00", "000", "Unknown tag (@1) in isc_info_svc_limbo_trans block after isc_svc_query()")
FB_IMPL_MSG(FBSVCMGR, 59, fbsvcmgr_limbo_state, -901, "00", "000", "Unknown tag (@1) in isc_spb_tra_state block after isc_svc_query()")
FB_IMPL_MSG(FBSVCMGR, 60, fbsvcmgr_limbo_advise, -901, "00", "000", "Unknown tag (@1) in isc_spb_tra_advise block after isc_svc_query()")
FB_IMPL_MSG(FBSVCMGR, 61, fbsvcmgr_bad_rm, -901, "00", "000", "Wrong value for replica mode")
