FB_IMPL_MSG(GFIX, 1, gfix_db_name, -901, "00", "000", "data base file name (@1) already given")
FB_IMPL_MSG(GFIX, 2, gfix_invalid_sw, -901, "00", "000", "invalid switch @1")
FB_IMPL_MSG_SYMBOL(GFIX, 3, gfix_version, "gfix version @1")
FB_IMPL_MSG(GFIX, 4, gfix_incmp_sw, -901, "00", "000", "incompatible switch combination")
FB_IMPL_MSG(GFIX, 5, gfix_replay_req, -901, "00", "000", "replay log pathname required")
FB_IMPL_MSG(GFIX, 6, gfix_pgbuf_req, -901, "00", "000", "number of page buffers for cache required")
FB_IMPL_MSG(GFIX, 7, gfix_val_req, -901, "00", "000", "numeric value required")
FB_IMPL_MSG(GFIX, 8, gfix_pval_req, -901, "00", "000", "positive numeric value required")
FB_IMPL_MSG(GFIX, 9, gfix_trn_req, -901, "00", "000", "number of transactions per sweep required")
FB_IMPL_MSG_SYMBOL(GFIX, 10, gfix_trn_all_req, "transaction number or \"all\" required")
FB_IMPL_MSG_SYMBOL(GFIX, 11, gfix_sync_req, "\"sync\" or \"async\" required")
FB_IMPL_MSG(GFIX, 12, gfix_full_req, -901, "00", "000", "\"full\" or \"reserve\" required")
FB_IMPL_MSG(GFIX, 13, gfix_usrname_req, -901, "00", "000", "user name required")
FB_IMPL_MSG(GFIX, 14, gfix_pass_req, -901, "00", "000", "password required")
FB_IMPL_MSG(GFIX, 15, gfix_subs_name, -901, "00", "000", "subsystem name")
FB_IMPL_MSG(GFIX, 16, gfix_wal_req, -901, "00", "000", "\"wal\" required")
FB_IMPL_MSG(GFIX, 17, gfix_sec_req, -901, "00", "000", "number of seconds required")
FB_IMPL_MSG(GFIX, 18, gfix_nval_req, -901, "00", "000", "numeric value between 0 and 32767 inclusive required")
FB_IMPL_MSG(GFIX, 19, gfix_type_shut, -901, "00", "000", "must specify type of shutdown")
FB_IMPL_MSG(GFIX, 20, gfix_retry, -901, "00", "000", "please retry, specifying an option")
FB_IMPL_MSG_SYMBOL(GFIX, 21, gfix_opt, "plausible options are:")
FB_IMPL_MSG_SYMBOL(GFIX, 22, gfix_qualifiers, "\\n    Options can be abbreviated to the unparenthesized characters")
FB_IMPL_MSG(GFIX, 23, gfix_retry_db, -901, "00", "000", "please retry, giving a database name")
FB_IMPL_MSG_SYMBOL(GFIX, 24, gfix_summary, "Summary of validation errors")
FB_IMPL_MSG_SYMBOL(GFIX, 25, gfix_opt_active, "   -ac(tivate_shadow)   activate shadow file for database usage")
FB_IMPL_MSG_SYMBOL(GFIX, 26, gfix_opt_attach, "   -at(tach)            shutdown new database attachments")
FB_IMPL_MSG_SYMBOL(GFIX, 27, gfix_opt_begin_log, "	-begin_log	begin logging for replay utility")
FB_IMPL_MSG_SYMBOL(GFIX, 28, gfix_opt_buffers, "   -b(uffers)           set page buffers <n>")
FB_IMPL_MSG_SYMBOL(GFIX, 29, gfix_opt_commit, "   -co(mmit)            commit transaction <tr / all>")
FB_IMPL_MSG_SYMBOL(GFIX, 30, gfix_opt_cache, "   -ca(che)             shutdown cache manager")
FB_IMPL_MSG_SYMBOL(GFIX, 31, gfix_opt_disable, "	-disable	disable WAL")
FB_IMPL_MSG_SYMBOL(GFIX, 32, gfix_opt_full, "   -fu(ll)              validate record fragments (-v)")
FB_IMPL_MSG_SYMBOL(GFIX, 33, gfix_opt_force, "   -fo(rce_shutdown)    force database shutdown")
FB_IMPL_MSG_SYMBOL(GFIX, 34, gfix_opt_housekeep, "   -h(ousekeeping)      set sweep interval <n>")
FB_IMPL_MSG_SYMBOL(GFIX, 35, gfix_opt_ignore, "   -i(gnore)            ignore checksum errors")
FB_IMPL_MSG_SYMBOL(GFIX, 36, gfix_opt_kill, "   -k(ill_shadow)       kill all unavailable shadow files")
FB_IMPL_MSG_SYMBOL(GFIX, 37, gfix_opt_list, "   -l(ist)              show limbo transactions")
FB_IMPL_MSG_SYMBOL(GFIX, 38, gfix_opt_mend, "   -me(nd)              prepare corrupt database for backup")
FB_IMPL_MSG_SYMBOL(GFIX, 39, gfix_opt_no_update, "   -n(o_update)         read-only validation (-v)")
FB_IMPL_MSG_SYMBOL(GFIX, 40, gfix_opt_online, "   -o(nline)            database online <single / multi / normal>")
FB_IMPL_MSG_SYMBOL(GFIX, 41, gfix_opt_prompt, "   -pr(ompt)            prompt for commit/rollback (-l)")
FB_IMPL_MSG_SYMBOL(GFIX, 42, gfix_opt_password, "   -pa(ssword)          default password")
FB_IMPL_MSG_SYMBOL(GFIX, 43, gfix_opt_quit_log, "	-quit_log	quit logging for replay utility")
FB_IMPL_MSG_SYMBOL(GFIX, 44, gfix_opt_rollback, "   -r(ollback)          rollback transaction <tr / all>")
FB_IMPL_MSG_SYMBOL(GFIX, 45, gfix_opt_sweep, "   -sw(eep)             force garbage collection")
FB_IMPL_MSG_SYMBOL(GFIX, 46, gfix_opt_shut, "   -sh(utdown)          shutdown <full / single / multi>")
FB_IMPL_MSG_SYMBOL(GFIX, 47, gfix_opt_two_phase, "   -tw(o_phase)         perform automated two-phase recovery")
FB_IMPL_MSG_SYMBOL(GFIX, 48, gfix_opt_tran, "   -tra(nsaction)       shutdown transaction startup")
FB_IMPL_MSG_SYMBOL(GFIX, 49, gfix_opt_use, "   -u(se)               use full or reserve space for versions")
FB_IMPL_MSG_SYMBOL(GFIX, 50, gfix_opt_user, "   -user                default user name")
FB_IMPL_MSG_SYMBOL(GFIX, 51, gfix_opt_validate, "   -v(alidate)          validate database structure")
FB_IMPL_MSG_SYMBOL(GFIX, 52, gfix_opt_write, "   -w(rite)             write synchronously or asynchronously")
FB_IMPL_MSG_SYMBOL(GFIX, 53, gfix_opt_x, "   -x                   set debug on")
FB_IMPL_MSG_SYMBOL(GFIX, 54, gfix_opt_z, "   -z                   print software version number")
FB_IMPL_MSG_SYMBOL(GFIX, 55, gfix_rec_err, "\\n	Number of record level errors	: @1")
FB_IMPL_MSG_SYMBOL(GFIX, 56, gfix_blob_err, "	Number of Blob page errors	: @1")
FB_IMPL_MSG_SYMBOL(GFIX, 57, gfix_data_err, "	Number of data page errors	: @1")
FB_IMPL_MSG_SYMBOL(GFIX, 58, gfix_index_err, "	Number of index page errors	: @1")
FB_IMPL_MSG_SYMBOL(GFIX, 59, gfix_pointer_err, "	Number of pointer page errors	: @1")
FB_IMPL_MSG_SYMBOL(GFIX, 60, gfix_trn_err, "	Number of transaction page errors	: @1")
FB_IMPL_MSG_SYMBOL(GFIX, 61, gfix_db_err, "	Number of database page errors	: @1")
FB_IMPL_MSG_SYMBOL(GFIX, 62, gfix_bad_block, "bad block type")
FB_IMPL_MSG(GFIX, 63, gfix_exceed_max, -901, "00", "000", "internal block exceeds maximum size")
FB_IMPL_MSG(GFIX, 64, gfix_corrupt_pool, -901, "00", "000", "corrupt pool")
FB_IMPL_MSG(GFIX, 65, gfix_mem_exhausted, -901, "00", "000", "virtual memory exhausted")
FB_IMPL_MSG(GFIX, 66, gfix_bad_pool, -901, "00", "000", "bad pool id")
FB_IMPL_MSG(GFIX, 67, gfix_trn_not_valid, -901, "00", "000", "Transaction state @1 not in valid range.")
FB_IMPL_MSG_SYMBOL(GFIX, 68, gfix_dbg_attach, "ATTACH_DATABASE: attempted attach of @1,")
FB_IMPL_MSG_SYMBOL(GFIX, 69, gfix_dbg_failed, " failed")
FB_IMPL_MSG_SYMBOL(GFIX, 70, gfix_dbg_success, " succeeded")
FB_IMPL_MSG_SYMBOL(GFIX, 71, gfix_trn_limbo, "Transaction @1 is in limbo.")
FB_IMPL_MSG_SYMBOL(GFIX, 72, gfix_try_again, "More limbo transactions than fit.  Try again")
FB_IMPL_MSG_SYMBOL(GFIX, 73, gfix_unrec_item, "Unrecognized info item @1")
FB_IMPL_MSG_SYMBOL(GFIX, 74, gfix_commit_violate, "A commit of transaction @1 will violate two-phase commit.")
FB_IMPL_MSG_SYMBOL(GFIX, 75, gfix_preserve, "A rollback of transaction @1 is needed to preserve two-phase commit.")
FB_IMPL_MSG_SYMBOL(GFIX, 76, gfix_part_commit, "Transaction @1 has already been partially committed.")
FB_IMPL_MSG_SYMBOL(GFIX, 77, gfix_rback_violate, "A rollback of this transaction will violate two-phase commit.")
FB_IMPL_MSG_SYMBOL(GFIX, 78, gfix_part_commit2, "Transaction @1 has been partially committed.")
FB_IMPL_MSG_SYMBOL(GFIX, 79, gfix_commit_pres, "A commit is necessary to preserve the two-phase commit.")
FB_IMPL_MSG_SYMBOL(GFIX, 80, gfix_insuff_info, "Insufficient information is available to determine")
FB_IMPL_MSG_SYMBOL(GFIX, 81, gfix_action, "a proper action for transaction @1.")
FB_IMPL_MSG_SYMBOL(GFIX, 82, gfix_all_prep, "Transaction @1: All subtransactions have been prepared.")
FB_IMPL_MSG_SYMBOL(GFIX, 83, gfix_comm_rback, "Either commit or rollback is possible.")
FB_IMPL_MSG(GFIX, 84, gfix_unexp_eoi, -901, "00", "000", "unexpected end of input")
FB_IMPL_MSG_SYMBOL(GFIX, 85, gfix_ask, "Commit, rollback, or neither (c, r, or n)?")
FB_IMPL_MSG_SYMBOL(GFIX, 86, gfix_reattach_failed, "Could not reattach to database for transaction @1.")
FB_IMPL_MSG_SYMBOL(GFIX, 87, gfix_org_path, "Original path: @1")
FB_IMPL_MSG_SYMBOL(GFIX, 88, gfix_enter_path, "Enter a valid path:")
FB_IMPL_MSG_SYMBOL(GFIX, 89, gfix_att_unsucc, "Attach unsuccessful.")
FB_IMPL_MSG(GFIX, 90, gfix_recon_fail, -901, "00", "000", "failed to reconnect to a transaction in database @1")
FB_IMPL_MSG_SYMBOL(GFIX, 91, gfix_trn2, "Transaction @1:")
FB_IMPL_MSG_SYMBOL(GFIX, 92, gfix_mdb_trn, "  Multidatabase transaction:")
FB_IMPL_MSG_SYMBOL(GFIX, 93, gfix_host_site, "    Host Site: @1")
FB_IMPL_MSG_SYMBOL(GFIX, 94, gfix_trn, "    Transaction @1")
FB_IMPL_MSG_SYMBOL(GFIX, 95, gfix_prepared, "has been prepared.")
FB_IMPL_MSG_SYMBOL(GFIX, 96, gfix_committed, "has been committed.")
FB_IMPL_MSG_SYMBOL(GFIX, 97, gfix_rolled_back, "has been rolled back.")
FB_IMPL_MSG_SYMBOL(GFIX, 98, gfix_not_available, "is not available.")
FB_IMPL_MSG_SYMBOL(GFIX, 99, gfix_not_prepared, "is not found, assumed not prepared.")
FB_IMPL_MSG_SYMBOL(GFIX, 100, gfix_be_committed, "is not found, assumed to be committed.")
FB_IMPL_MSG_SYMBOL(GFIX, 101, gfix_rmt_site, "        Remote Site: @1")
FB_IMPL_MSG_SYMBOL(GFIX, 102, gfix_db_path, "        Database Path: @1")
FB_IMPL_MSG_SYMBOL(GFIX, 103, gfix_auto_comm, "  Automated recovery would commit this transaction.")
FB_IMPL_MSG_SYMBOL(GFIX, 104, gfix_auto_rback, "  Automated recovery would rollback this transaction.")
FB_IMPL_MSG_SYMBOL(GFIX, 105, gfix_warning, "Warning: Multidatabase transaction is in inconsistent state for recovery.")
FB_IMPL_MSG_SYMBOL(GFIX, 106, gfix_trn_was_comm, "Transaction @1 was committed, but prior ones were rolled back.")
FB_IMPL_MSG_SYMBOL(GFIX, 107, gfix_trn_was_rback, "Transaction @1 was rolled back, but prior ones were committed.")
FB_IMPL_MSG(GFIX, 108, gfix_trn_unknown, -901, "00", "000", "Transaction description item unknown")
FB_IMPL_MSG_SYMBOL(GFIX, 109, gfix_opt_mode, "   -mo(de)              read_only or read_write database")
FB_IMPL_MSG(GFIX, 110, gfix_mode_req, -901, "00", "000", "\"read_only\" or \"read_write\" required")
FB_IMPL_MSG_SYMBOL(GFIX, 111, gfix_opt_SQL_dialect, "   -sq(l_dialect)       set database dialect n")
FB_IMPL_MSG_SYMBOL(GFIX, 112, gfix_SQL_dialect, "database SQL dialect must be one of '@1'")
FB_IMPL_MSG_SYMBOL(GFIX, 113, gfix_dialect_req, "dialect number required")
FB_IMPL_MSG(GFIX, 114, gfix_pzval_req, -901, "00", "000", "positive or zero numeric value required")
FB_IMPL_MSG_SYMBOL(GFIX, 115, gfix_opt_trusted, "   -tru(sted)           use trusted authentication")
FB_IMPL_MSG_NO_SYMBOL(GFIX, 116, "could not open password file @1, errno @2")
FB_IMPL_MSG_NO_SYMBOL(GFIX, 117, "could not read password file @1, errno @2")
FB_IMPL_MSG_NO_SYMBOL(GFIX, 118, "empty password file @1")
FB_IMPL_MSG_NO_SYMBOL(GFIX, 119, "   -fe(tch_password)    fetch password from file")
FB_IMPL_MSG_NO_SYMBOL(GFIX, 120, "usage: gfix [options] <database>")
FB_IMPL_MSG_SYMBOL(GFIX, 121, gfix_opt_nolinger, "   -nol(inger)          close database ignoring linger setting for it")
FB_IMPL_MSG_SYMBOL(GFIX, 122, gfix_pip_err, "	Number of inventory page errors	: @1")
FB_IMPL_MSG_SYMBOL(GFIX, 123, gfix_rec_warn, "	Number of record level warnings	: @1")
FB_IMPL_MSG_SYMBOL(GFIX, 124, gfix_blob_warn, "	Number of blob page warnings	: @1")
FB_IMPL_MSG_SYMBOL(GFIX, 125, gfix_data_warn, "	Number of data page warnings	: @1")
FB_IMPL_MSG_SYMBOL(GFIX, 126, gfix_index_warn, "	Number of index page warnings	: @1")
FB_IMPL_MSG_SYMBOL(GFIX, 127, gfix_pointer_warn, "	Number of pointer page warnings	: @1")
FB_IMPL_MSG_SYMBOL(GFIX, 128, gfix_trn_warn, "	Number of transaction page warnings	: @1")
FB_IMPL_MSG_SYMBOL(GFIX, 129, gfix_db_warn, "	Number of database page warnings	: @1")
FB_IMPL_MSG_SYMBOL(GFIX, 130, gfix_pip_warn, "	Number of inventory page warnings	: @1")
FB_IMPL_MSG_SYMBOL(GFIX, 131, gfix_opt_icu, "   -icu                 fix database to be usable with present ICU version")
FB_IMPL_MSG_SYMBOL(GFIX, 132, gfix_opt_role, "   -role                set SQL role name")
FB_IMPL_MSG_SYMBOL(GFIX, 133, gfix_role_req, "SQL role name required")
FB_IMPL_MSG_SYMBOL(GFIX, 134, gfix_opt_repl, "   -repl(ica)           replica mode <none / read_only / read_write>")
FB_IMPL_MSG_SYMBOL(GFIX, 135, gfix_repl_mode_req, "replica mode (none / read_only / read_write) required")
FB_IMPL_MSG_SYMBOL(GFIX, 136, gfix_opt_parallel, "   -par(allel)          parallel workers <n> (-sweep, -icu)")
FB_IMPL_MSG_SYMBOL(GFIX, 137, gfix_opt_upgrade, "   -up(grade)           upgrade database ODS")
