FB_IMPL_MSG_NO_SYMBOL(JRD, 0, "")
FB_IMPL_MSG(JRD, 1, arith_except, -802, "22", "000", "arithmetic exception, numeric overflow, or string truncation")
FB_IMPL_MSG(JRD, 2, bad_dbkey, -901, "HY", "000", "invalid database key")
FB_IMPL_MSG(JRD, 3, bad_db_format, -922, "HY", "000", "file @1 is not a valid database")
FB_IMPL_MSG(JRD, 4, bad_db_handle, -904, "08", "003", "invalid database handle (no active connection)")
FB_IMPL_MSG(JRD, 5, bad_dpb_content, -924, "HY", "000", "bad parameters on attach or create database")
FB_IMPL_MSG(JRD, 6, bad_dpb_form, -901, "HY", "000", "unrecognized database parameter block")
FB_IMPL_MSG(JRD, 7, bad_req_handle, -901, "42", "000", "invalid request handle")
FB_IMPL_MSG(JRD, 8, bad_segstr_handle, -901, "42", "000", "invalid BLOB handle")
FB_IMPL_MSG(JRD, 9, bad_segstr_id, -901, "42", "000", "invalid BLOB ID")
FB_IMPL_MSG(JRD, 10, bad_tpb_content, -901, "HY", "000", "invalid parameter in transaction parameter block")
FB_IMPL_MSG(JRD, 11, bad_tpb_form, -901, "HY", "000", "invalid format for transaction parameter block")
FB_IMPL_MSG(JRD, 12, bad_trans_handle, -901, "08", "003", "invalid transaction handle (expecting explicit transaction start)")
FB_IMPL_MSG(JRD, 13, bug_check, -902, "XX", "000", "internal Firebird consistency check (@1)")
FB_IMPL_MSG(JRD, 14, convert_error, -413, "22", "018", "conversion error from string \"@1\"")
FB_IMPL_MSG(JRD, 15, db_corrupt, -902, "XX", "001", "database file appears corrupt (@1)")
FB_IMPL_MSG(JRD, 16, deadlock, -913, "40", "001", "deadlock")
FB_IMPL_MSG(JRD, 17, excess_trans, -901, "HY", "000", "attempt to start more than @1 transactions")
FB_IMPL_MSG(JRD, 18, from_no_match, 100, "01", "000", "no match for first value expression")
FB_IMPL_MSG(JRD, 19, infinap, -901, "HY", "000", "information type inappropriate for object specified")
FB_IMPL_MSG(JRD, 20, infona, -901, "HY", "000", "no information of this type available for object specified")
FB_IMPL_MSG(JRD, 21, infunk, -901, "HY", "000", "unknown information item")
FB_IMPL_MSG(JRD, 22, integ_fail, -901, "27", "000", "action cancelled by trigger (@1) to preserve data integrity")
FB_IMPL_MSG(JRD, 23, invalid_blr, -104, "HY", "000", "invalid request BLR at offset @1")
FB_IMPL_MSG(JRD, 24, io_error, -902, "08", "001", "I/O error during \"@1\" operation for file \"@2\"")
FB_IMPL_MSG(JRD, 25, lock_conflict, -901, "40", "001", "lock conflict on no wait transaction")
FB_IMPL_MSG(JRD, 26, metadata_corrupt, -902, "XX", "001", "corrupt system table")
FB_IMPL_MSG(JRD, 27, not_valid, -625, "23", "000", "validation error for column @1, value \"@2\"")
FB_IMPL_MSG(JRD, 28, no_cur_rec, -508, "22", "000", "no current record for fetch operation")
FB_IMPL_MSG(JRD, 29, no_dup, -803, "23", "000", "attempt to store duplicate value (visible to active transactions) in unique index \"@1\"")
FB_IMPL_MSG(JRD, 30, no_finish, -901, "HY", "000", "program attempted to exit without finishing database")
FB_IMPL_MSG(JRD, 31, no_meta_update, -607, "42", "000", "unsuccessful metadata update")
FB_IMPL_MSG(JRD, 32, no_priv, -551, "28", "000", "no permission for @1 access to @2 @3")
FB_IMPL_MSG(JRD, 33, no_recon, -901, "HY", "000", "transaction is not in limbo")
FB_IMPL_MSG(JRD, 34, no_record, 100, "01", "000", "invalid database key")
FB_IMPL_MSG(JRD, 35, no_segstr_close, -901, "HY", "000", "BLOB was not closed")
FB_IMPL_MSG(JRD, 36, obsolete_metadata, -820, "HY", "000", "metadata is obsolete")
FB_IMPL_MSG(JRD, 37, open_trans, -901, "01", "002", "cannot disconnect database with open transactions (@1 active)")
FB_IMPL_MSG(JRD, 38, port_len, -901, "HY", "000", "message length error (encountered @1, expected @2)")
FB_IMPL_MSG(JRD, 39, read_only_field, -151, "42", "000", "attempted update of read-only column @1")
FB_IMPL_MSG(JRD, 40, read_only_rel, -150, "42", "000", "attempted update of read-only table")
FB_IMPL_MSG(JRD, 41, read_only_trans, -817, "25", "006", "attempted update during read-only transaction")
FB_IMPL_MSG(JRD, 42, read_only_view, -150, "42", "000", "cannot update read-only view @1")
FB_IMPL_MSG(JRD, 43, req_no_trans, -901, "25", "000", "no transaction for request")
FB_IMPL_MSG(JRD, 44, req_sync, -901, "HY", "000", "request synchronization error")
FB_IMPL_MSG(JRD, 45, req_wrong_db, -901, "HY", "000", "request referenced an unavailable database")
FB_IMPL_MSG(JRD, 46, segment, 101, "01", "000", "segment buffer length shorter than expected")
FB_IMPL_MSG(JRD, 47, segstr_eof, 100, "01", "000", "attempted retrieval of more segments than exist")
FB_IMPL_MSG(JRD, 48, segstr_no_op, -402, "HY", "000", "attempted invalid operation on a BLOB")
FB_IMPL_MSG(JRD, 49, segstr_no_read, -901, "HY", "000", "attempted read of a new, open BLOB")
FB_IMPL_MSG(JRD, 50, segstr_no_trans, -901, "HY", "000", "attempted action on BLOB outside transaction")
FB_IMPL_MSG(JRD, 51, segstr_no_write, -817, "HY", "000", "attempted write to read-only BLOB")
FB_IMPL_MSG(JRD, 52, segstr_wrong_db, -901, "HY", "000", "attempted reference to BLOB in unavailable database")
FB_IMPL_MSG(JRD, 53, sys_request, -902, "HY", "000", "operating system directive @1 failed")
FB_IMPL_MSG(JRD, 54, stream_eof, -596, "HY", "109", "attempt to fetch past the last record in a record stream")
FB_IMPL_MSG(JRD, 55, unavailable, -904, "08", "001", "unavailable database")
FB_IMPL_MSG(JRD, 56, unres_rel, -901, "HY", "000", "table @1 was omitted from the transaction reserving list")
FB_IMPL_MSG(JRD, 57, uns_ext, -901, "HY", "000", "request includes a DSRI extension not supported in this implementation")
FB_IMPL_MSG(JRD, 58, wish_list, -901, "0A", "000", "feature is not supported")
FB_IMPL_MSG(JRD, 59, wrong_ods, -820, "HY", "000", "unsupported on-disk structure for file @1; found @2.@3, support @4.@5")
FB_IMPL_MSG(JRD, 60, wronumarg, -804, "07", "002", "wrong number of arguments on call")
FB_IMPL_MSG(JRD, 61, imp_exc, -904, "54", "000", "Implementation limit exceeded")
FB_IMPL_MSG(JRD, 62, random, -901, "HY", "000", "@1")
FB_IMPL_MSG(JRD, 63, fatal_conflict, -901, "HY", "000", "unrecoverable conflict with limbo transaction @1")
FB_IMPL_MSG(JRD, 64, badblk, -902, "XX", "000", "internal error")
FB_IMPL_MSG(JRD, 65, invpoolcl, -902, "XX", "000", "internal error")
FB_IMPL_MSG(JRD, 66, nopoolids, -904, "HY", "000", "too many requests")
FB_IMPL_MSG(JRD, 67, relbadblk, -902, "XX", "000", "internal error")
FB_IMPL_MSG(JRD, 68, blktoobig, -902, "54", "000", "block size exceeds implementation restriction")
FB_IMPL_MSG(JRD, 69, bufexh, -904, "HY", "001", "buffer exhausted")
FB_IMPL_MSG(JRD, 70, syntaxerr, -104, "HY", "000", "BLR syntax error: expected @1 at offset @2, encountered @3")
FB_IMPL_MSG(JRD, 71, bufinuse, -904, "HY", "000", "buffer in use")
FB_IMPL_MSG(JRD, 72, bdbincon, -901, "XX", "000", "internal error")
FB_IMPL_MSG(JRD, 73, reqinuse, -904, "HY", "000", "request in use")
FB_IMPL_MSG(JRD, 74, badodsver, -902, "HY", "000", "incompatible version of on-disk structure")
FB_IMPL_MSG(JRD, 75, relnotdef, -219, "42", "S02", "table @1 is not defined")
FB_IMPL_MSG(JRD, 76, fldnotdef, -205, "42", "S22", "column @1 is not defined in table @2")
FB_IMPL_MSG(JRD, 77, dirtypage, -902, "XX", "000", "internal error")
FB_IMPL_MSG(JRD, 78, waifortra, -902, "XX", "000", "internal error")
FB_IMPL_MSG(JRD, 79, doubleloc, -902, "XX", "000", "internal error")
FB_IMPL_MSG(JRD, 80, nodnotfnd, -902, "XX", "000", "internal error")
FB_IMPL_MSG(JRD, 81, dupnodfnd, -902, "XX", "000", "internal error")
FB_IMPL_MSG(JRD, 82, locnotmar, -902, "XX", "000", "internal error")
FB_IMPL_MSG(JRD, 83, badpagtyp, -689, "42", "000", "page @1 is of wrong type (expected @2, found @3)")
FB_IMPL_MSG(JRD, 84, corrupt, -902, "XX", "000", "database corrupted")
FB_IMPL_MSG(JRD, 85, badpage, -902, "42", "000", "checksum error on database page @1")
FB_IMPL_MSG(JRD, 86, badindex, -902, "XX", "002", "index is broken")
FB_IMPL_MSG(JRD, 87, dbbnotzer, -901, "HY", "000", "database handle not zero")
FB_IMPL_MSG(JRD, 88, tranotzer, -901, "25", "000", "transaction handle not zero")
FB_IMPL_MSG(JRD, 89, trareqmis, -902, "25", "000", "transaction--request mismatch (synchronization error)")
FB_IMPL_MSG(JRD, 90, badhndcnt, -902, "HY", "000", "bad handle count")
FB_IMPL_MSG(JRD, 91, wrotpbver, -902, "HY", "000", "wrong version of transaction parameter block")
FB_IMPL_MSG(JRD, 92, wroblrver, -902, "HY", "000", "unsupported BLR version (expected @1, encountered @2)")
FB_IMPL_MSG(JRD, 93, wrodpbver, -902, "HY", "000", "wrong version of database parameter block")
FB_IMPL_MSG(JRD, 94, blobnotsup, -402, "42", "000", "BLOB and array data types are not supported for @1 operation")
FB_IMPL_MSG(JRD, 95, badrelation, -902, "XX", "001", "database corrupted")
FB_IMPL_MSG(JRD, 96, nodetach, -902, "XX", "000", "internal error")
FB_IMPL_MSG(JRD, 97, notremote, -902, "XX", "000", "internal error")
FB_IMPL_MSG(JRD, 98, trainlim, -901, "25", "000", "transaction in limbo")
FB_IMPL_MSG(JRD, 99, notinlim, -901, "25", "000", "transaction not in limbo")
FB_IMPL_MSG(JRD, 100, traoutsta, -901, "25", "000", "transaction outstanding")
FB_IMPL_MSG(JRD, 101, connect_reject, -923, "08", "004", "connection rejected by remote interface")
FB_IMPL_MSG(JRD, 102, dbfile, -902, "XX", "000", "internal error")
FB_IMPL_MSG(JRD, 103, orphan, -902, "XX", "000", "internal error")
FB_IMPL_MSG(JRD, 104, no_lock_mgr, -904, "HY", "000", "no lock manager available")
FB_IMPL_MSG(JRD, 105, ctxinuse, -104, "HY", "000", "context already in use (BLR error)")
FB_IMPL_MSG(JRD, 106, ctxnotdef, -104, "HY", "000", "context not defined (BLR error)")
FB_IMPL_MSG(JRD, 107, datnotsup, -402, "42", "000", "data operation not supported")
FB_IMPL_MSG(JRD, 108, badmsgnum, -901, "HY", "000", "undefined message number")
FB_IMPL_MSG(JRD, 109, badparnum, -104, "HY", "000", "undefined parameter number")
FB_IMPL_MSG(JRD, 110, virmemexh, -904, "HY", "001", "unable to allocate memory from operating system")
FB_IMPL_MSG(JRD, 111, blocking_signal, -901, "HY", "000", "blocking signal has been received")
FB_IMPL_MSG(JRD, 112, lockmanerr, -902, "40", "001", "lock manager error")
FB_IMPL_MSG(JRD, 113, journerr, -924, "HY", "000", "communication error with journal \"@1\"")
FB_IMPL_MSG(JRD, 114, keytoobig, -664, "42", "000", "key size exceeds implementation restriction for index \"@1\"")
FB_IMPL_MSG(JRD, 115, nullsegkey, -407, "HY", "000", "null segment of UNIQUE KEY")
FB_IMPL_MSG(JRD, 116, sqlerr, -902, "00", "000", "SQL error code = @1")
FB_IMPL_MSG(JRD, 117, wrodynver, -820, "HY", "000", "wrong DYN version")
FB_IMPL_MSG(JRD, 118, funnotdef, -172, "39", "000", "function @1 is not defined")
FB_IMPL_MSG(JRD, 119, funmismat, -171, "39", "000", "function @1 could not be matched")
FB_IMPL_MSG(JRD, 120, bad_msg_vec, -104, "22", "001", "")
FB_IMPL_MSG(JRD, 121, bad_detach, -924, "08", "007", "database detach completed with errors")
FB_IMPL_MSG(JRD, 122, noargacc_read, -901, "HY", "000", "database system cannot read argument @1")
FB_IMPL_MSG(JRD, 123, noargacc_write, -901, "HY", "000", "database system cannot write argument @1")
FB_IMPL_MSG(JRD, 124, read_only, -817, "42", "000", "operation not supported")
FB_IMPL_MSG(JRD, 125, ext_err, -677, "42", "000", "@1 extension error")
FB_IMPL_MSG(JRD, 126, non_updatable, -150, "42", "000", "not updatable")
FB_IMPL_MSG(JRD, 127, no_rollback, -926, "25", "S02", "no rollback performed")
FB_IMPL_MSG(JRD, 128, bad_sec_info, -902, "HY", "000", "")
FB_IMPL_MSG(JRD, 129, invalid_sec_info, -902, "28", "000", "")
FB_IMPL_MSG(JRD, 130, misc_interpreted, -901, "HY", "000", "@1")
FB_IMPL_MSG(JRD, 131, update_conflict, -904, "40", "001", "update conflicts with concurrent update")
FB_IMPL_MSG(JRD, 132, unlicensed, -906, "HY", "000", "product @1 is not licensed")
FB_IMPL_MSG(JRD, 133, obj_in_use, -904, "42", "000", "object @1 is in use")
FB_IMPL_MSG(JRD, 134, nofilter, -413, "HY", "000", "filter not found to convert type @1 to type @2")
FB_IMPL_MSG(JRD, 135, shadow_accessed, -904, "00", "000", "cannot attach active shadow file")
FB_IMPL_MSG(JRD, 136, invalid_sdl, -104, "HY", "000", "invalid slice description language at offset @1")
FB_IMPL_MSG(JRD, 137, out_of_bounds, -406, "42", "000", "subscript out of bounds")
FB_IMPL_MSG(JRD, 138, invalid_dimension, -171, "42", "000", "column not array or invalid dimensions (expected @1, encountered @2)")
FB_IMPL_MSG(JRD, 139, rec_in_limbo, -911, "HY", "000", "record from transaction @1 is stuck in limbo")
FB_IMPL_MSG(JRD, 140, shadow_missing, -904, "HY", "000", "a file in manual shadow @1 is unavailable")
FB_IMPL_MSG(JRD, 141, cant_validate, -923, "HY", "000", "secondary server attachments cannot validate databases")
FB_IMPL_MSG(JRD, 142, cant_start_journal, -923, "HY", "000", "secondary server attachments cannot start journaling")
FB_IMPL_MSG(JRD, 143, gennotdef, -204, "42", "000", "generator @1 is not defined")
FB_IMPL_MSG(JRD, 144, cant_start_logging, -923, "HY", "000", "secondary server attachments cannot start logging")
FB_IMPL_MSG(JRD, 145, bad_segstr_type, -685, "42", "000", "invalid BLOB type for operation")
FB_IMPL_MSG(JRD, 146, foreign_key, -530, "23", "000", "violation of FOREIGN KEY constraint \"@1\" on table \"@2\"")
FB_IMPL_MSG(JRD, 147, high_minor, -820, "HY", "000", "minor version too high found @1 expected @2")
FB_IMPL_MSG(JRD, 148, tra_state, -901, "00", "000", "transaction @1 is @2")
FB_IMPL_MSG(JRD, 149, trans_invalid, -532, "25", "000", "transaction marked invalid and cannot be committed")
FB_IMPL_MSG(JRD, 150, buf_invalid, -902, "HY", "000", "cache buffer for page @1 invalid")
FB_IMPL_MSG(JRD, 151, indexnotdefined, -902, "42", "S12", "there is no index in table @1 with id @2")
FB_IMPL_MSG(JRD, 152, login, -902, "28", "000", "Your user name and password are not defined. Ask your database administrator to set up a Firebird login.")
FB_IMPL_MSG(JRD, 153, invalid_bookmark, -823, "HY", "111", "invalid bookmark handle")
FB_IMPL_MSG(JRD, 154, bad_lock_level, -824, "HY", "000", "invalid lock level @1")
FB_IMPL_MSG(JRD, 155, relation_lock, -615, "40", "001", "lock on table @1 conflicts with existing lock")
FB_IMPL_MSG(JRD, 156, record_lock, -615, "40", "001", "requested record lock conflicts with existing lock")
FB_IMPL_MSG(JRD, 157, max_idx, -692, "54", "000", "maximum indexes per table (@1) exceeded")
FB_IMPL_MSG(JRD, 158, jrn_enable, -902, "HY", "000", "enable journal for database before starting online dump")
FB_IMPL_MSG(JRD, 159, old_failure, -902, "HY", "000", "online dump failure. Retry dump")
FB_IMPL_MSG(JRD, 160, old_in_progress, -902, "HY", "000", "an online dump is already in progress")
FB_IMPL_MSG(JRD, 161, old_no_space, -902, "HY", "000", "no more disk/tape space.  Cannot continue online dump")
FB_IMPL_MSG(JRD, 162, no_wal_no_jrn, -902, "HY", "000", "journaling allowed only if database has Write-ahead Log")
FB_IMPL_MSG(JRD, 163, num_old_files, -902, "HY", "000", "maximum number of online dump files that can be specified is 16")
FB_IMPL_MSG(JRD, 164, wal_file_open, -902, "HY", "000", "error in opening Write-ahead Log file during recovery")
FB_IMPL_MSG(JRD, 165, bad_stmt_handle, -901, "26", "000", "invalid statement handle")
FB_IMPL_MSG(JRD, 166, wal_failure, -902, "HY", "000", "Write-ahead log subsystem failure")
FB_IMPL_MSG(JRD, 167, walw_err, -230, "HY", "000", "WAL Writer error")
FB_IMPL_MSG(JRD, 168, logh_small, -231, "HY", "000", "Log file header of @1 too small")
FB_IMPL_MSG(JRD, 169, logh_inv_version, -232, "HY", "000", "Invalid version of log file @1")
FB_IMPL_MSG(JRD, 170, logh_open_flag, -233, "HY", "000", "Log file @1 not latest in the chain but open flag still set")
FB_IMPL_MSG(JRD, 171, logh_open_flag2, -234, "HY", "000", "Log file @1 not closed properly; database recovery may be required")
FB_IMPL_MSG(JRD, 172, logh_diff_dbname, -235, "HY", "000", "Database name in the log file @1 is different")
FB_IMPL_MSG(JRD, 173, logf_unexpected_eof, -236, "HY", "000", "Unexpected end of log file @1 at offset @2")
FB_IMPL_MSG(JRD, 174, logr_incomplete, -237, "HY", "000", "Incomplete log record at offset @1 in log file @2")
FB_IMPL_MSG(JRD, 175, logr_header_small, -238, "HY", "000", "Log record header too small at offset @1 in log file @2")
FB_IMPL_MSG(JRD, 176, logb_small, -239, "HY", "000", "Log block too small at offset @1 in log file @2")
FB_IMPL_MSG(JRD, 177, wal_illegal_attach, -240, "HY", "000", "Illegal attempt to attach to an uninitialized WAL segment for @1")
FB_IMPL_MSG(JRD, 178, wal_invalid_wpb, -241, "HY", "000", "Invalid WAL parameter block option @1")
FB_IMPL_MSG(JRD, 179, wal_err_rollover, -242, "HY", "000", "Cannot roll over to the next log file @1")
FB_IMPL_MSG(JRD, 180, no_wal, -243, "HY", "000", "database does not use Write-ahead Log")
FB_IMPL_MSG(JRD, 181, drop_wal, -615, "HY", "000", "cannot drop log file when journaling is enabled")
FB_IMPL_MSG(JRD, 182, stream_not_defined, -204, "HY", "000", "reference to invalid stream number")
FB_IMPL_MSG(JRD, 183, wal_subsys_error, -244, "HY", "000", "WAL subsystem encountered error")
FB_IMPL_MSG(JRD, 184, wal_subsys_corrupt, -245, "XX", "000", "WAL subsystem corrupted")
FB_IMPL_MSG(JRD, 185, no_archive, -902, "HY", "000", "must specify archive file when enabling long term journal for databases with round-robin log files")
FB_IMPL_MSG(JRD, 186, shutinprog, -902, "HY", "000", "database @1 shutdown in progress")
FB_IMPL_MSG(JRD, 187, range_in_use, -615, "42", "000", "refresh range number @1 already in use")
FB_IMPL_MSG(JRD, 188, range_not_found, -834, "42", "000", "refresh range number @1 not found")
FB_IMPL_MSG(JRD, 189, charset_not_found, -204, "2C", "000", "CHARACTER SET @1 is not defined")
FB_IMPL_MSG(JRD, 190, lock_timeout, -901, "40", "001", "lock time-out on wait transaction")
FB_IMPL_MSG(JRD, 191, prcnotdef, -204, "42", "000", "procedure @1 is not defined")
FB_IMPL_MSG(JRD, 192, prcmismat, -170, "07", "001", "Input parameter mismatch for procedure @1")
FB_IMPL_MSG(JRD, 193, wal_bugcheck, -246, "XX", "000", "Database @1: WAL subsystem bug for pid @2\n@3")
FB_IMPL_MSG(JRD, 194, wal_cant_expand, -247, "HY", "000", "Could not expand the WAL segment for database @1")
FB_IMPL_MSG(JRD, 195, codnotdef, -204, "HY", "000", "status code @1 unknown")
FB_IMPL_MSG(JRD, 196, xcpnotdef, -204, "HY", "000", "exception @1 not defined")
FB_IMPL_MSG(JRD, 197, except, -836, "HY", "000", "exception @1")
FB_IMPL_MSG(JRD, 198, cache_restart, -837, "HY", "013", "restart shared cache manager")
FB_IMPL_MSG(JRD, 199, bad_lock_handle, -825, "HY", "000", "invalid lock handle")
FB_IMPL_MSG(JRD, 200, jrn_present, -902, "HY", "000", "long-term journaling already enabled")
FB_IMPL_MSG(JRD, 201, wal_err_rollover2, -248, "HY", "000", "Unable to roll over please see Firebird log.")
FB_IMPL_MSG(JRD, 202, wal_err_logwrite, -249, "HY", "000", "WAL I/O error.  Please see Firebird log.")
FB_IMPL_MSG(JRD, 203, wal_err_jrn_comm, -250, "HY", "000", "WAL writer - Journal server communication error.  Please see Firebird log.")
FB_IMPL_MSG(JRD, 204, wal_err_expansion, -251, "HY", "000", "WAL buffers cannot be increased.  Please see Firebird log.")
FB_IMPL_MSG(JRD, 205, wal_err_setup, -252, "HY", "000", "WAL setup error.  Please see Firebird log.")
FB_IMPL_MSG(JRD, 206, wal_err_ww_sync, -253, "HY", "000", "obsolete")
FB_IMPL_MSG(JRD, 207, wal_err_ww_start, -254, "HY", "000", "Cannot start WAL writer for the database @1")
FB_IMPL_MSG(JRD, 208, shutdown, -902, "HY", "000", "database @1 shutdown")
FB_IMPL_MSG(JRD, 209, existing_priv_mod, -553, "28", "000", "cannot modify an existing user privilege")
FB_IMPL_MSG(JRD, 210, primary_key_ref, -616, "42", "000", "Cannot delete PRIMARY KEY being used in FOREIGN KEY definition.")
FB_IMPL_MSG(JRD, 211, primary_key_notnull, -291, "42", "000", "Column used in a PRIMARY constraint must be NOT NULL.")
FB_IMPL_MSG(JRD, 212, ref_cnstrnt_notfound, -204, "42", "000", "Name of Referential Constraint not defined in constraints table.")
FB_IMPL_MSG(JRD, 213, foreign_key_notfound, -660, "42", "000", "Non-existent PRIMARY or UNIQUE KEY specified for FOREIGN KEY.")
FB_IMPL_MSG(JRD, 214, ref_cnstrnt_update, -292, "42", "000", "Cannot update constraints (RDB$REF_CONSTRAINTS).")
FB_IMPL_MSG(JRD, 215, check_cnstrnt_update, -293, "44", "000", "Cannot update constraints (RDB$CHECK_CONSTRAINTS).")
FB_IMPL_MSG(JRD, 216, check_cnstrnt_del, -294, "44", "000", "Cannot delete CHECK constraint entry (RDB$CHECK_CONSTRAINTS)")
FB_IMPL_MSG(JRD, 217, integ_index_seg_del, -618, "42", "000", "Cannot delete index segment used by an Integrity Constraint")
FB_IMPL_MSG(JRD, 218, integ_index_seg_mod, -618, "42", "000", "Cannot update index segment used by an Integrity Constraint")
FB_IMPL_MSG(JRD, 219, integ_index_del, -616, "42", "000", "Cannot delete index used by an Integrity Constraint")
FB_IMPL_MSG(JRD, 220, integ_index_mod, -616, "42", "000", "Cannot modify index used by an Integrity Constraint")
FB_IMPL_MSG(JRD, 221, check_trig_del, -616, "44", "000", "Cannot delete trigger used by a CHECK Constraint")
FB_IMPL_MSG(JRD, 222, check_trig_update, -617, "44", "000", "Cannot update trigger used by a CHECK Constraint")
FB_IMPL_MSG(JRD, 223, cnstrnt_fld_del, -616, "23", "000", "Cannot delete column being used in an Integrity Constraint.")
FB_IMPL_MSG(JRD, 224, cnstrnt_fld_rename, -617, "23", "000", "Cannot rename column being used in an Integrity Constraint.")
FB_IMPL_MSG(JRD, 225, rel_cnstrnt_update, -295, "42", "000", "Cannot update constraints (RDB$RELATION_CONSTRAINTS).")
FB_IMPL_MSG(JRD, 226, constaint_on_view, -150, "42", "000", "Cannot define constraints on views")
FB_IMPL_MSG(JRD, 227, invld_cnstrnt_type, -296, "42", "000", "internal Firebird consistency check (invalid RDB$CONSTRAINT_TYPE)")
FB_IMPL_MSG(JRD, 228, primary_key_exists, -831, "42", "S11", "Attempt to define a second PRIMARY KEY for the same table")
FB_IMPL_MSG(JRD, 229, systrig_update, -607, "HY", "000", "cannot modify or erase a system trigger")
FB_IMPL_MSG(JRD, 230, not_rel_owner, -552, "28", "000", "only the owner of a table may reassign ownership")
FB_IMPL_MSG(JRD, 231, grant_obj_notfound, -204, "01", "007", "could not find object for GRANT")
FB_IMPL_MSG(JRD, 232, grant_fld_notfound, -205, "01", "007", "could not find column for GRANT")
FB_IMPL_MSG(JRD, 233, grant_nopriv, -552, "01", "007", "user does not have GRANT privileges for operation")
FB_IMPL_MSG(JRD, 234, nonsql_security_rel, -84, "28", "000", "object has non-SQL security class defined")
FB_IMPL_MSG(JRD, 235, nonsql_security_fld, -84, "28", "000", "column has non-SQL security class defined")
FB_IMPL_MSG(JRD, 236, wal_cache_err, -255, "HY", "000", "Write-ahead Log without shared cache configuration not allowed")
FB_IMPL_MSG(JRD, 237, shutfail, -902, "HY", "000", "database shutdown unsuccessful")
FB_IMPL_MSG(JRD, 238, check_constraint, -297, "23", "000", "Operation violates CHECK constraint @1 on view or table @2")
FB_IMPL_MSG(JRD, 239, bad_svc_handle, -901, "HY", "000", "invalid service handle")
FB_IMPL_MSG(JRD, 240, shutwarn, -838, "HY", "000", "database @1 shutdown in @2 seconds")
FB_IMPL_MSG(JRD, 241, wrospbver, -901, "HY", "000", "wrong version of service parameter block")
FB_IMPL_MSG(JRD, 242, bad_spb_form, -901, "42", "000", "unrecognized service parameter block")
FB_IMPL_MSG(JRD, 243, svcnotdef, -901, "HY", "000", "service @1 is not defined")
FB_IMPL_MSG(JRD, 244, no_jrn, -902, "HY", "000", "long-term journaling not enabled")
FB_IMPL_MSG(JRD, 245, transliteration_failed, -314, "22", "018", "Cannot transliterate character between character sets")
FB_IMPL_MSG(JRD, 246, start_cm_for_wal, -257, "HY", "000", "WAL defined; Cache Manager must be started first")
FB_IMPL_MSG(JRD, 247, wal_ovflow_log_required, -258, "HY", "000", "Overflow log specification required for round-robin log")
FB_IMPL_MSG(JRD, 248, text_subtype, -204, "42", "000", "Implementation of text subtype @1 not located.")
FB_IMPL_MSG(JRD, 249, dsql_error, -902, "42", "000", "Dynamic SQL Error")
FB_IMPL_MSG(JRD, 250, dsql_command_err, -104, "42", "000", "Invalid command")
FB_IMPL_MSG(JRD, 251, dsql_constant_err, -103, "HY", "004", "Data type for constant unknown")
FB_IMPL_MSG(JRD, 252, dsql_cursor_err, -504, "HY", "015", "Invalid cursor reference")
FB_IMPL_MSG(JRD, 253, dsql_datatype_err, -204, "HY", "004", "Data type unknown")
FB_IMPL_MSG(JRD, 254, dsql_decl_err, -502, "34", "000", "Invalid cursor declaration")
FB_IMPL_MSG(JRD, 255, dsql_cursor_update_err, -510, "24", "000", "Cursor @1 is not updatable")
FB_IMPL_MSG(JRD, 256, dsql_cursor_open_err, -502, "24", "000", "Attempt to reopen an open cursor")
FB_IMPL_MSG(JRD, 257, dsql_cursor_close_err, -501, "24", "000", "Attempt to reclose a closed cursor")
FB_IMPL_MSG(JRD, 258, dsql_field_err, -206, "42", "S22", "Column unknown")
FB_IMPL_MSG(JRD, 259, dsql_internal_err, -104, "XX", "000", "Internal error")
FB_IMPL_MSG(JRD, 260, dsql_relation_err, -204, "42", "S02", "Table unknown")
FB_IMPL_MSG(JRD, 261, dsql_procedure_err, -204, "42", "000", "Procedure unknown")
FB_IMPL_MSG(JRD, 262, dsql_request_err, -518, "42", "000", "Request unknown")
FB_IMPL_MSG(JRD, 263, dsql_sqlda_err, -804, "07", "002", "SQLDA error")
FB_IMPL_MSG(JRD, 264, dsql_var_count_err, -804, "21", "S01", "Count of read-write columns does not equal count of values")
FB_IMPL_MSG(JRD, 265, dsql_stmt_handle, -826, "HY", "000", "Invalid statement handle")
FB_IMPL_MSG(JRD, 266, dsql_function_err, -804, "39", "000", "Function unknown")
FB_IMPL_MSG(JRD, 267, dsql_blob_err, -206, "42", "000", "Column is not a BLOB")
FB_IMPL_MSG(JRD, 268, collation_not_found, -204, "22", "021", "COLLATION @1 for CHARACTER SET @2 is not defined")
FB_IMPL_MSG(JRD, 269, collation_not_for_charset, -204, "22", "021", "COLLATION @1 is not valid for specified CHARACTER SET")
FB_IMPL_MSG(JRD, 270, dsql_dup_option, -104, "42", "000", "Option specified more than once")
FB_IMPL_MSG(JRD, 271, dsql_tran_err, -104, "25", "000", "Unknown transaction option")
FB_IMPL_MSG(JRD, 272, dsql_invalid_array, -104, "HY", "000", "Invalid array reference")
FB_IMPL_MSG(JRD, 273, dsql_max_arr_dim_exceeded, -604, "54", "000", "Array declared with too many dimensions")
FB_IMPL_MSG(JRD, 274, dsql_arr_range_error, -604, "42", "000", "Illegal array dimension range")
FB_IMPL_MSG(JRD, 275, dsql_trigger_err, -204, "HY", "000", "Trigger unknown")
FB_IMPL_MSG(JRD, 276, dsql_subselect_err, -206, "42", "000", "Subselect illegal in this context")
FB_IMPL_MSG(JRD, 277, dsql_crdb_prepare_err, -531, "42", "000", "Cannot prepare a CREATE DATABASE/SCHEMA statement")
FB_IMPL_MSG(JRD, 278, specify_field_err, -157, "42", "000", "must specify column name for view select expression")
FB_IMPL_MSG(JRD, 279, num_field_err, -158, "07", "002", "number of columns does not match select list")
FB_IMPL_MSG(JRD, 280, col_name_err, -806, "42", "000", "Only simple column names permitted for VIEW WITH CHECK OPTION")
FB_IMPL_MSG(JRD, 281, where_err, -807, "42", "000", "No WHERE clause for VIEW WITH CHECK OPTION")
FB_IMPL_MSG(JRD, 282, table_view_err, -808, "42", "000", "Only one table allowed for VIEW WITH CHECK OPTION")
FB_IMPL_MSG(JRD, 283, distinct_err, -809, "42", "000", "DISTINCT, GROUP or HAVING not permitted for VIEW WITH CHECK OPTION")
FB_IMPL_MSG(JRD, 284, key_field_count_err, -832, "42", "000", "FOREIGN KEY column count does not match PRIMARY KEY")
FB_IMPL_MSG(JRD, 285, subquery_err, -810, "42", "000", "No subqueries permitted for VIEW WITH CHECK OPTION")
FB_IMPL_MSG(JRD, 286, expression_eval_err, -833, "42", "000", "expression evaluation not supported")
FB_IMPL_MSG(JRD, 287, node_err, -599, "HY", "000", "gen.c: node not supported")
FB_IMPL_MSG(JRD, 288, command_end_err, -104, "42", "000", "Unexpected end of command")
FB_IMPL_MSG(JRD, 289, index_name, -901, "42", "000", "INDEX @1")
FB_IMPL_MSG(JRD, 290, exception_name, -901, "22", "000", "EXCEPTION @1")
FB_IMPL_MSG(JRD, 291, field_name, -901, "42", "000", "COLUMN @1")
FB_IMPL_MSG(JRD, 292, token_err, -104, "42", "000", "Token unknown")
FB_IMPL_MSG(JRD, 293, union_err, -901, "42", "000", "union not supported")
FB_IMPL_MSG(JRD, 294, dsql_construct_err, -901, "42", "000", "Unsupported DSQL construct")
FB_IMPL_MSG(JRD, 295, field_aggregate_err, -830, "42", "000", "column used with aggregate")
FB_IMPL_MSG(JRD, 296, field_ref_err, -829, "42", "S22", "invalid column reference")
FB_IMPL_MSG(JRD, 297, order_by_err, -208, "42", "000", "invalid ORDER BY clause")
FB_IMPL_MSG(JRD, 298, return_mode_err, -171, "HY", "000", "Return mode by value not allowed for this data type")
FB_IMPL_MSG(JRD, 299, extern_func_err, -170, "38", "000", "External functions cannot have more than 10 parameters")
FB_IMPL_MSG(JRD, 300, alias_conflict_err, -204, "08", "001", "alias @1 conflicts with an alias in the same statement")
FB_IMPL_MSG(JRD, 301, procedure_conflict_error, -204, "42", "000", "alias @1 conflicts with a procedure in the same statement")
FB_IMPL_MSG(JRD, 302, relation_conflict_err, -204, "42", "000", "alias @1 conflicts with a table in the same statement")
FB_IMPL_MSG(JRD, 303, dsql_domain_err, -901, "42", "000", "Illegal use of keyword VALUE")
FB_IMPL_MSG(JRD, 304, idx_seg_err, -663, "42", "000", "segment count of 0 defined for index @1")
FB_IMPL_MSG(JRD, 305, node_name_err, -599, "HY", "000", "A node name is not permitted in a secondary, shadow, cache or log file name")
FB_IMPL_MSG(JRD, 306, table_name, -901, "00", "000", "TABLE @1")
FB_IMPL_MSG(JRD, 307, proc_name, -901, "42", "000", "PROCEDURE @1")
FB_IMPL_MSG(JRD, 308, idx_create_err, -660, "42", "000", "cannot create index @1")
FB_IMPL_MSG(JRD, 309, wal_shadow_err, -259, "HY", "000", "Write-ahead Log with shadowing configuration not allowed")
FB_IMPL_MSG(JRD, 310, dependency, -616, "42", "000", "there are @1 dependencies")
FB_IMPL_MSG(JRD, 311, idx_key_err, -663, "54", "011", "too many keys defined for index @1")
FB_IMPL_MSG(JRD, 312, dsql_file_length_err, -597, "42", "000", "Preceding file did not specify length, so @1 must include starting page number")
FB_IMPL_MSG(JRD, 313, dsql_shadow_number_err, -598, "HY", "000", "Shadow number must be a positive integer")
FB_IMPL_MSG(JRD, 314, dsql_token_unk_err, -104, "42", "000", "Token unknown - line @1, column @2")
FB_IMPL_MSG(JRD, 315, dsql_no_relation_alias, -204, "42", "S02", "there is no alias or table named @1 at this scope level")
FB_IMPL_MSG(JRD, 316, indexname, -204, "42", "000", "there is no index @1 for table @2")
FB_IMPL_MSG(JRD, 317, no_stream_plan, -281, "HY", "000", "table or procedure @1 is not referenced in plan")
FB_IMPL_MSG(JRD, 318, stream_twice, -282, "HY", "000", "table or procedure @1 is referenced more than once in plan; use aliases to distinguish")
FB_IMPL_MSG(JRD, 319, stream_not_found, -283, "HY", "000", "table or procedure @1 is referenced in the plan but not the from list")
FB_IMPL_MSG(JRD, 320, collation_requires_text, -204, "22", "021", "Invalid use of CHARACTER SET or COLLATE")
FB_IMPL_MSG(JRD, 321, dsql_domain_not_found, -901, "42", "000", "Specified domain or source column @1 does not exist")
FB_IMPL_MSG(JRD, 322, index_unused, -284, "42", "000", "index @1 cannot be used in the specified plan")
FB_IMPL_MSG(JRD, 323, dsql_self_join, -282, "42", "000", "the table @1 is referenced twice; use aliases to differentiate")
FB_IMPL_MSG(JRD, 324, stream_bof, -596, "HY", "109", "attempt to fetch before the first record in a record stream")
FB_IMPL_MSG(JRD, 325, stream_crack, -595, "HY", "000", "the current position is on a crack")
FB_IMPL_MSG(JRD, 326, db_or_file_exists, -601, "HY", "000", "database or file exists")
FB_IMPL_MSG(JRD, 327, invalid_operator, -401, "42", "000", "invalid comparison operator for find operation")
FB_IMPL_MSG(JRD, 328, conn_lost, -924, "HY", "000", "Connection lost to pipe server")
FB_IMPL_MSG(JRD, 329, bad_checksum, -835, "42", "000", "bad checksum")
FB_IMPL_MSG(JRD, 330, page_type_err, -689, "HY", "000", "wrong page type")
FB_IMPL_MSG(JRD, 331, ext_readonly_err, -816, "42", "000", "Cannot insert because the file is readonly or is on a read only medium.")
FB_IMPL_MSG(JRD, 332, sing_select_err, -811, "21", "000", "multiple rows in singleton select")
FB_IMPL_MSG(JRD, 333, psw_attach, -902, "28", "000", "cannot attach to password database")
FB_IMPL_MSG(JRD, 334, psw_start_trans, -902, "28", "000", "cannot start transaction for password database")
FB_IMPL_MSG(JRD, 335, invalid_direction, -827, "42", "000", "invalid direction for find operation")
FB_IMPL_MSG(JRD, 336, dsql_var_conflict, -901, "HY", "000", "variable @1 conflicts with parameter in same procedure")
FB_IMPL_MSG(JRD, 337, dsql_no_blob_array, -607, "HY", "000", "Array/BLOB/DATE data types not allowed in arithmetic")
FB_IMPL_MSG(JRD, 338, dsql_base_table, -155, "42", "000", "@1 is not a valid base table of the specified view")
FB_IMPL_MSG(JRD, 339, duplicate_base_table, -282, "42", "000", "table or procedure @1 is referenced twice in view; use an alias to distinguish")
FB_IMPL_MSG(JRD, 340, view_alias, -282, "42", "000", "view @1 has more than one base table; use aliases to distinguish")
FB_IMPL_MSG(JRD, 341, index_root_page_full, -904, "54", "000", "cannot add index, index root page is full.")
FB_IMPL_MSG(JRD, 342, dsql_blob_type_unknown, -204, "42", "000", "BLOB SUB_TYPE @1 is not defined")
FB_IMPL_MSG(JRD, 343, req_max_clones_exceeded, -693, "54", "001", "Too many concurrent executions of the same request")
FB_IMPL_MSG(JRD, 344, dsql_duplicate_spec, -637, "42", "000", "duplicate specification of @1 - not supported")
FB_IMPL_MSG(JRD, 345, unique_key_violation, -803, "23", "000", "violation of PRIMARY or UNIQUE KEY constraint \"@1\" on table \"@2\"")
FB_IMPL_MSG(JRD, 346, srvr_version_too_old, -901, "HY", "000", "server version too old to support all CREATE DATABASE options")
FB_IMPL_MSG(JRD, 347, drdb_completed_with_errs, -909, "HY", "000", "drop database completed with errors")
FB_IMPL_MSG(JRD, 348, dsql_procedure_use_err, -84, "42", "000", "procedure @1 does not return any values")
FB_IMPL_MSG(JRD, 349, dsql_count_mismatch, -313, "07", "002", "count of column list and variable list do not match")
FB_IMPL_MSG(JRD, 350, blob_idx_err, -685, "42", "000", "attempt to index BLOB column in index @1")
FB_IMPL_MSG(JRD, 351, array_idx_err, -685, "42", "000", "attempt to index array column in index @1")
FB_IMPL_MSG(JRD, 352, key_field_err, -663, "42", "000", "too few key columns found for index @1 (incorrect column name?)")
FB_IMPL_MSG(JRD, 353, no_delete, -901, "HY", "000", "cannot delete")
FB_IMPL_MSG(JRD, 354, del_last_field, -616, "42", "000", "last column in a table cannot be deleted")
FB_IMPL_MSG(JRD, 355, sort_err, -901, "HY", "000", "sort error")
FB_IMPL_MSG(JRD, 356, sort_mem_err, -904, "HY", "001", "sort error: not enough memory")
FB_IMPL_MSG(JRD, 357, version_err, -841, "54", "000", "too many versions")
FB_IMPL_MSG(JRD, 358, inval_key_posn, -828, "HY", "000", "invalid key position")
FB_IMPL_MSG(JRD, 359, no_segments_err, -690, "HY", "000", "segments not allowed in expression index @1")
FB_IMPL_MSG(JRD, 360, crrp_data_err, -600, "XX", "000", "sort error: corruption in data structure")
FB_IMPL_MSG(JRD, 361, rec_size_err, -691, "54", "000", "new record size of @1 bytes is too big")
FB_IMPL_MSG(JRD, 362, dsql_field_ref, -605, "42", "000", "Inappropriate self-reference of column")
FB_IMPL_MSG(JRD, 363, req_depth_exceeded, -904, "54", "001", "request depth exceeded. (Recursive definition?)")
FB_IMPL_MSG(JRD, 364, no_field_access, -694, "42", "S22", "cannot access column @1 in view @2")
FB_IMPL_MSG(JRD, 365, no_dbkey, -162, "HY", "000", "dbkey not available for multi-table views")
FB_IMPL_MSG(JRD, 366, jrn_format_err, -839, "HY", "000", "journal file wrong format")
FB_IMPL_MSG(JRD, 367, jrn_file_full, -840, "HY", "000", "intermediate journal file full")
FB_IMPL_MSG(JRD, 368, dsql_open_cursor_request, -519, "24", "000", "The prepare statement identifies a prepare statement with an open cursor")
FB_IMPL_MSG(JRD, 369, ib_error, -999, "HY", "000", "Firebird error")
FB_IMPL_MSG(JRD, 370, cache_redef, -260, "HY", "013", "Cache redefined")
FB_IMPL_MSG(JRD, 371, cache_too_small, -239, "HY", "013", "Insufficient memory to allocate page buffer cache")
FB_IMPL_MSG(JRD, 372, log_redef, -260, "HY", "000", "Log redefined")
FB_IMPL_MSG(JRD, 373, log_too_small, -239, "HY", "000", "Log size too small")
FB_IMPL_MSG(JRD, 374, partition_too_small, -239, "HY", "000", "Log partition size too small")
FB_IMPL_MSG(JRD, 375, partition_not_supp, -261, "HY", "000", "Partitions not supported in series of log file specification")
FB_IMPL_MSG(JRD, 376, log_length_spec, -261, "HY", "000", "Total length of a partitioned log must be specified")
FB_IMPL_MSG(JRD, 377, precision_err, -842, "HY", "104", "Precision must be from 1 to 18")
FB_IMPL_MSG(JRD, 378, scale_nogt, -842, "HY", "104", "Scale must be between zero and precision")
FB_IMPL_MSG(JRD, 379, expec_short, -842, "22", "003", "Short integer expected")
FB_IMPL_MSG(JRD, 380, expec_long, -842, "22", "003", "Long integer expected")
FB_IMPL_MSG(JRD, 381, expec_ushort, -842, "22", "003", "Unsigned short integer expected")
FB_IMPL_MSG(JRD, 382, escape_invalid, -105, "22", "025", "Invalid ESCAPE sequence")
FB_IMPL_MSG(JRD, 383, svcnoexe, -901, "HY", "000", "service @1 does not have an associated executable")
FB_IMPL_MSG(JRD, 384, net_lookup_err, -901, "08", "006", "Failed to locate host machine.")
FB_IMPL_MSG(JRD, 385, service_unknown, -901, "HY", "000", "Undefined service @1/@2.")
FB_IMPL_MSG(JRD, 386, host_unknown, -901, "08", "001", "The specified name was not found in the hosts file or Domain Name Services.")
FB_IMPL_MSG(JRD, 387, grant_nopriv_on_base, -552, "01", "007", "user does not have GRANT privileges on base table/view for operation")
FB_IMPL_MSG(JRD, 388, dyn_fld_ambiguous, -203, "42", "702", "Ambiguous column reference.")
FB_IMPL_MSG(JRD, 389, dsql_agg_ref_err, -104, "42", "000", "Invalid aggregate reference")
FB_IMPL_MSG(JRD, 390, complex_view, -282, "HY", "000", "navigational stream @1 references a view with more than one base table")
FB_IMPL_MSG(JRD, 391, unprepared_stmt, -901, "HY", "007", "Attempt to execute an unprepared dynamic SQL statement.")
FB_IMPL_MSG(JRD, 392, expec_positive, -842, "42", "000", "Positive value expected")
FB_IMPL_MSG(JRD, 393, dsql_sqlda_value_err, -804, "HY", "000", "Incorrect values within SQLDA structure")
FB_IMPL_MSG(JRD, 394, invalid_array_id, -104, "HY", "000", "invalid blob id")
FB_IMPL_MSG(JRD, 395, extfile_uns_op, -816, "42", "000", "Operation not supported for EXTERNAL FILE table @1")
FB_IMPL_MSG(JRD, 396, svc_in_use, -901, "HY", "000", "Service is currently busy: @1")
FB_IMPL_MSG(JRD, 397, err_stack_limit, -902, "HY", "013", "stack size insufficent to execute current request")
FB_IMPL_MSG(JRD, 398, invalid_key, -827, "42", "000", "Invalid key for find operation")
FB_IMPL_MSG(JRD, 399, net_init_error, -901, "08", "006", "Error initializing the network software.")
FB_IMPL_MSG(JRD, 400, loadlib_failure, -901, "HY", "000", "Unable to load required library @1.")
FB_IMPL_MSG(JRD, 401, network_error, -902, "08", "006", "Unable to complete network request to host \"@1\".")
FB_IMPL_MSG(JRD, 402, net_connect_err, -902, "08", "006", "Failed to establish a connection.")
FB_IMPL_MSG(JRD, 403, net_connect_listen_err, -902, "08", "006", "Error while listening for an incoming connection.")
FB_IMPL_MSG(JRD, 404, net_event_connect_err, -902, "08", "006", "Failed to establish a secondary connection for event processing.")
FB_IMPL_MSG(JRD, 405, net_event_listen_err, -902, "08", "006", "Error while listening for an incoming event connection request.")
FB_IMPL_MSG(JRD, 406, net_read_err, -902, "08", "006", "Error reading data from the connection.")
FB_IMPL_MSG(JRD, 407, net_write_err, -902, "08", "006", "Error writing data to the connection.")
FB_IMPL_MSG(JRD, 408, integ_index_deactivate, -616, "42", "000", "Cannot deactivate index used by an integrity constraint")
FB_IMPL_MSG(JRD, 409, integ_deactivate_primary, -616, "42", "000", "Cannot deactivate index used by a PRIMARY/UNIQUE constraint")
FB_IMPL_MSG(JRD, 410, cse_not_supported, -104, "HY", "000", "Client/Server Express not supported in this release")
FB_IMPL_MSG(JRD, 411, tra_must_sweep, -901, "HY", "000", "")
FB_IMPL_MSG(JRD, 412, unsupported_network_drive, -902, "HY", "000", "Access to databases on file servers is not supported.")
FB_IMPL_MSG(JRD, 413, io_create_err, -902, "08", "001", "Error while trying to create file")
FB_IMPL_MSG(JRD, 414, io_open_err, -902, "08", "001", "Error while trying to open file")
FB_IMPL_MSG(JRD, 415, io_close_err, -902, "HY", "000", "Error while trying to close file")
FB_IMPL_MSG(JRD, 416, io_read_err, -902, "HY", "000", "Error while trying to read from file")
FB_IMPL_MSG(JRD, 417, io_write_err, -902, "HY", "000", "Error while trying to write to file")
FB_IMPL_MSG(JRD, 418, io_delete_err, -902, "HY", "000", "Error while trying to delete file")
FB_IMPL_MSG(JRD, 419, io_access_err, -902, "HY", "000", "Error while trying to access file")
FB_IMPL_MSG(JRD, 420, udf_exception, -901, "38", "000", "A fatal exception occurred during the execution of a user defined function.")
FB_IMPL_MSG(JRD, 421, lost_db_connection, -901, "08", "006", "connection lost to database")
FB_IMPL_MSG(JRD, 422, no_write_user_priv, -901, "28", "000", "User cannot write to RDB$USER_PRIVILEGES")
FB_IMPL_MSG(JRD, 423, token_too_long, -104, "42", "000", "token size exceeds limit")
FB_IMPL_MSG(JRD, 424, max_att_exceeded, -906, "08", "001", "Maximum user count exceeded.  Contact your database administrator.")
FB_IMPL_MSG(JRD, 425, login_same_as_role_name, -902, "28", "000", "Your login @1 is same as one of the SQL role name. Ask your database administrator to set up a valid Firebird login.")
FB_IMPL_MSG(JRD, 426, reftable_requires_pk, -607, "42", "000", "\"REFERENCES table\" without \"(column)\" requires PRIMARY KEY on referenced table")
FB_IMPL_MSG(JRD, 427, usrname_too_long, -85, "28", "000", "The username entered is too long.  Maximum length is 31 bytes.")
FB_IMPL_MSG(JRD, 428, password_too_long, -85, "28", "000", "The password specified is too long.  Maximum length is 8 bytes.")
FB_IMPL_MSG(JRD, 429, usrname_required, -85, "28", "000", "A username is required for this operation.")
FB_IMPL_MSG(JRD, 430, password_required, -85, "28", "000", "A password is required for this operation")
FB_IMPL_MSG(JRD, 431, bad_protocol, -85, "42", "000", "The network protocol specified is invalid")
FB_IMPL_MSG(JRD, 432, dup_usrname_found, -85, "28", "000", "A duplicate user name was found in the security database")
FB_IMPL_MSG(JRD, 433, usrname_not_found, -85, "28", "000", "The user name specified was not found in the security database")
FB_IMPL_MSG(JRD, 434, error_adding_sec_record, -85, "28", "000", "An error occurred while attempting to add the user.")
FB_IMPL_MSG(JRD, 435, error_modifying_sec_record, -85, "28", "000", "An error occurred while attempting to modify the user record.")
FB_IMPL_MSG(JRD, 436, error_deleting_sec_record, -85, "28", "000", "An error occurred while attempting to delete the user record.")
FB_IMPL_MSG(JRD, 437, error_updating_sec_db, -85, "28", "000", "An error occurred while updating the security database.")
FB_IMPL_MSG(JRD, 438, sort_rec_size_err, -904, "HY", "000", "sort record size of @1 bytes is too big")
FB_IMPL_MSG(JRD, 439, bad_default_value, -204, "42", "000", "can not define a not null column with NULL as default value")
FB_IMPL_MSG(JRD, 440, invalid_clause, -204, "42", "000", "invalid clause --- '@1'")
FB_IMPL_MSG(JRD, 441, too_many_handles, -904, "HY", "000", "too many open handles to database")
FB_IMPL_MSG(JRD, 442, optimizer_blk_exc, -904, "HY", "000", "size of optimizer block exceeded")
FB_IMPL_MSG(JRD, 443, invalid_string_constant, -104, "42", "000", "a string constant is delimited by double quotes")
FB_IMPL_MSG(JRD, 444, transitional_date, -104, "HY", "000", "DATE must be changed to TIMESTAMP")
FB_IMPL_MSG(JRD, 445, read_only_database, -817, "42", "000", "attempted update on read-only database")
FB_IMPL_MSG(JRD, 446, must_be_dialect_2_and_up, -817, "HY", "000", "SQL dialect @1 is not supported in this database")
FB_IMPL_MSG(JRD, 447, blob_filter_exception, -901, "HY", "000", "A fatal exception occurred during the execution of a blob filter.")
FB_IMPL_MSG(JRD, 448, exception_access_violation, -901, "HY", "000", "Access violation.  The code attempted to access a virtual address without privilege to do so.")
FB_IMPL_MSG(JRD, 449, exception_datatype_missalignment, -901, "22", "000", "Datatype misalignment.  The attempted to read or write a value that was not stored on a memory boundary.")
FB_IMPL_MSG(JRD, 450, exception_array_bounds_exceeded, -901, "22", "000", "Array bounds exceeded.  The code attempted to access an array element that is out of bounds.")
FB_IMPL_MSG(JRD, 451, exception_float_denormal_operand, -901, "22", "000", "Float denormal operand.  One of the floating-point operands is too small to represent a standard float value.")
FB_IMPL_MSG(JRD, 452, exception_float_divide_by_zero, -901, "22", "012", "Floating-point divide by zero.  The code attempted to divide a floating-point value by zero.")
FB_IMPL_MSG(JRD, 453, exception_float_inexact_result, -901, "22", "000", "Floating-point inexact result.  The result of a floating-point operation cannot be represented as a decimal fraction.")
FB_IMPL_MSG(JRD, 454, exception_float_invalid_operand, -901, "22", "000", "Floating-point invalid operand.  An indeterminant error occurred during a floating-point operation.")
FB_IMPL_MSG(JRD, 455, exception_float_overflow, -901, "22", "003", "Floating-point overflow.  The exponent of a floating-point operation is greater than the magnitude allowed.")
FB_IMPL_MSG(JRD, 456, exception_float_stack_check, -901, "22", "000", "Floating-point stack check.  The stack overflowed or underflowed as the result of a floating-point operation.")
FB_IMPL_MSG(JRD, 457, exception_float_underflow, -901, "22", "003", "Floating-point underflow.  The exponent of a floating-point operation is less than the magnitude allowed.")
FB_IMPL_MSG(JRD, 458, exception_integer_divide_by_zero, -901, "22", "012", "Integer divide by zero.  The code attempted to divide an integer value by an integer divisor of zero.")
FB_IMPL_MSG(JRD, 459, exception_integer_overflow, -901, "22", "003", "Integer overflow.  The result of an integer operation caused the most significant bit of the result to carry.")
FB_IMPL_MSG(JRD, 460, exception_unknown, -901, "HY", "000", "An exception occurred that does not have a description.  Exception number @1.")
FB_IMPL_MSG(JRD, 461, exception_stack_overflow, -901, "HY", "001", "Stack overflow.  The resource requirements of the runtime stack have exceeded the memory available to it.")
FB_IMPL_MSG(JRD, 462, exception_sigsegv, -901, "HY", "000", "Segmentation Fault. The code attempted to access memory without privileges.")
FB_IMPL_MSG(JRD, 463, exception_sigill, -901, "HY", "000", "Illegal Instruction. The Code attempted to perform an illegal operation.")
FB_IMPL_MSG(JRD, 464, exception_sigbus, -901, "HY", "000", "Bus Error. The Code caused a system bus error.")
FB_IMPL_MSG(JRD, 465, exception_sigfpe, -901, "HY", "000", "Floating Point Error. The Code caused an Arithmetic Exception or a floating point exception.")
FB_IMPL_MSG(JRD, 466, ext_file_delete, -901, "42", "000", "Cannot delete rows from external files.")
FB_IMPL_MSG(JRD, 467, ext_file_modify, -901, "42", "000", "Cannot update rows in external files.")
FB_IMPL_MSG(JRD, 468, adm_task_denied, -901, "28", "000", "Unable to perform operation")
FB_IMPL_MSG(JRD, 469, extract_input_mismatch, -105, "42", "000", "Specified EXTRACT part does not exist in input datatype")
FB_IMPL_MSG(JRD, 470, insufficient_svc_privileges, -551, "28", "000", "Service @1 requires SYSDBA permissions.  Reattach to the Service Manager using the SYSDBA account.")
FB_IMPL_MSG(JRD, 471, file_in_use, -902, "HY", "000", "The file @1 is currently in use by another process.  Try again later.")
FB_IMPL_MSG(JRD, 472, service_att_err, -904, "HY", "000", "Cannot attach to services manager")
FB_IMPL_MSG(JRD, 473, ddl_not_allowed_by_db_sql_dial, -817, "42", "000", "Metadata update statement is not allowed by the current database SQL dialect @1")
FB_IMPL_MSG(JRD, 474, cancelled, -901, "HY", "008", "operation was cancelled")
FB_IMPL_MSG(JRD, 475, unexp_spb_form, -902, "HY", "000", "unexpected item in service parameter block, expected @1")
FB_IMPL_MSG(JRD, 476, sql_dialect_datatype_unsupport, -104, "HY", "000", "Client SQL dialect @1 does not support reference to @2 datatype")
FB_IMPL_MSG(JRD, 477, svcnouser, -901, "HY", "000", "user name and password are required while attaching to the services manager")
FB_IMPL_MSG(JRD, 478, depend_on_uncommitted_rel, -104, "42", "000", "You created an indirect dependency on uncommitted metadata. You must roll back the current transaction.")
FB_IMPL_MSG(JRD, 479, svc_name_missing, -904, "HY", "000", "The service name was not specified.")
FB_IMPL_MSG(JRD, 480, too_many_contexts, -204, "54", "001", "Too many Contexts of Relation/Procedure/Views. Maximum allowed is 256")
FB_IMPL_MSG(JRD, 481, datype_notsup, -901, "22", "008", "data type not supported for arithmetic")
FB_IMPL_MSG(JRD, 482, dialect_reset_warning, 501, "01", "000", "Database dialect being changed from 3 to 1")
FB_IMPL_MSG(JRD, 483, dialect_not_changed, -901, "HY", "000", "Database dialect not changed.")
FB_IMPL_MSG(JRD, 484, database_create_failed, -901, "HY", "000", "Unable to create database @1")
FB_IMPL_MSG(JRD, 485, inv_dialect_specified, -901, "42", "000", "Database dialect @1 is not a valid dialect.")
FB_IMPL_MSG(JRD, 486, valid_db_dialects, -901, "00", "000", "Valid database dialects are @1.")
FB_IMPL_MSG(JRD, 487, sqlwarn, 300, "00", "000", "SQL warning code = @1")
FB_IMPL_MSG(JRD, 488, dtype_renamed, 301, "HY", "000", "DATE data type is now called TIMESTAMP")
FB_IMPL_MSG(JRD, 489, extern_func_dir_error, -902, "38", "000", "Function @1 is in @2, which is not in a permitted directory for external functions.")
FB_IMPL_MSG(JRD, 490, date_range_exceeded, -833, "22", "008", "value exceeds the range for valid dates")
FB_IMPL_MSG(JRD, 491, inv_client_dialect_specified, -901, "42", "000", "passed client dialect @1 is not a valid dialect.")
FB_IMPL_MSG(JRD, 492, valid_client_dialects, -901, "00", "000", "Valid client dialects are @1.")
FB_IMPL_MSG(JRD, 493, optimizer_between_err, -904, "HY", "004", "Unsupported field type specified in BETWEEN predicate.")
FB_IMPL_MSG(JRD, 494, service_not_supported, -901, "HY", "000", "Services functionality will be supported in a later version  of the product")
FB_IMPL_MSG(JRD, 495, generator_name, -607, "00", "000", "GENERATOR @1")
FB_IMPL_MSG(JRD, 496, udf_name, -607, "38", "000", "Function @1")
FB_IMPL_MSG(JRD, 497, bad_limit_param, -204, "HY", "000", "Invalid parameter to FETCH or FIRST. Only integers >= 0 are allowed.")
FB_IMPL_MSG(JRD, 498, bad_skip_param, -204, "42", "000", "Invalid parameter to OFFSET or SKIP. Only integers >= 0 are allowed.")
FB_IMPL_MSG(JRD, 499, io_32bit_exceeded_err, -902, "54", "000", "File exceeded maximum size of 2GB.  Add another database file or use a 64 bit I/O version of Firebird.")
FB_IMPL_MSG(JRD, 500, invalid_savepoint, -901, "3B", "000", "Unable to find savepoint with name @1 in transaction context")
FB_IMPL_MSG(JRD, 501, dsql_column_pos_err, -104, "42", "000", "Invalid column position used in the @1 clause")
FB_IMPL_MSG(JRD, 502, dsql_agg_where_err, -104, "42", "000", "Cannot use an aggregate or window function in a WHERE clause, use HAVING (for aggregate only) instead")
FB_IMPL_MSG(JRD, 503, dsql_agg_group_err, -104, "42", "000", "Cannot use an aggregate or window function in a GROUP BY clause")
FB_IMPL_MSG(JRD, 504, dsql_agg_column_err, -104, "42", "000", "Invalid expression in the @1 (not contained in either an aggregate function or the GROUP BY clause)")
FB_IMPL_MSG(JRD, 505, dsql_agg_having_err, -104, "42", "000", "Invalid expression in the @1 (neither an aggregate function nor a part of the GROUP BY clause)")
FB_IMPL_MSG(JRD, 506, dsql_agg_nested_err, -104, "42", "000", "Nested aggregate and window functions are not allowed")
FB_IMPL_MSG(JRD, 507, exec_sql_invalid_arg, -904, "42", "000", "Invalid argument in EXECUTE STATEMENT - cannot convert to string")
FB_IMPL_MSG(JRD, 508, exec_sql_invalid_req, -904, "42", "000", "Wrong request type in EXECUTE STATEMENT '@1'")
FB_IMPL_MSG(JRD, 509, exec_sql_invalid_var, -904, "42", "000", "Variable type (position @1) in EXECUTE STATEMENT '@2' INTO does not match returned column type")
FB_IMPL_MSG(JRD, 510, exec_sql_max_call_exceeded, -904, "42", "000", "Too many recursion levels of EXECUTE STATEMENT")
FB_IMPL_MSG(JRD, 511, conf_access_denied, -902, "28", "000", "Use of @1 at location @2 is not allowed by server configuration")
FB_IMPL_MSG(JRD, 512, wrong_backup_state, -904, "HY", "000", "Cannot change difference file name while database is in backup mode")
FB_IMPL_MSG(JRD, 513, wal_backup_err, -904, "HY", "000", "Physical backup is not allowed while Write-Ahead Log is in use")
FB_IMPL_MSG(JRD, 514, cursor_not_open, -902, "24", "000", "Cursor is not open")
FB_IMPL_MSG(JRD, 515, bad_shutdown_mode, -901, "08", "007", "Target shutdown mode is invalid for database \"@1\"")
FB_IMPL_MSG(JRD, 516, concat_overflow, -802, "HY", "000", "Concatenation overflow. Resulting string cannot exceed 32765 bytes in length.")
FB_IMPL_MSG(JRD, 517, bad_substring_offset, -204, "22", "011", "Invalid offset parameter @1 to SUBSTRING. Only positive integers are allowed.")
FB_IMPL_MSG(JRD, 518, foreign_key_target_doesnt_exist, -530, "42", "000", "Foreign key reference target does not exist")
FB_IMPL_MSG(JRD, 519, foreign_key_references_present, -530, "42", "000", "Foreign key references are present for the record")
FB_IMPL_MSG(JRD, 520, no_update, -901, "HY", "000", "cannot update")
FB_IMPL_MSG(JRD, 521, cursor_already_open, -902, "24", "000", "Cursor is already open")
FB_IMPL_MSG(JRD, 522, stack_trace, -901, "00", "000", "@1")
FB_IMPL_MSG(JRD, 523, ctx_var_not_found, -901, "HY", "000", "Context variable '@1' is not found in namespace '@2'")
FB_IMPL_MSG(JRD, 524, ctx_namespace_invalid, -901, "HY", "000", "Invalid namespace name '@1' passed to @2")
FB_IMPL_MSG(JRD, 525, ctx_too_big, -901, "54", "000", "Too many context variables")
FB_IMPL_MSG(JRD, 526, ctx_bad_argument, -901, "HY", "000", "Invalid argument passed to @1")
FB_IMPL_MSG(JRD, 527, identifier_too_long, -901, "42", "000", "BLR syntax error. Identifier @1... is too long")
FB_IMPL_MSG(JRD, 528, except2, -836, "HY", "000", "exception @1")
FB_IMPL_MSG(JRD, 529, malformed_string, -104, "22", "000", "Malformed string")
FB_IMPL_MSG(JRD, 530, prc_out_param_mismatch, -170, "07", "002", "Output parameter mismatch for procedure @1")
FB_IMPL_MSG(JRD, 531, command_end_err2, -104, "42", "000", "Unexpected end of command - line @1, column @2")
FB_IMPL_MSG(JRD, 532, partner_idx_incompat_type, -904, "42", "000", "partner index segment no @1 has incompatible data type")
FB_IMPL_MSG(JRD, 533, bad_substring_length, -204, "22", "011", "Invalid length parameter @1 to SUBSTRING. Negative integers are not allowed.")
FB_IMPL_MSG(JRD, 534, charset_not_installed, -204, "2C", "000", "CHARACTER SET @1 is not installed")
FB_IMPL_MSG(JRD, 535, collation_not_installed, -204, "22", "021", "COLLATION @1 for CHARACTER SET @2 is not installed")
FB_IMPL_MSG(JRD, 536, att_shutdown, -902, "08", "003", "connection shutdown")
FB_IMPL_MSG(JRD, 537, blobtoobig, -904, "54", "000", "Maximum BLOB size exceeded")
FB_IMPL_MSG(JRD, 538, must_have_phys_field, -607, "42", "000", "Can't have relation with only computed fields or constraints")
FB_IMPL_MSG(JRD, 539, invalid_time_precision, -901, "22", "007", "Time precision exceeds allowed range (0-@1)")
FB_IMPL_MSG(JRD, 540, blob_convert_error, -413, "HY", "000", "Unsupported conversion to target type BLOB (subtype @1)")
FB_IMPL_MSG(JRD, 541, array_convert_error, -413, "22", "000", "Unsupported conversion to target type ARRAY")
FB_IMPL_MSG(JRD, 542, record_lock_not_supp, -904, "40", "001", "Stream does not support record locking")
FB_IMPL_MSG(JRD, 543, partner_idx_not_found, -904, "42", "000", "Cannot create foreign key constraint @1. Partner index does not exist or is inactive.")
FB_IMPL_MSG(JRD, 544, tra_num_exc, -904, "54", "000", "Transactions count exceeded. Perform backup and restore to make database operable again")
FB_IMPL_MSG(JRD, 545, field_disappeared, -904, "42", "000", "Column has been unexpectedly deleted")
FB_IMPL_MSG(JRD, 546, met_wrong_gtt_scope, -901, "HY", "000", "@1 cannot depend on @2")
FB_IMPL_MSG(JRD, 547, subtype_for_internal_use, -204, "HY", "000", "Blob sub_types bigger than 1 (text) are for internal use only")
FB_IMPL_MSG(JRD, 548, illegal_prc_type, -901, "42", "000", "Procedure @1 is not selectable (it does not contain a SUSPEND statement)")
FB_IMPL_MSG(JRD, 549, invalid_sort_datatype, -901, "42", "000", "Datatype @1 is not supported for sorting operation")
FB_IMPL_MSG(JRD, 550, collation_name, -901, "00", "000", "COLLATION @1")
FB_IMPL_MSG(JRD, 551, domain_name, -901, "00", "000", "DOMAIN @1")
FB_IMPL_MSG(JRD, 552, domnotdef, -219, "42", "000", "domain @1 is not defined")
FB_IMPL_MSG(JRD, 553, array_max_dimensions, -171, "54", "000", "Array data type can use up to @1 dimensions")
FB_IMPL_MSG(JRD, 554, max_db_per_trans_allowed, -901, "54", "000", "A multi database transaction cannot span more than @1 databases")
FB_IMPL_MSG(JRD, 555, bad_debug_format, 0, "00", "000", "Bad debug info format")
FB_IMPL_MSG(JRD, 556, bad_proc_BLR, -901, "2F", "000", "Error while parsing procedure @1's BLR")
FB_IMPL_MSG(JRD, 557, key_too_big, -901, "54", "000", "index key too big")
FB_IMPL_MSG(JRD, 558, concurrent_transaction, -904, "HY", "000", "concurrent transaction number is @1")
FB_IMPL_MSG(JRD, 559, not_valid_for_var, -625, "42", "000", "validation error for variable @1, value \"@2\"")
FB_IMPL_MSG(JRD, 560, not_valid_for, -625, "42", "000", "validation error for @1, value \"@2\"")
FB_IMPL_MSG(JRD, 561, need_difference, -820, "HY", "000", "Difference file name should be set explicitly for database on raw device")
FB_IMPL_MSG(JRD, 562, long_login, -902, "HY", "000", "Login name too long (@1 characters, maximum allowed @2)")
FB_IMPL_MSG(JRD, 563, fldnotdef2, -205, "42", "S22", "column @1 is not defined in procedure @2")
FB_IMPL_MSG(JRD, 564, invalid_similar_pattern, -105, "42", "000", "Invalid SIMILAR TO pattern")
FB_IMPL_MSG(JRD, 565, bad_teb_form, -901, "HY", "000", "Invalid TEB format")
FB_IMPL_MSG(JRD, 566, tpb_multiple_txn_isolation, -901, "HY", "000", "Found more than one transaction isolation in TPB")
FB_IMPL_MSG(JRD, 567, tpb_reserv_before_table, -901, "HY", "000", "Table reservation lock type @1 requires table name before in TPB")
FB_IMPL_MSG(JRD, 568, tpb_multiple_spec, -901, "HY", "000", "Found more than one @1 specification in TPB")
FB_IMPL_MSG(JRD, 569, tpb_option_without_rc, -901, "HY", "000", "Option @1 requires READ COMMITTED isolation in TPB")
FB_IMPL_MSG(JRD, 570, tpb_conflicting_options, -901, "HY", "000", "Option @1 is not valid if @2 was used previously in TPB")
FB_IMPL_MSG(JRD, 571, tpb_reserv_missing_tlen, -901, "HY", "000", "Table name length missing after table reservation @1 in TPB")
FB_IMPL_MSG(JRD, 572, tpb_reserv_long_tlen, -901, "HY", "000", "Table name length @1 is too long after table reservation @2 in TPB")
FB_IMPL_MSG(JRD, 573, tpb_reserv_missing_tname, -901, "HY", "000", "Table name length @1 without table name after table reservation @2 in TPB")
FB_IMPL_MSG(JRD, 574, tpb_reserv_corrup_tlen, -901, "HY", "000", "Table name length @1 goes beyond the remaining TPB size after table reservation @2")
FB_IMPL_MSG(JRD, 575, tpb_reserv_null_tlen, -901, "HY", "000", "Table name length is zero after table reservation @1 in TPB")
FB_IMPL_MSG(JRD, 576, tpb_reserv_relnotfound, -901, "HY", "000", "Table or view @1 not defined in system tables after table reservation @2 in TPB")
FB_IMPL_MSG(JRD, 577, tpb_reserv_baserelnotfound, -901, "HY", "000", "Base table or view @1 for view @2 not defined in system tables after table reservation @3 in TPB")
FB_IMPL_MSG(JRD, 578, tpb_missing_len, -901, "HY", "000", "Option length missing after option @1 in TPB")
FB_IMPL_MSG(JRD, 579, tpb_missing_value, -901, "HY", "000", "Option length @1 without value after option @2 in TPB")
FB_IMPL_MSG(JRD, 580, tpb_corrupt_len, -901, "HY", "000", "Option length @1 goes beyond the remaining TPB size after option @2")
FB_IMPL_MSG(JRD, 581, tpb_null_len, -901, "HY", "000", "Option length is zero after table reservation @1 in TPB")
FB_IMPL_MSG(JRD, 582, tpb_overflow_len, -901, "HY", "000", "Option length @1 exceeds the range for option @2 in TPB")
FB_IMPL_MSG(JRD, 583, tpb_invalid_value, -901, "HY", "000", "Option value @1 is invalid for the option @2 in TPB")
FB_IMPL_MSG(JRD, 584, tpb_reserv_stronger_wng, -901, "HY", "000", "Preserving previous table reservation @1 for table @2, stronger than new @3 in TPB")
FB_IMPL_MSG(JRD, 585, tpb_reserv_stronger, -901, "HY", "000", "Table reservation @1 for table @2 already specified and is stronger than new @3 in TPB")
FB_IMPL_MSG(JRD, 586, tpb_reserv_max_recursion, -901, "HY", "000", "Table reservation reached maximum recursion of @1 when expanding views in TPB")
FB_IMPL_MSG(JRD, 587, tpb_reserv_virtualtbl, -901, "HY", "000", "Table reservation in TPB cannot be applied to @1 because it's a virtual table")
FB_IMPL_MSG(JRD, 588, tpb_reserv_systbl, -901, "HY", "000", "Table reservation in TPB cannot be applied to @1 because it's a system table")
FB_IMPL_MSG(JRD, 589, tpb_reserv_temptbl, -901, "HY", "000", "Table reservation @1 or @2 in TPB cannot be applied to @3 because it's a temporary table")
FB_IMPL_MSG(JRD, 590, tpb_readtxn_after_writelock, -901, "HY", "000", "Cannot set the transaction in read only mode after a table reservation isc_tpb_lock_write in TPB")
FB_IMPL_MSG(JRD, 591, tpb_writelock_after_readtxn, -901, "HY", "000", "Cannot take a table reservation isc_tpb_lock_write in TPB because the transaction is in read only mode")
FB_IMPL_MSG(JRD, 592, time_range_exceeded, -833, "22", "008", "value exceeds the range for a valid time")
FB_IMPL_MSG(JRD, 593, datetime_range_exceeded, -833, "22", "008", "value exceeds the range for valid timestamps")
FB_IMPL_MSG(JRD, 594, string_truncation, -802, "22", "001", "string right truncation")
FB_IMPL_MSG(JRD, 595, blob_truncation, -802, "22", "001", "blob truncation when converting to a string: length limit exceeded")
FB_IMPL_MSG(JRD, 596, numeric_out_of_range, -802, "22", "003", "numeric value is out of range")
FB_IMPL_MSG(JRD, 597, shutdown_timeout, -901, "HY", "T00", "Firebird shutdown is still in progress after the specified timeout")
FB_IMPL_MSG(JRD, 598, att_handle_busy, -901, "HY", "010", "Attachment handle is busy")
FB_IMPL_MSG(JRD, 599, bad_udf_freeit, -901, "39", "000", "Bad written UDF detected: pointer returned in FREE_IT function was not allocated by ib_util_malloc")
FB_IMPL_MSG(JRD, 600, eds_provider_not_found, -901, "42", "000", "External Data Source provider '@1' not found")
FB_IMPL_MSG(JRD, 601, eds_connection, -901, "42", "000", "Execute statement error at @1 :\n@2Data source : @3")
FB_IMPL_MSG(JRD, 602, eds_preprocess, -901, "42", "000", "Execute statement preprocess SQL error")
FB_IMPL_MSG(JRD, 603, eds_stmt_expected, -901, "42", "000", "Statement expected")
FB_IMPL_MSG(JRD, 604, eds_prm_name_expected, -901, "42", "000", "Parameter name expected")
FB_IMPL_MSG(JRD, 605, eds_unclosed_comment, -901, "42", "000", "Unclosed comment found near '@1'")
FB_IMPL_MSG(JRD, 606, eds_statement, -901, "42", "000", "Execute statement error at @1 :\n@2Statement : @3\nData source : @4")
FB_IMPL_MSG(JRD, 607, eds_input_prm_mismatch, -901, "42", "000", "Input parameters mismatch")
FB_IMPL_MSG(JRD, 608, eds_output_prm_mismatch, -901, "42", "000", "Output parameters mismatch")
FB_IMPL_MSG(JRD, 609, eds_input_prm_not_set, -901, "42", "000", "Input parameter '@1' have no value set")
FB_IMPL_MSG(JRD, 610, too_big_blr, -104, "HY", "000", "BLR stream length @1 exceeds implementation limit @2")
FB_IMPL_MSG(JRD, 611, montabexh, 0, "HY", "001", "Monitoring table space exhausted")
FB_IMPL_MSG(JRD, 612, modnotfound, -172, "39", "000", "module name or entrypoint could not be found")
FB_IMPL_MSG(JRD, 613, nothing_to_cancel, -901, "HY", "018", "nothing to cancel")
FB_IMPL_MSG(JRD, 614, ibutil_not_loaded, -901, "39", "000", "ib_util library has not been loaded to deallocate memory returned by FREE_IT function")
FB_IMPL_MSG(JRD, 615, circular_computed, -904, "42", "000", "Cannot have circular dependencies with computed fields")
FB_IMPL_MSG(JRD, 616, psw_db_error, -902, "28", "000", "Security database error")
FB_IMPL_MSG(JRD, 617, invalid_type_datetime_op, -833, "42", "000", "Invalid data type in DATE/TIME/TIMESTAMP addition or subtraction in add_datettime()")
FB_IMPL_MSG(JRD, 618, onlycan_add_timetodate, -833, "42", "000", "Only a TIME value can be added to a DATE value")
FB_IMPL_MSG(JRD, 619, onlycan_add_datetotime, -833, "42", "000", "Only a DATE value can be added to a TIME value")
FB_IMPL_MSG(JRD, 620, onlycansub_tstampfromtstamp, -833, "42", "000", "TIMESTAMP values can be subtracted only from another TIMESTAMP value")
FB_IMPL_MSG(JRD, 621, onlyoneop_mustbe_tstamp, -833, "42", "000", "Only one operand can be of type TIMESTAMP")
FB_IMPL_MSG(JRD, 622, invalid_extractpart_time, -833, "42", "000", "Only HOUR, MINUTE, SECOND and MILLISECOND can be extracted from TIME values")
FB_IMPL_MSG(JRD, 623, invalid_extractpart_date, -833, "42", "000", "HOUR, MINUTE, SECOND and MILLISECOND cannot be extracted from DATE values")
FB_IMPL_MSG(JRD, 624, invalidarg_extract, -833, "42", "000", "Invalid argument for EXTRACT() not being of DATE/TIME/TIMESTAMP type")
FB_IMPL_MSG(JRD, 625, sysf_argmustbe_exact, -833, "42", "000", "Arguments for @1 must be integral types or NUMERIC/DECIMAL without scale")
FB_IMPL_MSG(JRD, 626, sysf_argmustbe_exact_or_fp, -833, "42", "000", "First argument for @1 must be integral type or floating point type")
FB_IMPL_MSG(JRD, 627, sysf_argviolates_uuidtype, -833, "42", "000", "Human readable UUID argument for @1 must be of string type")
FB_IMPL_MSG(JRD, 628, sysf_argviolates_uuidlen, -833, "42", "000", "Human readable UUID argument for @2 must be of exact length @1")
FB_IMPL_MSG(JRD, 629, sysf_argviolates_uuidfmt, -833, "42", "000", "Human readable UUID argument for @3 must have \"-\" at position @2 instead of \"@1\"")
FB_IMPL_MSG(JRD, 630, sysf_argviolates_guidigits, -833, "42", "000", "Human readable UUID argument for @3 must have hex digit at position @2 instead of \"@1\"")
FB_IMPL_MSG(JRD, 631, sysf_invalid_addpart_time, -833, "42", "000", "Only HOUR, MINUTE, SECOND and MILLISECOND can be added to TIME values in @1")
FB_IMPL_MSG(JRD, 632, sysf_invalid_add_datetime, -833, "42", "000", "Invalid data type in addition of part to DATE/TIME/TIMESTAMP in @1")
FB_IMPL_MSG(JRD, 633, sysf_invalid_addpart_dtime, -833, "42", "000", "Invalid part @1 to be added to a DATE/TIME/TIMESTAMP value in @2")
FB_IMPL_MSG(JRD, 634, sysf_invalid_add_dtime_rc, -833, "42", "000", "Expected DATE/TIME/TIMESTAMP type in evlDateAdd() result")
FB_IMPL_MSG(JRD, 635, sysf_invalid_diff_dtime, -833, "42", "000", "Expected DATE/TIME/TIMESTAMP type as first and second argument to @1")
FB_IMPL_MSG(JRD, 636, sysf_invalid_timediff, -833, "42", "000", "The result of TIME-<value> in @1 cannot be expressed in YEAR, MONTH, DAY or WEEK")
FB_IMPL_MSG(JRD, 637, sysf_invalid_tstamptimediff, -833, "42", "000", "The result of TIME-TIMESTAMP or TIMESTAMP-TIME in @1 cannot be expressed in HOUR, MINUTE, SECOND or MILLISECOND")
FB_IMPL_MSG(JRD, 638, sysf_invalid_datetimediff, -833, "42", "000", "The result of DATE-TIME or TIME-DATE in @1 cannot be expressed in HOUR, MINUTE, SECOND and MILLISECOND")
FB_IMPL_MSG(JRD, 639, sysf_invalid_diffpart, -833, "42", "000", "Invalid part @1 to express the difference between two DATE/TIME/TIMESTAMP values in @2")
FB_IMPL_MSG(JRD, 640, sysf_argmustbe_positive, -833, "42", "000", "Argument for @1 must be positive")
FB_IMPL_MSG(JRD, 641, sysf_basemustbe_positive, -833, "42", "000", "Base for @1 must be positive")
FB_IMPL_MSG(JRD, 642, sysf_argnmustbe_nonneg, -833, "42", "000", "Argument #@1 for @2 must be zero or positive")
FB_IMPL_MSG(JRD, 643, sysf_argnmustbe_positive, -833, "42", "000", "Argument #@1 for @2 must be positive")
FB_IMPL_MSG(JRD, 644, sysf_invalid_zeropowneg, -833, "42", "000", "Base for @1 cannot be zero if exponent is negative")
FB_IMPL_MSG(JRD, 645, sysf_invalid_negpowfp, -833, "42", "000", "Base for @1 cannot be negative if exponent is not an integral value")
FB_IMPL_MSG(JRD, 646, sysf_invalid_scale, -833, "42", "000", "The numeric scale must be between -128 and 127 in @1")
FB_IMPL_MSG(JRD, 647, sysf_argmustbe_nonneg, -833, "42", "000", "Argument for @1 must be zero or positive")
FB_IMPL_MSG(JRD, 648, sysf_binuuid_mustbe_str, -833, "42", "000", "Binary UUID argument for @1 must be of string type")
FB_IMPL_MSG(JRD, 649, sysf_binuuid_wrongsize, -833, "42", "000", "Binary UUID argument for @2 must use @1 bytes")
FB_IMPL_MSG(JRD, 650, missing_required_spb, -902, "HY", "000", "Missing required item @1 in service parameter block")
FB_IMPL_MSG(JRD, 651, net_server_shutdown, -902, "08", "006", "@1 server is shutdown")
FB_IMPL_MSG(JRD, 652, bad_conn_str, -924, "08", "001", "Invalid connection string")
FB_IMPL_MSG(JRD, 653, bad_epb_form, -901, "HY", "000", "Unrecognized events block")
FB_IMPL_MSG(JRD, 654, no_threads, -902, "08", "004", "Could not start first worker thread - shutdown server")
FB_IMPL_MSG(JRD, 655, net_event_connect_timeout, -902, "08", "006", "Timeout occurred while waiting for a secondary connection for event processing")
FB_IMPL_MSG(JRD, 656, sysf_argmustbe_nonzero, -833, "42", "000", "Argument for @1 must be different than zero")
FB_IMPL_MSG(JRD, 657, sysf_argmustbe_range_inc1_1, -833, "42", "000", "Argument for @1 must be in the range [-1, 1]")
FB_IMPL_MSG(JRD, 658, sysf_argmustbe_gteq_one, -833, "42", "000", "Argument for @1 must be greater or equal than one")
FB_IMPL_MSG(JRD, 659, sysf_argmustbe_range_exc1_1, -833, "42", "000", "Argument for @1 must be in the range ]-1, 1[")
FB_IMPL_MSG(JRD, 660, internal_rejected_params, -104, "HY", "000", "Incorrect parameters provided to internal function @1")
FB_IMPL_MSG(JRD, 661, sysf_fp_overflow, -833, "42", "000", "Floating point overflow in built-in function @1")
FB_IMPL_MSG(JRD, 662, udf_fp_overflow, -901, "39", "000", "Floating point overflow in result from UDF @1")
FB_IMPL_MSG(JRD, 663, udf_fp_nan, -901, "39", "000", "Invalid floating point value returned by UDF @1")
FB_IMPL_MSG(JRD, 664, instance_conflict, -902, "42", "000", "Shared memory area is probably already created by another engine instance in another Windows session")
FB_IMPL_MSG(JRD, 665, out_of_temp_space, -901, "HY", "000", "No free space found in temporary directories")
FB_IMPL_MSG(JRD, 666, eds_expl_tran_ctrl, -901, "42", "000", "Explicit transaction control is not allowed")
FB_IMPL_MSG(JRD, 667, no_trusted_spb, -902, "28", "000", "Use of TRUSTED switches in spb_command_line is prohibited")
FB_IMPL_MSG(JRD, 668, package_name, -901, "42", "000", "PACKAGE @1")
FB_IMPL_MSG(JRD, 669, cannot_make_not_null, -901, "22", "006", "Cannot make field @1 of table @2 NOT NULL because there are NULLs present")
FB_IMPL_MSG(JRD, 670, feature_removed, -901, "0A", "000", "Feature @1 is not supported anymore")
FB_IMPL_MSG(JRD, 671, view_name, -901, "00", "000", "VIEW @1")
FB_IMPL_MSG(JRD, 672, lock_dir_access, -904, "08", "006", "Can not access lock files directory @1")
FB_IMPL_MSG(JRD, 673, invalid_fetch_option, -901, "HY", "106", "Fetch option @1 is invalid for a non-scrollable cursor")
FB_IMPL_MSG(JRD, 674, bad_fun_BLR, -901, "2F", "000", "Error while parsing function @1's BLR")
FB_IMPL_MSG(JRD, 675, func_pack_not_implemented, -901, "2F", "000", "Cannot execute function @1 of the unimplemented package @2")
FB_IMPL_MSG(JRD, 676, proc_pack_not_implemented, -901, "2F", "000", "Cannot execute procedure @1 of the unimplemented package @2")
FB_IMPL_MSG(JRD, 677, eem_func_not_returned, -901, "39", "000", "External function @1 not returned by the external engine plugin @2")
FB_IMPL_MSG(JRD, 678, eem_proc_not_returned, -901, "39", "000", "External procedure @1 not returned by the external engine plugin @2")
FB_IMPL_MSG(JRD, 679, eem_trig_not_returned, -901, "39", "000", "External trigger @1 not returned by the external engine plugin @2")
FB_IMPL_MSG(JRD, 680, eem_bad_plugin_ver, -901, "39", "000", "Incompatible plugin version @1 for external engine @2")
FB_IMPL_MSG(JRD, 681, eem_engine_notfound, -901, "39", "000", "External engine @1 not found")
FB_IMPL_MSG(JRD, 682, attachment_in_use, -532, "08", "002", "Attachment is in use")
FB_IMPL_MSG(JRD, 683, transaction_in_use, -532, "25", "S02", "Transaction is in use")
FB_IMPL_MSG(JRD, 684, pman_cannot_load_plugin, -901, "39", "000", "Error loading plugin @1")
FB_IMPL_MSG(JRD, 685, pman_module_notfound, -901, "00", "000", "Loadable module @1 not found")
FB_IMPL_MSG(JRD, 686, pman_entrypoint_notfound, -901, "00", "000", "Standard plugin entrypoint does not exist in module @1")
FB_IMPL_MSG(JRD, 687, pman_module_bad, -901, "00", "000", "Module @1 exists but can not be loaded")
FB_IMPL_MSG(JRD, 688, pman_plugin_notfound, -901, "00", "000", "Module @1 does not contain plugin @2 type @3")
FB_IMPL_MSG(JRD, 689, sysf_invalid_trig_namespace, -833, "42", "000", "Invalid usage of context namespace DDL_TRIGGER")
FB_IMPL_MSG(JRD, 690, unexpected_null, -901, "22", "002", "Value is NULL but isNull parameter was not informed")
FB_IMPL_MSG(JRD, 691, type_notcompat_blob, -901, "22", "00G", "Type @1 is incompatible with BLOB")
FB_IMPL_MSG(JRD, 692, invalid_date_val, -901, "22", "003", "Invalid date")
FB_IMPL_MSG(JRD, 693, invalid_time_val, -901, "22", "003", "Invalid time")
FB_IMPL_MSG(JRD, 694, invalid_timestamp_val, -901, "22", "003", "Invalid timestamp")
FB_IMPL_MSG(JRD, 695, invalid_index_val, -901, "22", "003", "Invalid index @1 in function @2")
FB_IMPL_MSG(JRD, 696, formatted_exception, -836, "00", "000", "@1")
FB_IMPL_MSG(JRD, 697, async_active, -532, "HY", "018", "Asynchronous call is already running for this attachment")
FB_IMPL_MSG(JRD, 698, private_function, -901, "42", "000", "Function @1 is private to package @2")
FB_IMPL_MSG(JRD, 699, private_procedure, -901, "42", "000", "Procedure @1 is private to package @2")
FB_IMPL_MSG(JRD, 700, request_outdated, -904, "24", "000", "Request can't access new records in relation @1 and should be recompiled")
FB_IMPL_MSG(JRD, 701, bad_events_handle, -901, "08", "003", "invalid events id (handle)")
FB_IMPL_MSG(JRD, 702, cannot_copy_stmt, -104, "XX", "000", "Cannot copy statement @1")
FB_IMPL_MSG(JRD, 703, invalid_boolean_usage, -104, "22", "000", "Invalid usage of boolean expression")
FB_IMPL_MSG(JRD, 704, sysf_argscant_both_be_zero, -833, "42", "000", "Arguments for @1 cannot both be zero")
FB_IMPL_MSG(JRD, 705, spb_no_id, -901, "HY", "000", "missing service ID in spb")
FB_IMPL_MSG(JRD, 706, ee_blr_mismatch_null, -901, "42", "000", "External BLR message mismatch: invalid null descriptor at field @1")
FB_IMPL_MSG(JRD, 707, ee_blr_mismatch_length, -901, "42", "000", "External BLR message mismatch: length = @1, expected @2")
FB_IMPL_MSG(JRD, 708, ss_out_of_bounds, -406, "42", "000", "Subscript @1 out of bounds [@2, @3]")
FB_IMPL_MSG(JRD, 709, missing_data_structures, -902, "28", "000", "Install incomplete. To complete security database initialization please CREATE USER. For details read doc/README.security_database.txt.")
FB_IMPL_MSG(JRD, 710, protect_sys_tab, -902, "42", "000", "@1 operation is not allowed for system table @2")
FB_IMPL_MSG(JRD, 711, libtommath_generic, -901, "2F", "000", "Libtommath error code @1 in function @2")
FB_IMPL_MSG(JRD, 712, wroblrver2, -902, "HY", "000", "unsupported BLR version (expected between @1 and @2, encountered @3)")
FB_IMPL_MSG(JRD, 713, trunc_limits, -551, "28", "000", "expected length @1, actual @2")
FB_IMPL_MSG(JRD, 714, info_access, -551, "28", "000", "Wrong info requested in isc_svc_query() for anonymous service")
FB_IMPL_MSG(JRD, 715, svc_no_stdin, -104, "HY", "024", "No isc_info_svc_stdin in user request, but service thread requested stdin data")
FB_IMPL_MSG(JRD, 716, svc_start_failed, -551, "28", "000", "Start request for anonymous service is impossible")
FB_IMPL_MSG(JRD, 717, svc_no_switches, -104, "HY", "024", "All services except for getting server log require switches")
FB_IMPL_MSG(JRD, 718, svc_bad_size, -104, "HY", "109", "Size of stdin data is more than was requested from client")
FB_IMPL_MSG(JRD, 719, no_crypt_plugin, -104, "HY", "024", "Crypt plugin @1 failed to load")
FB_IMPL_MSG(JRD, 720, cp_name_too_long, -104, "22", "001", "Length of crypt plugin name should not exceed @1 bytes")
FB_IMPL_MSG(JRD, 721, cp_process_active, -901, "42", "818", "Crypt failed - already crypting database")
FB_IMPL_MSG(JRD, 722, cp_already_crypted, -901, "42", "818", "Crypt failed - database is already in requested state")
FB_IMPL_MSG(JRD, 723, decrypt_error, -902, "XX", "000", "Missing crypt plugin, but page appears encrypted")
FB_IMPL_MSG(JRD, 724, no_providers, -902, "39", "000", "No providers loaded")
FB_IMPL_MSG(JRD, 725, null_spb, -104, "42", "818", "NULL data with non-zero SPB length")
FB_IMPL_MSG(JRD, 726, max_args_exceeded, -833, "42", "000", "Maximum (@1) number of arguments exceeded for function @2")
FB_IMPL_MSG(JRD, 727, ee_blr_mismatch_names_count, -901, "42", "000", "External BLR message mismatch: names count = @1, blr count = @2")
FB_IMPL_MSG(JRD, 728, ee_blr_mismatch_name_not_found, -901, "42", "000", "External BLR message mismatch: name @1 not found")
FB_IMPL_MSG(JRD, 729, bad_result_set, -901, "26", "000", "Invalid resultset interface")
FB_IMPL_MSG(JRD, 730, wrong_message_length, -804, "07", "000", "Message length passed from user application does not match set of columns")
FB_IMPL_MSG(JRD, 731, no_output_format, -804, "07", "000", "Resultset is missing output format information")
FB_IMPL_MSG(JRD, 732, item_finish, -804, "HY", "021", "Message metadata not ready - item @1 is not finished")
FB_IMPL_MSG(JRD, 733, miss_config, -902, "XX", "000", "Missing configuration file: @1")
FB_IMPL_MSG(JRD, 734, conf_line, -902, "XX", "000", "@1: illegal line <@2>")
FB_IMPL_MSG(JRD, 735, conf_include, -902, "XX", "000", "Invalid include operator in @1 for <@2>")
FB_IMPL_MSG(JRD, 736, include_depth, -902, "XX", "000", "Include depth too big")
FB_IMPL_MSG(JRD, 737, include_miss, -902, "XX", "000", "File to include not found")
FB_IMPL_MSG(JRD, 738, protect_ownership, -552, "28", "000", "Only the owner can change the ownership")
FB_IMPL_MSG(JRD, 739, badvarnum, -901, "HY", "000", "undefined variable number")
FB_IMPL_MSG(JRD, 740, sec_context, -902, "28", "000", "Missing security context for @1")
FB_IMPL_MSG(JRD, 741, multi_segment, -902, "28", "000", "Missing segment @1 in multisegment connect block parameter")
FB_IMPL_MSG(JRD, 742, login_changed, -902, "28", "000", "Different logins in connect and attach packets - client library error")
FB_IMPL_MSG(JRD, 743, auth_handshake_limit, -902, "28", "000", "Exceeded exchange limit during authentication handshake")
FB_IMPL_MSG(JRD, 744, wirecrypt_incompatible, -902, "28", "000", "Incompatible wire encryption levels requested on client and server")
FB_IMPL_MSG(JRD, 745, miss_wirecrypt, -902, "28", "000", "Client attempted to attach unencrypted but wire encryption is required")
FB_IMPL_MSG(JRD, 746, wirecrypt_key, -902, "28", "000", "Client attempted to start wire encryption using unknown key @1")
FB_IMPL_MSG(JRD, 747, wirecrypt_plugin, -902, "28", "000", "Client attempted to start wire encryption using unsupported plugin @1")
FB_IMPL_MSG(JRD, 748, secdb_name, -902, "28", "000", "Error getting security database name from configuration file")
FB_IMPL_MSG(JRD, 749, auth_data, -902, "28", "000", "Client authentication plugin is missing required data from server")
FB_IMPL_MSG(JRD, 750, auth_datalength, -902, "28", "000", "Client authentication plugin expected @2 bytes of @3 from server, got @1")
FB_IMPL_MSG(JRD, 751, info_unprepared_stmt, -901, "HY", "007", "Attempt to get information about an unprepared dynamic SQL statement.")
FB_IMPL_MSG(JRD, 752, idx_key_value, -901, "HY", "007", "Problematic key value is @1")
FB_IMPL_MSG(JRD, 753, forupdate_virtualtbl, -901, "HY", "000", "Cannot select virtual table @1 for update WITH LOCK")
FB_IMPL_MSG(JRD, 754, forupdate_systbl, -901, "HY", "000", "Cannot select system table @1 for update WITH LOCK")
FB_IMPL_MSG(JRD, 755, forupdate_temptbl, -901, "HY", "000", "Cannot select temporary table @1 for update WITH LOCK")
FB_IMPL_MSG(JRD, 756, cant_modify_sysobj, -901, "42", "000", "System @1 @2 cannot be modified")
FB_IMPL_MSG(JRD, 757, server_misconfigured, -901, "08", "004", "Server misconfigured - contact administrator please")
FB_IMPL_MSG(JRD, 758, alter_role, -901, "0A", "000", "Deprecated backward compatibility ALTER ROLE ... SET/DROP AUTO ADMIN mapping may be used only for RDB$ADMIN role")
FB_IMPL_MSG(JRD, 759, map_already_exists, -901, "42", "S01", "Mapping @1 already exists")
FB_IMPL_MSG(JRD, 760, map_not_exists, -901, "42", "S02", "Mapping @1 does not exist")
FB_IMPL_MSG(JRD, 761, map_load, -901, "08", "004", "@1 failed when loading mapping cache")
FB_IMPL_MSG(JRD, 762, map_aster, -901, "08", "004", "Invalid name <*> in authentication block")
FB_IMPL_MSG(JRD, 763, map_multi, -901, "08", "004", "Multiple maps found for @1")
FB_IMPL_MSG(JRD, 764, map_undefined, -901, "08", "004", "Undefined mapping result - more than one different results found")
FB_IMPL_MSG(JRD, 765, baddpb_damaged_mode, -924, "HY", "000", "Incompatible mode of attachment to damaged database")
FB_IMPL_MSG(JRD, 766, baddpb_buffers_range, -924, "HY", "000", "Attempt to set in database number of buffers which is out of acceptable range [@1:@2]")
FB_IMPL_MSG(JRD, 767, baddpb_temp_buffers, -924, "HY", "000", "Attempt to temporarily set number of buffers less than @1")
FB_IMPL_MSG(JRD, 768, map_nodb, -901, "0A", "000", "Global mapping is not available when database @1 is not present")
FB_IMPL_MSG(JRD, 769, map_notable, -901, "0A", "000", "Global mapping is not available when table RDB$MAP is not present in database @1")
FB_IMPL_MSG(JRD, 770, miss_trusted_role, -901, "0P", "000", "Your attachment has no trusted role")
FB_IMPL_MSG(JRD, 771, set_invalid_role, -901, "0P", "000", "Role @1 is invalid or unavailable")
FB_IMPL_MSG(JRD, 772, cursor_not_positioned, -596, "HY", "109", "Cursor @1 is not positioned in a valid record")
FB_IMPL_MSG(JRD, 773, dup_attribute, -901, "42", "702", "Duplicated user attribute @1")
FB_IMPL_MSG(JRD, 774, dyn_no_priv, -901, "42", "000", "There is no privilege for this operation")
FB_IMPL_MSG(JRD, 775, dsql_cant_grant_option, -901, "42", "000", "Using GRANT OPTION on @1 not allowed")
FB_IMPL_MSG(JRD, 776, read_conflict, -904, "40", "001", "read conflicts with concurrent update")
FB_IMPL_MSG(JRD, 777, crdb_load, -901, "08", "004", "@1 failed when working with CREATE DATABASE grants")
FB_IMPL_MSG(JRD, 778, crdb_nodb, -901, "0A", "000", "CREATE DATABASE grants check is not possible when database @1 is not present")
FB_IMPL_MSG(JRD, 779, crdb_notable, -901, "0A", "000", "CREATE DATABASE grants check is not possible when table RDB$DB_CREATORS is not present in database @1")
FB_IMPL_MSG(JRD, 780, interface_version_too_old, -804, "HY", "000", "Interface @3 version too old: expected @1, found @2")
FB_IMPL_MSG(JRD, 781, fun_param_mismatch, -170, "07", "001", "Input parameter mismatch for function @1")
FB_IMPL_MSG(JRD, 782, savepoint_backout_err, -901, "HY", "000", "Error during savepoint backout - transaction invalidated")
FB_IMPL_MSG(JRD, 783, domain_primary_key_notnull, -291, "42", "000", "Domain used in the PRIMARY KEY constraint of table @1 must be NOT NULL")
FB_IMPL_MSG(JRD, 784, invalid_attachment_charset, -204, "2C", "000", "CHARACTER SET @1 cannot be used as a attachment character set")
FB_IMPL_MSG(JRD, 785, map_down, -901, "08", "004", "Some database(s) were shutdown when trying to read mapping data")
FB_IMPL_MSG(JRD, 786, login_error, -902, "08", "006", "Error occurred during login, please check server firebird.log for details")
FB_IMPL_MSG(JRD, 787, already_opened, -902, "08", "006", "Database already opened with engine instance, incompatible with current")
FB_IMPL_MSG(JRD, 788, bad_crypt_key, -902, "08", "006", "Invalid crypt key @1")
FB_IMPL_MSG(JRD, 789, encrypt_error, -901, "XX", "000", "Page requires encryption but crypt plugin is missing")
FB_IMPL_MSG(JRD, 790, max_idx_depth, -904, "54", "000", "Maximum index depth (@1 levels) is reached")
FB_IMPL_MSG(JRD, 791, wrong_prvlg, -901, "0A", "000", "System privilege @1 does not exist")
FB_IMPL_MSG(JRD, 792, miss_prvlg, -902, "28", "000", "System privilege @1 is missing")
FB_IMPL_MSG(JRD, 793, crypt_checksum, -902, "XX", "000", "Invalid or missing checksum of encrypted database")
FB_IMPL_MSG(JRD, 794, not_dba, -902, "28", "000", "You must have SYSDBA rights at this server")
FB_IMPL_MSG(JRD, 795, no_cursor, -901, "07", "005", "Cannot open cursor for non-SELECT statement")
FB_IMPL_MSG(JRD, 796, dsql_window_incompat_frames, -104, "42", "000", "If <window frame bound 1> specifies @1, then <window frame bound 2> shall not specify @2")
FB_IMPL_MSG(JRD, 797, dsql_window_range_multi_key, -104, "42", "000", "RANGE based window with <expr> {PRECEDING | FOLLOWING} cannot have ORDER BY with more than one value")
FB_IMPL_MSG(JRD, 798, dsql_window_range_inv_key_type, -104, "42", "000", "RANGE based window with <offset> PRECEDING/FOLLOWING must have a single ORDER BY key of numerical, date, time or timestamp types")
FB_IMPL_MSG(JRD, 799, dsql_window_frame_value_inv_type, -104, "42", "000", "Window RANGE/ROWS PRECEDING/FOLLOWING value must be of a numerical type")
FB_IMPL_MSG(JRD, 800, window_frame_value_invalid, -833, "42", "000", "Invalid PRECEDING or FOLLOWING offset in window function: cannot be negative")
FB_IMPL_MSG(JRD, 801, dsql_window_not_found, -833, "42", "000", "Window @1 not found")
FB_IMPL_MSG(JRD, 802, dsql_window_cant_overr_part, -833, "42", "000", "Cannot use PARTITION BY clause while overriding the window @1")
FB_IMPL_MSG(JRD, 803, dsql_window_cant_overr_order, -833, "42", "000", "Cannot use ORDER BY clause while overriding the window @1 which already has an ORDER BY clause")
FB_IMPL_MSG(JRD, 804, dsql_window_cant_overr_frame, -833, "42", "000", "Cannot override the window @1 because it has a frame clause. Tip: it can be used without parenthesis in OVER")
FB_IMPL_MSG(JRD, 805, dsql_window_duplicate, -833, "42", "000", "Duplicate window definition for @1")
FB_IMPL_MSG(JRD, 806, sql_too_long, -902, "54", "001", "SQL statement is too long. Maximum size is @1 bytes.")
FB_IMPL_MSG(JRD, 807, cfg_stmt_timeout, -901, "HY", "008", "Config level timeout expired.")
FB_IMPL_MSG(JRD, 808, att_stmt_timeout, -901, "HY", "008", "Attachment level timeout expired.")
FB_IMPL_MSG(JRD, 809, req_stmt_timeout, -901, "HY", "008", "Statement level timeout expired.")
FB_IMPL_MSG(JRD, 810, att_shut_killed, -902, "08", "003", "Killed by database administrator.")
FB_IMPL_MSG(JRD, 811, att_shut_idle, -902, "08", "003", "Idle timeout expired.")
FB_IMPL_MSG(JRD, 812, att_shut_db_down, -902, "08", "003", "Database is shutdown.")
FB_IMPL_MSG(JRD, 813, att_shut_engine, -902, "08", "003", "Engine is shutdown.")
FB_IMPL_MSG(JRD, 814, overriding_without_identity, -902, "42", "000", "OVERRIDING clause can be used only when an identity column is present in the INSERT's field list for table/view @1")
FB_IMPL_MSG(JRD, 815, overriding_system_invalid, -902, "42", "000", "OVERRIDING SYSTEM VALUE can be used only for identity column defined as 'GENERATED ALWAYS' in INSERT for table/view @1")
// Next message was incorrect - but left for compatibility with older engines.
FB_IMPL_MSG(JRD, 816, overriding_user_invalid, -902, "42", "000", "OVERRIDING USER VALUE can be used only for identity column defined as 'GENERATED BY DEFAULT' in INSERT for table/view @1")
FB_IMPL_MSG(JRD, 817, overriding_missing, -902, "42", "000", "OVERRIDING clause should be used when an identity column defined as 'GENERATED ALWAYS' is present in the INSERT's field list for table table/view @1")
FB_IMPL_MSG(JRD, 818, decprecision_err, -842, "HY", "104", "DecFloat precision must be 16 or 34")
FB_IMPL_MSG(JRD, 819, decfloat_divide_by_zero, -901, "22", "012", "Decimal float divide by zero.  The code attempted to divide a DECFLOAT value by zero.")
FB_IMPL_MSG(JRD, 820, decfloat_inexact_result, -901, "22", "000", "Decimal float inexact result.  The result of an operation cannot be represented as a decimal fraction.")
FB_IMPL_MSG(JRD, 821, decfloat_invalid_operation, -901, "22", "000", "Decimal float invalid operation.  An indeterminant error occurred during an operation.")
FB_IMPL_MSG(JRD, 822, decfloat_overflow, -901, "22", "003", "Decimal float overflow.  The exponent of a result is greater than the magnitude allowed.")
FB_IMPL_MSG(JRD, 823, decfloat_underflow, -901, "22", "003", "Decimal float underflow.  The exponent of a result is less than the magnitude allowed.")
FB_IMPL_MSG(JRD, 824, subfunc_notdef, -901, "42", "000", "Sub-function @1 has not been defined")
FB_IMPL_MSG(JRD, 825, subproc_notdef, -901, "42", "000", "Sub-procedure @1 has not been defined")
FB_IMPL_MSG(JRD, 826, subfunc_signat, -901, "42", "000", "Sub-function @1 has a signature mismatch with its forward declaration")
FB_IMPL_MSG(JRD, 827, subproc_signat, -901, "42", "000", "Sub-procedure @1 has a signature mismatch with its forward declaration")
FB_IMPL_MSG(JRD, 828, subfunc_defvaldecl, -901, "42", "000", "Default values for parameters are not allowed in definition of the previously declared sub-function @1")
FB_IMPL_MSG(JRD, 829, subproc_defvaldecl, -901, "42", "000", "Default values for parameters are not allowed in definition of the previously declared sub-procedure @1")
FB_IMPL_MSG(JRD, 830, subfunc_not_impl, -901, "42", "000", "Sub-function @1 was declared but not implemented")
FB_IMPL_MSG(JRD, 831, subproc_not_impl, -901, "42", "000", "Sub-procedure @1 was declared but not implemented")
FB_IMPL_MSG(JRD, 832, sysf_invalid_hash_algorithm, -901, "42", "000", "Invalid HASH algorithm @1")
FB_IMPL_MSG(JRD, 833, expression_eval_index, -901, "42", "000", "Expression evaluation error for index \"@1\" on table \"@2\"")
FB_IMPL_MSG(JRD, 834, invalid_decfloat_trap, -901, "42", "000", "Invalid decfloat trap state @1")
FB_IMPL_MSG(JRD, 835, invalid_decfloat_round, -901, "42", "000", "Invalid decfloat rounding mode @1")
FB_IMPL_MSG(JRD, 836, sysf_invalid_first_last_part, -833, "42", "000", "Invalid part @1 to calculate the @1 of a DATE/TIMESTAMP")
FB_IMPL_MSG(JRD, 837, sysf_invalid_date_timestamp, -833, "42", "000", "Expected DATE/TIMESTAMP value in @1")
FB_IMPL_MSG(JRD, 838, precision_err2, -842, "HY", "104", "Precision must be from @1 to @2")
FB_IMPL_MSG(JRD, 839, bad_batch_handle, -901, "08", "003", "invalid batch handle")
FB_IMPL_MSG(JRD, 840, intl_char, -901, "22", "021", "Bad international character in tag @1")
FB_IMPL_MSG(JRD, 841, null_block, -901, "22", "000", "Null data in parameters block with non-zero length")
FB_IMPL_MSG(JRD, 842, mixed_info, -901, "22", "000", "Items working with running service and getting generic server information should not be mixed in single info block")
FB_IMPL_MSG(JRD, 843, unknown_info, -901, "22", "000", "Unknown information item, code @1")
FB_IMPL_MSG(JRD, 844, bpb_version, -901, "22", "000", "Wrong version of blob parameters block @1, should be @2")
FB_IMPL_MSG(JRD, 845, user_manager, -901, "28", "000", "User management plugin is missing or failed to load")
FB_IMPL_MSG(JRD, 846, icu_entrypoint, -902, "XX", "000", "Missing entrypoint @1 in ICU library")
FB_IMPL_MSG(JRD, 847, icu_library, -902, "XX", "000", "Could not find acceptable ICU library")
FB_IMPL_MSG(JRD, 848, metadata_name, -901, "02", "000", "Name @1 not found in system MetadataBuilder")
FB_IMPL_MSG(JRD, 849, tokens_parse, -901, "42", "000", "Parse to tokens error")
FB_IMPL_MSG(JRD, 850, iconv_open, -902, "08", "006", "Error opening international conversion descriptor from @1 to @2")
FB_IMPL_MSG(JRD, 851, batch_compl_range, -901, "07", "002", "Message @1 is out of range, only @2 messages in batch")
FB_IMPL_MSG(JRD, 852, batch_compl_detail, -901, "07", "002", "Detailed error info for message @1 is missing in batch")
FB_IMPL_MSG(JRD, 853, deflate_init, -902, "08", "006", "Compression stream init error @1")
FB_IMPL_MSG(JRD, 854, inflate_init, -902, "08", "006", "Decompression stream init error @1")
FB_IMPL_MSG(JRD, 855, big_segment, -901, "22", "026", "Segment size (@1) should not exceed 65535 (64K - 1) when using segmented blob")
FB_IMPL_MSG(JRD, 856, batch_policy, -901, "22", "000", "Invalid blob policy in the batch for @1() call")
FB_IMPL_MSG(JRD, 857, batch_defbpb, -901, "22", "000", "Can't change default BPB after adding any data to batch")
FB_IMPL_MSG(JRD, 858, batch_align, -901, "22", "000", "Unexpected info buffer structure querying for server batch parameters")
FB_IMPL_MSG(JRD, 859, multi_segment_dup, -901, "22", "000", "Duplicated segment @1 in multisegment connect block parameter")
FB_IMPL_MSG(JRD, 860, non_plugin_protocol, -902, "08", "004", "Plugin not supported by network protocol")
FB_IMPL_MSG(JRD, 861, message_format, -901, "22", "000", "Error parsing message format")
FB_IMPL_MSG(JRD, 862, batch_param_version, -901, "22", "000", "Wrong version of batch parameters block @1, should be @2")
FB_IMPL_MSG(JRD, 863, batch_msg_long, -901, "54", "000", "Message size (@1) in batch exceeds internal buffer size (@2)")
FB_IMPL_MSG(JRD, 864, batch_open, -901, "08", "002", "Batch already opened for this statement")
FB_IMPL_MSG(JRD, 865, batch_type, -901, "07", "003", "Invalid type of statement used in batch")
FB_IMPL_MSG(JRD, 866, batch_param, -901, "07", "001", "Statement used in batch must have parameters")
FB_IMPL_MSG(JRD, 867, batch_blobs, -901, "07", "001", "There are no blobs in associated with batch statement")
FB_IMPL_MSG(JRD, 868, batch_blob_append, -901, "22", "000", "appendBlobData() is used to append data to last blob but no such blob was added to the batch")
FB_IMPL_MSG(JRD, 869, batch_stream_align, -901, "22", "000", "Portions of data, passed as blob stream, should have size multiple to the alignment required for blobs")
FB_IMPL_MSG(JRD, 870, batch_rpt_blob, -901, "22", "000", "Repeated blob id @1 in registerBlob()")
FB_IMPL_MSG(JRD, 871, batch_blob_buf, -901, "22", "000", "Blob buffer format error")
FB_IMPL_MSG(JRD, 872, batch_small_data, -901, "22", "000", "Unusable (too small) data remained in @1 buffer")
FB_IMPL_MSG(JRD, 873, batch_cont_bpb, -901, "22", "000", "Blob continuation should not contain BPB")
FB_IMPL_MSG(JRD, 874, batch_big_bpb, -901, "22", "000", "Size of BPB (@1) greater than remaining data (@2)")
FB_IMPL_MSG(JRD, 875, batch_big_segment, -901, "22", "000", "Size of segment (@1) greater than current BLOB data (@2)")
FB_IMPL_MSG(JRD, 876, batch_big_seg2, -901, "22", "000", "Size of segment (@1) greater than available data (@2)")
FB_IMPL_MSG(JRD, 877, batch_blob_id, -901, "22", "000", "Unknown blob ID @1 in the batch message")
FB_IMPL_MSG(JRD, 878, batch_too_big, -901, "54", "000", "Internal buffer overflow - batch too big")
FB_IMPL_MSG(JRD, 879, num_literal, -901, "54", "000", "Numeric literal too long")
FB_IMPL_MSG(JRD, 880, map_event, -902, "XX", "000", "Error using events in mapping shared memory: @1")
FB_IMPL_MSG(JRD, 881, map_overflow, -902, "54", "000", "Global mapping memory overflow")
FB_IMPL_MSG(JRD, 882, hdr_overflow, -901, "54", "000", "Header page overflow - too many clumplets on it")
FB_IMPL_MSG(JRD, 883, vld_plugins, -901, "28", "000", "No matching client/server authentication plugins configured for execute statement in embedded datasource")
FB_IMPL_MSG(JRD, 884, db_crypt_key, -902, "08", "004", "Missing database encryption key for your attachment")
FB_IMPL_MSG(JRD, 885, no_keyholder_plugin, -104, "HY", "024", "Key holder plugin @1 failed to load")
FB_IMPL_MSG(JRD, 886, ses_reset_err, -901, "01", "002", "Cannot reset user session")
FB_IMPL_MSG(JRD, 887, ses_reset_open_trans, -901, "25", "S02", "There are open transactions (@1 active)")
FB_IMPL_MSG(JRD, 888, ses_reset_warn, -901, "01", "000", "Session was reset with warning(s)")
FB_IMPL_MSG(JRD, 889, ses_reset_tran_rollback, -901, "01", "102", "Transaction is rolled back due to session reset, all changes are lost")
FB_IMPL_MSG(JRD, 890, plugin_name, -901, "00", "000", "Plugin @1:")
FB_IMPL_MSG(JRD, 891, parameter_name, -901, "42", "000", "PARAMETER @1")
FB_IMPL_MSG(JRD, 892, file_starting_page_err, -901, "HY", "000", "Starting page number for file @1 must be @2 or greater")
FB_IMPL_MSG(JRD, 893, invalid_timezone_offset, -901, "22", "009", "Invalid time zone offset: @1 - must use format +/-hours:minutes and be between -14:00 and +14:00")
FB_IMPL_MSG(JRD, 894, invalid_timezone_region, -901, "22", "009", "Invalid time zone region: @1")
FB_IMPL_MSG(JRD, 895, invalid_timezone_id, -901, "22", "009", "Invalid time zone ID: @1")
FB_IMPL_MSG(JRD, 896, tom_decode64len, -901, "22", "023", "Wrong base64 text length @1, should be multiple of 4")
FB_IMPL_MSG(JRD, 897, tom_strblob, -901, "22", "023", "Invalid first parameter datatype - need string or blob")
FB_IMPL_MSG(JRD, 898, tom_reg, -901, "22", "023", "Error registering @1 - probably bad tomcrypt library")
FB_IMPL_MSG(JRD, 899, tom_algorithm, -901, "22", "023", "Unknown crypt algorithm @1 in USING clause")
FB_IMPL_MSG(JRD, 900, tom_mode_miss, -901, "22", "023", "Should specify mode parameter for symmetric cipher")
FB_IMPL_MSG(JRD, 901, tom_mode_bad, -901, "22", "023", "Unknown symmetric crypt mode specified")
FB_IMPL_MSG(JRD, 902, tom_no_mode, -901, "22", "023", "Mode parameter makes no sense for chosen cipher")
FB_IMPL_MSG(JRD, 903, tom_iv_miss, -901, "22", "023", "Should specify initialization vector (IV) for chosen cipher and/or mode")
FB_IMPL_MSG(JRD, 904, tom_no_iv, -901, "22", "023", "Initialization vector (IV) makes no sense for chosen cipher and/or mode")
FB_IMPL_MSG(JRD, 905, tom_ctrtype_bad, -901, "22", "023", "Invalid counter endianess @1")
FB_IMPL_MSG(JRD, 906, tom_no_ctrtype, -901, "22", "023", "Counter endianess parameter is not used in mode @1")
FB_IMPL_MSG(JRD, 907, tom_ctr_big, -901, "22", "023", "Too big counter value @1, maximum @2 can be used")
FB_IMPL_MSG(JRD, 908, tom_no_ctr, -901, "22", "023", "Counter length/value parameter is not used with @1 @2")
FB_IMPL_MSG(JRD, 909, tom_iv_length, -901, "22", "023", "Invalid initialization vector (IV) length @1, need @2")
FB_IMPL_MSG(JRD, 910, tom_error, -901, "22", "000", "TomCrypt library error: @1")
FB_IMPL_MSG(JRD, 911, tom_yarrow_start, -901, "22", "023", "Starting PRNG yarrow")
FB_IMPL_MSG(JRD, 912, tom_yarrow_setup, -901, "22", "023", "Setting up PRNG yarrow")
FB_IMPL_MSG(JRD, 913, tom_init_mode, -901, "22", "023", "Initializing @1 mode")
FB_IMPL_MSG(JRD, 914, tom_crypt_mode, -901, "22", "023", "Encrypting in @1 mode")
FB_IMPL_MSG(JRD, 915, tom_decrypt_mode, -901, "22", "023", "Decrypting in @1 mode")
FB_IMPL_MSG(JRD, 916, tom_init_cip, -901, "22", "023", "Initializing cipher @1")
FB_IMPL_MSG(JRD, 917, tom_crypt_cip, -901, "22", "023", "Encrypting using cipher @1")
FB_IMPL_MSG(JRD, 918, tom_decrypt_cip, -901, "22", "023", "Decrypting using cipher @1")
FB_IMPL_MSG(JRD, 919, tom_setup_cip, -901, "22", "023", "Setting initialization vector (IV) for @1")
FB_IMPL_MSG(JRD, 920, tom_setup_chacha, -901, "22", "023", "Invalid initialization vector (IV) length @1, need  8 or 12")
FB_IMPL_MSG(JRD, 921, tom_encode, -901, "22", "023", "Encoding @1")
FB_IMPL_MSG(JRD, 922, tom_decode, -901, "22", "023", "Decoding @1")
FB_IMPL_MSG(JRD, 923, tom_rsa_import, -901, "22", "023", "Importing RSA key")
FB_IMPL_MSG(JRD, 924, tom_oaep, -901, "22", "023", "Invalid OAEP packet")
FB_IMPL_MSG(JRD, 925, tom_hash_bad, -901, "22", "023", "Unknown hash algorithm @1")
FB_IMPL_MSG(JRD, 926, tom_rsa_make, -901, "22", "023", "Making RSA key")
FB_IMPL_MSG(JRD, 927, tom_rsa_export, -901, "22", "023", "Exporting @1 RSA key")
FB_IMPL_MSG(JRD, 928, tom_rsa_sign, -901, "22", "023", "RSA-signing data")
FB_IMPL_MSG(JRD, 929, tom_rsa_verify, -901, "22", "023", "Verifying RSA-signed data")
FB_IMPL_MSG(JRD, 930, tom_chacha_key, -901, "22", "023", "Invalid key length @1, need 16 or 32")
FB_IMPL_MSG(JRD, 931, bad_repl_handle, -901, "08", "003", "invalid replicator handle")
FB_IMPL_MSG(JRD, 932, tra_snapshot_does_not_exist, -901, "0B", "000", "Transaction's base snapshot number does not exist")
FB_IMPL_MSG(JRD, 933, eds_input_prm_not_used, -901, "42", "000", "Input parameter '@1' is not used in SQL query text")
FB_IMPL_MSG(JRD, 934, effective_user, -551, "28", "000", "Effective user is @1")
FB_IMPL_MSG(JRD, 935, invalid_time_zone_bind, -901, "42", "000", "Invalid time zone bind mode @1")
FB_IMPL_MSG(JRD, 936, invalid_decfloat_bind, -901, "42", "000", "Invalid decfloat bind mode @1")
FB_IMPL_MSG(JRD, 937, odd_hex_len, -901, "22", "023", "Invalid hex text length @1, should be multiple of 2")
FB_IMPL_MSG(JRD, 938, invalid_hex_digit, -901, "22", "023", "Invalid hex digit @1 at position @2")
FB_IMPL_MSG(JRD, 939, bind_err, -902, "08", "004", "Error processing isc_dpb_set_bind clumplet \"@1\"")
FB_IMPL_MSG(JRD, 940, bind_statement, -902, "08", "004", "The following statement failed: @1")
FB_IMPL_MSG(JRD, 941, bind_convert, -901, "22", "000", "Can not convert @1 to @2")
FB_IMPL_MSG(JRD, 942, cannot_update_old_blob, -402, "42", "000", "cannot update old BLOB")
FB_IMPL_MSG(JRD, 943, cannot_read_new_blob, -402, "42", "000", "cannot read from new BLOB")
FB_IMPL_MSG(JRD, 944, dyn_no_create_priv, -901, "42", "000", "No permission for CREATE @1 operation")
FB_IMPL_MSG(JRD, 945, suspend_without_returns, -901, "42", "000", "SUSPEND could not be used without RETURNS clause in PROCEDURE or EXECUTE BLOCK")
FB_IMPL_MSG(JRD, 946, truncate_warn, 304, "01", "004", "String truncated warning due to the following reason")
FB_IMPL_MSG(JRD, 947, truncate_monitor, 304, "01", "004", "Monitoring data does not fit into the field")
FB_IMPL_MSG(JRD, 948, truncate_context, 304, "01", "004", "Engine data does not fit into return value of system function")
FB_IMPL_MSG(JRD, 949, merge_dup_update, -811, "21", "000", "Multiple source records cannot match the same target during MERGE")
FB_IMPL_MSG(JRD, 950, wrong_page, -902, "XX", "000", "RDB$PAGES written by non-system transaction, DB appears to be damaged")
FB_IMPL_MSG(JRD, 951, repl_error, -902, "HY", "000", "Replication error")
FB_IMPL_MSG(JRD, 952, ses_reset_failed, -902, "08", "003", "Reset of user session failed. Connection is shut down.")
FB_IMPL_MSG(JRD, 953, block_size, -902, "XX", "000", "File size is less than expected")
FB_IMPL_MSG(JRD, 954, tom_key_length, -901, "22", "023", "Invalid key length @1, need >@2")
FB_IMPL_MSG(JRD, 955, inf_invalid_args, -901, "HY", "000", "Invalid information arguments")
FB_IMPL_MSG(JRD, 956, sysf_invalid_null_empty, -901, "22", "023", "Empty or NULL parameter @1 is not accepted")
FB_IMPL_MSG(JRD, 957, bad_loctab_num, -901, "HY", "000", "Undefined local table number @1")
FB_IMPL_MSG(JRD, 958, quoted_str_bad, -901, "22", "024", "Invalid text <@1> after quoted string")
FB_IMPL_MSG(JRD, 959, quoted_str_miss, -901, "22", "024", "Missing terminating quote <@1> in the end of quoted string")
FB_IMPL_MSG(JRD, 960, wrong_shmem_ver, -902, "08", "006", "@1: inconsistent shared memory type/version; found @2, expected @3")
FB_IMPL_MSG(JRD, 961, wrong_shmem_bitness, -902, "08", "006", "@1-bit engine can't open database already opened by @2-bit engine")
FB_IMPL_MSG(JRD, 962, wrong_proc_plan, -281, "HY", "000", "Procedures cannot specify access type other than NATURAL in the plan")
FB_IMPL_MSG(JRD, 963, invalid_blob_util_handle, -402, "42", "000", "Invalid RDB$BLOB_UTIL handle")
FB_IMPL_MSG(JRD, 964, bad_temp_blob_id, -402, "42", "000", "Invalid temporary BLOB ID")
FB_IMPL_MSG(JRD, 965, ods_upgrade_err, -901, "HY", "000", "ODS upgrade failed while adding new system %s")
FB_IMPL_MSG(JRD, 966, bad_par_workers, -924, "HY", "000", "Wrong parallel workers value @1, valid range are from 1 to @2")
FB_IMPL_MSG(JRD, 967, idx_expr_not_found, -902, "42", "000", "Definition of index expression is not found for index @1")
FB_IMPL_MSG(JRD, 968, idx_cond_not_found, -902, "42", "000", "Definition of index condition is not found for index @1")
// Codes 969..987 are used in v6
FB_IMPL_MSG(JRD, 988, sweep_unable_to_run, -901, "42", "000", "Unable to run sweep")
FB_IMPL_MSG(JRD, 989, sweep_concurrent_instance, -901, "42", "000", "Another instance of sweep is already running")
FB_IMPL_MSG(JRD, 990, sweep_read_only, -901, "42", "000", "Database in read only state")
FB_IMPL_MSG(JRD, 991, sweep_attach_no_cleanup, -901, "42", "000", "Attachment has no cleanup flag set")
// Codes 992..997 are used in v6
FB_IMPL_MSG(JRD, 998, no_user_att_while_restore, -901, "HY", "000", "User attachments are not allowed for the database being restored")
