FB_IMPL_MSG_SYMBOL(GSEC, 1, GsecMsg1, "GSEC>")
FB_IMPL_MSG_SYMBOL(GSEC, 2, GsecMsg2, "gsec")
FB_IMPL_MSG_SYMBOL(GSEC, 3, GsecMsg3, "ADD            add user")
FB_IMPL_MSG_SYMBOL(GSEC, 4, GsecMsg4, "DELETE         delete user")
FB_IMPL_MSG_SYMBOL(GSEC, 5, GsecMsg5, "DISPLAY        display user(s)")
FB_IMPL_MSG_SYMBOL(GSEC, 6, GsecMsg6, "MODIFY         modify user")
FB_IMPL_MSG_SYMBOL(GSEC, 7, GsecMsg7, "PW             user's password")
FB_IMPL_MSG_SYMBOL(GSEC, 8, GsecMsg8, "UID            user's ID")
FB_IMPL_MSG_SYMBOL(GSEC, 9, GsecMsg9, "GID            user's group ID")
FB_IMPL_MSG_SYMBOL(GSEC, 10, GsecMsg10, "PROJ           user's project name")
FB_IMPL_MSG_SYMBOL(GSEC, 11, GsecMsg11, "ORG            user's organization name")
FB_IMPL_MSG_SYMBOL(GSEC, 12, GsecMsg12, "FNAME          user's first name")
FB_IMPL_MSG_SYMBOL(GSEC, 13, GsecMsg13, "MNAME          user's middle name/initial")
FB_IMPL_MSG_SYMBOL(GSEC, 14, GsecMsg14, "LNAME          user's last name")
FB_IMPL_MSG(GSEC, 15, gsec_cant_open_db, -901, "00", "000", "unable to open database")
FB_IMPL_MSG(GSEC, 16, gsec_switches_error, -901, "00", "000", "error in switch specifications")
FB_IMPL_MSG(GSEC, 17, gsec_no_op_spec, -901, "00", "000", "no operation specified")
FB_IMPL_MSG(GSEC, 18, gsec_no_usr_name, -901, "00", "000", "no user name specified")
FB_IMPL_MSG(GSEC, 19, gsec_err_add, -901, "00", "000", "add record error")
FB_IMPL_MSG(GSEC, 20, gsec_err_modify, -901, "00", "000", "modify record error")
FB_IMPL_MSG(GSEC, 21, gsec_err_find_mod, -901, "00", "000", "find/modify record error")
FB_IMPL_MSG(GSEC, 22, gsec_err_rec_not_found, -901, "00", "000", "record not found for user: @1")
FB_IMPL_MSG(GSEC, 23, gsec_err_delete, -901, "00", "000", "delete record error")
FB_IMPL_MSG(GSEC, 24, gsec_err_find_del, -901, "00", "000", "find/delete record error")
FB_IMPL_MSG_SYMBOL(GSEC, 25, GsecMsg25, "users defined for node")
FB_IMPL_MSG_SYMBOL(GSEC, 26, GsecMsg26, "     user name                    uid   gid admin     full name")
FB_IMPL_MSG_SYMBOL(GSEC, 27, GsecMsg27, "------------------------------------------------------------------------------------------------")
FB_IMPL_MSG(GSEC, 28, gsec_err_find_disp, -901, "00", "000", "find/display record error")
FB_IMPL_MSG(GSEC, 29, gsec_inv_param, -901, "00", "000", "invalid parameter, no switch defined")
FB_IMPL_MSG(GSEC, 30, gsec_op_specified, -901, "00", "000", "operation already specified")
FB_IMPL_MSG(GSEC, 31, gsec_pw_specified, -901, "00", "000", "password already specified")
FB_IMPL_MSG(GSEC, 32, gsec_uid_specified, -901, "00", "000", "uid already specified")
FB_IMPL_MSG(GSEC, 33, gsec_gid_specified, -901, "00", "000", "gid already specified")
FB_IMPL_MSG(GSEC, 34, gsec_proj_specified, -901, "00", "000", "project already specified")
FB_IMPL_MSG(GSEC, 35, gsec_org_specified, -901, "00", "000", "organization already specified")
FB_IMPL_MSG(GSEC, 36, gsec_fname_specified, -901, "00", "000", "first name already specified")
FB_IMPL_MSG(GSEC, 37, gsec_mname_specified, -901, "00", "000", "middle name already specified")
FB_IMPL_MSG(GSEC, 38, gsec_lname_specified, -901, "00", "000", "last name already specified")
FB_IMPL_MSG_SYMBOL(GSEC, 39, GsecMsg39, "gsec version")
FB_IMPL_MSG(GSEC, 40, gsec_inv_switch, -901, "00", "000", "invalid switch specified")
FB_IMPL_MSG(GSEC, 41, gsec_amb_switch, -901, "00", "000", "ambiguous switch specified")
FB_IMPL_MSG(GSEC, 42, gsec_no_op_specified, -901, "00", "000", "no operation specified for parameters")
FB_IMPL_MSG(GSEC, 43, gsec_params_not_allowed, -901, "00", "000", "no parameters allowed for this operation")
FB_IMPL_MSG(GSEC, 44, gsec_incompat_switch, -901, "00", "000", "incompatible switches specified")
FB_IMPL_MSG_SYMBOL(GSEC, 45, GsecMsg45, "gsec utility - maintains user password database")
FB_IMPL_MSG_SYMBOL(GSEC, 46, GsecMsg46, "command line usage:")
FB_IMPL_MSG_SYMBOL(GSEC, 47, GsecMsg47, "<command> [ <parameter> ... ]")
FB_IMPL_MSG_SYMBOL(GSEC, 48, GsecMsg48, "interactive usage:")
FB_IMPL_MSG_SYMBOL(GSEC, 49, GsecMsg49, "available commands:")
FB_IMPL_MSG_SYMBOL(GSEC, 50, GsecMsgs50, "adding a new user:")
FB_IMPL_MSG_SYMBOL(GSEC, 51, GsecMsg51, "add <name> [ <parameter> ... ]")
FB_IMPL_MSG_SYMBOL(GSEC, 52, GsecMsg52, "deleting a current user:")
FB_IMPL_MSG_SYMBOL(GSEC, 53, GsecMsg53, "delete <name>")
FB_IMPL_MSG_SYMBOL(GSEC, 54, GsecMsg54, "displaying all users:")
FB_IMPL_MSG_SYMBOL(GSEC, 55, GsecMsg55, "display")
FB_IMPL_MSG_SYMBOL(GSEC, 56, GsecMsg56, "displaying one user:")
FB_IMPL_MSG_SYMBOL(GSEC, 57, GsecMsg57, "display <name>")
FB_IMPL_MSG_SYMBOL(GSEC, 58, GsecMsg58, "modifying a user's parameters:")
FB_IMPL_MSG_SYMBOL(GSEC, 59, GsecMsg59, "modify <name> <parameter> [ <parameter> ... ]")
FB_IMPL_MSG_SYMBOL(GSEC, 60, GsecMsg60, "help:")
FB_IMPL_MSG_SYMBOL(GSEC, 61, GsecMsg61, "? (interactive only)")
FB_IMPL_MSG_SYMBOL(GSEC, 62, GsecMsg62, "help")
FB_IMPL_MSG_SYMBOL(GSEC, 63, GsecMsg63, "quit interactive session:")
FB_IMPL_MSG_SYMBOL(GSEC, 64, GsecMsg64, "quit (interactive only)")
FB_IMPL_MSG_SYMBOL(GSEC, 65, GsecMsg65, "available parameters:")
FB_IMPL_MSG_SYMBOL(GSEC, 66, GsecMsg66, "-pw <password>")
FB_IMPL_MSG_SYMBOL(GSEC, 67, GsecMsg67, "-uid <uid>")
FB_IMPL_MSG_SYMBOL(GSEC, 68, GsecMsg68, "-gid <uid>")
FB_IMPL_MSG_SYMBOL(GSEC, 69, GsecMsg69, "-proj <projectname>")
FB_IMPL_MSG_SYMBOL(GSEC, 70, GsecMsg70, "-org <organizationname>")
FB_IMPL_MSG_SYMBOL(GSEC, 71, GsecMsg71, "-fname <firstname>")
FB_IMPL_MSG_SYMBOL(GSEC, 72, GsecMsg72, "-mname <middlename>")
FB_IMPL_MSG_SYMBOL(GSEC, 73, GsecMsg73, "-lname <lastname>")
FB_IMPL_MSG_NO_SYMBOL(GSEC, 74, "gsec - memory allocation error")
FB_IMPL_MSG_NO_SYMBOL(GSEC, 75, "gsec error")
FB_IMPL_MSG(GSEC, 76, gsec_inv_username, -901, "00", "000", "Invalid user name (maximum 31 bytes allowed)")
FB_IMPL_MSG(GSEC, 77, gsec_inv_pw_length, -901, "00", "000", "Warning - maximum 8 significant bytes of password used")
FB_IMPL_MSG(GSEC, 78, gsec_db_specified, -901, "00", "000", "database already specified")
FB_IMPL_MSG(GSEC, 79, gsec_db_admin_specified, -901, "00", "000", "database administrator name already specified")
FB_IMPL_MSG(GSEC, 80, gsec_db_admin_pw_specified, -901, "00", "000", "database administrator password already specified")
FB_IMPL_MSG(GSEC, 81, gsec_sql_role_specified, -901, "00", "000", "SQL role name already specified")
FB_IMPL_MSG_SYMBOL(GSEC, 82, GsecMsg82, "[ <options> ... ]")
FB_IMPL_MSG_SYMBOL(GSEC, 83, GsecMsg83, "available options:")
FB_IMPL_MSG_SYMBOL(GSEC, 84, GsecMsg84, "-user <database administrator name>")
FB_IMPL_MSG_SYMBOL(GSEC, 85, GsecMsg85, "-password <database administrator password>")
FB_IMPL_MSG_SYMBOL(GSEC, 86, GsecMsg86, "-role <database administrator SQL role name>")
FB_IMPL_MSG_SYMBOL(GSEC, 87, GsecMsg87, "-database <database to manage>")
FB_IMPL_MSG_SYMBOL(GSEC, 88, GsecMsg88, "-z")
FB_IMPL_MSG_SYMBOL(GSEC, 89, GsecMsg89, "displaying version number:")
FB_IMPL_MSG_SYMBOL(GSEC, 90, GsecMsg90, "z (interactive only)")
FB_IMPL_MSG_SYMBOL(GSEC, 91, GsecMsg91, "-trusted (use trusted authentication)")
FB_IMPL_MSG_SYMBOL(GSEC, 92, GsecMsg92, "invalid switch specified in interactive mode")
FB_IMPL_MSG_SYMBOL(GSEC, 93, GsecMsg93, "error closing security database")
FB_IMPL_MSG_SYMBOL(GSEC, 94, GsecMsg94, "error releasing request in security database")
FB_IMPL_MSG_SYMBOL(GSEC, 95, GsecMsg95, "-fetch_password <file to fetch password from>")
FB_IMPL_MSG_SYMBOL(GSEC, 96, GsecMsg96, "error fetching password from file")
FB_IMPL_MSG_SYMBOL(GSEC, 97, GsecMsg97, "error changing AUTO ADMINS MAPPING in security database")
FB_IMPL_MSG_SYMBOL(GSEC, 98, GsecMsg98, "changing admins mapping to RDB$ADMIN role in security database:")
FB_IMPL_MSG_SYMBOL(GSEC, 99, GsecMsg99, "invalid parameter for -MAPPING, only SET or DROP is accepted")
FB_IMPL_MSG_SYMBOL(GSEC, 100, GsecMsg100, "mapping {set|drop}")
FB_IMPL_MSG_SYMBOL(GSEC, 101, GsecMsg101, "use gsec -? to get help")
FB_IMPL_MSG_SYMBOL(GSEC, 102, GsecMsg102, "-admin {yes|no}")
FB_IMPL_MSG_SYMBOL(GSEC, 103, GsecMsg103, "invalid parameter for -ADMIN, only YES or NO is accepted")
FB_IMPL_MSG_SYMBOL(GSEC, 104, GsecMsg104, "not enough privileges to complete operation")
