FB_IMPL_MSG_NO_SYMBOL(NBACKUP, 1, "ERROR: ")
FB_IMPL_MSG_NO_SYMBOL(NBACKUP, 2, "Physical Backup Manager    Copyright (C) 2004 Firebird development team")
FB_IMPL_MSG_NO_SYMBOL(NBACKUP, 3, "  Original idea is of Sean Leyne <sean@@broadviewsoftware.com>")
FB_IMPL_MSG_NO_SYMBOL(NBACKUP, 4, "  Designed and implemented by Nickolay Samofatov <skidder@@bssys.com>")
FB_IMPL_MSG_NO_SYMBOL(NBACKUP, 5, "  This work was funded through a grant from BroadView Software, Inc.\\n")
FB_IMPL_MSG_NO_SYMBOL(NBACKUP, 6, "Usage: nbackup <options>")
FB_IMPL_MSG_NO_SYMBOL(NBACKUP, 7, "exclusive options are:")
FB_IMPL_MSG_NO_SYMBOL(NBACKUP, 8, "  -L(OCK) <database>                     Lock database for filesystem copy")
FB_IMPL_MSG_NO_SYMBOL(NBACKUP, 9, "  -UN(LOCK) <database>                   Unlock previously locked database")
FB_IMPL_MSG_NO_SYMBOL(NBACKUP, 10, "  -F(IXUP) <database>                    Fixup database after filesystem copy")
FB_IMPL_MSG_NO_SYMBOL(NBACKUP, 11, "  -B(ACKUP) <level>|<GUID> <db> [<file>] Create incremental backup")
FB_IMPL_MSG_NO_SYMBOL(NBACKUP, 12, "  -R(ESTORE) <db> [<file0> [<file1>...]] Restore incremental backup")
FB_IMPL_MSG_NO_SYMBOL(NBACKUP, 13, "  -U(SER) <user>                         User name")
FB_IMPL_MSG_NO_SYMBOL(NBACKUP, 14, "  -P(ASSWORD) <password>                 Password")
FB_IMPL_MSG_NO_SYMBOL(NBACKUP, 15, "  -FETCH_PASSWORD <file>                 Fetch password from file")
FB_IMPL_MSG_NO_SYMBOL(NBACKUP, 16, "  -NOD(BTRIGGERS)                        Do not run database triggers")
FB_IMPL_MSG_NO_SYMBOL(NBACKUP, 17, "  -S(IZE)                                Print database size in pages after lock")
FB_IMPL_MSG_NO_SYMBOL(NBACKUP, 18, "  -Z                                     Print program version")
FB_IMPL_MSG_NO_SYMBOL(NBACKUP, 19, "Notes:")
FB_IMPL_MSG_NO_SYMBOL(NBACKUP, 20, "  <database> may specify database alias.")
FB_IMPL_MSG_NO_SYMBOL(NBACKUP, 21, "  Incremental backups of multi-file databases are not supported yet.")
FB_IMPL_MSG_NO_SYMBOL(NBACKUP, 22, "  \"stdout\" may be used as a value of <filename> for -B option.")
FB_IMPL_MSG_NO_SYMBOL(NBACKUP, 23, "PROBLEM ON \"@1\".")
FB_IMPL_MSG_NO_SYMBOL(NBACKUP, 24, "general options are:")
FB_IMPL_MSG_NO_SYMBOL(NBACKUP, 25, "switches can be abbreviated to the unparenthesized characters")
FB_IMPL_MSG_NO_SYMBOL(NBACKUP, 26, "  Option -S(IZE) only is valid together with -L(OCK).")
FB_IMPL_MSG_NO_SYMBOL(NBACKUP, 27, "  For historical reasons, -N is equivalent to -UN(LOCK)")
FB_IMPL_MSG_NO_SYMBOL(NBACKUP, 28, "  and -T is equivalent to -NOD(BTRIGGERS).")
FB_IMPL_MSG(NBACKUP, 29, nbackup_missing_param, -901, "00", "000", "Missing parameter for switch @1")
FB_IMPL_MSG(NBACKUP, 30, nbackup_allowed_switches, -901, "00", "000", "Only one of -LOCK, -UNLOCK, -FIXUP, -BACKUP or -RESTORE should be specified")
FB_IMPL_MSG(NBACKUP, 31, nbackup_unknown_param, -901, "00", "000", "Unrecognized parameter @1")
FB_IMPL_MSG(NBACKUP, 32, nbackup_unknown_switch, -901, "00", "000", "Unknown switch @1")
FB_IMPL_MSG(NBACKUP, 33, nbackup_nofetchpw_svc, -901, "00", "000", "Fetch password can't be used in service mode")
FB_IMPL_MSG(NBACKUP, 34, nbackup_pwfile_error, -901, "00", "000", "Error working with password file \"@1\"")
FB_IMPL_MSG(NBACKUP, 35, nbackup_size_with_lock, -901, "00", "000", "Switch -SIZE can be used only with -LOCK")
FB_IMPL_MSG(NBACKUP, 36, nbackup_no_switch, -901, "00", "000", "None of -LOCK, -UNLOCK, -FIXUP, -BACKUP or -RESTORE specified")
FB_IMPL_MSG_NO_SYMBOL(NBACKUP, 37, "Failure: ")
FB_IMPL_MSG_NO_SYMBOL(NBACKUP, 38, "Enter name of the backup file of level @1 (\".\" - do not restore further):")
FB_IMPL_MSG(NBACKUP, 39, nbackup_err_read, -901, "00", "000", "IO error reading file: @1")
FB_IMPL_MSG(NBACKUP, 40, nbackup_err_write, -901, "00", "000", "IO error writing file: @1")
FB_IMPL_MSG(NBACKUP, 41, nbackup_err_seek, -901, "00", "000", "IO error seeking file: @1")
FB_IMPL_MSG(NBACKUP, 42, nbackup_err_opendb, -901, "00", "000", "Error opening database file: @1")
FB_IMPL_MSG(NBACKUP, 43, nbackup_err_fadvice, -901, "00", "000", "Error in posix_fadvise(@1) for database @2")
FB_IMPL_MSG(NBACKUP, 44, nbackup_err_createdb, -901, "00", "000", "Error creating database file: @1")
FB_IMPL_MSG(NBACKUP, 45, nbackup_err_openbk, -901, "00", "000", "Error opening backup file: @1")
FB_IMPL_MSG(NBACKUP, 46, nbackup_err_createbk, -901, "00", "000", "Error creating backup file: @1")
FB_IMPL_MSG(NBACKUP, 47, nbackup_err_eofdb, -901, "00", "000", "Unexpected end of database file @1")
FB_IMPL_MSG(NBACKUP, 48, nbackup_fixup_wrongstate, -901, "00", "000", "Database @1 is not in state (@2) to be safely fixed up")
FB_IMPL_MSG(NBACKUP, 49, nbackup_err_db, -901, "00", "000", "Database error")
FB_IMPL_MSG(NBACKUP, 50, nbackup_userpw_toolong, -901, "00", "000", "Username or password is too long")
FB_IMPL_MSG(NBACKUP, 51, nbackup_lostrec_db, -901, "00", "000", "Cannot find record for database \"@1\" backup level @2 in the backup history")
FB_IMPL_MSG(NBACKUP, 52, nbackup_lostguid_db, -901, "00", "000", "Internal error. History query returned null SCN or GUID")
FB_IMPL_MSG(NBACKUP, 53, nbackup_err_eofhdrdb, -901, "00", "000", "Unexpected end of file when reading header of database file \"@1\" (stage @2)")
FB_IMPL_MSG(NBACKUP, 54, nbackup_db_notlock, -901, "00", "000", "Internal error. Database file is not locked. Flags are @1")
FB_IMPL_MSG(NBACKUP, 55, nbackup_lostguid_bk, -901, "00", "000", "Internal error. Cannot get backup guid clumplet")
FB_IMPL_MSG(NBACKUP, 56, nbackup_page_changed, -901, "00", "000", "Internal error. Database page @1 had been changed during backup (page SCN=@2, backup SCN=@3)")
FB_IMPL_MSG(NBACKUP, 57, nbackup_dbsize_inconsistent, -901, "00", "000", "Database file size is not a multiple of page size")
FB_IMPL_MSG(NBACKUP, 58, nbackup_failed_lzbk, -901, "00", "000", "Level 0 backup is not restored")
FB_IMPL_MSG(NBACKUP, 59, nbackup_err_eofhdrbk, -901, "00", "000", "Unexpected end of file when reading header of backup file: @1")
FB_IMPL_MSG(NBACKUP, 60, nbackup_invalid_incbk, -901, "00", "000", "Invalid incremental backup file: @1")
FB_IMPL_MSG(NBACKUP, 61, nbackup_unsupvers_incbk, -901, "00", "000", "Unsupported version @1 of incremental backup file: @2")
FB_IMPL_MSG(NBACKUP, 62, nbackup_invlevel_incbk, -901, "00", "000", "Invalid level @1 of incremental backup file: @2, expected @3")
FB_IMPL_MSG(NBACKUP, 63, nbackup_wrong_orderbk, -901, "00", "000", "Wrong order of backup files or invalid incremental backup file detected, file: @1")
FB_IMPL_MSG(NBACKUP, 64, nbackup_err_eofbk, -901, "00", "000", "Unexpected end of backup file: @1")
FB_IMPL_MSG(NBACKUP, 65, nbackup_err_copy, -901, "00", "000", "Error creating database file: @1 via copying from: @2")
FB_IMPL_MSG(NBACKUP, 66, nbackup_err_eofhdr_restdb, -901, "00", "000", "Unexpected end of file when reading header of restored database file (stage @1)")
FB_IMPL_MSG(NBACKUP, 67, nbackup_lostguid_l0bk, -901, "00", "000", "Cannot get backup guid clumplet from L0 backup")
FB_IMPL_MSG_NO_SYMBOL(NBACKUP, 68, "Physical Backup Manager version @1")
FB_IMPL_MSG_NO_SYMBOL(NBACKUP, 69, "Enter name of the backup file of level @1 (\".\" - do not restore further):")
FB_IMPL_MSG_NO_SYMBOL(NBACKUP, 70, "  -D(IRECT) <ON | OFF>                   Use or not direct I/O when backing up database")
FB_IMPL_MSG(NBACKUP, 71, nbackup_switchd_parameter, -901, "00", "000", "Wrong parameter @1 for switch -D, need ON or OFF")
FB_IMPL_MSG_NO_SYMBOL(NBACKUP, 72, "special options are:")
FB_IMPL_MSG(NBACKUP, 73, nbackup_user_stop, -901, "08", "006", "Terminated due to user request")
FB_IMPL_MSG_NO_SYMBOL(NBACKUP, 74, "  -DE(COMPRESS) <command>                Command to extract archives during restore")
FB_IMPL_MSG(NBACKUP, 75, nbackup_deco_parse, -901, "54", "023", "Too complex decompress command (> @1 arguments)")
FB_IMPL_MSG_NO_SYMBOL(NBACKUP, 76, "  -RO(LE) <role>                         SQL role name")
FB_IMPL_MSG(NBACKUP, 77, nbackup_lostrec_guid_db, -901, "00", "000", "Cannot find record for database \"@1\" backup GUID @2 in the backup history")
FB_IMPL_MSG_NO_SYMBOL(NBACKUP, 78, "  -I(NPLACE)                             Restore incremental backup(s) to existing database")
FB_IMPL_MSG_NO_SYMBOL(NBACKUP, 79, "  -INPLACE option could corrupt the database that has changed since previous restore.")
FB_IMPL_MSG_NO_SYMBOL(NBACKUP, 80, "  -SEQ(UENCE)                            Preserve original replication sequence")
FB_IMPL_MSG(NBACKUP, 81, nbackup_seq_misuse, -901, "00", "000", "Switch -SEQ(UENCE) can be used only with -FIXUP or -RESTORE")
FB_IMPL_MSG_NO_SYMBOL(NBACKUP, 82, "  -CLEAN_HIST(ORY)                       Clean old records from backup history")
FB_IMPL_MSG_NO_SYMBOL(NBACKUP, 83, "  -K(EEP) <N> <(R)OWS | (D)AYS>          How many recent rows (or days back from today) should be kept in the history")
FB_IMPL_MSG(NBACKUP, 84, nbackup_wrong_param, -901, "00", "000", "Wrong parameter value for switch @1")
FB_IMPL_MSG(NBACKUP, 85, nbackup_clean_hist_misuse, -901, "00", "000", "Switch -CLEAN_HISTORY can be used only with -BACKUP")
FB_IMPL_MSG(NBACKUP, 86, nbackup_clean_hist_missed, -901, "00", "000", "-KEEP can be used only with -CLEAN_HISTORY")
FB_IMPL_MSG(NBACKUP, 87, nbackup_keep_hist_missed, -901, "00", "000", "-KEEP is required with -CLEAN_HISTORY")
FB_IMPL_MSG(NBACKUP, 88, nbackup_second_keep_switch, -901, "00", "000", "-KEEP can be used one time only")
