FB_IMPL_MSG_NO_SYMBOL(DYN, 1, "ODS version not supported by DYN")
FB_IMPL_MSG_NO_SYMBOL(DYN, 2, "unsupported DYN verb")
FB_IMPL_MSG_NO_SYMBOL(DYN, 3, "STORE RDB$FIELD_DIMENSIONS failed")
FB_IMPL_MSG_NO_SYMBOL(DYN, 4, "unsupported DYN verb")
FB_IMPL_MSG_NO_SYMBOL(DYN, 5, "@1")
FB_IMPL_MSG_NO_SYMBOL(DYN, 6, "unsupported DYN verb")
FB_IMPL_MSG_NO_SYMBOL(DYN, 7, "DEFINE BLOB FILTER failed")
FB_IMPL_MSG_NO_SYMBOL(DYN, 8, "DEFINE GENERATOR failed")
FB_IMPL_MSG_NO_SYMBOL(DYN, 9, "DEFINE GENERATOR unexpected DYN verb")
FB_IMPL_MSG_NO_SYMBOL(DYN, 10, "DEFINE FUNCTION failed")
FB_IMPL_MSG_NO_SYMBOL(DYN, 11, "unsupported DYN verb")
FB_IMPL_MSG_NO_SYMBOL(DYN, 12, "DEFINE FUNCTION ARGUMENT failed")
FB_IMPL_MSG_NO_SYMBOL(DYN, 13, "STORE RDB$FIELDS failed")
FB_IMPL_MSG_NO_SYMBOL(DYN, 14, "No table specified for index")
FB_IMPL_MSG_NO_SYMBOL(DYN, 15, "STORE RDB$INDEX_SEGMENTS failed")
FB_IMPL_MSG_NO_SYMBOL(DYN, 16, "unsupported DYN verb")
FB_IMPL_MSG_NO_SYMBOL(DYN, 17, "PRIMARY KEY column lookup failed")
FB_IMPL_MSG_NO_SYMBOL(DYN, 18, "could not find UNIQUE or PRIMARY KEY constraint in table @1 with specified columns")
FB_IMPL_MSG_NO_SYMBOL(DYN, 19, "PRIMARY KEY lookup failed")
FB_IMPL_MSG_NO_SYMBOL(DYN, 20, "could not find PRIMARY KEY index in specified table @1")
FB_IMPL_MSG_NO_SYMBOL(DYN, 21, "STORE RDB$INDICES failed")
FB_IMPL_MSG_NO_SYMBOL(DYN, 22, "STORE RDB$FIELDS failed")
FB_IMPL_MSG_NO_SYMBOL(DYN, 23, "STORE RDB$RELATION_FIELDS failed")
FB_IMPL_MSG_NO_SYMBOL(DYN, 24, "STORE RDB$RELATIONS failed")
FB_IMPL_MSG_NO_SYMBOL(DYN, 25, "STORE RDB$USER_PRIVILEGES failed defining a table")
FB_IMPL_MSG_NO_SYMBOL(DYN, 26, "unsupported DYN verb")
FB_IMPL_MSG_NO_SYMBOL(DYN, 27, "STORE RDB$RELATIONS failed")
FB_IMPL_MSG_NO_SYMBOL(DYN, 28, "STORE RDB$FIELDS failed")
FB_IMPL_MSG_NO_SYMBOL(DYN, 29, "STORE RDB$RELATION_FIELDS failed")
FB_IMPL_MSG_NO_SYMBOL(DYN, 30, "unsupported DYN verb")
FB_IMPL_MSG_NO_SYMBOL(DYN, 31, "DEFINE TRIGGER failed")
FB_IMPL_MSG_NO_SYMBOL(DYN, 32, "unsupported DYN verb")
FB_IMPL_MSG_NO_SYMBOL(DYN, 33, "DEFINE TRIGGER MESSAGE failed")
FB_IMPL_MSG_NO_SYMBOL(DYN, 34, "STORE RDB$VIEW_RELATIONS failed")
FB_IMPL_MSG_NO_SYMBOL(DYN, 35, "ERASE RDB$FIELDS failed")
FB_IMPL_MSG_NO_SYMBOL(DYN, 36, "ERASE BLOB FILTER failed")
FB_IMPL_MSG(DYN, 37, dyn_filter_not_found, -901, "42", "000", "BLOB Filter @1 not found")
FB_IMPL_MSG_NO_SYMBOL(DYN, 38, "unsupported DYN verb")
FB_IMPL_MSG_NO_SYMBOL(DYN, 39, "ERASE RDB$FUNCTION_ARGUMENTS failed")
FB_IMPL_MSG_NO_SYMBOL(DYN, 40, "ERASE RDB$FUNCTIONS failed")
FB_IMPL_MSG(DYN, 41, dyn_func_not_found, -901, "42", "000", "Function @1 not found")
FB_IMPL_MSG_NO_SYMBOL(DYN, 42, "unsupported DYN verb")
FB_IMPL_MSG_NO_SYMBOL(DYN, 43, "Domain @1 is used in table @2 (local name @3) and cannot be dropped")
FB_IMPL_MSG_NO_SYMBOL(DYN, 44, "ERASE RDB$FIELDS failed")
FB_IMPL_MSG_NO_SYMBOL(DYN, 45, "ERASE RDB$FIELDS failed")
FB_IMPL_MSG_NO_SYMBOL(DYN, 46, "Column not found")
FB_IMPL_MSG_NO_SYMBOL(DYN, 47, "ERASE RDB$INDICES failed")
FB_IMPL_MSG(DYN, 48, dyn_index_not_found, -901, "42", "000", "Index not found")
FB_IMPL_MSG_NO_SYMBOL(DYN, 49, "ERASE RDB$INDEX_SEGMENTS failed")
FB_IMPL_MSG_NO_SYMBOL(DYN, 50, "No segments found for index")
FB_IMPL_MSG_NO_SYMBOL(DYN, 51, "No table specified in ERASE RFR")
FB_IMPL_MSG_NO_SYMBOL(DYN, 52, "Column @1 from table @2 is referenced in view @3")
FB_IMPL_MSG_NO_SYMBOL(DYN, 53, "ERASE RDB$RELATION_FIELDS failed")
FB_IMPL_MSG(DYN, 54, dyn_view_not_found, -901, "42", "000", "View @1 not found")
FB_IMPL_MSG_NO_SYMBOL(DYN, 55, "Column not found for table")
FB_IMPL_MSG_NO_SYMBOL(DYN, 56, "ERASE RDB$INDEX_SEGMENTS failed")
FB_IMPL_MSG_NO_SYMBOL(DYN, 57, "ERASE RDB$INDICES failed")
FB_IMPL_MSG_NO_SYMBOL(DYN, 58, "ERASE RDB$RELATION_FIELDS failed")
FB_IMPL_MSG_NO_SYMBOL(DYN, 59, "ERASE RDB$VIEW_RELATIONS failed")
FB_IMPL_MSG_NO_SYMBOL(DYN, 60, "ERASE RDB$RELATIONS failed")
FB_IMPL_MSG_NO_SYMBOL(DYN, 61, "Table not found")
FB_IMPL_MSG_NO_SYMBOL(DYN, 62, "ERASE RDB$USER_PRIVILEGES failed")
FB_IMPL_MSG_NO_SYMBOL(DYN, 63, "ERASE RDB$FILES failed")
FB_IMPL_MSG_NO_SYMBOL(DYN, 64, "unsupported DYN verb")
FB_IMPL_MSG_NO_SYMBOL(DYN, 65, "ERASE RDB$TRIGGER_MESSAGES failed")
FB_IMPL_MSG_NO_SYMBOL(DYN, 66, "ERASE RDB$TRIGGERS failed")
FB_IMPL_MSG_NO_SYMBOL(DYN, 67, "Trigger not found")
FB_IMPL_MSG_NO_SYMBOL(DYN, 68, "MODIFY RDB$VIEW_RELATIONS failed")
FB_IMPL_MSG_NO_SYMBOL(DYN, 69, "unsupported DYN verb")
FB_IMPL_MSG_NO_SYMBOL(DYN, 70, "TRIGGER NAME expected")
FB_IMPL_MSG_NO_SYMBOL(DYN, 71, "ERASE TRIGGER MESSAGE failed")
FB_IMPL_MSG_NO_SYMBOL(DYN, 72, "Trigger Message not found")
FB_IMPL_MSG_NO_SYMBOL(DYN, 73, "unsupported DYN verb")
FB_IMPL_MSG_NO_SYMBOL(DYN, 74, "ERASE RDB$SECURITY_CLASSES failed")
FB_IMPL_MSG_NO_SYMBOL(DYN, 75, "Security class not found")
FB_IMPL_MSG_NO_SYMBOL(DYN, 76, "unsupported DYN verb")
FB_IMPL_MSG_NO_SYMBOL(DYN, 77, "SELECT RDB$USER_PRIVILEGES failed in grant")
FB_IMPL_MSG_NO_SYMBOL(DYN, 78, "SELECT RDB$USER_PRIVILEGES failed in grant")
FB_IMPL_MSG_NO_SYMBOL(DYN, 79, "STORE RDB$USER_PRIVILEGES failed in grant")
FB_IMPL_MSG_NO_SYMBOL(DYN, 80, "Specified domain or source column does not exist")
FB_IMPL_MSG_NO_SYMBOL(DYN, 81, "Generation of column name failed")
FB_IMPL_MSG_NO_SYMBOL(DYN, 82, "Generation of index name failed")
FB_IMPL_MSG_NO_SYMBOL(DYN, 83, "Generation of trigger name failed")
FB_IMPL_MSG_NO_SYMBOL(DYN, 84, "MODIFY DATABASE failed")
FB_IMPL_MSG_NO_SYMBOL(DYN, 85, "MODIFY RDB$CHARACTER_SETS failed")
FB_IMPL_MSG_NO_SYMBOL(DYN, 86, "MODIFY RDB$COLLATIONS failed")
FB_IMPL_MSG_NO_SYMBOL(DYN, 87, "MODIFY RDB$FIELDS failed")
FB_IMPL_MSG_NO_SYMBOL(DYN, 88, "MODIFY RDB$BLOB_FILTERS failed")
FB_IMPL_MSG(DYN, 89, dyn_domain_not_found, -901, "42", "000", "Domain not found")
FB_IMPL_MSG_NO_SYMBOL(DYN, 90, "unsupported DYN verb")
FB_IMPL_MSG_NO_SYMBOL(DYN, 91, "MODIFY RDB$INDICES failed")
FB_IMPL_MSG_NO_SYMBOL(DYN, 92, "MODIFY RDB$FUNCTIONS failed")
FB_IMPL_MSG_NO_SYMBOL(DYN, 93, "Index column not found")
FB_IMPL_MSG_NO_SYMBOL(DYN, 94, "MODIFY RDB$GENERATORS failed")
FB_IMPL_MSG_NO_SYMBOL(DYN, 95, "MODIFY RDB$RELATION_FIELDS failed")
FB_IMPL_MSG_NO_SYMBOL(DYN, 96, "Local column @1 not found")
FB_IMPL_MSG_NO_SYMBOL(DYN, 97, "add EXTERNAL FILE not allowed")
FB_IMPL_MSG_NO_SYMBOL(DYN, 98, "drop EXTERNAL FILE not allowed")
FB_IMPL_MSG_NO_SYMBOL(DYN, 99, "MODIFY RDB$RELATIONS failed")
FB_IMPL_MSG_NO_SYMBOL(DYN, 100, "MODIFY RDB$PROCEDURE_PARAMETERS failed")
FB_IMPL_MSG_NO_SYMBOL(DYN, 101, "Table column not found")
FB_IMPL_MSG_NO_SYMBOL(DYN, 102, "MODIFY TRIGGER failed")
FB_IMPL_MSG_NO_SYMBOL(DYN, 103, "TRIGGER NAME expected")
FB_IMPL_MSG_NO_SYMBOL(DYN, 104, "unsupported DYN verb")
FB_IMPL_MSG_NO_SYMBOL(DYN, 105, "MODIFY TRIGGER MESSAGE failed")
FB_IMPL_MSG_NO_SYMBOL(DYN, 106, "Create metadata BLOB failed")
FB_IMPL_MSG_NO_SYMBOL(DYN, 107, "Write metadata BLOB failed")
FB_IMPL_MSG_NO_SYMBOL(DYN, 108, "Close metadata BLOB failed")
FB_IMPL_MSG(DYN, 109, dyn_cant_modify_auto_trig, -901, "42", "000", "Triggers created automatically cannot be modified")
FB_IMPL_MSG_NO_SYMBOL(DYN, 110, "unsupported DYN verb")
FB_IMPL_MSG_NO_SYMBOL(DYN, 111, "ERASE RDB$USER_PRIVILEGES failed in revoke(1)")
FB_IMPL_MSG_NO_SYMBOL(DYN, 112, "Access to RDB$USER_PRIVILEGES failed in revoke(2)")
FB_IMPL_MSG_NO_SYMBOL(DYN, 113, "ERASE RDB$USER_PRIVILEGES failed in revoke (3)")
FB_IMPL_MSG_NO_SYMBOL(DYN, 114, "Access to RDB$USER_PRIVILEGES failed in revoke (4)")
FB_IMPL_MSG_NO_SYMBOL(DYN, 115, "CREATE VIEW failed")
FB_IMPL_MSG_NO_SYMBOL(DYN, 116, " attempt to index BLOB column in INDEX @1")
FB_IMPL_MSG_NO_SYMBOL(DYN, 117, " attempt to index array column in index @1")
FB_IMPL_MSG_NO_SYMBOL(DYN, 118, "key size too big for index @1")
FB_IMPL_MSG_NO_SYMBOL(DYN, 119, "no keys for index @1")
FB_IMPL_MSG_NO_SYMBOL(DYN, 120, "Unknown columns in index @1")
FB_IMPL_MSG_NO_SYMBOL(DYN, 121, "STORE RDB$RELATION_CONSTRAINTS failed")
FB_IMPL_MSG_NO_SYMBOL(DYN, 122, "STORE RDB$CHECK_CONSTRAINTS failed")
FB_IMPL_MSG_NO_SYMBOL(DYN, 123, "Column: @1 not defined as NOT NULL - cannot be used in PRIMARY KEY constraint definition")
FB_IMPL_MSG_NO_SYMBOL(DYN, 124, "A column name is repeated in the definition of constraint: @1")
FB_IMPL_MSG_NO_SYMBOL(DYN, 125, "Integrity Constraint lookup failed")
FB_IMPL_MSG_NO_SYMBOL(DYN, 126, "Same set of columns cannot be used in more than one PRIMARY KEY and/or UNIQUE constraint definition")
FB_IMPL_MSG_NO_SYMBOL(DYN, 127, "STORE RDB$REF_CONSTRAINTS failed")
FB_IMPL_MSG_NO_SYMBOL(DYN, 128, "No table specified in delete_constraint")
FB_IMPL_MSG_NO_SYMBOL(DYN, 129, "ERASE RDB$RELATION_CONSTRAINTS failed")
FB_IMPL_MSG_NO_SYMBOL(DYN, 130, "CONSTRAINT @1 does not exist.")
FB_IMPL_MSG_NO_SYMBOL(DYN, 131, "Generation of constraint name failed")
FB_IMPL_MSG(DYN, 132, dyn_dup_table, -901, "42", "S01", "Table @1 already exists")
FB_IMPL_MSG_NO_SYMBOL(DYN, 133, "Number of referencing columns do not equal number of referenced columns")
FB_IMPL_MSG_NO_SYMBOL(DYN, 134, "STORE RDB$PROCEDURES failed")
FB_IMPL_MSG_SYMBOL(DYN, 135, dyn_dup_procedure, "Procedure @1 already exists")
FB_IMPL_MSG_NO_SYMBOL(DYN, 136, "STORE RDB$PROCEDURE_PARAMETERS failed")
FB_IMPL_MSG_NO_SYMBOL(DYN, 137, "Store into system table @1 failed")
FB_IMPL_MSG_NO_SYMBOL(DYN, 138, "ERASE RDB$PROCEDURE_PARAMETERS failed")
FB_IMPL_MSG_NO_SYMBOL(DYN, 139, "ERASE RDB$PROCEDURES failed")
FB_IMPL_MSG(DYN, 140, dyn_proc_not_found, -901, "42", "000", "Procedure @1 not found")
FB_IMPL_MSG_NO_SYMBOL(DYN, 141, "MODIFY RDB$PROCEDURES failed")
FB_IMPL_MSG_NO_SYMBOL(DYN, 142, "DEFINE EXCEPTION failed")
FB_IMPL_MSG_NO_SYMBOL(DYN, 143, "ERASE EXCEPTION failed")
FB_IMPL_MSG(DYN, 144, dyn_exception_not_found, -901, "42", "000", "Exception not found")
FB_IMPL_MSG_NO_SYMBOL(DYN, 145, "MODIFY EXCEPTION failed")
FB_IMPL_MSG(DYN, 146, dyn_proc_param_not_found, -901, "42", "000", "Parameter @1 in procedure @2 not found")
FB_IMPL_MSG(DYN, 147, dyn_trig_not_found, -901, "42", "000", "Trigger @1 not found")
FB_IMPL_MSG_NO_SYMBOL(DYN, 148, "Only one data type change to the domain @1 allowed at a time")
FB_IMPL_MSG_NO_SYMBOL(DYN, 149, "Only one data type change to the field @1 allowed at a time")
FB_IMPL_MSG_NO_SYMBOL(DYN, 150, "STORE RDB$FILES failed")
FB_IMPL_MSG(DYN, 151, dyn_charset_not_found, -901, "42", "000", "Character set @1 not found")
FB_IMPL_MSG(DYN, 152, dyn_collation_not_found, -901, "42", "000", "Collation @1 not found")
FB_IMPL_MSG_NO_SYMBOL(DYN, 153, "ERASE RDB$LOG_FILES failed")
FB_IMPL_MSG_NO_SYMBOL(DYN, 154, "STORE RDB$LOG_FILES failed")
FB_IMPL_MSG(DYN, 155, dyn_role_not_found, -901, "42", "000", "Role @1 not found")
FB_IMPL_MSG_NO_SYMBOL(DYN, 156, "Difference file lookup failed")
FB_IMPL_MSG_NO_SYMBOL(DYN, 157, "DEFINE SHADOW failed")
FB_IMPL_MSG_NO_SYMBOL(DYN, 158, "MODIFY RDB$ROLES failed")
FB_IMPL_MSG(DYN, 159, dyn_name_longer, -901, "42", "000", "Name longer than database column size")
FB_IMPL_MSG_NO_SYMBOL(DYN, 160, "\"Only one constraint allowed for a domain\"")
FB_IMPL_MSG_NO_SYMBOL(DYN, 162, "Looking up column position failed")
FB_IMPL_MSG_NO_SYMBOL(DYN, 163, "A node name is not permitted in a table with external file definition")
FB_IMPL_MSG_NO_SYMBOL(DYN, 164, "Shadow lookup failed")
FB_IMPL_MSG_NO_SYMBOL(DYN, 165, "Shadow @1 already exists")
FB_IMPL_MSG_NO_SYMBOL(DYN, 166, "Cannot add file with the same name as the database or added files")
FB_IMPL_MSG_NO_SYMBOL(DYN, 167, "no grant option for privilege @1 on column @2 of table/view @3")
FB_IMPL_MSG_NO_SYMBOL(DYN, 168, "no grant option for privilege @1 on column @2 of base table/view @3")
FB_IMPL_MSG_NO_SYMBOL(DYN, 169, "no grant option for privilege @1 on table/view @2 (for column @3)")
FB_IMPL_MSG_NO_SYMBOL(DYN, 170, "no grant option for privilege @1 on base table/view @2 (for column @3)")
FB_IMPL_MSG_NO_SYMBOL(DYN, 171, "no @1 privilege with grant option on table/view @2 (for column @3)")
FB_IMPL_MSG_NO_SYMBOL(DYN, 172, "no @1 privilege with grant option on base table/view @2 (for column @3)")
FB_IMPL_MSG_NO_SYMBOL(DYN, 173, "no grant option for privilege @1 on table/view @2")
FB_IMPL_MSG_NO_SYMBOL(DYN, 174, "no @1 privilege with grant option on table/view @2")
FB_IMPL_MSG_NO_SYMBOL(DYN, 175, "table/view @1 does not exist")
FB_IMPL_MSG(DYN, 176, dyn_column_does_not_exist, -901, "42", "S22", "column @1 does not exist in table/view @2")
FB_IMPL_MSG_NO_SYMBOL(DYN, 177, "Can not alter a view")
FB_IMPL_MSG_NO_SYMBOL(DYN, 178, "EXTERNAL FILE table not supported in this context")
FB_IMPL_MSG_NO_SYMBOL(DYN, 179, "attempt to index COMPUTED BY column in INDEX @1")
FB_IMPL_MSG_NO_SYMBOL(DYN, 180, "Table Name lookup failed")
FB_IMPL_MSG_NO_SYMBOL(DYN, 181, "attempt to index a view")
FB_IMPL_MSG_NO_SYMBOL(DYN, 182, "SELECT RDB$RELATIONS failed in grant")
FB_IMPL_MSG_NO_SYMBOL(DYN, 183, "SELECT RDB$RELATION_FIELDS failed in grant")
FB_IMPL_MSG_NO_SYMBOL(DYN, 184, "SELECT RDB$RELATIONS/RDB$OWNER_NAME failed in grant")
FB_IMPL_MSG_NO_SYMBOL(DYN, 185, "SELECT RDB$USER_PRIVILEGES failed in grant")
FB_IMPL_MSG_NO_SYMBOL(DYN, 186, "SELECT RDB$VIEW_RELATIONS/RDB$RELATION_FIELDS/... failed in grant")
FB_IMPL_MSG_NO_SYMBOL(DYN, 187, "column @1 from table @2 is referenced in index @3")
FB_IMPL_MSG(DYN, 188, dyn_role_does_not_exist, -901, "28", "000", "SQL role @1 does not exist")
FB_IMPL_MSG(DYN, 189, dyn_no_grant_admin_opt, -901, "28", "000", "user @1 has no grant admin option on SQL role @2")
FB_IMPL_MSG(DYN, 190, dyn_user_not_role_member, -901, "28", "000", "user @1 is not a member of SQL role @2")
FB_IMPL_MSG(DYN, 191, dyn_delete_role_failed, -901, "28", "000", "@1 is not the owner of SQL role @2")
FB_IMPL_MSG(DYN, 192, dyn_grant_role_to_user, -901, "28", "000", "@1 is a SQL role and not a user")
FB_IMPL_MSG(DYN, 193, dyn_inv_sql_role_name, -901, "28", "000", "user name @1 could not be used for SQL role")
FB_IMPL_MSG(DYN, 194, dyn_dup_sql_role, -901, "42", "000", "SQL role @1 already exists")
FB_IMPL_MSG(DYN, 195, dyn_kywd_spec_for_role, -901, "28", "000", "keyword @1 can not be used as a SQL role name")
FB_IMPL_MSG(DYN, 196, dyn_roles_not_supported, -901, "28", "000", "SQL roles are not supported in on older versions of the database.  A backup and restore of the database is required.")
FB_IMPL_MSG(DYN, 204, dyn_domain_name_exists, -612, "42", "000", "Cannot rename domain @1 to @2.  A domain with that name already exists.")
FB_IMPL_MSG(DYN, 205, dyn_field_name_exists, -612, "42", "S21", "Cannot rename column @1 to @2.  A column with that name already exists in table @3.")
FB_IMPL_MSG(DYN, 206, dyn_dependency_exists, -383, "42", "000", "Column @1 from table @2 is referenced in @3")
FB_IMPL_MSG(DYN, 207, dyn_dtype_invalid, -315, "42", "000", "Cannot change datatype for column @1.  Changing datatype is not supported for BLOB or ARRAY columns.")
FB_IMPL_MSG(DYN, 208, dyn_char_fld_too_small, -829, "42", "000", "New size specified for column @1 must be at least @2 characters.")
FB_IMPL_MSG(DYN, 209, dyn_invalid_dtype_conversion, -829, "42", "000", "Cannot change datatype for @1.  Conversion from base type @2 to @3 is not supported.")
FB_IMPL_MSG(DYN, 210, dyn_dtype_conv_invalid, -829, "42", "000", "Cannot change datatype for column @1 from a character type to a non-character type.")
FB_IMPL_MSG_SYMBOL(DYN, 211, dyn_virmemexh, "unable to allocate memory from the operating system")
FB_IMPL_MSG(DYN, 212, dyn_zero_len_id, -901, "42", "000", "Zero length identifiers are not allowed")
FB_IMPL_MSG_SYMBOL(DYN, 213, del_gen_fail, "ERASE RDB$GENERATORS failed")
FB_IMPL_MSG(DYN, 214, dyn_gen_not_found, -901, "42", "000", "Sequence @1 not found")
FB_IMPL_MSG_NO_SYMBOL(DYN, 215, "Difference file is not defined")
FB_IMPL_MSG_NO_SYMBOL(DYN, 216, "Difference file is already defined")
FB_IMPL_MSG_NO_SYMBOL(DYN, 217, "Database is already in the physical backup mode")
FB_IMPL_MSG_NO_SYMBOL(DYN, 218, "Database is not in the physical backup mode")
FB_IMPL_MSG_NO_SYMBOL(DYN, 219, "DEFINE COLLATION failed")
FB_IMPL_MSG_NO_SYMBOL(DYN, 220, "CREATE COLLATION statement is not supported in older versions of the database.  A backup and restore is required.")
FB_IMPL_MSG(DYN, 221, max_coll_per_charset, -829, "2C", "000", "Maximum number of collations per character set exceeded")
FB_IMPL_MSG(DYN, 222, invalid_coll_attr, -829, "HY", "000", "Invalid collation attributes")
FB_IMPL_MSG_NO_SYMBOL(DYN, 223, "Collation @1 not installed for character set @2")
FB_IMPL_MSG_NO_SYMBOL(DYN, 224, "Cannot use the internal domain @1 as new type for field @2")
FB_IMPL_MSG_NO_SYMBOL(DYN, 225, "Default value is not allowed for array type in field @1")
FB_IMPL_MSG_NO_SYMBOL(DYN, 226, "Default value is not allowed for array type in domain @1")
FB_IMPL_MSG_NO_SYMBOL(DYN, 227, "DYN_UTIL_is_array failed for domain @1")
FB_IMPL_MSG_NO_SYMBOL(DYN, 228, "DYN_UTIL_copy_domain failed for domain @1")
FB_IMPL_MSG_NO_SYMBOL(DYN, 229, "Local column @1 doesn't have a default")
FB_IMPL_MSG_NO_SYMBOL(DYN, 230, "Local column @1 default belongs to domain @2")
FB_IMPL_MSG_NO_SYMBOL(DYN, 231, "File name is invalid")
FB_IMPL_MSG(DYN, 232, dyn_wrong_gtt_scope, -901, "HY", "000", "@1 cannot reference @2")
FB_IMPL_MSG_NO_SYMBOL(DYN, 233, "Local column @1 is computed, cannot set a default value")
FB_IMPL_MSG_SYMBOL(DYN, 234, del_coll_fail, "ERASE RDB$COLLATIONS failed")
FB_IMPL_MSG(DYN, 235, dyn_coll_used_table, -901, "HY", "000", "Collation @1 is used in table @2 (field name @3) and cannot be dropped")
FB_IMPL_MSG(DYN, 236, dyn_coll_used_domain, -901, "HY", "000", "Collation @1 is used in domain @2 and cannot be dropped")
FB_IMPL_MSG(DYN, 237, dyn_cannot_del_syscoll, -607, "HY", "000", "Cannot delete system collation")
FB_IMPL_MSG(DYN, 238, dyn_cannot_del_def_coll, -901, "HY", "000", "Cannot delete default collation of CHARACTER SET @1")
FB_IMPL_MSG_NO_SYMBOL(DYN, 239, "Domain @1 is used in procedure @2 (parameter name @3) and cannot be dropped")
FB_IMPL_MSG_NO_SYMBOL(DYN, 240, "Field @1 cannot be used twice in index @2")
FB_IMPL_MSG(DYN, 241, dyn_table_not_found, -901, "42", "000", "Table @1 not found")
FB_IMPL_MSG_NO_SYMBOL(DYN, 242, "attempt to reference a view (@1) in a foreign key")
FB_IMPL_MSG(DYN, 243, dyn_coll_used_procedure, -901, "HY", "000", "Collation @1 is used in procedure @2 (parameter name @3) and cannot be dropped")
FB_IMPL_MSG(DYN, 244, dyn_scale_too_big, -829, "42", "000", "New scale specified for column @1 must be at most @2.")
FB_IMPL_MSG(DYN, 245, dyn_precision_too_small, -829, "42", "000", "New precision specified for column @1 must be at least @2.")
FB_IMPL_MSG_NO_SYMBOL(DYN, 246, "@1 is not grantor of @2 on @3 to @4.")
FB_IMPL_MSG(DYN, 247, dyn_miss_priv_warning, 106, "42", "000", "Warning: @1 on @2 is not granted to @3.")
FB_IMPL_MSG(DYN, 248, dyn_ods_not_supp_feature, -901, "0A", "000", "Feature '@1' is not supported in ODS @2.@3")
FB_IMPL_MSG(DYN, 249, dyn_cannot_addrem_computed, -829, "42", "000", "Cannot add or remove COMPUTED from column @1")
FB_IMPL_MSG(DYN, 250, dyn_no_empty_pw, -901, "42", "000", "Password should not be empty string")
FB_IMPL_MSG(DYN, 251, dyn_dup_index, -901, "42", "S11", "Index @1 already exists")
FB_IMPL_MSG_SYMBOL(DYN, 252, dyn_locksmith_use_granted, "Only @1 or user with privilege USE_GRANTED_BY_CLAUSE can use GRANTED BY clause")
FB_IMPL_MSG_SYMBOL(DYN, 253, dyn_dup_exception, "Exception @1 already exists")
FB_IMPL_MSG_SYMBOL(DYN, 254, dyn_dup_generator, "Sequence @1 already exists")
FB_IMPL_MSG_NO_SYMBOL(DYN, 255, "ERASE RDB$USER_PRIVILEGES failed in REVOKE ALL ON ALL")
FB_IMPL_MSG(DYN, 256, dyn_package_not_found, -901, "42", "000", "Package @1 not found")
FB_IMPL_MSG(DYN, 257, dyn_schema_not_found, -901, "42", "000", "Schema @1 not found")
FB_IMPL_MSG(DYN, 258, dyn_cannot_mod_sysproc, -607, "HY", "000", "Cannot ALTER or DROP system procedure @1")
FB_IMPL_MSG(DYN, 259, dyn_cannot_mod_systrig, -607, "HY", "000", "Cannot ALTER or DROP system trigger @1")
FB_IMPL_MSG(DYN, 260, dyn_cannot_mod_sysfunc, -607, "HY", "000", "Cannot ALTER or DROP system function @1")
FB_IMPL_MSG(DYN, 261, dyn_invalid_ddl_proc, -607, "HY", "000", "Invalid DDL statement for procedure @1")
FB_IMPL_MSG(DYN, 262, dyn_invalid_ddl_trig, -607, "HY", "000", "Invalid DDL statement for trigger @1")
FB_IMPL_MSG(DYN, 263, dyn_funcnotdef_package, -901, "42", "000", "Function @1 has not been defined on the package body @2")
FB_IMPL_MSG(DYN, 264, dyn_procnotdef_package, -901, "42", "000", "Procedure @1 has not been defined on the package body @2")
FB_IMPL_MSG(DYN, 265, dyn_funcsignat_package, -901, "42", "000", "Function @1 has a signature mismatch on package body @2")
FB_IMPL_MSG(DYN, 266, dyn_procsignat_package, -901, "42", "000", "Procedure @1 has a signature mismatch on package body @2")
FB_IMPL_MSG(DYN, 267, dyn_defvaldecl_package_proc, -901, "42", "000", "Default values for parameters are not allowed in the definition of a previously declared packaged procedure @1.@2")
FB_IMPL_MSG_SYMBOL(DYN, 268, dyn_dup_function, "Function @1 already exists")
FB_IMPL_MSG(DYN, 269, dyn_package_body_exists, -901, "42", "000", "Package body @1 already exists")
FB_IMPL_MSG(DYN, 270, dyn_invalid_ddl_func, -607, "HY", "000", "Invalid DDL statement for function @1")
FB_IMPL_MSG(DYN, 271, dyn_newfc_oldsyntax, -901, "42", "000", "Cannot alter new style function @1 with ALTER EXTERNAL FUNCTION. Use ALTER FUNCTION instead.")
FB_IMPL_MSG_NO_SYMBOL(DYN, 272, "Cannot delete system generator @1")
FB_IMPL_MSG_NO_SYMBOL(DYN, 273, "Identity column @1 of table @2 must be of exact number type with zero scale")
FB_IMPL_MSG_NO_SYMBOL(DYN, 274, "Identity column @1 of table @2 cannot be changed to NULLable")
FB_IMPL_MSG_NO_SYMBOL(DYN, 275, "Identity column @1 of table @2 cannot have default value")
FB_IMPL_MSG_NO_SYMBOL(DYN, 276, "Domain @1 must be of exact number type with zero scale because it's used in an identity column")
FB_IMPL_MSG_NO_SYMBOL(DYN, 277, "Generation of generator name failed")
FB_IMPL_MSG(DYN, 278, dyn_func_param_not_found, -901, "42", "000", "Parameter @1 in function @2 not found")
FB_IMPL_MSG(DYN, 279, dyn_routine_param_not_found, -901, "42", "000", "Parameter @1 of routine @2 not found")
FB_IMPL_MSG(DYN, 280, dyn_routine_param_ambiguous, -901, "42", "000", "Parameter @1 of routine @2 is ambiguous (found in both procedures and functions). Use a specifier keyword.")
FB_IMPL_MSG(DYN, 281, dyn_coll_used_function, -901, "HY", "000", "Collation @1 is used in function @2 (parameter name @3) and cannot be dropped")
FB_IMPL_MSG(DYN, 282, dyn_domain_used_function, -901, "HY", "000", "Domain @1 is used in function @2 (parameter name @3) and cannot be dropped")
FB_IMPL_MSG(DYN, 283, dyn_alter_user_no_clause, -901, "42", "000", "ALTER USER requires at least one clause to be specified")
FB_IMPL_MSG_NO_SYMBOL(DYN, 284, "Cannot delete system SQL role @1")
FB_IMPL_MSG_NO_SYMBOL(DYN, 285, "Column @1 is not an identity column")
FB_IMPL_MSG(DYN, 286, dyn_duplicate_package_item, -901, "42", "000", "Duplicate @1 @2")
FB_IMPL_MSG(DYN, 287, dyn_cant_modify_sysobj, -901, "42", "000", "System @1 @2 cannot be modified")
FB_IMPL_MSG(DYN, 288, dyn_cant_use_zero_increment, -901, "42", "000", "INCREMENT BY 0 is an illegal option for sequence @1")
FB_IMPL_MSG(DYN, 289, dyn_cant_use_in_foreignkey, -901, "42", "000", "Can't use @1 in FOREIGN KEY constraint")
FB_IMPL_MSG(DYN, 290, dyn_defvaldecl_package_func, -901, "42", "000", "Default values for parameters are not allowed in the definition of a previously declared packaged function @1.@2")
FB_IMPL_MSG_SYMBOL(DYN, 291, dyn_create_user_no_password, "Password must be specified when creating user")
FB_IMPL_MSG(DYN, 292, dyn_cyclic_role, -901, "42", "000", "role @1 can not be granted to role @2")
FB_IMPL_MSG_NO_SYMBOL(DYN, 293, "DROP SYSTEM PRIVILEGES should not be used in CREATE ROLE operator")
FB_IMPL_MSG_NO_SYMBOL(DYN, 294, "Access to SYSTEM PRIVILEGES in ROLES denied to @1")
FB_IMPL_MSG_NO_SYMBOL(DYN, 295, "Only @1, DB owner @2 or user with privilege USE_GRANTED_BY_CLAUSE can use GRANTED BY clause")
FB_IMPL_MSG(DYN, 296, dyn_cant_use_zero_inc_ident, -901, "42", "000", "INCREMENT BY 0 is an illegal option for identity column @1 of table @2")
FB_IMPL_MSG_SYMBOL(DYN, 297, dyn_concur_alter_database, "Concurrent ALTER DATABASE is not supported")
FB_IMPL_MSG_SYMBOL(DYN, 298, dyn_incompat_alter_database, "Incompatible ALTER DATABASE clauses: '@1' and '@2'")
FB_IMPL_MSG(DYN, 299, dyn_no_ddl_grant_opt_priv, -901, "42", "000", "no @1 privilege with grant option on DDL @2")
FB_IMPL_MSG(DYN, 300, dyn_no_grant_opt_priv, -901, "42", "000", "no @1 privilege with grant option on object @2")
FB_IMPL_MSG(DYN, 301, dyn_func_not_exist, -901, "42", "000", "Function @1 does not exist")
FB_IMPL_MSG(DYN, 302, dyn_proc_not_exist, -901, "42", "000", "Procedure @1 does not exist")
FB_IMPL_MSG(DYN, 303, dyn_pack_not_exist, -901, "42", "000", "Package @1 does not exist")
FB_IMPL_MSG(DYN, 304, dyn_trig_not_exist, -901, "42", "000", "Trigger @1 does not exist")
FB_IMPL_MSG(DYN, 305, dyn_view_not_exist, -901, "42", "000", "View @1 does not exist")
FB_IMPL_MSG(DYN, 306, dyn_rel_not_exist, -901, "42", "000", "Table @1 does not exist")
FB_IMPL_MSG(DYN, 307, dyn_exc_not_exist, -901, "42", "000", "Exception @1 does not exist")
FB_IMPL_MSG(DYN, 308, dyn_gen_not_exist, -901, "42", "000", "Generator/Sequence @1 does not exist")
FB_IMPL_MSG(DYN, 309, dyn_fld_not_exist, -901, "42", "000", "Field @1 of table @2 does not exist")
