FB_IMPL_MSG_NO_SYMBOL(FBTRACEMGR, 1, "Firebird Trace Manager version @1")
FB_IMPL_MSG_NO_SYMBOL(FBTRACEMGR, 2, "ERROR: ")
FB_IMPL_MSG_NO_SYMBOL(FBTRACEMGR, 3, "Firebird Trace Manager.")
FB_IMPL_MSG_NO_SYMBOL(FBTRACEMGR, 4, "Usage: fbtracemgr <action> [<parameters>]")
FB_IMPL_MSG_NO_SYMBOL(FBTRACEMGR, 5, "Actions:")
FB_IMPL_MSG_NO_SYMBOL(FBTRACEMGR, 6, "  -STA[RT]                              Start trace session")
FB_IMPL_MSG_NO_SYMBOL(FBTRACEMGR, 7, "  -STO[P]                               Stop trace session")
FB_IMPL_MSG_NO_SYMBOL(FBTRACEMGR, 8, "  -SU[SPEND]                            Suspend trace session")
FB_IMPL_MSG_NO_SYMBOL(FBTRACEMGR, 9, "  -R[ESUME]                             Resume trace session")
FB_IMPL_MSG_NO_SYMBOL(FBTRACEMGR, 10, "  -L[IST]                               List existing trace sessions")
FB_IMPL_MSG_NO_SYMBOL(FBTRACEMGR, 11, "  -Z                                    Show program version")
FB_IMPL_MSG_NO_SYMBOL(FBTRACEMGR, 12, "Action parameters:")
FB_IMPL_MSG_NO_SYMBOL(FBTRACEMGR, 13, "  -N[AME]    <string>                   Session name")
FB_IMPL_MSG_NO_SYMBOL(FBTRACEMGR, 14, "  -I[D]      <number>                   Session ID")
FB_IMPL_MSG_NO_SYMBOL(FBTRACEMGR, 15, "  -C[ONFIG]  <string>                   Trace configuration file name")
FB_IMPL_MSG_NO_SYMBOL(FBTRACEMGR, 16, "Connection parameters:")
FB_IMPL_MSG_NO_SYMBOL(FBTRACEMGR, 17, "  -SE[RVICE]  <string>                  Service name")
FB_IMPL_MSG_NO_SYMBOL(FBTRACEMGR, 18, "  -U[SER]     <string>                  User name")
FB_IMPL_MSG_NO_SYMBOL(FBTRACEMGR, 19, "  -P[ASSWORD] <string>                  Password")
FB_IMPL_MSG_NO_SYMBOL(FBTRACEMGR, 20, "  -FE[TCH]    <string>                  Fetch password from file")
FB_IMPL_MSG_NO_SYMBOL(FBTRACEMGR, 21, "  -T[RUSTED]  <string>                  Force trusted authentication")
FB_IMPL_MSG_NO_SYMBOL(FBTRACEMGR, 22, "Examples:")
FB_IMPL_MSG_NO_SYMBOL(FBTRACEMGR, 23, "  fbtracemgr -SE remote_host:service_mgr -USER SYSDBA -PASS masterkey -LIST")
FB_IMPL_MSG_NO_SYMBOL(FBTRACEMGR, 24, "  fbtracemgr -SE service_mgr -START -NAME my_trace -CONFIG my_cfg.txt")
FB_IMPL_MSG_NO_SYMBOL(FBTRACEMGR, 25, "  fbtracemgr -SE service_mgr -SUSPEND -ID 2")
FB_IMPL_MSG_NO_SYMBOL(FBTRACEMGR, 26, "  fbtracemgr -SE service_mgr -RESUME -ID 2")
FB_IMPL_MSG_NO_SYMBOL(FBTRACEMGR, 27, "  fbtracemgr -SE service_mgr -STOP -ID 4")
FB_IMPL_MSG_NO_SYMBOL(FBTRACEMGR, 28, "Notes:")
FB_IMPL_MSG_NO_SYMBOL(FBTRACEMGR, 29, "  Press CTRL+C to stop interactive trace session")
FB_IMPL_MSG(FBTRACEMGR, 30, trace_conflict_acts, -901, "00", "000", "conflicting actions \"@1\" and \"@2\" found")
FB_IMPL_MSG(FBTRACEMGR, 31, trace_act_notfound, -901, "00", "000", "action switch not found")
FB_IMPL_MSG(FBTRACEMGR, 32, trace_switch_once, -901, "00", "000", "switch \"@1\" must be set only once")
FB_IMPL_MSG(FBTRACEMGR, 33, trace_param_val_miss, -901, "00", "000", "value for switch \"@1\" is missing")
FB_IMPL_MSG(FBTRACEMGR, 34, trace_param_invalid, -901, "00", "000", "invalid value (\"@1\") for switch \"@2\"")
FB_IMPL_MSG(FBTRACEMGR, 35, trace_switch_unknown, -901, "00", "000", "unknown switch \"@1\" encountered")
FB_IMPL_MSG(FBTRACEMGR, 36, trace_switch_svc_only, -901, "00", "000", "switch \"@1\" can be used by service only")
FB_IMPL_MSG(FBTRACEMGR, 37, trace_switch_user_only, -901, "00", "000", "switch \"@1\" can be used by interactive user only")
FB_IMPL_MSG(FBTRACEMGR, 38, trace_switch_param_miss, -901, "00", "000", "mandatory parameter \"@1\" for switch \"@2\" is missing")
FB_IMPL_MSG(FBTRACEMGR, 39, trace_param_act_notcompat, -901, "00", "000", "parameter \"@1\" is incompatible with action \"@2\"")
FB_IMPL_MSG(FBTRACEMGR, 40, trace_mandatory_switch_miss, -901, "00", "000", "mandatory switch \"@1\" is missing")
